package com.b_noble.n_life;

import java.util.List;
import java.util.Map;

import com.b_noble.n_life.info.AbnormalRecordInfo;
import com.b_noble.n_life.info.AlarmRecordsInfo;
import com.b_noble.n_life.info.AreaInfo;
import com.b_noble.n_life.info.BindDeviceInfo;
import com.b_noble.n_life.info.DeviceInfo;
import com.b_noble.n_life.info.DoorlockNotification;
import com.b_noble.n_life.info.DoorlockRecentStatusInfo;
import com.b_noble.n_life.info.DoorlockUser;
import com.b_noble.n_life.info.GateWayInfo;
import com.b_noble.n_life.info.IrDeviceInfo;
import com.b_noble.n_life.info.IrLinkageInfo;
import com.b_noble.n_life.info.IrTaskInfo;
import com.b_noble.n_life.info.K1MemberDetailsInfo;
import com.b_noble.n_life.info.K1MemberInfo;
import com.b_noble.n_life.info.K1RecordInfo;
import com.b_noble.n_life.info.K1TemPassworkInfo;
import com.b_noble.n_life.info.LinkageCondition;
import com.b_noble.n_life.info.LinkageInfo;
import com.b_noble.n_life.info.LinkageTask;
import com.b_noble.n_life.info.LockAbnormalRecordInfo;
import com.b_noble.n_life.info.LockUnlockRecordInfo;
import com.b_noble.n_life.info.LockUserInfo;
import com.b_noble.n_life.info.RemoteControlInfo;
import com.b_noble.n_life.info.ScenePanelInfo;
import com.b_noble.n_life.info.ScenePanelTask;
import com.b_noble.n_life.info.SenceInfo;
import com.b_noble.n_life.info.TaskDeviceAction;
import com.b_noble.n_life.info.TaskInfo;
import com.b_noble.n_life.info.TaskTimerAction;
import com.b_noble.n_life.info.ThermostatConfigureInfo;
import com.b_noble.n_life.info.ThermostatRunStatusInfo;
import com.b_noble.n_life.info.UnlockRecordInfo;
import com.b_noble.n_life.info.WifiModelDeviceInfo;
import com.b_noble.n_life.info.WifiModuleInformation;
import com.b_noble.n_life.model.DeviceTaskInfo;
import com.b_noble.n_life.model.SceneMemberInfo;

import android.R.integer;
import android.content.Context;

/**
 * @company：深圳市中泰智丰物联网科技有限公司
 * @project：智能家居
 * @describe：app调用接口
 * @author：zhangfan @date：2016-08-04 @version：V0.0.1
 */
public interface Serial {

	public void setmContext(Context mContext);

	/**
	 * 连接到远程的网关
	 * 
	 * @param userName
	 *            用户名
	 * @param passWd
	 *            密码
	 * @return 1，连接成功且已绑定网关,-1为账号或密码错误,0为未绑定网关,-2与服务端或网关建立链接失败，-3鉴权系统链接超时，-4mac错误
	 * 
	 */
	public int connectRemoteZll(String userName, String passWd);

	/**
	 * 连接到远程的网关
	 * 
	 * @param userName
	 *            用户名
	 * @param passWd
	 *            密码
	 * @param mac
	 *            手机mac地址
	 * @return 1，连接成功且已绑定网关,-1为账号或密码错误,0为未绑定网关,-2与服务端或网关建立链接失败，-3鉴权系统链接超时，-4mac错误
	 * 
	 */
	public int connectRemoteZll(String userName, String passWd, String mac, String appToken, String ostype,
			String appLang);

	/**
	 * 连接到远程的网关
	 * 
	 * @param userName
	 *            用户名
	 * @param passWd
	 *            密码
	 * @param sn
	 * 
	 * @param token
	 * 
	 * @return 1，连接成功且已绑定网关,-1为账号或密码错误,0为未绑定网关,-2与服务端或网关建立链接失败，-3鉴权系统链接超时，-4mac错误
	 */
	public int connectRemoteZll(String userName, String passWd, String sn, String token, String mac, String appToken,
			String ostype, String appLang);

	/**
	 * 局域网登录网关，执行改方法前需要先执行connectLANZllByIp方法
	 * 
	 * @param userName
	 *            用户名
	 * @param passWd
	 *            密码 登录结果在回调loginGaByLan_Callback()中返回
	 */
	public int loginGaByLan(String userName, String passWd);

	/**
	 * 向服务端发送登录验证指令
	 */
	public void sendLoginCmd();

	/**
	 * 获取网关或zigbee版本
	 * 
	 * @param 0x01：request
	 *            gateway version 0x02：request zigbee version
	 */
	public void requestGaOrZigbeeVersion(int command);

	/**
	 * 获取网关或zigbee版本回调
	 */
	public void requestGaOrZigbeeVersion_callBack(int command, int version);

	/**
	 * 升级完主动通知（目前只有zigbee升级完成后有通知）
	 * 
	 * @param command
	 * @param version
	 */
	public void reportUpgradeStatus_callBack(int command, int version);

	/**
	 * 升级网关或zigbee固件
	 * 
	 * @param command
	 */
	public void upgradeGaOrZigbee(int command, int version);

	/**
	 * 通过ip、snid、port来连接到本地的网关
	 * 
	 * @param ip
	 * @param snid
	 * @param port
	 * @return -1 连接失败，-3连接超时，>0连接成功
	 */
	public int connectLANZllByIp(String ip, String snid, int port);

	/**
	 * 获取当前找到所有的网关ip,结果在newGate_CallBack中回调返回
	 * 
	 */
	public Map<String, String> getGatewayIps();

	/**
	 * 向网关发送绑定网关指令
	 * 
	 * @param sn
	 *            网关sn码
	 * @return 若返回ip:可以绑定 ，返回0则表示该网关不能绑定
	 */
	public String bangdingGa(String sn);

	/**
	 * 向网关发送网关绑定信息 绑定结果在UserBindToGa_callBack()中返回
	 */
	public void UserBindToGa(String sn, String username, String password);

	/**
	 * 向网关发送新增用户指令 结果在addUserToGa_callBack()回调中返回
	 */
	public void addUserToGa(String username, String password);

	/**
	 * 查看网关信息
	 */
	public void getGateWayInfo();

	/**
	 * 复位网关
	 * 
	 * @return
	 */
	public int resetGateway();

	/**
	 * 查询该用户所有网关
	 */
	public List<GateWayInfo> getGateWays(String username);

	/**
	 * 获取当前连接的所有设备 可以在newDevice_CallBack（）这个回调中，来获得所有设备
	 */
	public DeviceInfo[] getDevices();

	/**
	 * 更改设备或组名称,传入字符数组
	 * 
	 * @param dInfo
	 *            要更改的设备（必须有device UId 和deviceName）
	 * @param dName
	 *            新的设备名 执行该方法后结果在ChangeDeviceName_callBack(byte[] uid,String
	 *            deviceName) 中返回
	 */
	public int ChangeDeviceName(DeviceInfo dInfo, String dName);

	/**
	 * 删除当前设备
	 * 
	 * @param info
	 *            要删除的设备（必须有device Uid）
	 */
	public int deleteDevice(DeviceInfo info);
	/**
	 * 删除当前设备回调
	 * 
	 */
	public void deleteDevice_callBack(int state);

	/**
	 * 改变设备状态：1 开/ 0 关
	 * 
	 * @param info
	 *            要改变状态的设备（必须要有Uid）
	 * @param state
	 *            要改变的状态 执行此方法后在setDeviceState_CallBack() 中返回状态
	 */
	public int setDeviceState(DeviceInfo info, int state);

	/**
	 * 改变设备状态：1 开/ 0 关
	 * 
	 * @param info
	 *            要改变状态的设备（必须要有Uid）
	 * @param state
	 *            要改变的状态
	 * @param transitionTime
	 *            延迟时间 执行此方法后在setDeviceState_CallBack() 中返回状态
	 * 
	 */
	public int setDeviceState(DeviceInfo info, int state, int transitionTime);

	/**
	 * 获得设备状态，结果在getDeviceState_CallBack这个回调中会有返回
	 * 
	 * @param info
	 *            要获取的设备（必须要有Uid）
	 */
	public int getDeviceState(DeviceInfo info);

	/**
	 * 改变设备值，（亮度）
	 * 
	 * @param info
	 *            要改变设备值的设备（必须要有Uid）
	 * @param value
	 *            要改变的值
	 */
	public int setDeviceLevel(DeviceInfo info, byte value);

	/**
	 * 改变设备值，（亮度）
	 * 
	 * @param info
	 *            要改变设备值的设备（必须要有Uid）
	 * @param value
	 *            要改变的值
	 * @param transitionTime
	 *            延时时间（单位100ms）
	 * @return
	 */
	public int setDeviceLevel(DeviceInfo info, byte value, short transitionTime);

	/**
	 * 获得设备值（输出级别， 如亮度） ， 结果在getDeviceLevel_CallBack这个回调中有返回
	 * 
	 * @param info
	 *            要获取设备值的设备（必须要有Uid）
	 */
	public int getDeviceLevel(DeviceInfo info);

	/**
	 * 改变设备色调、饱和度
	 * 
	 * @param info
	 *            要改变色调、饱和度的设备
	 * @param hue
	 *            色调
	 * @param sat
	 *            饱和度
	 */
	public int setDeviceHueSat(DeviceInfo info, byte hue, byte sat);

	/**
	 * 改变设备色调、饱和度
	 * 
	 * @param info
	 *            要改变色调、饱和度的设备
	 * @param hue
	 *            色调
	 * @param sat
	 *            饱和度
	 * @param transitionTime
	 *            延时时间（单位100ms）
	 * 
	 * @return
	 */
	public int setDeviceHueSat(DeviceInfo info, byte hue, byte sat, short transitionTime);

	/**
	 * 改变设备色温
	 * 
	 * @param info
	 *            要改变色温的设备
	 * @param value
	 *            色温值
	 */
	public int SetColorTemperature(DeviceInfo info, int value);

	/**
	 * 
	 * 改变设备色温
	 * 
	 * @param info
	 *            要改变色温的设备
	 * @param value
	 *            色温值
	 * @param transitionTime
	 *            延时时间（单位100ms）
	 * @return
	 */
	public int SetColorTemperature(DeviceInfo info, int value, short transitionTime);

	/**
	 * 获取设备色调与饱和度，结果在 getDeviceHueAndSat_CallBack这个回调中
	 * 
	 * @param info
	 *            要获取设备色调的设备 （必须要有Uid）
	 */
	public int getDeviceHueAndSat(DeviceInfo info);

	/**
	 * 获取设备色温值，结果在 getColorTemperature_CallBack这个回调中
	 * 
	 * @param info
	 *            要获取设备色温的设备（必须要有Uid）
	 */
	public int getColorTemperature(DeviceInfo info);

	/***********************************************/
	/* about sence */

	/**
	 * 获取当前所有场景
	 * 
	 * @return 返回NULL，其结果在newSence_CallBack（） 中返回
	 */
	public SenceInfo[] getSences();

	/**
	 * 创建新场景
	 * 
	 * @param senceName
	 *            场景名
	 * @param smInfos
	 *            场景成员信息，包括操作设备uid，操作类型：如开关、灯颜色等，设备值以及延迟时间
	 * 
	 *            添加完成后新场景在addSence_callBack(byte sceneId,String senceName)中返回
	 */
	public int addSence(String senceName, List<SceneMemberInfo> smInfos);

	/**
	 * 将指定的设备动作添加到指定的场景中，若场景不存在，则创建新场景
	 * 
	 * @param senceId
	 *            场景id
	 * @param uids
	 *            要添加的设备列表
	 */
	//public int addDeviceToSence(int senceId, List<byte[]> uids, int delaytime);
	
	/**
	 * 修改场景
	 * @param senceId
	 * @param senceName
	 * @param smInfos
	 */
	public void modifyScene(int senceId,String senceName, List<SceneMemberInfo> smInfos);
	/**
	 * 修改场景回调
	 */
	public void modifyScene_callBack(int senceId,String senceName);

	/**
	 * 打开指定的场景
	 * 
	 * @param senceId
	 *            要打开的场景的ID
	 */
	public int recallScene(int sceneId);

	/**
	 * 打开指定的场景
	 * 
	 * @param senceId
	 *            要打开的场景的ID delaytime 延迟时间
	 */
	//public int recallScene(int sceneId, int delaytime);

	/**
	 * 获取指定场景的详细信息， 结果在getSenceMember_CallBack()这个回调中返回
	 * 
	 * @param senceId
	 *            场景Id
	 */
	public int getSenceMember(int sceneId);

	/**
	 * 删除场景中指定设备成员
	 * 
	 * @param senceName
	 *            场景名
	 * @param uIds
	 *            设备uId列表
	 *    升级去掉接口
	 */
	//public int deleteSenceMember(int sceneId, String sceneName, List<byte[]> uIds);

	/**
	 * 删除指定场景
	 * 
	 * @param senceName
	 */
	public int deleteSence(int senceId, String sceneName);
	/**
	 * 删除指定场景回调
	 */
	public void deleteSence_callBack(int state);
	

	/**
	 * 修改场景名称
	 * 
	 * @param senceId
	 *            场景Id
	 * @param sName
	 *            新的场景名
	 */
	public int ChangeSceneName(short sceneId, String newSceneName);
	/**
	 * 修改场景名称回调
	 * 
	 */
	public void ChangeSceneName_callBack(int state);

	/***********************************************/
	/* about task */
	/***********************************************/
	
	/**
	 * 添加场景定时任务
	 * 
	 * @param taskInfo
	 * @return 此方法在addSceneTimerTask_callBack这个回调中返回
	 */
	public int addSceneTimerTask(String taskName, TaskTimerAction timerAction, int sceneId);

	/**
	 * 添加设备定时任务
	 * 
	 * @param taskInfo
	 * @return 此方法在addDeviceTimerTask_callBack这个回调中返回
	 */
	public int addDeviceTimerTask(String taskName, TaskTimerAction timerAction, DeviceTaskInfo deviceTaskInfo);
	
	/**
	 * 删除指定定时任务
	 * 
	 * @param taskID
	 *            指定的任务id
	 * @return
	 */
	public int deleteTask(List<Integer> taskId);
	/**
	 * 删除指定定时任务回调
	 * 
	 */
	public void deleteTask_callBack(int state);
	
	/**
	 * 修改场景定时任务
	 * 
	 * @return 此方法在updateSceneTimerTask_callBack这个回调中返回
	 * @return
	 */
	public int updateSceneTimerTask(int taksId, String taskName, TaskTimerAction timerAction, short sceneId);
	/**
	 * 修改场景定时任务回调
	 * @param taksId
	 * @param taskName
	 */
	public void updateSceneTimerTask_callBack(int taksId, String taskName);
	/**
	 * 修改设备定时任务
	 * 
	 * @return 此方法在updateDeviceTimerTask_callBack这个回调中返回
	 */
	public int updateDeviceTimerTask(int taksId, String taskName, TaskTimerAction timerAction, DeviceTaskInfo deviceTaskInfo);
	
	/**
	 * 修改设备定时任务回调
	 */
	public void updateDeviceTimerTask_callBack(int taksId, String taskName);
	
	/**	
	 * 修改任务名称
	 * @param taskId
	 * @param taskType
	 * @param taskName
	 */
	public void updateTaskName(int taskId,int taskType, String taskName); 
	/**	
	 * 修改任务名称回调
	 * @param taskId
	 * @param taskType
	 * @param taskName
	 */
	public void updateTaskName_callBack(int taskId,int taskType, String taskName); 
	
	/**
	 * 更改任务状态
	 * 
	 * @param taskId
	 *            任务id
	 * @param state
	 *            任务状态 1开 0关
	 */
	public void updateTaskState(byte taskId,byte taskType, byte state);


	/**
	 * 简述 根据场景id查询该场景的所有定时任务
	 * 
	 * @param sceneId
	 *            场景id
	 * @author zhangfan
	 * @date 2016-07-26
	 * @return 此方法在getTimerTaskBySceneId_CallBack这个回调方法中返回
	 */
	public void getTimerTaskBySceneId(int sceneId);
	
	/**
	 * 获取指定设备的所有定时任务，结果在getDeviceTimerTask_CallBack中返回
	 * 
	 * @param uid
	 *            设备唯一标示
	 */
	public void getDeviceTimerTask(byte[] uid);
	
	
	
	/*******************************************联动任务相关**********************************************************
	/**
	 * 添加联动场景任务
	 * 
	 * @param taskName
	 *            任务名称 deviceAction 触发条件 sceneid 触发场景id
	 * @return
	 */
	public int addSceneLinkageTask(String taskName, List<LinkageCondition> conditionList,List<LinkageTask> taskList);
	
	/**
	 * 添加场景联动任务回调
	 */
	public void addSceneLinkageTask_callBack(int state,int linkageid,String linkageName);

	/**
	 * 添加联动设备任务
	 * 
	 */
	public int addDeviceLinkageTask(String taskName, List<LinkageCondition> conditionList,List<LinkageTask> taskList);
	
	/**
	 * 添加设备联动任务回调
	 */
	public void addDeviceLinkageTask_callBack(int state,int linkageid,String linkageName);

	
	/**
	 * 删除指定的联动任务
	 */
	public void deleteLinkageTask(List<Integer> linkageIds);
	/**
	 * 删除指定的联动任务
	 */
	public void deleteLinkageTask_callBack(int state);
	
	/**
	 * 修改联动场景任务
	 * 
	 * @return
	 */
	public int updateSceneLinkageTask(int linkageId,String taskName, List<LinkageCondition> conditionList,List<LinkageTask> taskList);
	
	/**
	 * 修改场景联动任务回调
	 */
	public void updateSceneLinkageTask_callBack(int state,int linkageid,String linkageName);

	/**
	 * 修改联动设备任务
	 * 
	 */
	public int updateDeviceLinkageTask(int linkageId,String taskName, List<LinkageCondition> conditionList,List<LinkageTask> taskList);
	
	/**
	 * 修改设备联动任务回调
	 */
	public void updateDeviceLinkageTask_callBack(int state,int linkageid,String linkageName);
	
	/**
	 * 修改联动任务名称
	 */
	public void updateLinkageName(int linkageId,int linkageType,String linkageName);
	/**
	 * 修改联动任务名称回调
	 */
	public void updateLinkageName_callBack(int state,int linkageId,int linkageType,String linkageName);
	
	/**
	 * 修改联动任务状态
	 */
	public void updateLinkageStutus(int linkageId,int linkageType,int status);
	/**
	 * 修改联动任务状态回调
	 */
	public void updateLinkageStutus_callBack(int state);
	
	
	/**
	 * 查询联动任务详细
	 */
	public void getLinkageTaskDetails(int linkageId);

	/**
	 * 查询联动任务详细回调
	 */
	public void getLinkageTaskDetails_callBack(LinkageInfo linkageInfo);
	
	
	/**
	 * 查询所有联动任务
	 */
	public void queryAllGaLinkage();
	
	/**
	 * 查询所有联动任务
	 */
	public void queryAllGaLinkage_callBack(List<LinkageInfo> linkageInfoList);
	
	
	/**
	 * 根据设备查询联动任务
	 */
	public void queryGaLinkageByUid(byte[] uid);
	/**
	 * 根据设备查询联动任务
	 */
	public void queryGaLinkageByUid_callBack(List<LinkageInfo> linkageInfoList);
	
	
	
	
	
	
	
	
	/**
	 * 根据设备uid与任务类型查询该设备的任务
	 * 
	 * @param uid
	 *            设备id
	 * @param taskType
	 *            任务类型
	 */
	public void getTasksByUid(byte[] uid, byte taskType);

	/**
	 * 查询设备联动任务详细 结果在getDeviceLinkageTaskDetails_callBack()中返回
	 */
	public void getDeviceLinkageTaskDetails(byte linkageId);

	/**
	 * 查询场景联动任务详细 结果在getSceneLinkageTaskDetails_callBack()中返回
	 */
	public void getSceneLinkageTaskDetails(byte linkageId);

	/**
	 * 根据场景id查询该场景的联动任务 结果在getSceneLinkageTasks_callBack()中返回
	 */
	public void getSceneLinkageTasks(int sceneId);

	/**
	 * 根据设备短地址+endpoint查询该设备的联动任务 结果在getDeviceLinkageTasks_callBack()中返回
	 */
	public void getDeviceLinkageTasks(byte[] uid);


	/**
	 * 修改设备触发任务
	 * 
	 * @param taskName
	 * @param isAlarm
	 *            是否需要报警
	 * @return
	 *//*
		 * public int updateDeviceTask(int taskId, String taskName,
		 * TaskDeviceAction deviceAction, short sceneId, byte isAlarm);
		 */

	/**
	 * 修改设备报警任务
	 * 
	 * @param taskName
	 * @param deviceAction
	 * @param SenceName
	 * @param isAlarm
	 * @return
	 *//*
		 * public int updateDeviceAlarmTask(int taskId, String taskName,
		 * TaskDeviceAction deviceAction);
		 */


	/**
	 * 查看指定定时任务的详细信息
	 * 
	 * @param taskId
	 *            指定的任务id
	 * @return
	 */
	public int getTaskInfo(int taskId, byte taskType);

	/**
	 * 查询设备定时任务详细 查询结果在getDeviceTimerTaskDetails_CallBack中返回
	 */
	public void getDeviceTimerTaskInfo(int taskId);

	/**
	 * 查询场景定时任务详细 查询结果在getSceneTimerTaskDetails_CallBack中返回
	 */
	public void getSceneTimerTaskInfo(int taskId);



	/******************************************* 区域 *****************************************/
	/**
	 * 添加区域 添加结果在addArea_callBack()回调中返回
	 */
	public void addArea(AreaInfo areaInfo);

	/**
	 * 根据查询区域详细 结果在getAreaDetails_callBack()中返回
	 */
	public void getAreaDetails(int areaId);

	/**
	 * 删除区域
	 */
	public void deleteArea(int areaId);

	/**
	 * 查询所有区域 结果在getAllArea_callBack()中返回
	 */
	public void getAllArea();

	/**
	 * 向网关发送心跳信息 响应心跳在sendHeartbeat_CallBack中返回
	 */
	public void sendHeartbeat();

	/**
	 * 允许入网指令，设备入网成功后结果在回调newDevice_Callback()中返回
	 */
	public int permitJoin();

	/**
	 * 收到设备入网指令返回给网关
	 */
	public void responseReportNewDevice();

	/**
	 * 验证网关管理密码,结果在verificationManagerPwd_Callback()中返回
	 */
	public int verificationManagerPwd(String username, String managerPwd);

	/**
	 * 修改管理密码,修改结果状态在回调方法modifyManagerPwd_Callback()中返回
	 */
	public int modifyManagerPwd(String username, String oldManagerPwd, String newManagerPwd);

	/**
	 * 修改登录密码,修改结果状态在回调方法modifyLoginPwd_Callback()中返回
	 * 
	 * @param isNotBindGa
	 *            ：是否有绑定网关 1有，0没有
	 */
	public int modifyLoginPwd(String username, String oldLoginPwd, String newLoginPwd, int isNotBindGa);

	/**
	 * 查询管理密码 结果在queryManagerPwd_callBack()回调中返回
	 */
	public void queryManagerPwd(String username);

	/**
	 * 关闭所有现有socket链接
	 */
	public void closeAllSocket();

	/**
	 * 发送清除网关用户指令
	 */
	public void deleteUserFromGateway(String username, String pwd, int userLevel);
	/**
	 * 发送清除网关用户指令
	 */
	public void deleteUserFromGateway(String username, String pwd, int userLevel,String sn);

	/* about electric */
	/***********************************************/
	/**
	 * 设置窗帘电机方向
	 * 
	 * @param uid
	 * @param direction
	 *            0默认方向，1相反方向
	 */
	public void setDlectricMotorDirection(byte[] uid, int direction);

	/**
	 * 配置窗帘电机
	 * 
	 * @param handPull
	 *            是否启动手拉 0关闭，1启动
	 * @param linkage
	 *            是否启动联动 0关闭，1启动
	 */
	public void configurationElectricMotor(byte[] uid, int handPull, int linkage);

	/**
	 * 查询窗帘电机配置信息
	 * 
	 * @param uid
	 *            返回：查询结果在queryElectricInfo_CallBack()回调中返回
	 */
	public void queryElectricInfo(byte[] uid);

	/**
	 * 查询窗帘电机状态
	 * 
	 * @param uid
	 *            返回:查询结果在queryElectricMotorStatus_CallBack()回调中返回
	 */
	public void queryElectricMotorStatus(byte[] uid);

	/**
	 * 打开或关闭窗帘
	 * 
	 * @param uid
	 * @param state
	 *            0表示全关 100表示全开 0~100表示打开到指定位置
	 */
	public void openOrCloseCurtain(byte[] uid, int state);

	/**
	 * 停止操作窗帘
	 * 
	 * @param uid
	 */
	public void stopOperatingCurtain(byte[] uid);

	/**
	 * 查询窗帘位置 返回:查询结果在queryCurtainPosition_CallBack()回调中返回
	 */
	public void queryCurtainPosition(byte[] uid);

	/**
	 * 卷帘行程控制 0x00-set the upper limit position 0x01-set the lower limit
	 * position 0x02-upward 0x03-downward
	 */
	public void curtainStrokeControl(byte[] uid, int value);

	/**
	 * 卷帘行程控制回调
	 */
	public void curtainStrokeControl_callBack(byte[] uid, int state);

	/**
	 * 删除行程
	 */
	public void deleteStroke(byte[] uid);

	/* about doorlock */
	/**
	 * 设置门锁开关状态
	 * 
	 * @param uid
	 * @param state:
	 *            1-open 0-close
	 */
	public void setDoorlockSwitchState(byte[] uid, int state);

	/**
	 * 查询门锁开关状态
	 * 
	 * @param uid
	 *            返回：查询结果在queryDoorlockSwitchState_CallBack()回调中返回
	 */
	public void queryDoorlockSwitchState(byte[] uid);

	/**
	 * 查询门锁电量
	 */
	public void queryDoorlockElectricity(byte[] uid);

	/**
	 * 查询门锁电量
	 */
	public void queryDoorlockElectricity_callback(byte[] uid, String electricity,int state);

	/**
	 * 设置门锁权限
	 * 
	 * @param uid
	 * @param permission
	 *            0- ordinary users， 1-only manage
	 */
	/*
	 * public void setPermissionDoorlock(byte[] uid,int permission);
	 * 
	 *//**
		 * 查询门锁权限
		 * 
		 * @param uid
		 *            返回：查询结果在queryPermissionDoorlock_CallBack()回调中返回
		 *//*
		 * public void queryPermissionDoorlock(byte[] uid);
		 */

	/**
	 * 设置门锁用户名称
	 */
	public void setUserName(byte[] uid, int uerid, String uname);

	/**
	 * 获取门锁用户列表
	 */
	public void queryDoorUserInfos(byte[] uid);

	/**
	 * 获取门锁用户列表回调
	 */
	public void queryDoorUserInfos_callBack(byte[] uid, List<DoorlockUser> list);

	/**
	 * 添加用户到门锁
	 * 
	 * @param doorlockUser
	 */
	public void addUserToDoorlock(DoorlockUser doorlockUser);

	/**
	 * 添加用户返回
	 */
	public void addUserToDoorlock_callBack(int state);

	/**
	 * 删除用户从门锁
	 * 
	 * @param doorlockUser
	 */
	public void deleteUserToDoorlock(byte[] uid, int userid);
	
	/**
	 * 删除用户从门锁回调
	 * 
	 * @param doorlockUser
	 */
	public void deleteUserToDoorlock_callBack(byte[] uid, int userid);

	/**
	 * 查询开锁记录
	 */
	public void queryUnlockRecord(byte[] uid);

	/**
	 * 查询开锁记录
	 */
	public void queryUnlockRecord_callBack(List<UnlockRecordInfo> list);

	/**
	 * 删除开锁记录
	 */
	public void deleteUnlockRecord(byte[] uid, List<Integer> listrecordId);
	/**
	 * 删除开锁记录回调
	 */
	public void deleteUnlockRecord_callBack(byte[] uid);

	/**
	 * 异常事件通知 event: 0x01- password error 0x02-fingerprint error 0x03-violent
	 * destruction
	 * 
	 */
	public void abnormalEventNotification_callBack(byte[] uid, byte event);

	/**
	 * 根据时间查询开锁记录
	 */
	public void queryUnlockRecordByTime(byte[] uid, byte[] starttime, byte[] endTime);

	/**
	 * 查询异常记录
	 */
	public void queryAbnormalRecord(byte[] uid);

	/**
	 * 根据时间查询异常记录
	 */
	public void queryAbnormalRecordByTime(byte[] uid, byte[] starttime, byte[] endTime);

	/**
	 * 查询异常记录回调
	 */
	public void queryAbnormalRecord_callBack(List<AbnormalRecordInfo> list);

	/**
	 * 删除异常记录
	 */
	public void deleteAbnormalRecord(byte[] uid, List<Integer> listrecordId);
	
	/**
	 * 冻结门锁用户（爱尔福德锁）
	 * @param uid
	 * @param type   0x00-Keypad，0x01-R，0x02-Manual，0x03-RFID，0xFF-all user
	 * @param userId
	 * @param freeze 1 冻结 0 解除冻结
	 */
	public void freezeLockUserPassword(byte[] uid,int type,int userId,int freeze);
	
	/**
	 * 查询机器码
	 * @param uid
	 */
	public void queryLockMachineCode(byte[] uid);
	
	/**
	 * 查询机器码回调
	 * @param uid
	 */
	public void queryLockMachineCode_callBack(byte[] uid,String machineCode);

	/**
	 * 设置门锁时间
	 */
	public void SetTheLocktime(byte[] uid, byte[] lockTime);

	/**
	 * 获取网关温湿度
	 */
	public void requestTemperatureAndHumidity();

	/**
	 * 获取网关温湿度
	 */
	public void requestTemperatureAndHumidity_callBack(int tem, int hum);

	/************************** 红外遥控器相关方法 *******************************/
	/**
	 * 获取红外遥控器所有设备 返回在quiryIrAllDevice_Callback回调中返回
	 */
	public void quiryIrAllDevice();

	/**
	 * 获取红外遥控器所有设备回调
	 */
	public void quiryIrAllDevice_Callback(List<IrDeviceInfo> list);

	/**
	 * 获取指定设备的信息 查询结果在getIrDeviceInfo_Callback回调中返回
	 */
	public void getIrDeviceInfo(byte[] irid);

	/**
	 * 获取指定设备的信息回调
	 */
	public void getIrDeviceInfo_Callback(IrDeviceInfo irdeviceInfo);

	/**
	 * 设置灯的状态
	 */
	public void setLampState(byte[] irid, byte effective, byte switchState, byte brigth, byte saturation, byte r,
			byte g, byte b);

	/**
	 * 获取灯的状态
	 */
	public void getLampState(byte[] irid);

	/**
	 * 获取灯的状态回调
	 */
	public void getLampState_callBack(byte[] irid, byte switchState, byte brigth, byte saturation, byte r, byte g,
			byte b);

	/**
	 * 设置指定设备开关状态
	 */
	public void setIrDeviceSwitchState(byte[] irid, byte state);

	/**
	 * 设置指定设备饱和度
	 */
	public void setIrDeviceSaturation(byte[] irid, byte saturation);

	/**
	 * 获取指定设备开关状态 查询结果在getIrDeviceSwitchState_Callback回调中返回
	 */
	public void getIrDeviceSwitchState(byte[] irid);

	/**
	 * 获取指定设备开关状态回调
	 */
	public void getIrDeviceSwitchState_Callback(byte[] irid, int state);

	/**
	 * 设置红外灯的亮度
	 */
	public void setIrLigthBrightness(byte[] irid, byte brightness, int curtime);

	/**
	 * 获取红外灯的亮度
	 */
	public void getIrLigthBrightness(byte[] irid);

	/**
	 * 获取红外灯的亮度回调
	 */
	public void getIrLigthBrightness_Callback(byte[] irid, short brightness);

	/**
	 * 设置灯的颜色
	 */
	public void setIrLigthRgb(byte[] irid, byte r, byte g, byte b, int curtime);

	/**
	 * 获取红外灯的颜色
	 */
	public void getIrLigthRgb(byte[] irid);

	/**
	 * 获取红外灯的色调饱和度回调
	 */
	public void getIrLigthHueAndSat_Callback(byte[] irid, byte r, byte g, byte b);

	/**
	 * 获取红外灯的色温回调
	 */
	public void getColorTemperature_Callback(byte[] irid, short colorTemperature);

	/**
	 * 设置灯的感应模式
	 */
	public void setLampSensingMode(byte switchState, int keeyTime);

	/**
	 * 设置灯光流光溢彩的模式
	 */
	public void setLightAmbilightMode(byte switchState);

	/**
	 * 发送红外码
	 */
	public void requireRemoteControlInfraredCode(byte[] irid, String ircode);

	/**
	 * 获取温度
	 */
	public void requestTemperatureInformation(byte[] irid);

	/**
	 * 获取温度回调
	 */
	public void requestTemperatureInformation_callBack(byte[] Temperature);

	/**
	 * 获取湿度
	 */
	public void requestHumidityInformation(byte[] irid);

	/**
	 * 获取湿度
	 */
	public void requestHumidityInformation_callBack(byte[] Humidity);

	/**
	 * 查询所有红外遥控器定时任务
	 */
	public void queryAllIrTask();

	/**
	 * 查询所有红外遥控器定时任务回调
	 */
	public void queryAllIrTask_callBack(List<IrTaskInfo> list);

	/**
	 * 添加任务
	 */
	public void addIrTask(IrTaskInfo irtaskInfo);

	/**
	 * 添加任务回调
	 */
	public void addIrTask_callBack(int state);

	/**
	 * 删除任务
	 */
	public void deleteIrTask(int taskid);

	/**
	 * 修改任务
	 */
	public void updateIrTask(IrTaskInfo irtaskInfo);

	/**
	 * 查询指定任务详细
	 */
	public void queryIrTaskInfo(int taskid);

	/**
	 * 查询指定任务详细回调
	 */
	public void queryIrTaskInfo_callBack(IrTaskInfo irTaskInfo);

	/**
	 * 查询所有任务详细
	 */
	public void queryAllIrtaskInfo();

	/**
	 * 查询所有任务详细回调
	 */
	public void queryAllIrtaskInfo_callBack(List<IrTaskInfo> list);

	/**
	 * 更新任务状态
	 */
	public void updateIrTaskState(int taskid, int state);

	/**
	 * 获取遥控器信息
	 */
	public void getRemoteControlInformation();

	/**
	 * 获取遥控器信息回调
	 */
	public void getRemoteControlInformation_callBack(RemoteControlInfo rcinfo);

	/**
	 * 设置wifi信息
	 */
	public void setWifiNetworkInformation(String ssid, String pwd);

	/**
	 * 获取wifi信息
	 */
	public void requestWifiNetworkInformation();

	/**
	 * 获取wifi信息回调
	 */
	public void requestWifiNetworkInformation_callBack(String ssid, String pwd);

	/**
	 * 重置遥控器 0x0A：only reset user flash of gateway 0x50：delete the wifi netwok
	 * information ,Restore the factory value 0x06：upgrade
	 */
	public void resetRemoteControl(byte resetCommand);

	/**
	 * 上报新红外设备
	 */
	public void reportNewDevice(int devType, String devName, int devkindsid);

	/**
	 * 上报新红外设备回调
	 */
	public void reportNewDevice_callBack(byte[] irid, int devkinds, String deviceName);

	/**
	 * 移除红外设备
	 */
	public void removeIrDevice(byte[] irid);

	/**
	 * 移除红外设备回调
	 */
	public void removeIrDevice_callBack(int state);

	/**
	 * 更新遥控器名称
	 */
	public void updateIrDeviceName(byte[] irid, String deviceName);

	/**
	 * 更新遥控器名称回调
	 */
	public void updateIrDeviceName_callBack(int state);

	/**
	 * 添加红外联动任务
	 */
	public void addIrLinkage(IrLinkageInfo irLinkageInfo);

	/**
	 * 查询红外联动任务详细
	 */
	public void queryLinkageDetails(int linkageid);

	/**
	 * 查询红外联动任务详细回调
	 */
	public void queryLinkageDetails_callBack(IrLinkageInfo irLinkageInfo);

	/**
	 * 查询所有联动任务
	 */
	public void queryAllLinkage();

	/**
	 * 查询所有联动任务回调
	 */
	public void queryAllLinkage_callBack(List<IrLinkageInfo> list);

	/**
	 * 删除联动任务
	 */
	public void deleteLinkage(int linkageid);

	/**
	 * 设置智能模式
	 * 
	 * @param smartName
	 * @param irid
	 * @param ambientTemperature
	 */
	public void setSmartMode(String smartName, byte[] irid, int ambientTemperature);

	/**
	 * 设置低温智能模式
	 * 
	 * @param lowTemperature
	 * @param ircode
	 */
	public void setSmartModeLowTemperatureCmd(int lowTemperature, String ircode);

	/**
	 * 设置高温智能模式
	 * 
	 * @param lowTemperature
	 * @param ircode
	 */
	public void setSmartModeHigthTemperatureCmd(int higthTemperature, String ircode);

	/**
	 * 查询智能模式
	 */
	public void querySmartMode();

	/**
	 * 查询智能模式
	 */
	public void querySmartMode_callBack(byte[] irid, int ambientTemperature, int lowTemperature, int higthTemperature,
			int state);

	/**
	 * 设置智能模式状态
	 * 
	 * @param state
	 */
	public void updateSmartState(int state);

	/**
	 * 获取遥控器固件版本
	 */
	public void requestRemoteControlVersion();

	/**
	 * 获取遥控器固件版本回调
	 */
	public void requestRemoteControlVersion_callBack(String version);

	/**
	 * 获取遥控器固件长度
	 */
	public void requestRemoteControlFirmwareLength(String version);

	/**
	 * 获取遥控器固件长度回调
	 */
	public void requestRemoteControlFirmwareLength_callBack(String version, int totalPackets);

	/**
	 * 要求遥控器升级固件
	 */
	public void requestToUpgrade(int totalPackets, String newVersion, int cs8);

	/**
	 * 升级成功
	 */
	public void upgradeOk_callBack(int totalPacket, int currentPacket);

	/**
	 * 自定义遥控器按键
	 */
	public void customRemoteControlKeys(byte[] irid, String keyName);

	/**
	 * 自定义遥控器按键回调
	 */
	public void customRemoteControlKeys_callBack(byte[] irid, int state, String keyName, int key);

	/**
	 * 根据设备查询自定义遥控器按键
	 */
	public void requestCustomRemoteControlByDevice(byte[] irid);

	/**
	 * 根据设备查询自定义遥控器按键回调
	 */
	public void requestCustomRemoteControlByDevice_callBack(byte[] irid, Map<Integer, String> keys);

	/**
	 * 执行自定义遥控器按键操作
	 */
	public void sendCustomRemoteControlKey(byte[] irid, int key);

	/**
	 * 获取客户端是否在线状态
	 */
	public void getTheOnlineStatusOfThClient(String sn);

	/**
	 * 获取客户端是否在线状态回调
	 * 
	 * @param status:
	 *            0离线 1在线
	 */
	public void getTheOnlineStatusOfThClient_callback(int status);

	/**
	 * --------------------------------以下是回调方法----------------------------------
	 * -
	 **/
	/**
	 * 这是一个测试回调方法
	 * 
	 * @param result
	 */
	public void callback(String result);

	/**
	 * 获取所有设备回调方法
	 * 
	 * @param dinfo
	 */
	public void newDevice_CallBack(List<DeviceInfo> dinfos);

	/**
	 * 允许入网回调
	 */
	public void newDevice_Callback(DeviceInfo info);

	/**
	 * 本地查找网关返回
	 * 
	 * @param ip
	 */
	public void newGate_CallBack(String ip, String sn);

	/**
	 * 获取设备的值回调方法
	 */
	public void getDeviceLevel_CallBack(int level, byte[] uId);

	/**
	 * 获取所有场景回调方法
	 * 
	 * @param dinfo
	 */
	public void newSence_CallBack(List<SenceInfo> sinfos);

	/**
	 * 获取网关信息返回
	 */
	public void getGateWayInfo_CallBack(GateWayInfo gainfo);

	/**
	 * 获取设备状态回调,通过state来判断设备状态（>0 开、<= 0关）
	 * 
	 * @param state
	 * @param uId
	 */
	public void getDeviceState_CallBack(int state, byte[] uId);

	/**
	 * 获取设备色调与饱和度回调
	 * 
	 * @param hue
	 *            色调
	 * @param sat
	 *            饱和度
	 * @param uId
	 */
	public void getDeviceHueAndSat_CallBack(int hue, int sat, byte[] uId);

	/**
	 * 获取设备色温值回调
	 * 
	 * @param colorTemperature
	 * @param uId
	 */
	public void getColorTemperature_CallBack(int colorTemperature, byte[] uId);

	/**
	 * 获取场景成员回调
	 */
	public void getSenceMember_CallBack(int sceneId, String sceneName, List<DeviceTaskInfo> dts);

	/**
	 * 获取所有任务回调
	 */
	public void newTask_CallBack(List<TaskInfo> tasks);

	/**
	 * 获取指定场景定时任务 当调用getTimerTaskBySceneId方法后回调
	 */
	public void getTimerTaskBySceneId_CallBack(List<TaskInfo> tasks);

	/**
	 * 获取指定设备联动任务 当条用getSensorTaskByUid方法后回调
	 */
	// public void getSensorTaskByUid_CallBack(List<TaskInfo> tasks);

	/**
	 * 当调用getTaskInfo()时返回
	 * 
	 * @param taskId
	 *            task's id
	 * @param taskName
	 *            task's name
	 * @param action1
	 *            first task's action
	 * @param action2
	 *            second task's action
	 */
	public void getSceneTimerTaskDetails_CallBack(TaskInfo taskInfo, TaskTimerAction timerAction, short sceneId);

	/**
	 * 当调用getTaskInfo()时返回
	 * 
	 * @param taskId
	 *            task's id
	 * @param taskName
	 *            task's name
	 * @param action1
	 *            first task's action
	 * @param action2
	 *            second task's action
	 */
	public void getDeviceTimerTaskDetails_CallBack(TaskInfo taskInfo, TaskTimerAction timerAction,
			DeviceTaskInfo DeviceTaskInfo);

	/**
	 * 当调用getTaskInfo()时返回，返回获取设备联动任务
	 * 
	 * @param taskName
	 *            任务名
	 * @param deviceAction
	 *            设备联动时，设备动作信息
	 * @param senceName
	 *            联动执行场景
	 * @param isAlarm
	 *            是否报警标志
	 */
	public void getDeviceTaskDetails_CallBack(TaskInfo taskInfo, TaskDeviceAction deviceAction, short sceneId,
			byte isAlarm);

	/**
	 * 当调用addSence后返回
	 * 
	 * @param sceneId
	 *            场景id
	 * 
	 * @param senceName
	 *            场景名称
	 */
	public void addSence_callBack(byte sceneId, String senceName);

	/**
	 * 当调用ChangeDeviceName后返回
	 * 
	 * @param uid
	 *            uid
	 * 
	 * @param deviceName
	 *            设备名称
	 */
	public void ChangeDeviceName_callBack(byte[] uid, String deviceName);

	/**
	 * 传感器推送数据回调
	 * 
	 * @param uid
	 *            设备uid
	 * @param 参数
	 *            请参考recentValue对照表
	 */
	public void sensorReport_callBack(byte[] uid, byte[] recentValue, byte[] deviceId, short attrId);

	/**
	 * 温湿度传感器推送回调方法
	 * 
	 * @param temperature
	 *            温度
	 * @param humidity
	 *            湿度
	 * @param battery
	 *            电量 0正常，1低电量
	 */
	public void TemperatureAndHumidityReport_callBack(Double temperature, Double humidity, Integer battery, byte[] uid);

	/**
	 * 紧急按钮推送回调方法
	 * 
	 * @param state
	 *            状态
	 */
	public void EmergencyButtonReprot_callBack(byte state, byte[] uid);

	/**
	 * 燃气传感器推送回调方法
	 * 
	 * @param state
	 *            状态
	 */
	public void GasSensorReprot_callBack(byte state, byte[] uid);

	/**
	 * 烟雾传感器推送回调方法
	 * 
	 * @param state
	 *            状态
	 */
	public void FireSensorReprot_callBack(byte state, byte[] uid);

	/**
	 * 一氧化碳传感器推送回调方法
	 * 
	 * @param state
	 *            状态
	 */
	public void CoSensorReprot_callBack(byte state, byte[] uid);

	/**
	 * 多功能遥控器推送回调方法
	 * 
	 * @param state
	 *            状态
	 */
	public void KeyFobReprot_callBack(byte state, byte[] uid);

	/**
	 * 客户端离线后回调方法
	 */
	public void clientClose();

	/**
	 * 客户端建立链接回调方法
	 */
	public void clientActive();

	/**
	 * 获取设备定时任务回调方法
	 */
	public void getDeviceTimerTask_CallBack(List<TaskInfo> taskInfos);

	/**
	 * 心跳响应回调方法
	 */
	public void sendHeartbeat_CallBack();

	/**
	 * 验证管理面回调方法
	 */
	public void verificationManagerPwd_Callback(int state);

	/**
	 * 修改登录密码回调方法
	 * 
	 * @param state
	 *            : 0成功，1网关未链接云，2 用户名无效，3 原始密码错误，4新密码无效
	 */
	public void modifyLoginPwd_Callback(int state);

	/**
	 * 修改管理密码密码回调方法
	 * 
	 * @param state
	 *            : 0成功，1 用户名无效，2 原始密码错误，3新密码无效
	 */
	public void modifyManagerPwd_Callback(int state);

	/**
	 * 网关局域网登录验证回调方法
	 * 
	 * @param state
	 *            ：0成功，1用户名无效，2密码错误
	 */
	public void loginGaByLan_Callback(int state);

	/**
	 * 绑定网关结果回调方法
	 * 
	 * @param state：
	 *            0成功，1网关为链接云，2sn无效，3用户名无效，4密码无效
	 */
	public void UserBindToGa_callBack(int state);

	/**
	 * 添加用户到网关回调方法
	 * 
	 * @param state：
	 *            0成功,1 用户名无效，2密码无效
	 */
	public void addUserToGa_callBack(int state);

	/**
	 * 查询管理密码返回
	 * 
	 * @param username
	 * @param password
	 */
	public void queryManagerPwd_callBack(String username, String password);

	/**
	 * 添加场景定时任务回调
	 */
	public void addSceneTimerTask_callBack(String taskName, int taskId);

	/**
	 * 添加场景定时任务回调
	 */
	public void addDeviceTimerTask_callBack(String taskName, int taskId);

	/**
	 * 查询设备联动任务回调
	 */
	public void getDeviceLinkageTaskDetails_callBack(TaskInfo taskInfo);

	/**
	 * 查询场景联动任务回调
	 */
	public void getSceneLinkageTaskDetails_callBack(TaskInfo taskInfo);

	/**
	 * 获取指定场景联动任务列表回调
	 */
	public void getSceneLinkageTasks_callBack(List<TaskInfo> taskInfos);

	/**
	 * 获取指定设备联动任务列表回调
	 */
	public void getDeviceLinkageTasks_callBack(List<TaskInfo> taskInfos);

	/**
	 * 获取区域详细回调
	 */
	public void getAreaDetails_callBack(AreaInfo areaInfo);

	/**
	 * 获取所有区域
	 */
	public void getAllArea_callBack(List<AreaInfo> areaInfos);

	/**
	 * 添加区域回调
	 * 
	 * @param state
	 *            0、响应成功 1、一般错误 2、区域名称冲突 3、区域数量达到上限
	 */
	public void addArea_callBack(int state);

	/**
	 * 强制退出登录回调
	 */
	public void signOut_callBack();

	/**
	 * 未找到网关
	 */
	public void notFindGa_callback();

	/**
	 * 未找到遥控器
	 */
	public void notFindIr_callback();

	/**
	 * 查询窗帘电机状态回调
	 * 
	 * @param operable
	 *            是否可操作 0可以，1不行
	 * @param ismobile
	 *            是否可动 0不可移动，1可移动
	 * @param direction
	 * 				电机方向 0正常，1相反方向
	 */
	public void queryElectricMotorStatus_CallBack(int operable, int ismobile,int direction);

	/**
	 * 查询窗帘电机配置信息回调
	 * 
	 * @param handPull
	 *            是否启动手拉 0关闭，1启动
	 * @param linkage
	 *            是否启动联动 0关闭，1启动
	 */
	public void queryElectricInfo_CallBack(int handpull, int linkage);

	/**
	 * 查询窗帘位置回调
	 * 
	 * @param value
	 *            : 0全关 100全开 0-100当前位置
	 */
	public void queryCurtainPosition_CallBack(int value);

	/**
	 * 查询门锁状态
	 * 
	 * @param uid
	 * @param state:
	 *            1-open 0-close
	 */
	public void queryDoorlockSwitchState_CallBack(byte[] uid, int state);

	/**
	 * 门锁操作状态推送
	 */
	public void operationEventNotification(DoorlockNotification doorlockNotification,int state);

	/**
	 * 查询门锁权限回调
	 * 
	 * @param uid
	 * @param permission
	 *            0x00- ordinary users，0x01-only manage
	 */
	public void queryPermissionDoorlock_CallBack(byte[] uid, int permission);

	/************************************************ wifi模块接口 *****************************************/

	/**
	 * 获取wifi模块信息
	 */
	public void getWifiModuleInformation(String sn);

	/**
	 * 获取wifi模块信息回调
	 */
	public void getWifiModuleInformation_callBack(WifiModuleInformation wifiModuleInformation);

	/**
	 * 设置wifi信息
	 */
	public void setWifiModuleWifiNetworkInformation(String sn,String ssid, String password);

	/**
	 * 设置wifi信息回调
	 */
	public void setWifiModuleWifiNetworkInformation_callBack(String sn, int state);

	/**
	 * 获取wifi信息
	 */
	public void requestWifiModuleWifiNetworkInformation(String sn);

	/**
	 * 获取wifi信息回调
	 */
	public void requestWifiModuleWifiNetworkInformation_callBack(String ssid, String password);

	/**
	 * 升级或重置wifi模块 resetCommand: 0x01： upgrade wifi module 0x02： Reset wifi
	 * module
	 */
	public void upgradeOrResetWifiModule(String sn,int resetCommand, int newVersion);

	/**
	 * 切换模块的在线状态
	 */
	public void switchOnlineStateOfWifiModule(String sn,int state);

	/**
	 * 切换模块的在线状态回调
	 */
	public void switchOnlineStateOfWifiModule_callBack(int state);

	/**
	 * 获取模块上的所有设备
	 */
	public void getModuleAllDevice(String sn);

	/**
	 * 获取模块上的所有设备回调
	 */
	public void getModuleAllDevice_callBack(List<WifiModelDeviceInfo> devices);

	/**
	 * 获取模块的版本
	 */
	public void requestWifiModuleVersion(String sn,int command);

	/**
	 * 获取模块的版本回调
	 */
	public void requestWifiModuleVersion_callBack(String version);

	/**
	 * 报告升级状态
	 */
	public void reportUpgradeStatus(int responseCode, String version);

	/**
	 * 将模块设置成网络模式
	 */
	public void setWifiModuleIntoTheNetworkMode(String sn);

	/**
	 * 将模块设置成网络模式
	 */
	public void setWifiModuleIntoTheNetworkMode_callBack(int panID, byte[] expan, int channel, int version);

	/**
	 * 设置wifi设备开关状态
	 */
	public void setWifiDeviceSwitchState(String sn,byte[] uid, int switchState);
	/**
	 * 设置wifi设备开关状态回调
	 */
	public void setWifiDeviceSwitchState_callBack(byte[] uid, int switchState);
	
	/**
	 * 获取设备开关状态
	 */
	public void requireWifiDeviceSwitchState(String sn,byte[] uid);
	/**
	 * 获取设备开关状态回调
	 */
	public void requireWifiDeviceSwitchState_callBack(byte[] uid, int switchState);
	
	/**
	 * 设置灯的亮度
	 */
	public void setWifiLightBrightness(String sn,byte[] uid,int brightCommand,int cutTime);
	/**
	 * 设置灯的亮度
	 */
	public void setWifiLightBrightness_callBack(byte[] uid,int brightValue);
	
	/**
	 * 获取灯的亮度
	 */
	public void requireWifiLightBrightness(String sn,byte[] uid);
	/**
	 * 获取灯的亮度回调
	 */
	public void requireWifiLightBrightness_callBack(byte[] uid,int brightValue);
	
	/**
	 * 设置灯的色调与饱和度
	 */
	public void setWifiLighthueOrSaturation(String sn,byte[] uid,int hue,int sat,int cutTime);
	/**
	 * 设置灯的色调与饱和度回调
	 */
	public void setWifiLighthueOrSaturation_callBack(byte[] uid,int hue,int sat);
	
	/**
	 * 查询灯的色调饱和度
	 */
	public void requireWifiLighthueOrSaturation(String sn,byte[] uid);
	/**
	 * 查询灯的色调饱和度回调
	 */
	public void requireWifiLighthueOrSaturation_callBack(byte[] uid,int hue,int sat);
	
	/**
	 * 设置灯的色温
	 */
	public void setWifiLightColorTemperature(String sn,byte[] uid,int colorTemperature,int cutTime);
	/**
	 * 设置灯的色温回调
	 */
	public void setWifiLightColorTemperature_callBack(byte[] uid,int colorTemperature);
	
	/**
	 * 获取灯的色温
	 */
	public void requireWifiLightColorTemperature(String sn,byte[] uid);
	/**
	 * 获取灯的色温回调
	 */
	public void requireWifiLightColorTemperature_callBack(byte[] uid,int colorTemperature);
	
	/**
	 * 设置电机方向
	 */
	public void  setWifiElectricMotorDirection(String sn,byte[] uid ,int direction);
	/**
	 * 设置电机方向回调
	 */
	public void  setWifiElectricMotorDirection_callBack(byte[] uid ,int direction);
	
	/**
	 * 配置电动马达
	 */
	public void configurationWifiElectricMotor(String sn,byte[] uid,int handPull,int linkage);
	/**
	 * 配置电动马达回调
	 */
	public void configurationWifiElectricMotor_callBack(byte[] uid,byte value);
	
	/**
	 * 查询电机配置信息
	 */
	public void queryWifiElectricMotorConfigurationInfo(String sn,byte[] uid);
	/**
	 * 查询电机配置信息回调
	 */
	public void queryWifiElectricMotorConfigurationInfo_callBack(byte[] uid,byte value);
	
	/**
	 * 查询电机状态
	 */
	public void queryWifiElectricMotorStatus(String sn,byte[] uid);
	/**
	 * 查询电机状态回调
	 */
	public void queryWifiElectricMotorStatus_callBack(byte[] uid,byte value);
	
	/**
	 *开启或关闭窗帘 
	 */
	public void openOrCloseWifiCurtain(String sn,byte[] uid,int value);
	/**
	 *开启或关闭窗帘 回调
	 */
	public void openOrCloseWifiCurtain_callBack(byte[] uid,int value);
	
	/**
	 * 停止操作窗帘
	 */
	public void stopOperatingWifiCurtain(String sn,byte[] uid);
	/**
	 * 停止操作窗帘回调
	 */
	public void stopOperatingWifiCurtain_callBack(byte[] uid);
	
	/**
	 * 查询窗帘位置
	 */
	public void queryWifiCurtainPosition(String sn,byte[] uid);
	/**
	 * 查询窗帘位置回调
	 */
	public void queryWifiCurtainPosition_callBack(byte[] uid,int value);
	
	/**
	 * 窗帘行程控制（卷帘）
	 */
	public void wifiCurtainStrokeControl(String sn,byte[] uid,int value);
	/**
	 * 窗帘行程控制回调
	 */
	public void wifiCurtainStrokeControl_callBack(byte[] uid);
	
	/**
	 * 删除行程
	 */
	public void  deleteWifiStroke(String sn,byte[] uid);
	/**
	 * 删除行程回调
	 */
	public void  deleteWifiStroke_callBack(byte[] uid);
	
	/**
	 * 添加定时任务
	 */
	public void addWifiTask(String sn,TaskInfo taskInfo);
	/**
	 * 添加wifi定时任务回调
	 * @param taskId
	 */
	public void addWifiTask_callBack(int taskId);
	
	/**
	 * 删除任务
	 */
	public void deleteWifiTask(String sn,int taskId);
	/**
	 * 删除任务回调
	 */
	public void deleteWifiTask_callBack(int state);
	
	/**
	 * 修改定时任务
	 */
	public void updateWifiTask(String sn,TaskInfo taskInfo);
	/**
	 * 修改定时任务回调
	 */
	public void updateWifiTask_callBack(int taskId);
	
	/**
	 * 查询定时任务详细
	 */
	public void queryTheWifiTaskDetails(String sn,int taskId);
	/**
	 * 查询定时任务详细回调
	 */
	public void queryTheWifiTaskDetails_callBack(TaskInfo taskInfo);
	
	/**
	 * 查询定时任务详细
	 */
	public void queryAllWifiTask(String sn);
	/**
	 * 查询定时任务详细回调
	 */
	public void queryAllWifiTask_callBack(List<TaskInfo> list);
	
	
	/**************************情景面板*****************************************/
	/**
	 * 设备按键配置
	 */
	public void deviceKeyConfigureForDevice(byte[] keyUid,List<ScenePanelTask> listTask);
	/**
	 * 场景按键配置
	 */
	public void deviceKeyConfigureForScene(byte[] keyUid,List<ScenePanelTask> listTask);
	
	/**
	 * 按键配置回调
	 * @param keyUid
	 * @param state
	 */
	public void deviceKeyConfigure_callBack(byte[] keyUid,int state);
	
	/**
	 * 删除按键配置
	 * @param keyUid
	 */
	public void deleteConfigureOfDeviceKey(byte[] keyUid);
	/**
	 * 删除按键配置回调
	 */
	public void deleteConfigureOfDeviceKey_callBack(byte[] keyUid,int state);
	
	/**
	 * 查询所有按键配置
	 */
	public void queryAllConfigureOfTheDevice(byte[] uid,byte[] ieeeAddr);

	/**
	 * 查询所有按键配置回调
	 */
	public void queryAllConfigureOfTheDevice_callBack(List<ScenePanelInfo> list);
	
	/**************************************温控器相关接口*****************************************/
	/**
	 * 设置温控器模式
	 * @param uid 
	 * @param modelValue 制冷：0x01 ,风扇：0x02,制热：0x03,自动：0x04
	 */
	public void  setTheThermostatMode(byte[] uid,int modelValue);
	
	/**
	 * 设置温控器模式回调
	 * @param uid 
	 * @param modelValue 制冷：0x01 ,风扇：0x02,制热：0x03,自动：0x04
	 */
	public void  setTheThermostatMode_callBack(byte[] uid,int modelValue);
	
	/**
	 *  设置风速
	 * @param uid
	 * @param speed 低速：0x01,中速：0x02,高速：0x03,自动：0x04
	 */
	public void  setTheWindSpeed(byte[] uid,int speed);
	/**
	 *  设置风速回调
	 * @param uid
	 * @param speed 低速：0x01,中速：0x02,高速：0x03,自动：0x04
	 */
	public void  setTheWindSpeed_callBack(byte[] uid,int speed);
	
	/**
	 * 调节温度
	 * @param uid
	 * @param value 上调 1℃： 0x01,下调 1℃： 0x00
	 */
	public void adjusttTheTemperature(byte[] uid,int value);
	/**
	 * 调节温度回调
	 * @param uid
	 * @param value 上调 1℃： 0x01,下调 1℃： 0x00
	 */
	public void adjusttTheTemperature_callBack(byte[] uid,int value);
	
	/**
	 * 配置来电运行方式
	 * @param uid
	 * @param value 来电保持关机 0x00,来电恢复断电前的状态 0x01,来电强制开机 0x02
	 */
	public void setTheRunModeThatPowerResume(byte[] uid,int value);
	/**
	 * 配置来电运行方式回调
	 * @param uid
	 * @param value 来电保持关机 0x00,来电恢复断电前的状态 0x01,来电强制开机 0x02
	 */
	public void setTheRunModeThatPowerResume_callBack(byte[] uid,int value);
	
	/**
	 * 查询温控器配置信息
	 */
	public void queryTheThermostatConfigureInfo(byte[] uid);
	/**
	 * 查询温控器配置信息回调
	 */
	public void queryTheThermostatConfigureInfo_callBack(ThermostatConfigureInfo thermostatConfigureInfo);
	
	/**
	 * 查询温控器当前运行状态
	 * @param uid
	 */
	public void queryTheThermostatRunStatus(byte[] uid);
	/**
	 * 查询温控器当前运行状态回调
	 * @param uid
	 */
	public void queryTheThermostatRunStatus_callBack(ThermostatRunStatusInfo thermostatRunStatusInfo);
	
	/**
	 * 设置温控器开关状态
	 */
	public void setThermostatState(byte[] uid,int state);
	/**
	 * 设置温控器开关状态回调
	 */
	public void setThermostatState_callBack(byte[] uid,int state);
	
	//*****************************杨格公寓锁相关************************************/
	/**
	 * 根据用户名查询设备的操作权限
	 */
	//public void queryOperationPermissionByusername(String username,List<byte[]> uids);
	/**
	 * 根据用户名查询设备的操作权限回调
	 */
	//public void queryOperationPermissionByusername_callBack(String username,List<LockOperationPermissionInfo> infos);
	
	/**
	 * 设置锁的开关状态
	 */
	public void setGwDoorlockSwitchState(byte[] uid,int switchState);	
	/**
	 * 设置锁的开关状态回调
	 */
	public void setDoorlockSwitchState_callBack(int state);	
	
	/**
	 * 查询锁的开关状态
	 */
	public void queryGyDoorlockSwitchState(byte[] uid);	
	/**
	 * 查询锁的开关状态回调
	 */
	public void queryGyDoorlockSwitchState_callBack(byte[] uid,int switchState);
	
	/**
	 * 配置门锁是否长开
	 */
	public void configureDoorlockNormalOpen(byte[] uid,int state); 
	/**
	 * 配置门锁是否长开回调
	 */
	public void configureDoorlockNormalOpen_callBack(int state); 
	
	/**
	 * 查询门锁最近状态
	 */
	public void queryDoorlockRecentStatus(byte[] uid);
	/**
	 * 查询门锁最近状态回调
	 */
	public void queryDoorlockRecentStatus_callBack(DoorlockRecentStatusInfo info);
	
	/**
	 * 添加门锁用户
	 */
	public void addGyDoorlockUser(byte[] uid,LockUserInfo lockUserInfo);
	/**
	 * 添加门锁用户回调
	 */
	public void addGyDoorlockUser_callBack(int state);
	
	/**
	 * 删除门锁用户
	 */
	public void deleteGyDoorlockUser(byte[] uid,LockUserInfo lockUserInfo);
	/**
	 * 删除门锁用户回调
	 */
	public void deleteGyDoorlockUser_callBack(int state);
	
	/**
	 * 冻结门锁用户
	 */
	public void freezeDoorlockUser(byte[] uid,LockUserInfo lockUserInfo,int freeze);
	/**
	 * 冻结门锁用户回调
	 */
	public void freezeDoorlockUser_callBack(int state);
	
	/**
	 * 更改门锁用户密码
	 */
	public void modifyDoorlockUserPasswd(byte[] uid,LockUserInfo lockUserInfo);	
	/**
	 * 更改门锁用户密码回调
	 */
	public void modifyDoorlockUserPasswd_callBack(int state);
	
	/**
	 * 查询所有用户信息
	 */
	public void queryAllLockUserInfo(byte[] uid);
	/**
	 * 查询所有用户信息回调
	 */
	public void queryAllLockUserInfo_callBack(List<LockUserInfo> infos);
	
	/**
	 * 查询开锁记录
	 */
	public void queryUnlockRecord(byte[] uid,String username,String startTime,String endTime);	
	/**
	 * 查询开锁记录回调
	 */
	public void queryUnlockRecord_callBack(byte[] uid,String username,List<LockUnlockRecordInfo> infos);	
	
	/**
	 * 删除开锁记录
	 */
	public void deleteUnlockRecord(byte[] uid,String username,List<Integer> idList);
	/**
	 * 删除开锁记录回调
	 */
	public void deleteUnlockRecord_callBack(int state);
	
	/**
	 * 查询异常记录
	 */
	public void queryAbnormalRecord(byte[] uid,String username,String startTime,String endTime);
	/**
	 * 查询异常记录回调
	 */
	public void queryAbnormalRecord_callBack(byte[] uid,String username,List<LockAbnormalRecordInfo> infos);
	
	/**
	 * 删除异常记录
	 */
	public void deleteAbnormalRecord(byte[] uid,String username,List<Integer> idList);
	/**
	 * 删除异常记录回调
	 */
	public void deleteAbnormalRecord_callBack(int state);
	
	/**
	 * 更改用户别名
	 */
	public void modifyDoorlockUserAlias(byte[] uid,LockUserInfo info,String newAlias);
	/**
	 * 更改用户别名
	 */
	public void modifyDoorlockUserAlias_callBack(int state);
	
	/**
	 * 门锁操作通知
	 */
	public void doorlockEventPush(byte[] ieee,byte[] uid,int eventType,int event,byte[] time,int permission,String name);
	
	/***********************************窗帘面板相关***************************************************/
	/**
	 * 窗帘面板绑定
	 * 
	 */
	public void bindDevice(byte[] uid,byte[] destUid);
	/**
	 * 窗帘面板绑定回调
	 * 
	 */
	public void bindDevice_callBack(int state);
	
	/**
	 * 删除窗帘面板绑定
	 */
	public void cancelBind(byte[] uid);
	/**
	 * 删除窗帘面板绑定回调
	 */
	public void cancelBind_callBack(int state);
	
	/**
	 * 查询面板绑定信息
	 */
	public void queryAllBind(byte[] uid,byte[] ieedAddr);
	/**
	 * 查询面板绑定信息回调
	 */
	public void queryAllBind_callBack(List<BindDeviceInfo> list);
	
	/***********************报警器相关*****************************/
	/**
	 * 查询报警器记录
	 * @param uid
	 * @param startTime
	 * @param endTime
	 */
	public void queryAlarmRecords(byte[] uid,String startTime,String endTime);
	/**
	 * 查询报警器记录回调
	 */
	public void queryAlarmRecords_callBack(List<AlarmRecordsInfo> list);
	
	/**
	 * 删除记录 
	 */
	public void deleteAlarmRecords(byte[] uid,List<Integer> recordIds);
	
	/**
	 *设备紧急报警推送
	 *alarmType: 0x01 异常报警, 0x02 低电报警,0x03 钥匙非法开锁报警
	 */
	public void deviceEmergencyAlarmPush(byte[] uid,int alarmType);
	
	
	
	
	/******************************k1锁相关接口********************************/
	/**
	 * k1查看设备状态
	 * stypes:状态类型数组，状态类型如下
	 * 状态类型： 1-在线状态	2-开关状态  3-电量状态  4-室内反锁状态  5-上提反锁状态  6-网关互动开关状态
	 * */
	public void getK1DeviceStates(byte[] uid,List<Integer> stypes);
	
	/**
	 * k1查看设备状态回调
	 * @param uid
	 */
	public void getK1DeviceStates_callBack(byte[] uid,Map<Integer, String> stateMap);
	
	/**
	 * k1锁上报设备状态
	 * stype 状态类型： 1-在线状态	2-开关状态  3-电量状态  4-室内反锁状态  5-上提反锁状态  6-网关互动开关状态 7-室外开锁
					8-室内开锁  10-锁重置状态上报  11-敲门事件上报  12-开关门事件上报
	 */
	public void reportk1State(byte[] uid,Integer stype,String stateValue);
	
	/**
	 * k1异常报警信息推送
	 * code:报警码 1-密码错误 2-指纹错误 3-暴力破坏 4-常开报警 5-钥匙非法开锁报警 6-低电报警  7-防挟持开锁报警 8-姿态报警
	 */
	public void reportK1Abnormal(byte[] uid,Integer code,String memberName);
	
	/**
	 * 查看当前 APP  开锁钥匙 ID
	 */
	public void getK1KeysId(byte[] uid,String username);
	
	/**
	 * 查看当前 APP  开锁钥匙 ID回调
	 */
	public void getK1KeysId_callBack(byte[] uid,String username,Integer keysId);
	
	/**
	 * 查询成员列表
	 */
	public void getK1Member(byte[] uid);
	/**
	 * 查询成员列表回调
	 */
	public void getK1Member_callBack(List<K1MemberInfo> members);
	
	/**
	 * 添加成员
	 */
	public void addK1Member(byte[] uid,K1MemberInfo member);
	/**
	 * 添加成员回调
	 */
	public void addK1Member_callBack(Integer state,Integer memberId,String memberName);
	
	/**
	 * 删除成员
	 */
	public void deleteK1Member(byte[] uid,Integer memberId); 
	/**
	 * 删除成员回调
	 */
	public void deleteK1Member_callBack(Integer state); 
	
	/**
	 * 修成成员名称
	 */
	public void updateK1MemberName(byte[] uid,Integer memberId,String memberName);
	/**
	 * 修成成员名称回调
	 */
	public void updateK1MemberName_callBack(Integer state);
	
	/**
	 * 查询成员详细信息
	 */
	public void getK1MemberInfo(byte[] uid,Integer memberId);
	/**
	 * 查询成员详细信息
	 */
	public void getK1MemberInfo_callBack(K1MemberDetailsInfo info);
	
	/**
	 * 添加钥匙
	 * 注：本接口仅适用于添加指纹、密码、防挟持密码
			keyType钥匙类型： 0-密码 1-网络 2-指纹 3-卡 4-防挟持密码 5-防挟持指纹
			password密码：仅用于密码类型和防挟持密码类型
	 */
	public void addK1Key(byte[] uid,Integer memberId,Integer keyType,String password);
	/**
	 * 添加钥匙回调
	 */
	public void addK1Key_callBack(Integer state);
	
	/**
	 * 指纹钥匙录入上报
	 * state状态： 0-成功 1-失败,2指纹重复
	   number录入次数：1-第一次 2-第二次 ... 0xFF-录入完成
	 */
	public void reportFingerprintState(byte[] uid,Integer memberId,Integer keyType,Integer keyId,Integer state,Integer number);
	
	/**
	 * 删除钥匙
	 * 本接口仅适用于删除指纹、密码、防挟持密码、防挟持指纹
		keyType钥匙类型： 0-密码 1-网络 2-指纹 3-卡 4-防挟持密码 5-防挟持指纹
	 */
	public void deteteK1Key(byte[] uid,Integer memberId,Integer keyType,Integer keyId);
	/**
	 * 删除钥匙回调
	 */
	public void deteteK1Key_callBack(Integer state);
	
	/**
	 * 修改密码
	 * 本接口仅适用于修改密码和防挟持密码
		keyType钥匙类型： 0-密码 1-网络 2-指纹 3-卡 4-防挟持密码 5-防挟持指纹
	 */
	public void updateK1Password(byte[] uid,Integer memberId,Integer keyType,Integer keyId,String password);
	/**
	 * 修改密码回调
	 */
	public void updateK1Password_callBack(Integer state);
	
	/**
	 * 修改指纹名称
	 */
	public void updateK1FingerprintName(byte[] uid,Integer memberId,Integer keyType,Integer keyId,String kname);
	/**
	 * 修改指纹名称
	 * 本接口仅适用于修改指纹名称
	 */
	public void updateK1FingerprintName_callBack(Integer state);
	
	/**
	 * 查询记录列表
	 * type事件类型： 0-所有记录 1-开锁记录 2-异常记录
		page页码：表示开始查询的页数，默认从 1 开始。
		pageSize最大数量：每一页记录的最大条数，默认为 16 条，最大不超过 32 条
		startTime起始时间：按时间查询的起始值
		endTime终止时间：按时间查询的终止值
	 */
	public void getK1RecordList(byte[] uid,Integer type,Integer page,Integer pageSize,String startTime,String endTime);
	/**
	 * 查询记录列表回调
	 */
	public void getK1RecordList_callBack(byte[] uid,Integer page,List<K1RecordInfo> infos);
	
	/**
	 * 删除记录
	 */
	public void deleteK1Record(byte[] uid,int type,List<Integer> ids);
	/**
	 * 删除记录回调
	 */
	public void deleteK1Record_callBack(Integer state);
	
	/**
	 * 解除当前警报
	 */
	public void relieveAlarm(byte[] uid,Integer type,Integer recordId);
	/**
	 * 解除当前警报回调
	 */
	public void relieveAlarm_callBack(Integer state);
	
	/**
	 * 添加临时密码
	 */
	public void addK1TemPassword(byte[] uid,String name,String number,String password);
	/**
	 * 添加临时密码回调
	 * id 记录 ID：每添加一个临时密码，新增一条记录
		pwdId密码 ID：对应锁端 ID
		state密码状态 0-正常 1-已使用 2-已取消 3-已过期
	 */
	public void addK1TemPassword_callBack(Integer states,byte[] uid,String name,String number,Integer id,Integer pwdId,Integer state,String addTime);
	
	/**
	 * 删除临时密码
	 */
	public void deleteK1TemPassword(byte[] uid,Integer pwdId);
	/**
	 * 删除临时密码回调
	 */
	public void deleteK1TemPassword_callBack(Integer state);
	
	/**
	 * 查看临时密码列表
	 */
	public void getK1TemPassworkList(byte[] uid,Integer page,Integer pageSize);
	
	/**
	 * 查看临时密码列表回调
	 */
	public void getK1TemPassworkList_callBack(byte[] uid,Integer page,List<K1TemPassworkInfo> infos);
	
	/**
	 * 删除临时密码记录
	 */
	public void deleteTemPasswordRecords(byte[] uid,List<Integer> ids);
	/**
	 * 删除临时密码记录回调
	 */
	public void deleteTemPasswordRecords_callBack(Integer state);
	
	/**
	 * 防劫持上报
	 * 注：code报警码 	1-防挟持开锁报警 
		uname成员名称：被挟持成员名称
		phones 电话1~n：待接收短信通知的手机号码

	 */
	public void reportHijack(byte[] uid,Integer code,String uname,List<String> phones);
	
	/**
	 * 读取门锁信息
	 * type类型  1-ZigBee Mac地址
		2-BLE Mac地址
		3-机芯码
		4-Zigbee 软件版本号 

	 */
	public void getK1Infos(byte[] uid,Integer type);
	/**
	 * 读取门锁信息回调
	 */
	public void getK1Infos_callBack(byte[] uid,String value);
	
	/**
	 * 门锁升级请求
	 */
	public void upgradeK1Request(byte[] uid,int version);
	/**
	 * 门锁升级请求回调
	 */
	public void upgradeK1Request_callBack(Integer state);
	
	/**
	 * 门锁升级上报
	 */
	public void reportUpgradeK1(int version);
	
	/**
	 * 验证原始密码
	 */
	public void vilidateK1Pwd(byte[] uid,int memberId,int keyType,int keyId,String pwd);
	/**
	 * 验证原始密码回调
	 */
	public void vilidateK1Pwd_callBack(int state);
	
	/**
	 * 配置wifi信息
	 * subCmd：0x01-query wifi info
		0x02-set wifi info
	 */
	public void configurWIFIInfo(int subCmd,String ssid,String pwd);
	/**
	 * 配置wifi信息回调
	 */
	public void configurWIFIInfo_callBack(int state,int subCmd,String ssid,String pwd);
	
	/**
	 * 搜索wifi
	 */
	public void searchWifi();
	/**
	 * 搜索wifi回调
	 */
	public void searchWifi_callBack(List<String> list);
	
	/**
	 * 门锁升级进度上报
	 */
	public void reportUpgradeSpeed(byte[] uid,int Speed);
	
	/**
	 * M1通知
	 */
	public void reportM1Notice(int ntype,String sn);
	
	/**
	 * 3D模块设置,3D角度查询
	 * type: 目前1 3d模块初始化   2为角度查询
	 * value : value目前只传1
	 */
	public void set3DModule(byte[] uid,Integer type,Integer value);
	
	/**
	 * 3D模块设置回调
	 */
	public void set3DModule_callback(Integer state,Integer type,Integer value);
	
	/**
	 * 带3D角度的记录查询
	 * type事件类型： 0-所有记录 1-开锁记录 2-异常记录
		page页码：表示开始查询的页数，默认从 1 开始。
		pageSize最大数量：每一页记录的最大条数，默认为 16 条，最大不超过 32 条
		startTime起始时间：按时间查询的起始值
		endTime终止时间：按时间查询的终止值
	 */
	public void getK1RecordListAnd3D(byte[] uid,Integer type,Integer page,Integer pageSize,String startTime,String endTime);
}
