package com.b_noble.n_life.handler;

import java.io.UnsupportedEncodingException;
import java.security.InvalidAlgorithmParameterException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;

import javax.crypto.BadPaddingException;
import javax.crypto.IllegalBlockSizeException;
import javax.crypto.NoSuchPaddingException;

import com.b_noble.n_life.BaseApplication;
import com.b_noble.n_life.Serial;
import com.b_noble.n_life.event.CmdTypeEnum;
import com.b_noble.n_life.handler.processing.GaHandlerProcessing;
import com.b_noble.n_life.handler.processing.IrHandlerProcessing;
import com.b_noble.n_life.handler.processing.WifiHandlerProcessing;
import com.b_noble.n_life.utils.Global;
import com.b_noble.n_life.utils.SymmetricEncoder;
import com.b_noble.n_life.utils.Test16Binary;

import io.netty.buffer.ByteBuf;
import io.netty.buffer.Unpooled;
import io.netty.channel.ChannelHandlerContext;
import io.netty.channel.ChannelInboundHandlerAdapter;

/**
 * @公司：深圳市中泰智丰物联网科技有限公司
 * @项目：智能家居
 * @简述：客户端handler
 * @作者：zhangfan @date：2016-08-02 @版本：V0.0.1
 */
public class ClientHandler extends ChannelInboundHandlerAdapter  {

	public void channelActive(ChannelHandlerContext ctx) throws Exception {
		
		Global.result = 1;
		Global.group.add(ctx.channel());
		Serial s = BaseApplication.getInstance();
		s.clientActive();
		
	}

	public void channelRead(ChannelHandlerContext ctx, Object msg) {

		ByteBuf buf = (ByteBuf) msg;

		int count = buf.readableBytes();
		byte[] b = new byte[count];
		
		if (count >= 4) {
			byte header = buf.readByte();
			short totalLength = buf.readShort();
			
			//sn
			byte[] sn = new byte[8];
			buf.readBytes(sn);
			
			//clientid
			buf.readInt();
			
			//seqNumber
			buf.readShort();
			//cmdType
			byte cmdType = buf.readByte();
			
			int responseType = buf.readUnsignedByte();

			byte state = buf.readByte();
			byte[] paramter = new byte[totalLength-22];
			byte[] crc16 = new byte[2];
			buf.readBytes(paramter);
			buf.readBytes(crc16);
			
			//解密
			try {
				if (cmdType == 0) {
					paramter = SymmetricEncoder.aesDecryptBytes(paramter, SymmetricEncoder.AES.getBytes());
				}
			} catch (Exception e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			} 
			
			//System.out.println("响应指令paramter："+Test16Binary.bytes2hex03(new byte[]{(byte) responseType})+"\n" + Test16Binary.bytes2hex03(paramter));
			
			ByteBuf heapBuf = Unpooled.buffer(paramter.length+2); 
			
			heapBuf.writeByte(state);
			heapBuf.writeBytes(paramter);
			heapBuf.writeBytes(crc16);
			
			if (totalLength == count && cmdType == CmdTypeEnum.GA.getVal()) {
				GaHandlerProcessing.processing(responseType, heapBuf);
			}else if(totalLength == count && cmdType == CmdTypeEnum.IR.getVal()){
				IrHandlerProcessing.processing(responseType, heapBuf,sn);
			}else if(totalLength == count && cmdType == CmdTypeEnum.WIFI.getVal()){
				WifiHandlerProcessing.processing(responseType, heapBuf,sn);
			}
		}

		/**
		 * 接收原始指令
		 */
		byte[] yb = new byte[count];

		buf.resetReaderIndex();
		for (int i = 0; i < count; i++) {
			yb[i] = buf.readByte();
		}
		System.out.println("响应指令：\n" + Test16Binary.bytes2hex03(yb));

	}

	public void handlerRemoved(ChannelHandlerContext ctx) {

		System.out.println("handlerRemoved(链接关闭)");
		
		Global.buf = "";
		if (Global.group.size() > 0) {

			Global.group.close();
			Global.group.clear();
		}
		BaseApplication.getInstance().clientClose();

	}

	public void exceptionCaught(ChannelHandlerContext ctx, Throwable throwable) {
		// 释放资源
		System.out.println("exceptionCaught:" + throwable.getMessage());

		Global.buf = "";
		if (Global.group.size() > 0) {
			Global.group.close();
			Global.group.clear();
		}

		ctx.close();
	}

}
