package com.b_noble.n_life.handler;

import java.util.Arrays;

import com.b_noble.n_life.event.CmdTypeEnum;
import com.b_noble.n_life.event.IrControlTypeEnum;
import com.b_noble.n_life.handler.processing.GaEncoderProcessing;
import com.b_noble.n_life.handler.processing.IrEncoderProcessing;
import com.b_noble.n_life.handler.processing.WifiEncoderProcessing;
import com.b_noble.n_life.model.RequestHead;
import com.b_noble.n_life.model.RequestMessage;
import com.b_noble.n_life.utils.Global;
import com.b_noble.n_life.utils.SymmetricEncoder;
import com.b_noble.n_life.utils.Test16Binary;

import io.netty.buffer.ByteBuf;
import io.netty.buffer.Unpooled;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.MessageToByteEncoder;

/**
 * 公司：深圳市中泰智丰物联网科技有限公司
 * 项目：智能家居
 * 简述：请求消息编码类
 * 作者：zhangfan
 * 时间：2016-08-02
 * 版本：V0.0.1
 */
public class Encoder extends MessageToByteEncoder<Object> {

	
	@Override
	protected void encode(ChannelHandlerContext ctx, Object msg, ByteBuf rbuf) throws Exception {

		
		RequestMessage requestMessage = (RequestMessage) msg;

		RequestHead head = requestMessage.getHeader();
		
		ByteBuf buf = Unpooled.buffer(head.getLength()+4);
		

		buf.writeByte(head.getHeader());
		
		buf.writeShort(head.getLength()+4);

		buf.writeBytes(head.getSncode().getBytes());
		
		buf.writeInt(Global.userid);
		
		//自生成序列号
		buf.writeShort(head.getSeqNumber());
		
		buf.writeByte(head.getControlMark());

		buf.writeByte(head.getControlType());

		if(head.getControlMark() == CmdTypeEnum.GA.getVal()){
			GaEncoderProcessing.processing(requestMessage, buf);
		}else if(head.getControlMark() == CmdTypeEnum.IR.getVal()){
			IrEncoderProcessing.processing(requestMessage, buf);
		}else if(head.getControlMark() == CmdTypeEnum.WIFI.getVal()){
			WifiEncoderProcessing.processing(requestMessage, buf);
		}
		
		/**
		 * 输出发送指令
		 */
		byte[] header = new byte[20];
		byte[] paramter = new byte[head.getLength()+4-22];
		byte[] crc16 = new byte[2];
		buf.readBytes(header);
		buf.readBytes(paramter);
		buf.readBytes(crc16);
		
		//System.out.println("发送指令paramter：\n"+Test16Binary.bytes2hex03(paramter));
		
		//加密
		int totalLength =head.getLength()+4;
		if (head.getControlMark()==0) {
			paramter = SymmetricEncoder.aesEncryptBytes(paramter, SymmetricEncoder.AES.getBytes());
			totalLength =  22+paramter.length;
		}
		
		byte[] data = byteMerger(header, paramter);
		data = byteMerger(data, crc16);
		System.out.println("发送指令：\n"+Test16Binary.bytes2hex03(data));
		
		rbuf.writeByte(0xfe);
		rbuf.writeShort(totalLength);
		for (int i = 3; i < header.length; i++) {
			rbuf.writeByte(header[i]);
		}
		rbuf.writeBytes(paramter);
		rbuf.writeBytes(crc16);
		
		
		
	}
	
	/**
	 * 合并数组
	 */
	public static byte[] byteMerger(byte[] byte_1, byte[] byte_2) {
		byte[] byte_3 = new byte[byte_1.length + byte_2.length];
		System.arraycopy(byte_1, 0, byte_3, 0, byte_1.length);
		System.arraycopy(byte_2, 0, byte_3, byte_1.length, byte_2.length);
		return byte_3;
	}
	

}
