package com.b_noble.n_life.handler.processing;

import java.io.UnsupportedEncodingException;

import com.b_noble.n_life.info.LinkageCondition;
import com.b_noble.n_life.info.LinkageTask;
import com.b_noble.n_life.model.RequesUpdateTaskStateData;
import com.b_noble.n_life.model.Request3DModuleData;
import com.b_noble.n_life.model.RequestAddDeviceTimingTaskData;
import com.b_noble.n_life.model.RequestAddSenceData;
import com.b_noble.n_life.model.RequestAddTaskData;
import com.b_noble.n_life.model.RequestAddUserToGaDate;
import com.b_noble.n_life.model.RequestAlarmRecordsData;
import com.b_noble.n_life.model.RequestAreaData;
import com.b_noble.n_life.model.RequestBindDeviceData;
import com.b_noble.n_life.model.RequestConfigurWIFIInfoData;
import com.b_noble.n_life.model.RequestConfigurationElectricMotorData;
import com.b_noble.n_life.model.RequestDeleteDeviceData;
import com.b_noble.n_life.model.RequestDeleteDeviceTimingTaskData;
import com.b_noble.n_life.model.RequestDeleteSceneData;
import com.b_noble.n_life.model.RequestDeleteSceneMemberData;
import com.b_noble.n_life.model.RequestDeleteTaskData;
import com.b_noble.n_life.model.RequestDeleteUserFromGatewayData;
import com.b_noble.n_life.model.RequestDoorlockData;
import com.b_noble.n_life.model.RequestDoorlockUserData;
import com.b_noble.n_life.model.RequestGetColorTemperatureData;
import com.b_noble.n_life.model.RequestGetDeviceHueAndSatData;
import com.b_noble.n_life.model.RequestGetDeviceLevelData;
import com.b_noble.n_life.model.RequestGetDeviceStateData;
import com.b_noble.n_life.model.RequestGetDeviceTimingTaskData;
import com.b_noble.n_life.model.RequestGetSceneMemberData;
import com.b_noble.n_life.model.RequestGetSensorTaskByUidData;
import com.b_noble.n_life.model.RequestGetTaskBySceneIdData;
import com.b_noble.n_life.model.RequestGetTaskByUidData;
import com.b_noble.n_life.model.RequestGetTaskInfoData;
import com.b_noble.n_life.model.RequestGetTheOnlineStatusOfThClientData;
import com.b_noble.n_life.model.RequestGyDoorlockData;
import com.b_noble.n_life.model.RequestK1DeviceData;
import com.b_noble.n_life.model.RequestLinkageData;
import com.b_noble.n_life.model.RequestLoginGaByLanData;
import com.b_noble.n_life.model.RequestLoginValidateData;
import com.b_noble.n_life.model.RequestModifyPwdData;
import com.b_noble.n_life.model.RequestOpenOrCloseCurtainData;
import com.b_noble.n_life.model.RequestPermissionDoorlockData;
import com.b_noble.n_life.model.RequestQueryCurtainPositionData;
import com.b_noble.n_life.model.RequestQueryElectricInfoData;
import com.b_noble.n_life.model.RequestQueryElectricMotorStatusData;
import com.b_noble.n_life.model.RequestQueryPwdData;
import com.b_noble.n_life.model.RequestRecallSceneData;
import com.b_noble.n_life.model.RequestRollingBlindData;
import com.b_noble.n_life.model.RequestSetColorTemperatureData;
import com.b_noble.n_life.model.RequestSetDeviceColorData;
import com.b_noble.n_life.model.RequestSetDeviceLevelData;
import com.b_noble.n_life.model.RequestSetDeviceStateData;
import com.b_noble.n_life.model.RequestSetDlectricMotorDirectionData;
import com.b_noble.n_life.model.RequestSetDoorlockSwitchStateData;
import com.b_noble.n_life.model.RequestStopOperatingCurtainData;
import com.b_noble.n_life.model.RequestThermostatData;
import com.b_noble.n_life.model.RequestTimerTaskData;
import com.b_noble.n_life.model.RequestUpdateDeviceData;
import com.b_noble.n_life.model.RequestUpdateDeviceTimingTaskData;
import com.b_noble.n_life.model.RequestUpdateSceneNameData;
import com.b_noble.n_life.model.RequestUpdateTaskData;
import com.b_noble.n_life.model.RequestUpdateTimerTaskData;
import com.b_noble.n_life.model.RequestUpgradeDate;
import com.b_noble.n_life.model.RequestUserToGaDate;
import com.b_noble.n_life.model.RequestVerificationManagerPwdData;
import com.b_noble.n_life.model.SceneMemberInfo;
import com.b_noble.n_life.model.ScenePanelData;
import com.b_noble.n_life.utils.EffectiveTimeUtils;

import io.netty.buffer.ByteBuf;

/**
 * 公司：深圳市中泰智丰物联网科技有限公司 项目：智能家居 简述：编码处理实现类 作者：zhangfan 时间：2016-08-02 版本：V0.0.1
 */
public class GaEncoderProcessingRealization {

	/**
	 * 设定指定设备开关状态
	 */
	public static void setDeviceState(RequestSetDeviceStateData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getUid());

		buf.writeByte(data.getState());

		buf.writeShort(data.getTransitionTime());

		// tbd 8 bytes
		for (int i = 0; i < 8; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 添加场景
	 */
	public static void addSence(RequestAddSenceData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		try {
			buf.writeBytes(data.getSenceName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getSenceName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// 场景中设备个数totalDevices
		int size = data.getSmInfos().size();
		buf.writeByte(size);

		// shortAddress Endpoint
		for (int i = 0; i < size; i++) {

			SceneMemberInfo sminfo = data.getSmInfos().get(i);
			buf.writeBytes(sminfo.getUid());
			buf.writeByte(sminfo.getCommand());
			buf.writeBytes(sminfo.getData());
			buf.writeByte(sminfo.getDelayTime());
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 修改场景
	 * 
	 * @param data
	 * @param buf
	 */
	public static void modifyScene(RequestAddSenceData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(data.getSceneId());

		try {
			buf.writeBytes(data.getSenceName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getSenceName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// 场景中设备个数totalDevices
		int size = data.getSmInfos().size();
		buf.writeByte(size);

		// shortAddress Endpoint
		for (int i = 0; i < size; i++) {

			SceneMemberInfo sminfo = data.getSmInfos().get(i);
			buf.writeBytes(sminfo.getUid());
			buf.writeByte(sminfo.getCommand());
			buf.writeBytes(sminfo.getData());
			buf.writeByte(sminfo.getDelayTime());
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 调用场景
	 * 
	 * @param data
	 * @param buf
	 */
	public static void recallSence(RequestRecallSceneData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(data.getSceneid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 删除场景
	 * 
	 * @param data
	 * @param buf
	 */
	public static void deleteSence(RequestDeleteSceneData data, ByteBuf buf) {
		// TODO Auto-generated method stub

		// state
		buf.writeByte(0xff);

		buf.writeByte(data.getSceneid());
		try {
			buf.writeBytes(data.getSceneName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getSceneName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 添加传感器任务
	 * 
	 * @param data
	 * @param buf
	 */
	public static void addSensorTask(RequestAddTaskData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		// taskType
		buf.writeByte(data.getTaskType());

		System.out.println(data.getTaskName().getBytes().length);
		// taskName
		try {
			buf.writeBytes(data.getTaskName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getTaskName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// judgement
		// uid
		buf.writeBytes(data.getUid());
		// deviceID
		buf.writeBytes(data.getDeviceId());

		// Condition1
		buf.writeByte(data.getCondition1());
		// value1
		buf.writeByte(data.getValue1());
		// Condition2
		buf.writeByte(data.getCondition2());
		// value2
		buf.writeByte(data.getValue2());

		// TBD 7bytes
		for (int i = 0; i < 7; i++) {
			buf.writeByte(0x00);
		}

		// sceneID
		buf.writeByte(data.getSceneId());

		// enable
		buf.writeByte(data.getEnable());

		// alarm
		buf.writeByte(data.getAlarm());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 添加场景定时任务
	 * 
	 * @param data
	 * @param buf
	 */
	public static void addSceneTimerTask(RequestTimerTaskData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		// taskType
		buf.writeByte(data.getTaskType());

		// taskName
		try {
			buf.writeBytes(data.getTaskName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getTaskName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// judgement 18bytes
		// sceneID
		buf.writeShort(data.getSceneId());
		buf.writeByte(0x00);
		// minute
		buf.writeByte(data.getMinute());
		// hour
		buf.writeByte(data.getHour());
		// day
		buf.writeByte(data.getDay());
		// month
		buf.writeByte(data.getMonth());
		// week
		buf.writeByte(data.getWeek());

		// TBD 11bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

		// taskStatus
		buf.writeByte(0x01);

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 添加设备定时任务
	 * 
	 * @param data
	 * @param buf
	 */
	public static void addDeviceTimerTask(RequestTimerTaskData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		// taskType
		buf.writeByte(data.getTaskType());

		// taskName
		try {
			buf.writeBytes(data.getTaskName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getTaskName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// judgement 18bytes
		// uid
		buf.writeBytes(data.getUid());

		// minute
		buf.writeByte(data.getMinute());
		// hour
		buf.writeByte(data.getHour());
		// day
		buf.writeByte(data.getDay());
		// month
		buf.writeByte(data.getMonth());
		// week
		buf.writeByte(data.getWeek());

		// cmd
		buf.writeByte(data.getCmd());

		// TBD
		buf.writeBytes(data.getTbd());

		buf.writeByte(0x01);
		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 修改传感器任务
	 * 
	 * @param data
	 * @param buf
	 */
	public static void updateSensorTask(RequestUpdateTaskData data, ByteBuf buf) {
		// taskType
		buf.writeByte(data.getTaskType());

		// taskName
		try {
			buf.writeBytes(data.getTaskName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getTaskName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		buf.writeByte(data.getSceneId());

		// judgement
		// uid
		buf.writeBytes(data.getUid());
		// deviceID
		buf.writeBytes(data.getDeviceId());
		// Condition1
		buf.writeByte(data.getCondition1());
		// value1
		buf.writeByte(data.getValue1());
		// Condition2
		buf.writeByte(data.getCondition2());
		// value2
		buf.writeByte(data.getValue2());

		// TBD 7bytes
		for (int i = 0; i < 7; i++) {
			buf.writeByte(0x00);
		}

		// sceneID
		buf.writeByte(data.getSceneId());

		// enable
		buf.writeByte(data.getEnable());

		// alarm
		buf.writeByte(data.getAlarm());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 更新定时任务
	 * 
	 * @param data
	 * @param buf
	 */
	public static void updateTimerTask(RequestUpdateTimerTaskData data, ByteBuf buf) {

		// taskType
		buf.writeByte(data.getTaskType());

		// taskName
		try {
			buf.writeBytes(data.getTaskName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getTaskName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		buf.writeByte(data.getSceneId());

		// judgement 9bytes
		// week
		buf.writeByte(data.getWeek());
		// hour
		buf.writeByte(data.getHour());
		// minute
		buf.writeByte(data.getMinute());
		// Second
		buf.writeByte(data.getSecond());

		// 补位
		for (int i = 0; i < 5; i++) {
			buf.writeByte(0x00);
		}

		// TBD 7bytes
		for (int i = 0; i < 7; i++) {
			buf.writeByte(0x00);
		}

		// sceneID
		buf.writeByte(data.getSceneId());

		// enable
		buf.writeByte(data.getEnable());

		// alarm
		buf.writeByte(data.getAlarm());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 设置灯光亮度
	 * 
	 * @param data
	 * @param buf
	 */
	public static void setDeviceLevel(RequestSetDeviceLevelData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		// addressMode
		buf.writeByte(data.getAddressMode());

		// uid
		buf.writeBytes(data.getUid());

		// brightComand
		buf.writeByte(data.getLevelValue());

		// cutTime
		buf.writeShort(data.getSwitchTime());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 设置设备颜色（饱和度/色调）
	 * 
	 * @param data
	 * @param buf
	 */
	public static void setDeviceColor(RequestSetDeviceColorData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		// addressMode
		buf.writeByte(data.getAddressMode());

		// uid
		buf.writeBytes(data.getUid());

		// hue
		buf.writeByte(data.getHue());

		// saturation
		buf.writeByte(data.getSat());

		// cutTime
		buf.writeShort(data.getSwitchTime());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 设置设备色温
	 * 
	 * @param data
	 * @param buf
	 */
	public static void setColorTemperature(RequestSetColorTemperatureData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		// addressMode
		buf.writeByte(data.getAddressMode());

		// uid
		buf.writeBytes(data.getUid());

		// colorTemperature
		buf.writeShort(data.getColorTemperature());

		// cutTime
		buf.writeShort(data.getSwitchTime());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 删除指定任务
	 * 
	 * @param data
	 * @param buf
	 */
	public static void deleteTask(RequestDeleteTaskData data, ByteBuf buf) {
		// TODO Auto-generated method stub

		// state
		buf.writeByte(0xff);

		int totalTasks = data.getTaskids().size();
		buf.writeByte(totalTasks);

		for (int i = 0; i < totalTasks; i++) {
			// taskID
			buf.writeShort(data.getTaskids().get(i));
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 获取设备开关状态
	 * 
	 * @param data
	 * @param buf
	 */
	public static void getDeviceState(RequestGetDeviceStateData data, ByteBuf buf) {
		// TODO Auto-generated method stub

		buf.writeByte(0xff);

		// addressMode
		buf.writeByte(data.getAddressMode());

		// shortAddress Endpoint
		buf.writeBytes(data.getUid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 删除指定设备
	 * 
	 * @param data
	 * @param buf
	 */
	public static void deleteDevice(RequestDeleteDeviceData data, ByteBuf buf) {
		// TODO Auto-generated method stub

		// state
		buf.writeByte(0xff);

		// addressMode
		buf.writeByte(data.getAddressMode());

		// shortAddress Endpoint
		buf.writeBytes(data.getUid());

		// ieee
		buf.writeBytes(data.getIeeeAddress());
		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 更新设备名称
	 * 
	 * @param data
	 * @param buf
	 */
	public static void updateDeviceName(RequestUpdateDeviceData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		// addressMode
		buf.writeByte(data.getAddressMode());

		// shortAddress Endpoint
		buf.writeBytes(data.getUid());
		// deviceName
		try {
			buf.writeBytes(data.getDeviceName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getDeviceName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 获取设备亮度
	 * 
	 * @param data
	 * @param buf
	 */
	public static void getDeviceLevel(RequestGetDeviceLevelData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		// addressMode
		buf.writeByte(data.getAddressMode());

		// shortAddress Endpoint
		buf.writeBytes(data.getUid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 获取设备色调与饱和度
	 * 
	 * @param data
	 * @param buf
	 */
	public static void getDeviceHueAndSat(RequestGetDeviceHueAndSatData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		// addressMode
		buf.writeByte(data.getAddressMode());

		// shortAddress Endpoint
		buf.writeBytes(data.getUid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 获取设备色温
	 * 
	 * @param data
	 * @param buf
	 */
	public static void getColorTemperature(RequestGetColorTemperatureData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		// addressMode
		buf.writeByte(data.getAddressMode());

		// shortAddress Endpoint
		buf.writeBytes(data.getUid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 更新场景名称
	 * 
	 * @param data
	 * @param buf
	 */
	public static void updateSceneName(RequestUpdateSceneNameData data, ByteBuf buf) {
		// TODO Auto-generated method stub

		// state
		buf.writeByte(0xff);

		// sceneID
		buf.writeByte(data.getSceneid());

		try {
			buf.writeBytes(data.getSceneName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getSceneName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 获取场景成员
	 * 
	 * @param data
	 * @param buf
	 */
	public static void getSceneMember(RequestGetSceneMemberData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		// sceneID
		buf.writeByte(data.getSceneID());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 删除指定场景成员
	 * 
	 * @param data
	 * @param buf
	 */
	public static void delteteSceneMember(RequestDeleteSceneMemberData data, ByteBuf buf) {

		// sceneID
		buf.writeByte(data.getSceneID());

		// sceneName
		try {
			buf.writeBytes(data.getSceneName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getSceneName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// totalDelDevices
		buf.writeByte(data.getUids().size());

		// shortAddress endPoint
		for (int i = 0; i < data.getUids().size(); i++) {
			buf.writeBytes(data.getUids().get(i));
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 添加设备到场景
	 * 
	 * @param data
	 * @param buf
	 *            升级后去除掉
	 */
	/*
	 * public static void addDeviceToScene(RequestAddDeviceToSenceData data,
	 * ByteBuf buf) { // TODO Auto-generated method stub // sceneID
	 * buf.writeByte(data.getSceneID());
	 * 
	 * // totalAdddevices buf.writeByte(data.getTotalAdddevices());
	 * 
	 * // shortAddress endPoint for (int i = 0; i < data.getTotalAdddevices();
	 * i++) { buf.writeBytes(data.getUids().get(i)); }
	 * 
	 * // delayTime buf.writeByte(data.getDelayTime());
	 * 
	 * // tbd 8 bytes for (int i = 0; i < 10; i++) { buf.writeByte(0x00); }
	 * 
	 * }
	 */

	/**
	 * 获取任务详细
	 * 
	 * @param data
	 * @param buf
	 */
	public static void getTaskInfo(RequestGetTaskInfoData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		// taskType
		buf.writeByte(data.getTaskType());

		buf.writeByte(data.getTaskId());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 获取指定场景定时任务
	 * 
	 * @param data
	 * @param buf
	 */
	public static void getTimerTaskBySceneId(RequestGetTaskBySceneIdData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		// taskType
		buf.writeByte(data.getTaskType());

		// sceneid
		buf.writeByte(data.getSceneId());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 获取指定设备任务
	 */
	public static void getTaskByUId(RequestGetTaskByUidData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		// taskType
		buf.writeByte(data.getTaskType());

		// uid
		buf.writeBytes(data.getUid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 添加设备定时任务
	 * 
	 * @param data
	 * @param buf
	 */
	public static void addDeviceTimingTask(RequestAddDeviceTimingTaskData data, ByteBuf buf) {

		// timingName
		try {
			buf.writeBytes(data.getTimingName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getTimingName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// uid
		buf.writeBytes(data.getUid());

		// week
		buf.writeByte(data.getTaskTimerAction().getWorkMode());
		// hour
		buf.writeByte(data.getTaskTimerAction().getH());
		// minute
		buf.writeByte(data.getTaskTimerAction().getM());
		// second
		buf.writeByte(data.getTaskTimerAction().getS());

		// switch
		buf.writeByte(data.getSwitchState());

		// brightness
		buf.writeByte(data.getBrightness());

		// hue
		buf.writeByte(data.getHue());

		// saturation
		buf.writeByte(data.getSaturation());

		// colorTemperature
		buf.writeByte(data.getColorTemperature());

		// enable
		buf.writeByte(data.getIsenable());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 删除指定设备定时任务
	 * 
	 * @param data
	 * @param buf
	 */
	public static void deleteDeviceTimingTask(RequestDeleteDeviceTimingTaskData data, ByteBuf buf) {

		buf.writeByte(data.getTimingID());

		buf.writeByte(data.getCheckCode());

		buf.writeByte(data.getCRC8());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 更新设备定时任务
	 * 
	 * @param data
	 * @param buf
	 */
	public static void updateDeviceTimingTask(RequestUpdateDeviceTimingTaskData data, ByteBuf buf) {

		// timingId
		buf.writeByte(data.getTimingId());

		// timingName
		try {
			buf.writeBytes(data.getTimingName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getTimingName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// week
		buf.writeByte(data.getTaskTimerAction().getWorkMode());
		// hour
		buf.writeByte(data.getTaskTimerAction().getH());
		// minute
		buf.writeByte(data.getTaskTimerAction().getM());
		// second
		buf.writeByte(data.getTaskTimerAction().getS());

		// switch
		buf.writeByte(data.getSwitchState());

		// brightness
		buf.writeByte(data.getBrightness());

		// hue
		buf.writeByte(data.getHue());

		// saturation
		buf.writeByte(data.getSaturation());

		// colorTemperature
		buf.writeByte(data.getColorTemperature());

		// enable
		buf.writeByte(data.getIsenable());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 获取设备定时任务
	 * 
	 * @param data
	 * @param buf
	 */
	public static void getDeviceTimingTask(RequestGetDeviceTimingTaskData data, ByteBuf buf) {
		// TODO Auto-generated method stub

		buf.writeBytes(data.getUid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 获取指定设备的联动任务
	 * 
	 * @param data
	 * @param buf
	 */
	public static void getSensorTaskByUid(RequestGetSensorTaskByUidData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(data.getUid()[2]);

		buf.writeByte(data.getUid()[0]);
		buf.writeByte(data.getUid()[1]);

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void loginValidate(RequestLoginValidateData data, ByteBuf buf) {
		// TODO Auto-generated method stub

		buf.writeByte(data.getState());

		buf.writeBytes(data.getSn().getBytes());

		buf.writeBytes(data.getToken().getBytes());

		// username
		try {
			buf.writeBytes(data.getLoginName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getLoginName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void verificationManagerPwd(RequestVerificationManagerPwdData data, ByteBuf buf) {

		buf.writeByte(data.getState());

		// username
		try {
			buf.writeBytes(data.getUsername().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getUsername().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// pwd
		try {
			buf.writeBytes(data.getManagerPwd().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getManagerPwd().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void modifyPwd(RequestModifyPwdData data, ByteBuf buf) {

		buf.writeByte(data.getState());

		// username
		try {
			buf.writeBytes(data.getUsername().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getUsername().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// oldpwd
		try {
			buf.writeBytes(data.getOldPwd().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getOldPwd().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// newpwd
		try {
			buf.writeBytes(data.getNewPwd().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getNewPwd().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void loginGaByLan(RequestLoginGaByLanData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(data.getState());

		// username
		try {
			buf.writeBytes(data.getUserName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getUserName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// pwd
		try {
			buf.writeBytes(data.getPassWord().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getPassWord().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void bindGa(RequestUserToGaDate data, ByteBuf buf) {
		// TODO Auto-generated method stub
		// state
		buf.writeByte(0xff);

		// sn
		buf.writeBytes(data.getSn().getBytes());

		// username
		try {
			buf.writeBytes(data.getUsername().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getUsername().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// password
		try {
			buf.writeBytes(data.getPassword().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getPassword().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void addUserToGa(RequestAddUserToGaDate data, ByteBuf buf) {
		// state
		buf.writeByte(0xff);

		// username
		try {
			buf.writeBytes(data.getUsername().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getUsername().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// password
		try {
			buf.writeBytes(data.getPassword().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getPassword().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void queryPwd(RequestQueryPwdData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		// state
		buf.writeByte(0xff);
		// pwdType
		buf.writeByte(data.getPwdType());
		// username
		try {
			buf.writeBytes(data.getUsername().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getUsername().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	/**
	 * 增加场景联动任务
	 * 
	 * @param data
	 * @param buf
	 */
	public static void addSceneLinkageTask(RequestLinkageData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);

		// linkageType
		buf.writeByte(data.getLinkageType());

		// linkageName
		try {
			buf.writeBytes(data.getLinkageName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getLinkageName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		buf.writeByte(data.getConditionList().size());
		for (LinkageCondition c : data.getConditionList()) {
			buf.writeByte(c.getConditionType());
			if (c.getConditionType() == 1) {
				buf.writeBytes(c.getUid());
				buf.writeByte(c.getSymbol());
				buf.writeByte(c.getValue());

				buf.writeByte(0);
				buf.writeByte(0);
				buf.writeByte(0);
			}
			if (c.getConditionType() == 2) {
				buf.writeByte(c.getMonth());
				buf.writeByte(c.getDay());
				buf.writeByte(c.getWeekdays());
				buf.writeByte(c.getSymbol());
				buf.writeByte(c.getHour());
				buf.writeByte(c.getMinute());

				buf.writeByte(0);
				buf.writeByte(0);
			}
		}

		buf.writeByte(data.getTaskList().size());
		for (LinkageTask task : data.getTaskList()) {
			buf.writeShort(task.getSceneid());

			buf.writeByte(0);
			buf.writeByte(0);
			buf.writeByte(0);

			buf.writeByte(task.getDelay());

			buf.writeByte(0);
			buf.writeByte(0);
		}

		buf.writeByte(data.getLinkageStatus());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void addDeviceLinkageTask(RequestLinkageData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);

		// linkageType
		buf.writeByte(data.getLinkageType());

		// linkageName
		try {
			buf.writeBytes(data.getLinkageName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getLinkageName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		buf.writeByte(data.getConditionList().size());
		for (LinkageCondition c : data.getConditionList()) {
			buf.writeByte(c.getConditionType());
			if (c.getConditionType() == 1) {
				buf.writeBytes(c.getUid());
				buf.writeByte(c.getSymbol());
				buf.writeByte(c.getValue());

				buf.writeByte(0);
				buf.writeByte(0);
				buf.writeByte(0);
			}
			if (c.getConditionType() == 2) {
				buf.writeByte(c.getMonth());
				buf.writeByte(c.getDay());
				buf.writeByte(c.getWeekdays());
				buf.writeByte(c.getSymbol());
				buf.writeByte(c.getHour());
				buf.writeByte(c.getMinute());

				buf.writeByte(0);
				buf.writeByte(0);
			}
		}

		buf.writeByte(data.getTaskList().size());
		for (LinkageTask task : data.getTaskList()) {

			buf.writeBytes(task.getUid());
			buf.writeByte(task.getCmd());
			buf.writeByte(task.getValue());
			buf.writeByte(task.getDelay());

			buf.writeByte(0);
			buf.writeByte(0);
		}

		buf.writeByte(data.getLinkageStatus());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void deleteLinkageTask(RequestDeleteTaskData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeByte(data.getTaskids().size());

		for (int i = 0; i < data.getTaskids().size(); i++) {
			buf.writeShort(data.getTaskids().get(i));
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void getLinkageTaskInfo(RequestLinkageData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);

		buf.writeShort(data.getLinkageId());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void getLinkageScene(RequestGetTaskBySceneIdData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);
		buf.writeByte(data.getSceneId());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void getLinkageDevice(RequestGetTaskByUidData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);
		buf.writeBytes(data.getUid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void addArea(RequestAreaData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);

		// areaName
		try {
			buf.writeBytes(data.getAreaName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getAreaName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// totals
		buf.writeByte(data.getTotals());

		for (int i = 0; i < data.getTotals(); i++) {
			// memberType
			buf.writeByte(data.getMemberType());

			// uid
			buf.writeBytes(data.getUids().get(i));

			// tbd
			for (int j = 0; j < 8; j++) {
				buf.writeByte(0x00);
			}

		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void deleteArea(RequestAreaData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);

		buf.writeByte(data.getAreaId());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void getAreaDetails(RequestAreaData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);

		buf.writeByte(data.getAreaId());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void getAllArea(RequestAreaData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);
		buf.writeByte(0x00);

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void updateTaskState(RequesUpdateTaskStateData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);
		buf.writeShort(data.getTaskId());
		buf.writeByte(data.getTaskType());
		buf.writeByte(data.getState());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void setDlectricMotorDirection(RequestSetDlectricMotorDirectionData data, ByteBuf buf) {
		// TODO Auto-generated method stub

		buf.writeByte(0xff);
		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getUid());
		buf.writeByte(data.getDirection());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void configurationElectricMotor(RequestConfigurationElectricMotorData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);
		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getUid());

		// value
		if (data.getHandPull() == 0 && data.getLinkage() == 0) {
			buf.writeByte(0x00);
		} else if (data.getHandPull() == 0 && data.getLinkage() == 1) {
			buf.writeByte(0x01);
		} else if (data.getHandPull() == 1 && data.getLinkage() == 0) {
			buf.writeByte(0x10);
		} else if (data.getHandPull() == 1 && data.getLinkage() == 1) {
			buf.writeByte(0x11);
		}
		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void queryElectricInfo(RequestQueryElectricInfoData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);
		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getUid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryElectricMotorStatus(RequestQueryElectricMotorStatusData data, ByteBuf buf) {
		// TODO Auto-generated method stub

		buf.writeByte(0xff);
		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getUid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void openOrCloseCurtain(RequestOpenOrCloseCurtainData data, ByteBuf buf) {
		// TODO Auto-generated method stub

		buf.writeByte(0xff);
		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getUid());

		buf.writeByte(data.getValue());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void stopOperatingCurtain(RequestStopOperatingCurtainData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);
		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getUid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryCurtainPosition(RequestQueryCurtainPositionData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);
		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getUid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void setDoorlockSwitchState(RequestSetDoorlockSwitchStateData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		buf.writeByte(data.getState());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void quertDoorlockSwitchState(RequestSetDoorlockSwitchStateData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void setPermissionDoorlock(RequestPermissionDoorlockData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		buf.writeByte(data.getPremission());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryPermissionDoorlock(RequestPermissionDoorlockData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void addUserToDoorlock(RequestDoorlockUserData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		// effectiveTime
		buf.writeBytes(data.getEffectiveTime());

		// value
		try {
			buf.writeBytes(data.getValue().getBytes("gbk"));
		} catch (UnsupportedEncodingException e) {
		}

		// areaName
		try {
			buf.writeBytes(data.getUsername().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getUsername().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void deleteUserToDoorlock(RequestDoorlockUserData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		// userid
		buf.writeShort(data.getUserid());

		/*
		 * // value try { buf.writeBytes(data.getValue().getBytes("gbk")); }
		 * catch (UnsupportedEncodingException e) { // TODO Auto-generated catch
		 * block }
		 */

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void deleteUserFromGateway(RequestDeleteUserFromGatewayData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeByte(data.getUserLevel());

		// usernmae
		try {
			buf.writeBytes(data.getUsername().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getUsername().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		// pwd
		try {
			buf.writeBytes(data.getPwd().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getPwd().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void requestGaOrZigbeeVersion(RequestUpgradeDate data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeByte(data.getCommand());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void upgradeGaOrZigbee(RequestUpgradeDate data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeByte(data.getCommand());
		buf.writeShort(data.getVersion());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void requestTemperatureAndHumidity(ByteBuf buf) {
		buf.writeByte(0xff);

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void getTheOnlineStatusOfThClient(RequestGetTheOnlineStatusOfThClientData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeBytes(data.getSn().getBytes());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryDoorlockElectricity(RequestSetDoorlockSwitchStateData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void setUserName(RequestDoorlockData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		buf.writeShort(data.getUserid());

		// name
		try {
			buf.writeBytes(data.getName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryDoorUserInfos(RequestDoorlockData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryUnlockRecord(RequestDoorlockData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryUnlockRecordByTime(RequestDoorlockData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		buf.writeBytes(data.getStarttime());

		buf.writeBytes(data.getEndtime());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryAbnormalRecord(RequestDoorlockData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryAbnormalRecordByTime(RequestDoorlockData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		buf.writeBytes(data.getStarttime());

		buf.writeBytes(data.getEndtime());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void deleteUnlockRecord(RequestDoorlockData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		int totalRecords = data.getRecordIdList().size();

		buf.writeByte(totalRecords);

		for (int i = 0; i < totalRecords; i++) {
			buf.writeShort(data.getRecordIdList().get(i));
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void deleteAbnormalRecord(RequestDoorlockData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		int totalRecords = data.getRecordIdList().size();

		buf.writeByte(totalRecords);

		for (int i = 0; i < totalRecords; i++) {
			buf.writeShort(data.getRecordIdList().get(i));
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void SetTheLocktime(RequestDoorlockData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		buf.writeBytes(data.getStarttime());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void curtainStrokeControl(RequestRollingBlindData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		buf.writeByte(data.getValue());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void deleteStroke(RequestRollingBlindData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void updateDeviceTimerTask(RequestTimerTaskData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeShort(data.getTaskid());

		// taskType
		buf.writeByte(data.getTaskType());

		// taskName
		try {
			buf.writeBytes(data.getTaskName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getTaskName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// judgement 18bytes
		// uid
		buf.writeBytes(data.getUid());

		// minute
		buf.writeByte(data.getMinute());
		// hour
		buf.writeByte(data.getHour());
		// day
		buf.writeByte(data.getDay());
		// month
		buf.writeByte(data.getMonth());
		// week
		buf.writeByte(data.getWeek());

		// cmd
		buf.writeByte(data.getCmd());

		// TBD
		buf.writeBytes(data.getTbd());

		buf.writeByte(0x01);
		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void updateSceneTimerTask(RequestTimerTaskData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeShort(data.getTaskid());

		// taskType
		buf.writeByte(data.getTaskType());

		// taskName
		try {
			buf.writeBytes(data.getTaskName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getTaskName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// judgement 18bytes
		// sceneID
		buf.writeShort(data.getSceneId());
		buf.writeByte(0x00);
		// minute
		buf.writeByte(data.getMinute());
		// hour
		buf.writeByte(data.getHour());
		// day
		buf.writeByte(data.getDay());
		// month
		buf.writeByte(data.getMonth());
		// week
		buf.writeByte(data.getWeek());

		// TBD 11bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

		// taskStatus
		buf.writeByte(0x01);

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void updateTaskName(RequestTimerTaskData data, ByteBuf buf) {
		// state
		buf.writeByte(0xff);

		buf.writeShort(data.getTaskid());

		// taskType
		buf.writeByte(data.getTaskType());

		// taskName
		try {
			buf.writeBytes(data.getTaskName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getTaskName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void getDeviceTimerTask(RequestTimerTaskData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeByte(data.getTaskType());

		buf.writeBytes(data.getUid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void getSceneTimerTask(RequestTimerTaskData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(data.getTaskType());

		buf.writeShort(data.getSceneId());

		buf.writeByte(0x00);

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void moditySceneLinkageTask(RequestLinkageData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeShort(data.getLinkageId());
		// linkageType
		buf.writeByte(data.getLinkageType());

		// linkageName
		try {
			buf.writeBytes(data.getLinkageName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getLinkageName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		buf.writeByte(data.getConditionList().size());
		for (LinkageCondition c : data.getConditionList()) {
			buf.writeByte(c.getConditionType());
			if (c.getConditionType() == 1) {
				buf.writeBytes(c.getUid());
				buf.writeByte(c.getSymbol());
				buf.writeByte(c.getValue());

				buf.writeByte(0);
				buf.writeByte(0);
				buf.writeByte(0);
			}
			if (c.getConditionType() == 2) {
				buf.writeByte(c.getMonth());
				buf.writeByte(c.getDay());
				buf.writeByte(c.getWeekdays());
				buf.writeByte(c.getSymbol());
				buf.writeByte(c.getHour());
				buf.writeByte(c.getMinute());

				buf.writeByte(0);
				buf.writeByte(0);
			}
		}

		buf.writeByte(data.getTaskList().size());
		for (LinkageTask task : data.getTaskList()) {
			buf.writeShort(task.getSceneid());

			buf.writeByte(0);
			buf.writeByte(0);
			buf.writeByte(0);

			buf.writeByte(task.getDelay());

			buf.writeByte(0);
			buf.writeByte(0);
		}

		buf.writeByte(data.getLinkageStatus());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void modityDeviceLinkageTask(RequestLinkageData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeShort(data.getLinkageId());

		// linkageType
		buf.writeByte(data.getLinkageType());

		// linkageName
		try {
			buf.writeBytes(data.getLinkageName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getLinkageName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		buf.writeByte(data.getConditionList().size());
		for (LinkageCondition c : data.getConditionList()) {
			buf.writeByte(c.getConditionType());
			if (c.getConditionType() == 1) {
				buf.writeBytes(c.getUid());
				buf.writeByte(c.getSymbol());
				buf.writeByte(c.getValue());

				buf.writeByte(0);
				buf.writeByte(0);
				buf.writeByte(0);
			}
			if (c.getConditionType() == 2) {
				buf.writeByte(c.getMonth());
				buf.writeByte(c.getDay());
				buf.writeByte(c.getWeekdays());
				buf.writeByte(c.getSymbol());
				buf.writeByte(c.getHour());
				buf.writeByte(c.getMinute());

				buf.writeByte(0);
				buf.writeByte(0);
			}
		}

		buf.writeByte(data.getTaskList().size());
		for (LinkageTask task : data.getTaskList()) {

			buf.writeBytes(task.getUid());
			buf.writeByte(task.getCmd());
			buf.writeByte(task.getValue());
			buf.writeByte(task.getDelay());

			buf.writeByte(0);
			buf.writeByte(0);
		}

		buf.writeByte(data.getLinkageStatus());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void updateLinkageName(RequestLinkageData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeShort(data.getLinkageId());

		// linkageType
		buf.writeByte(data.getLinkageType());

		// linkageName
		try {
			buf.writeBytes(data.getLinkageName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getLinkageName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void updateLinkageStutus(RequestLinkageData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeShort(data.getLinkageId());

		// linkageType
		buf.writeByte(data.getLinkageType());

		buf.writeByte(data.getLinkageStatus());

		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryAllGaLinkage(ByteBuf buf) {

		buf.writeByte(0xff);

		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryGaLinkageByUid(RequestGetTaskByUidData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);

		buf.writeBytes(data.getUid());

		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void deviceKeyConfigure(ScenePanelData data, ByteBuf buf) {
		buf.writeByte(0xff);
		buf.writeByte(0x02);

		buf.writeBytes(data.getKeyUid());

		buf.writeByte(data.getTaskType());

		buf.writeByte(data.getTaskList().size());

		for (int i = 0; i < data.getTaskList().size(); i++) {
			if (data.getTaskType() == 1) {
				buf.writeBytes(data.getTaskList().get(i).getUid());
				buf.writeByte(data.getTaskList().get(i).getCmd());
				buf.writeByte(data.getTaskList().get(i).getValue());
				buf.writeByte(data.getTaskList().get(i).getDelay());
				buf.writeByte(0x00);
				buf.writeByte(0x00);
			} else {
				buf.writeShort(data.getTaskList().get(i).getSceneid());
				buf.writeByte(0x00);
				buf.writeByte(0x00);
				buf.writeByte(0x00);
				buf.writeByte(data.getTaskList().get(i).getDelay());
				buf.writeByte(0x00);
				buf.writeByte(0x00);
			}
		}

		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void deleteConfigureOfDeviceKey(ScenePanelData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);
		buf.writeByte(0x02);

		buf.writeBytes(data.getKeyUid());

		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryAllConfigureOfTheDevice(ScenePanelData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);
		buf.writeByte(0x02);

		buf.writeByte(data.getKeyUid()[0]);
		buf.writeByte(data.getKeyUid()[1]);

		buf.writeBytes(data.getIeeeAddr());

		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void setTheThermostatMode(RequestThermostatData data, ByteBuf buf) {

		buf.writeByte(0xff);
		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		buf.writeByte(data.getMode());

		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void setTheWindSpeed(RequestThermostatData data, ByteBuf buf) {
		buf.writeByte(0xff);
		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		buf.writeByte(data.getSpeed());

		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void adjusttTheTemperature(RequestThermostatData data, ByteBuf buf) {

		buf.writeByte(0xff);
		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		buf.writeByte(data.getTemperature());

		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void setTheRunModeThatPowerResume(RequestThermostatData data, ByteBuf buf) {

		buf.writeByte(0xff);
		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		buf.writeByte(data.getSwitchState());

		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryTheThermostatConfigureInfo(RequestThermostatData data, ByteBuf buf) {

		buf.writeByte(0xff);
		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryTheThermostatRunStatus(RequestThermostatData data, ByteBuf buf) {

		buf.writeByte(0xff);
		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());

		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void setThermostatState(RequestThermostatData data, ByteBuf buf) {
		buf.writeByte(0xff);
		buf.writeByte(0x02);

		buf.writeBytes(data.getUid());
		buf.writeByte(data.getState());

		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryOperationPermissionByusername(RequestGyDoorlockData data, ByteBuf buf) {

		buf.writeByte(0xff);

		try {
			buf.writeBytes(data.getUsername().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getUsername().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		buf.writeByte(data.getUids().size());

		for (int i = 0; i < data.getUids().size(); i++) {
			buf.writeBytes(data.getUids().get(i));
		}
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void setDoorlockSwitchState(RequestGyDoorlockData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeByte(data.getSwitchState());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryGyDoorlockSwitchState(RequestGyDoorlockData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void configureDoorlockNormalOpen(RequestGyDoorlockData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeByte(data.getSwitchState());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryDoorlockRecentStatus(RequestGyDoorlockData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void addGyDoorlockUser(RequestGyDoorlockData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		
		buf.writeByte(data.getLockUserInfo().getPermission());
		try {
			buf.writeBytes(data.getLockUserInfo().getName().getBytes("gbk"));
			for (int i = 0; i < 8 - data.getLockUserInfo().getName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		try {
			buf.writeBytes(data.getLockUserInfo().getPassword().getBytes("gbk"));
			for (int i = 0; i < 12 - data.getLockUserInfo().getPassword().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		buf.writeBytes(data.getLockUserInfo().getEffectiveTime());
		
		buf.writeByte(data.getLockUserInfo().getUnlockNumber());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void deleteGyDoorlockUser(RequestGyDoorlockData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		
		buf.writeByte(data.getLockUserInfo().getPermission());
		try {
			buf.writeBytes(data.getLockUserInfo().getName().getBytes("gbk"));
			for (int i = 0; i < 8 - data.getLockUserInfo().getName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void freezeDoorlockUser(RequestGyDoorlockData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeByte(data.getLockUserInfo().getPermission());
		try {
			buf.writeBytes(data.getLockUserInfo().getName().getBytes("gbk"));
			for (int i = 0; i < 8 - data.getLockUserInfo().getName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		buf.writeByte(data.getFreeze());
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void modifyDoorlockUserPasswd(RequestGyDoorlockData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeByte(data.getLockUserInfo().getPermission());
		try {
			buf.writeBytes(data.getLockUserInfo().getName().getBytes("gbk"));
			for (int i = 0; i < 8 - data.getLockUserInfo().getName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		try {
			buf.writeBytes(data.getLockUserInfo().getPassword().getBytes("gbk"));
			for (int i = 0; i < 12 - data.getLockUserInfo().getPassword().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		buf.writeBytes(data.getLockUserInfo().getEffectiveTime());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryAllLockUserInfo(RequestGyDoorlockData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void modifyDoorlockUserAlias(RequestGyDoorlockData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeByte(data.getLockUserInfo().getPermission());
		try {
			buf.writeBytes(data.getLockUserInfo().getName().getBytes("gbk"));
			for (int i = 0; i < 8 - data.getLockUserInfo().getName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		try {
			buf.writeBytes(data.getUsername().getBytes("gbk"));
			for (int i = 0; i < 8 - data.getUsername().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void freezeLockUserPassword(RequestDoorlockData data, ByteBuf buf) {
		
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeByte(data.getType());
		
		buf.writeShort(data.getUserid());
		
		buf.writeByte(data.getFreeze());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryLockMachineCode(RequestDoorlockData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void bindDevice(RequestBindDeviceData data, ByteBuf buf) {
		
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getSrcUid());
		
		buf.writeBytes(data.getDestUid());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void cancelBind(RequestBindDeviceData data, ByteBuf buf) {
		
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getSrcUid());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryAllBind(RequestBindDeviceData data, ByteBuf buf) {
		
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeByte(data.getSrcUid()[0]);
		buf.writeByte(data.getSrcUid()[1]);
		
		buf.writeBytes(data.getIeeeAddr());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryAlarmRecords(RequestAlarmRecordsData data, ByteBuf buf) {
		
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeBytes(data.getStartTime());
		buf.writeBytes(data.getEndTime());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void deleteAlarmRecords(RequestAlarmRecordsData data, ByteBuf buf) {
		

		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeByte(data.getRecordIds().size());
		for (int i = 0; i < data.getRecordIds().size(); i++) {
			buf.writeShort(data.getRecordIds().get(i));
		}
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void getK1DeviceStates(RequestK1DeviceData data, ByteBuf buf) {
		
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeByte(data.getStypes().size());
		for (int i = 0; i < data.getStypes().size(); i++) {
			buf.writeByte(data.getStypes().get(i));
		}
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
		
	}

	public static void getK1KeysId(RequestK1DeviceData data, ByteBuf buf) {
		
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		try {
			buf.writeBytes(data.getUsername().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getUsername().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void getK1Member(RequestK1DeviceData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void addK1Member(RequestK1DeviceData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		try {
			buf.writeBytes(data.getMemberInfo().getUsername().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getMemberInfo().getUsername().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		try {
			buf.writeBytes(data.getMemberInfo().getName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getMemberInfo().getName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
		
	}

	public static void deleteK1Member(RequestK1DeviceData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeShort(data.getMemberId());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void updateK1MemberName(RequestK1DeviceData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeShort(data.getMemberId());
		
		try {
			buf.writeBytes(data.getMemberName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getMemberName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void getK1MemberInfo(RequestK1DeviceData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeShort(data.getMemberId());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void addK1Key(RequestK1DeviceData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeShort(data.getMemberId());
		
		buf.writeByte(data.getKeyType());
		
		try {
			buf.writeBytes(data.getPassword().getBytes("gbk"));
			for (int i = 0; i < 12 - data.getPassword().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void deteteK1Key(RequestK1DeviceData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeShort(data.getMemberId());
		
		buf.writeByte(data.getKeyType());
		
		buf.writeShort(data.getKeyId());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void updateK1Password(RequestK1DeviceData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeShort(data.getMemberId());
		
		buf.writeByte(data.getKeyType());
		
		buf.writeShort(data.getKeyId());
		
		try {
			buf.writeBytes(data.getPassword().getBytes("gbk"));
			for (int i = 0; i < 12 - data.getPassword().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void updateK1FingerprintName(RequestK1DeviceData data, ByteBuf buf) {
		
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeShort(data.getMemberId());
		
		buf.writeByte(data.getKeyType());
		
		buf.writeShort(data.getKeyId());
		
		try {
			buf.writeBytes(data.getKeyName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getKeyName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void getK1RecordList(RequestK1DeviceData data, ByteBuf buf) {
		
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeByte(data.getType());
		
		buf.writeByte(data.getPage());
		
		buf.writeByte(data.getPageSize());
		
		buf.writeBytes(EffectiveTimeUtils.timeToByte(data.getStartTime()));
		
		buf.writeBytes(EffectiveTimeUtils.timeToByte(data.getEndTime()));
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
		
	}

	public static void deleteK1Record(RequestK1DeviceData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeByte(data.getKeyType());
		
		buf.writeByte(data.getStypes().size());
		
		for (int i = 0; i < data.getStypes().size(); i++) {
			buf.writeShort(data.getStypes().get(i));
		}
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void relieveAlarm(RequestK1DeviceData data, ByteBuf buf) {
		
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeByte(data.getKeyType());
		
		buf.writeShort(data.getRecordId());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void addK1TemPassword(RequestK1DeviceData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		try {
			buf.writeBytes(data.getMemberName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getMemberName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		try {
			buf.writeBytes(data.getNumber().getBytes("gbk"));
			for (int i = 0; i < 16 - data.getNumber().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		try {
			buf.writeBytes(data.getPassword().getBytes("gbk"));
			for (int i = 0; i < 12 - data.getPassword().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void deleteK1TemPassword(RequestK1DeviceData data, ByteBuf buf) {
		
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeShort(data.getKeyId());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void getK1TemPassworkList(RequestK1DeviceData data, ByteBuf buf) {
		
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeByte(data.getPage());
		
		buf.writeByte(data.getPageSize());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void deleteTemPasswordRecords(RequestK1DeviceData data, ByteBuf buf) {
		
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeByte(data.getStypes().size());
		
		for (int i = 0; i < data.getStypes().size(); i++) {
			buf.writeShort(data.getStypes().get(i));
		}
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void getK1Infos(RequestK1DeviceData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeByte(data.getType());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void upgradeK1Request(RequestK1DeviceData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeInt(data.getVersion());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void vilidateK1Pwd(RequestK1DeviceData data, ByteBuf buf) {
		buf.writeByte(0xff);

		buf.writeByte(0x02);
		buf.writeBytes(data.getUid());
		
		buf.writeShort(data.getMemberId());
		
		buf.writeByte(data.getKeyType());
		
		buf.writeShort(data.getKeyId());
		
		try {
			buf.writeBytes(data.getPassword().getBytes("gbk"));
			for (int i = 0; i < 12 - data.getPassword().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void configurWIFIInfo(RequestConfigurWIFIInfoData data, ByteBuf buf) {
		
		buf.writeByte(0xff);
		
		buf.writeByte(data.getSubCmd());
		
		try {
			buf.writeBytes(data.getSsid().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getSsid().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		try {
			buf.writeBytes(data.getPwd().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getPwd().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void searchWifi(RequestConfigurWIFIInfoData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.writeByte(0xff);
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void set3DModule(Request3DModuleData data, ByteBuf buf) {

		buf.writeByte(0xff);

		buf.writeByte(0x02);
		
		buf.writeBytes(data.getUid());
		
		buf.writeByte(data.getType());
		
		buf.writeByte(0x01);
		
		buf.writeByte(data.getValue());
		
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
		
	}

	

}
