package com.b_noble.n_life.handler.processing;

import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.b_noble.n_life.BaseApplication;
import com.b_noble.n_life.event.AttrIdEnum;
import com.b_noble.n_life.info.AbnormalRecordInfo;
import com.b_noble.n_life.info.AlarmRecordsInfo;
import com.b_noble.n_life.info.AreaInfo;
import com.b_noble.n_life.info.BindDeviceInfo;
import com.b_noble.n_life.info.DeviceInfo;
import com.b_noble.n_life.info.DoorlockNotification;
import com.b_noble.n_life.info.DoorlockRecentStatusInfo;
import com.b_noble.n_life.info.DoorlockUser;
import com.b_noble.n_life.info.GateWayInfo;
import com.b_noble.n_life.info.K1MemberDetailsInfo;
import com.b_noble.n_life.info.K1MemberInfo;
import com.b_noble.n_life.info.K1RecordInfo;
import com.b_noble.n_life.info.K1TemPassworkInfo;
import com.b_noble.n_life.info.LinkageCondition;
import com.b_noble.n_life.info.LinkageInfo;
import com.b_noble.n_life.info.LinkageTask;
import com.b_noble.n_life.info.LockUserInfo;
import com.b_noble.n_life.info.ScenePanelInfo;
import com.b_noble.n_life.info.ScenePanelTask;
import com.b_noble.n_life.info.SenceInfo;
import com.b_noble.n_life.info.TaskDeviceAction;
import com.b_noble.n_life.info.TaskInfo;
import com.b_noble.n_life.info.TaskTimerAction;
import com.b_noble.n_life.info.ThermostatConfigureInfo;
import com.b_noble.n_life.info.ThermostatRunStatusInfo;
import com.b_noble.n_life.info.UnlockRecordInfo;
import com.b_noble.n_life.model.DeviceTaskInfo;
import com.b_noble.n_life.utils.EffectiveTimeUtils;
import com.b_noble.n_life.utils.StringNamesUtils;
import com.b_noble.n_life.utils.Test16Binary;

import io.netty.buffer.ByteBuf;

/**
 * @公司：深圳市中泰智丰物联网科技有限公司
 * @项目：智能家居 @简述： handler处理实现类
 * @作者：zhangfan @date：2016-08-04 @版本：V0.0.1
 */
public class GaHandlerProcessingRealization {

	/**
	 * 获取所有设备返回处理
	 */
	public static void getAllDeviceResponseProcessing(ByteBuf buf) {

		// state
		buf.readByte();

		List<DeviceInfo> deviceInfos = new ArrayList<DeviceInfo>();

		byte totalOnlines = buf.readByte();

		// 循环获取Device
		for (int i = 0; i < totalOnlines; i++) {
			DeviceInfo deviceInfo = new DeviceInfo();

			byte[] IEEE = new byte[8];
			// IEEEAddress
			for (int j = 0; j < 8; j++) {
				IEEE[j] = buf.readByte();
			}

			byte[] shortAddress = new byte[3];
			// shortAddress endPoint
			shortAddress[0] = buf.readByte();
			shortAddress[1] = buf.readByte();
			shortAddress[2] = buf.readByte();

			// profileId
			byte[] profileId = new byte[2];
			profileId[0] = buf.readByte();
			profileId[1] = buf.readByte();

			// deviceId
			byte[] deviceId = new byte[2];
			deviceId[0] = buf.readByte();
			deviceId[1] = buf.readByte();

			// atrrId
			short atrrId = buf.readShort();

			// deviceName
			byte[] dnamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				dnamebyte[j] = buf.readByte();
			}
			String deviceName = StringNamesUtils.byteToString(dnamebyte);

			// sn
			byte[] snbyte = new byte[8];
			for (int j = 0; j < 8; j++) {
				snbyte[j] = buf.readByte();
			}
			String sn = "";
			sn = new String(snbyte);
			// recentValue
			byte[] recentValue = new byte[7];
			for (int j = 0; j < 7; j++) {
				recentValue[j] = buf.readByte();
			}

			// TBD
			buf.readByte();
			buf.readByte();

			deviceInfo.setDeviceName(deviceName);
			deviceInfo.setIEEE(IEEE);
			deviceInfo.setProfileId(profileId);
			deviceInfo.setDeviceId(deviceId);
			deviceInfo.setuId(shortAddress);
			deviceInfo.setAtrrId(atrrId);
			deviceInfo.setRecentValue(recentValue);

			deviceInfos.add(deviceInfo);
		}

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		// 为回调函数赋值
		BaseApplication.getInstance().newDevice_CallBack(deviceInfos);

	}

	/**
	 * 获取所有场景返回处理
	 */
	public static void getAllSceneResponseProcessing(ByteBuf buf) {
		List<SenceInfo> senceInfos = new ArrayList<SenceInfo>();

		// state
		buf.readByte();

		byte totalOnlines = buf.readByte();

		// 循环获取sence
		for (int i = 0; i < totalOnlines; i++) {
			SenceInfo senceInfo = new SenceInfo();

			// senceid
			byte senceid = buf.readByte();

			// senceName
			byte[] sencebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				sencebyte[j] = buf.readByte();
			}
			String senceName = StringNamesUtils.byteToString(sencebyte);

			senceInfo.setSenceName(senceName);
			senceInfo.setSenceId(senceid);

			senceInfos.add(senceInfo);
		}
		// TBD
		for (int j = 0; j < 10; j++) {
			buf.readByte();
		}

		// 为回调函数赋值
		BaseApplication.getInstance().newSence_CallBack(senceInfos);

	}

	/**
	 * 获取网关信息返回
	 * 
	 * @param buf
	 */
	public static void getGateinfoResponseProcessing(ByteBuf buf) {

		GateWayInfo gateWayInfo = new GateWayInfo();

		// version
		byte[] versionbyte = new byte[8];
		for (int j = 0; j < 8; j++) {
			versionbyte[j] = buf.readByte();
		}
		String version = new String(versionbyte);

		// sn
		byte[] snbyte = new byte[8];
		for (int i = 0; i < 8; i++) {
			snbyte[i] = buf.readByte();
		}
		String sn = new String(snbyte);

		// user
		byte[] userbyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			userbyte[j] = buf.readByte();
		}
		String user = StringNamesUtils.byteToString(userbyte);

		// passwrd
		byte[] passwrdbyte = new byte[24];
		for (int j = 0; j < 24; j++) {
			passwrdbyte[j] = buf.readByte();
		}
		String passwrd = StringNamesUtils.byteToString(passwrdbyte);

		// totalDevices
		byte totalDevices = buf.readByte();

		// totalGroup
		byte totalGroup = buf.readByte();

		// totalTimers
		byte totalTimers = buf.readByte();

		// totalScenes
		byte totalScenes = buf.readByte();

		// totalTasks
		byte totalTasks = buf.readByte();

		gateWayInfo.setVersion(version);
		gateWayInfo.setSn(sn);
		gateWayInfo.setUser(user);
		gateWayInfo.setPasswrd(passwrd);
		gateWayInfo.setTotalDevices(totalDevices);
		gateWayInfo.setTotalGroup(totalGroup);
		gateWayInfo.setTotalScenes(totalScenes);
		gateWayInfo.setTotalTasks(totalTasks);
		gateWayInfo.setTotalTimers(totalTimers);

		// 为回调函数赋值
		BaseApplication.getInstance().getGateWayInfo_CallBack(gateWayInfo);

	}

	/**
	 * 获取设备开关状态返回
	 * 
	 * @param buf
	 */
	public static void getDeviceStateResponseProcessing(ByteBuf buf) {

		buf.readByte();

		// shortAddress Endpoint
		byte[] uid = new byte[3];
		for (int i = 0; i < 3; i++) {
			uid[i] = buf.readByte();
		}

		// switchState
		byte state = buf.readByte();

		// TBD
		for (int j = 0; j < 10; j++) {
			buf.readByte();
		}

		BaseApplication.getInstance().getDeviceState_CallBack(state, uid);
	}

	/**
	 * 获取设备亮度返回处理
	 * 
	 * @param buf
	 */
	public static void getDeviceLevelProcessing(ByteBuf buf) {

		// state
		buf.readByte();

		// shortAddress Endpoint
		byte[] uid = new byte[3];
		for (int i = 0; i < 3; i++) {
			uid[i] = buf.readByte();
		}

		// brightness
		int brightness = buf.readUnsignedByte();

		// TBD
		for (int j = 0; j < 10; j++) {
			buf.readByte();
		}

		BaseApplication.getInstance().getDeviceLevel_CallBack(brightness, uid);
	}

	/**
	 * 获取设备色调与饱和度处理
	 * 
	 * @param buf
	 */
	public static void getDeviceHueProcessing(ByteBuf buf) {

		// state
		buf.readByte();

		// shortAddress Endpoint
		byte[] uid = new byte[3];
		for (int i = 0; i < 3; i++) {
			uid[i] = buf.readByte();
		}

		// hue
		int hue = buf.readUnsignedByte();

		// saturation

		int sat = buf.readUnsignedByte();

		// TBD
		for (int j = 0; j < 10; j++) {
			buf.readByte();
		}

		BaseApplication.getInstance().getDeviceHueAndSat_CallBack(hue, sat, uid);
	}

	/**
	 * 获取设备色温返回处理
	 * 
	 * @param buf
	 */
	public static void getColorTemperatureProcessing(ByteBuf buf) {

		// state
		buf.readByte();

		// shortAddress Endpoint
		byte[] uid = new byte[3];
		for (int i = 0; i < 3; i++) {
			uid[i] = buf.readByte();
		}

		// colorTemperature
		int colorTemperature = buf.readShort();

		// TBD
		for (int j = 0; j < 10; j++) {
			buf.readByte();
		}

		BaseApplication.getInstance().getColorTemperature_CallBack(colorTemperature, uid);
	}

	/**
	 * 获取场景成员处理
	 * 
	 * @param buf
	 */
	public static void getSceneMemberProcessing(ByteBuf buf) {

		// state
		buf.readByte();

		// sceneID
		int sceneID = buf.readByte();

		// sceneName
		byte[] sceneNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			sceneNamebyte[j] = buf.readByte();
		}
		String sceneName = StringNamesUtils.byteToString(sceneNamebyte);

		// totalDevice
		int totalDevice = buf.readByte();

		List<DeviceTaskInfo> dts = new ArrayList<DeviceTaskInfo>();
		// shortAddress endPoint
		for (int i = 0; i < totalDevice; i++) {
			byte[] uid = new byte[3];
			uid[0] = buf.readByte();
			uid[1] = buf.readByte();
			uid[2] = buf.readByte();

			byte command = buf.readByte();

			byte[] data = new byte[8];
			for (int j = 0; j < data.length; j++) {
				data[j] = buf.readByte();
			}

			byte delayTime = buf.readByte();

			DeviceTaskInfo dt = new DeviceTaskInfo(uid, command, data);

			dts.add(dt);

		}

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().getSenceMember_CallBack(sceneID, sceneName, dts);
	}

	/**
	 * 获取所有任务
	 * 
	 * @param buf
	 */
	public static void getAllTaskProcessing(ByteBuf buf) {

		// state
		buf.readByte();

		List<TaskInfo> tasks = new ArrayList<TaskInfo>();
		// totalTasks
		int totalTasks = buf.readByte();

		for (int i = 0; i < totalTasks; i++) {
			byte taskType = buf.readByte();
			byte taskID = buf.readByte();

			byte taskState = buf.readByte();

			byte[] taskNamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				taskNamebyte[j] = buf.readByte();
			}
			String taskName = StringNamesUtils.byteToString(taskNamebyte);

			TaskInfo info = new TaskInfo();
			info.setTaskId(taskID);
			info.setTaskType(taskType);
			info.setTaskName(taskName);
			info.setTaskState(taskState);

			tasks.add(info);
		}

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().newTask_CallBack(tasks);
	}

	/**
	 * 获取任务详细
	 * 
	 * @param buf
	 */
	public static void getTaskInfoProcessing(ByteBuf buf) {

		// state
		buf.readByte();

		TaskTimerAction timerAction = null;
		TaskDeviceAction deviceAction = null;

		DeviceTaskInfo deviceTaskInfo = null;

		short sceneid = 0;

		TaskInfo taskInfo = new TaskInfo();

		// taskType
		byte taskType = buf.readByte();

		byte[] taskNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			taskNamebyte[j] = buf.readByte();
		}
		String taskName = StringNamesUtils.byteToString(taskNamebyte);

		byte taskId = buf.readByte();

		byte taskState = 0x00;

		// judgement 17bytes
		if (taskType == 0x01) {

			byte[] uid = new byte[3];
			for (int i = 0; i < 3; i++) {
				uid[i] = buf.readByte();
			}

			byte minute = buf.readByte();
			byte hour = buf.readByte();

			byte day = buf.readByte();
			byte month = buf.readByte();
			byte week = buf.readByte();

			byte cmd = buf.readByte();

			taskState = buf.readByte();

			byte[] tbd = new byte[8];
			for (int i = 0; i < 8; i++) {
				tbd[i] = buf.readByte();
			}
			timerAction = new TaskTimerAction(week, hour, minute);

			deviceTaskInfo = new DeviceTaskInfo(uid, cmd, tbd);

		} else if (taskType == 0x02) {

			// sceneId
			sceneid = buf.readByte();

			byte minute = buf.readByte();
			byte hour = buf.readByte();

			byte day = buf.readByte();
			byte month = buf.readByte();
			byte week = buf.readByte();

			for (int i = 0; i < 3; i++) {
				buf.readByte();
			}

			taskState = buf.readByte();

			for (int i = 0; i < 8; i++) {
				buf.readByte();
			}

			timerAction = new TaskTimerAction(week, hour, minute);
		}

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		taskInfo.setTaskType(taskType);
		taskInfo.setTaskName(taskName);
		taskInfo.setTaskId(taskId);
		taskInfo.setTaskState(taskState);

		if (taskType == 0x01) {
			BaseApplication.getInstance().getDeviceTimerTaskDetails_CallBack(taskInfo, timerAction, deviceTaskInfo);
		} else if (taskType == 0x02) {
			BaseApplication.getInstance().getSceneTimerTaskDetails_CallBack(taskInfo, timerAction, sceneid);
		}

	}

	/**
	 * 添加场景后返回
	 * 
	 * @param buf
	 */
	public static void addSenceResponseProcessing(ByteBuf buf) {

		// state
		buf.readByte();

		// sceneID
		byte sceneId = buf.readByte();

		// sceneName
		byte[] sceneNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			sceneNamebyte[j] = buf.readByte();
		}
		String sceneName = StringNamesUtils.byteToString(sceneNamebyte);

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().addSence_callBack(sceneId, sceneName);
	}

	/**
	 * 更改设备名称后返回
	 * 
	 * @param buf
	 */
	public static void updateDeviceNameResponseProcessing(ByteBuf buf) {

		// state
		buf.readByte();

		// uid
		byte[] uid = new byte[3];
		for (int i = 0; i < uid.length; i++) {
			uid[i] = buf.readByte();
		}

		// deviceName
		byte[] deviceNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			deviceNamebyte[j] = buf.readByte();
		}
		String deviceName = StringNamesUtils.byteToString(deviceNamebyte);

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().ChangeDeviceName_callBack(uid, deviceName);

	}

	/**
	 * 获取指定场景任务返回
	 * 
	 * @param buf
	 */
	public static void getTaskBySceneId(ByteBuf buf) {

		System.out.println("获取指定场景任务返回！！！！！！！！！！！！");

		// state
		buf.readByte();

		List<TaskInfo> tasks = new ArrayList<TaskInfo>();

		// totaltimertask
		byte totaltimertask = buf.readByte();

		// taskType
		byte taskType = buf.readByte();

		for (int i = 0; i < totaltimertask; i++) {

			// taskName
			byte[] taskNamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				taskNamebyte[j] = buf.readByte();
			}
			String taskName = StringNamesUtils.byteToString(taskNamebyte);

			// taskID
			byte taskId = buf.readByte();

			// sceneid
			byte sceneid = buf.readByte();

			byte m = buf.readByte();
			byte h = buf.readByte();
			byte day = buf.readByte();
			byte month = buf.readByte();
			byte workMode = buf.readByte();

			for (int j = 0; j < 3; j++) {
				buf.readByte();
			}

			byte taskState = buf.readByte();

			// tbd
			for (int j = 0; j < 8; j++) {
				buf.readByte();
			}

			TaskTimerAction taskTimerAction = new TaskTimerAction(workMode, h, m);

			TaskInfo taskInfo = new TaskInfo(taskId, taskName, taskType, taskTimerAction, sceneid, taskState);

			tasks.add(taskInfo);
		}

		if (taskType == 0x02) {
			BaseApplication.getInstance().getTimerTaskBySceneId_CallBack(tasks);

		}

	}

	/**
	 * 获取设备任务
	 * 
	 * @param buf
	 */
	public static void getTaskByUid(ByteBuf buf) {

		// state
		buf.readByte();

		List<TaskInfo> taskInfos = new ArrayList<TaskInfo>();

		// totalTimeTasks
		byte totalTimeTasks = buf.readByte();

		// taskType
		byte taskType = buf.readByte();

		for (int i = 0; i < totalTimeTasks; i++) {

			// taskName
			byte[] taskNamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				taskNamebyte[j] = buf.readByte();
			}
			String taskName = StringNamesUtils.byteToString(taskNamebyte);

			byte taskId = buf.readByte();

			// uid
			byte[] uid = new byte[3];
			for (int a = 0; a < uid.length; a++) {
				uid[a] = buf.readByte();
			}

			byte minute = buf.readByte();
			byte hour = buf.readByte();
			byte day = buf.readByte();
			byte month = buf.readByte();
			byte week = buf.readByte();

			short command = buf.readUnsignedByte();

			byte taskState = buf.readByte();

			// tbd
			byte[] data = new byte[8];
			for (int j = 0; j < 8; j++) {
				data[j] = buf.readByte();
			}

			TaskTimerAction taskTimerAction = new TaskTimerAction(week, hour, minute);

			DeviceTaskInfo deviceTaskInfo = new DeviceTaskInfo(uid, (byte) command, data);

			TaskInfo taskInfo = new TaskInfo(taskId, taskName, taskType, taskTimerAction, deviceTaskInfo, taskState);
			taskInfos.add(taskInfo);
		}

		if (taskType == 0x01) {
			BaseApplication.getInstance().getDeviceTimerTask_CallBack(taskInfos);
		}

	}

	public static void verificationManagerPwd(ByteBuf buf) {

		// state
		byte state = buf.readByte();

		// TBD+CRC
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().verificationManagerPwd_Callback(state);

	}

	public static void modifyPwd(ByteBuf buf) {

		// state
		byte state = buf.readByte();

		// TBD+CRC
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().modifyLoginPwd_Callback(state);
	}

	public static void loginGaByLan(ByteBuf buf) {
		// state
		byte state = buf.readByte();

		// TBD+CRC
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().loginGaByLan_Callback(state);
	}

	public static void bindGa(ByteBuf buf) {
		// state
		byte state = buf.readByte();

		// userLevel
		byte userLevel = buf.readByte();

		// userName
		byte[] userNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			userNamebyte[j] = buf.readByte();
		}
		String userName = StringNamesUtils.byteToString(userNamebyte);

		// TBD+CRC
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().UserBindToGa_callBack(state);

	}

	public static void addUserToGa(ByteBuf buf) {
		// state
		byte state = buf.readByte();

		// userLevel
		byte userLevel = buf.readByte();

		// userName
		byte[] userNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			userNamebyte[j] = buf.readByte();
		}
		String userName = StringNamesUtils.byteToString(userNamebyte);

		// TBD+CRC
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().addUserToGa_callBack(state);
	}

	public static void queryPwd(ByteBuf buf) {
		// state
		buf.readByte();

		// userName
		byte[] userNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			userNamebyte[j] = buf.readByte();
		}
		String userName = StringNamesUtils.byteToString(userNamebyte);

		// password
		byte[] passwordbyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			passwordbyte[j] = buf.readByte();
		}
		String password = StringNamesUtils.byteToString(passwordbyte);

		// TBD+CRC
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryManagerPwd_callBack(userName, password);
	}

	public static void modifyManagerPwd(ByteBuf buf) {
		// state
		byte state = buf.readByte();

		// TBD+CRC
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().modifyManagerPwd_Callback(state);
	}

	public static void reportNewDevice(ByteBuf buf) {

		// state
		buf.readByte();

		int totalDevices = buf.readByte();

		for (int i = 0; i < totalDevices; i++) {
			// IEEEAddress
			byte[] IEEEAddress = new byte[8];
			for (int j = 0; j < 8; j++) {
				IEEEAddress[j] = buf.readByte();
			}
			// shortAddress endPoint
			byte[] uid = new byte[3];
			for (int j = 0; j < 3; j++) {
				uid[j] = buf.readByte();
			}

			// profileId
			byte[] profileId = new byte[2];
			profileId[0] = buf.readByte();
			profileId[1] = buf.readByte();

			// deviceId
			byte[] deviceId = new byte[2];
			deviceId[0] = buf.readByte();
			deviceId[1] = buf.readByte();

			// atrrId
			short atrrId = buf.readShort();

			// deviceName
			byte[] deviceNamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				deviceNamebyte[j] = buf.readByte();
			}
			String deviceName = StringNamesUtils.byteToString(deviceNamebyte);

			// sn
			byte[] snbyte = new byte[8];
			for (int j = 0; j < 8; j++) {
				snbyte[j] = buf.readByte();
			}

			DeviceInfo info = new DeviceInfo();
			info.setDeviceId(deviceId);
			info.setuId(uid);
			info.setIEEE(IEEEAddress);
			info.setProfileId(profileId);
			info.setAtrrId(atrrId);
			info.setDeviceName(deviceName);

			BaseApplication.getInstance().newDevice_Callback(info);
		}

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

	}

	public static void addTaskResponseProcessing(ByteBuf buf) {

		// state
		buf.readByte();

		// taskType
		byte taskType = buf.readByte();

		// taskName
		byte[] taskNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			taskNamebyte[j] = buf.readByte();
		}
		String taskName = StringNamesUtils.byteToString(taskNamebyte);

		// taskID
		int taskId = buf.readShort();

		int taskStatus = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		if (taskType == 0x01) {
			BaseApplication.getInstance().addDeviceTimerTask_callBack(taskName, taskId);
		} else if (taskType == 0x02) {
			BaseApplication.getInstance().addSceneTimerTask_callBack(taskName, taskId);
		}
	}

	public static void endpointReport(ByteBuf buf) {

		// state
		buf.readByte();

		// numberReports
		byte numberReports = buf.readByte();
		for (int i = 0; i < numberReports; i++) {

			// shortAddress Endpoint
			byte[] uid = new byte[3];
			for (int j = 0; j < uid.length; j++) {
				uid[j] = buf.readByte();
			}

			// profileId
			byte[] profileId = new byte[2];
			profileId[0] = buf.readByte();
			profileId[1] = buf.readByte();

			// deviceId
			byte[] deviceId = new byte[2];
			deviceId[0] = buf.readByte();
			deviceId[1] = buf.readByte();

			// atrrId
			short atrrId = buf.readShort();

			String did = Test16Binary.bytes2hex03(deviceId).replaceAll(" ", "");
			if (did.equals("0302")) {
				// 温湿度传感器数据解析
				byte onlineState = buf.readByte();
				int TemperatureInt = buf.readUnsignedShort();
				int HumidityInt = buf.readUnsignedShort();
				int Interval = buf.readUnsignedShort();

				Double Temperature = (double) (TemperatureInt / 100.d);
				Double Humidity = (double) (HumidityInt / 100.d);
				Integer battery = 0;

				for (int j = 0; j < 10; j++) {
					buf.readByte();
				}

				BaseApplication.getInstance().TemperatureAndHumidityReport_callBack(Temperature, Humidity, battery,
						uid);
			} else {
				// recentValue
				byte[] recentValue = new byte[7];
				for (int j = 0; j < recentValue.length; j++) {
					recentValue[j] = buf.readByte();
				}

				System.out.println("recentValue" + Test16Binary.bytes2hex03(recentValue));

				for (int j = 0; j < 10; j++) {
					buf.readByte();
				}

				// 紧急按钮
				if (atrrId == AttrIdEnum.PERSONAL_EMERGENCY.getVal()) {
					BaseApplication.getInstance().EmergencyButtonReprot_callBack(recentValue[1], uid);
				} else if (atrrId == AttrIdEnum.GAS_SENSOR.getVal()) {
					BaseApplication.getInstance().GasSensorReprot_callBack(recentValue[1], uid);
				} else if (atrrId == AttrIdEnum.CO_SENSOR.getVal()) {
					BaseApplication.getInstance().CoSensorReprot_callBack(recentValue[1], uid);
				} else if (atrrId == AttrIdEnum.KEY_FOB.getVal()) {
					BaseApplication.getInstance().KeyFobReprot_callBack(recentValue[1], uid);
				} else if (atrrId == AttrIdEnum.FIRE_SENSOR.getVal()) {
					BaseApplication.getInstance().FireSensorReprot_callBack(recentValue[1], uid);
				} else {
					// 回调方法中赋值
					BaseApplication.getInstance().sensorReport_callBack(uid, recentValue, deviceId, atrrId);
				}

			}

		}
	}

	/**
	 * 获取联动任务详细
	 * 
	 * @param buf
	 */
	public static void getLinkageTaskDetails(ByteBuf buf) {

		List<LinkageCondition> conditionList = new ArrayList<LinkageCondition>();

		List<LinkageTask> taskList = new ArrayList<LinkageTask>();

		buf.readByte();

		int linkageId = buf.readShort();

		// LinkageType
		byte linkageType = buf.readByte();

		// LinkageName
		byte[] linkageNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			linkageNamebyte[j] = buf.readByte();
		}
		String linkageName = StringNamesUtils.byteToString(linkageNamebyte);

		int totalCondition = buf.readByte();
		for (int i = 0; i < totalCondition; i++) {

			byte conditionType = buf.readByte();
			if (conditionType == 1) {
				byte[] uid = new byte[3];
				for (int j = 0; j < uid.length; j++) {
					uid[j] = buf.readByte();
				}
				byte symbol = buf.readByte();
				byte value = buf.readByte();

				buf.readByte();
				buf.readByte();
				buf.readByte();

				LinkageCondition condition = new LinkageCondition(uid, symbol, value, conditionType);
				conditionList.add(condition);
			}
			if (conditionType == 2) {
				byte month = buf.readByte();
				byte day = buf.readByte();
				byte weekdays = buf.readByte();
				byte symbol = buf.readByte();
				byte hour = buf.readByte();
				byte minute = buf.readByte();

				buf.readByte();
				buf.readByte();

				LinkageCondition condition = new LinkageCondition(symbol, conditionType, month, day, weekdays, hour,
						minute);
				conditionList.add(condition);
			}
		}

		int totalTask = buf.readByte();
		for (int i = 0; i < totalTask; i++) {
			if (linkageType == 1) {
				byte[] uid = new byte[3];
				for (int j = 0; j < uid.length; j++) {
					uid[j] = buf.readByte();
				}
				byte cmd = buf.readByte();
				byte value = buf.readByte();
				byte delay = buf.readByte();

				buf.readByte();
				buf.readByte();
				LinkageTask task = new LinkageTask(uid, cmd, value, delay);

				taskList.add(task);
			} else {
				int sceneid = buf.readShort();

				buf.readByte();
				buf.readByte();
				buf.readByte();

				byte delay = buf.readByte();

				buf.readByte();
				buf.readByte();

				LinkageTask task = new LinkageTask(delay, (byte) sceneid);
				taskList.add(task);
			}

		}

		int linkageStatus = buf.readByte();

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		LinkageInfo linkageInfo = new LinkageInfo(linkageType, linkageId, linkageName, conditionList, taskList,
				linkageStatus);

		BaseApplication.getInstance().getLinkageTaskDetails_callBack(linkageInfo);

	}

	public static void getLinkageScene(ByteBuf buf) {
		// state
		buf.readByte();
		// LinkageType
		buf.readByte();
		// LinkageName
	}

	public static void getLinkageDevice(ByteBuf buf) {

		List<TaskInfo> taskDeviceInfos = new ArrayList<TaskInfo>();
		List<TaskInfo> taskSceneInfos = new ArrayList<TaskInfo>();

		// state
		buf.readByte();

		// totalLinkage
		int totalLinkage = buf.readByte();

		for (int i = 0; i < totalLinkage; i++) {

			// linkType
			byte linkType = buf.readByte();
			System.out.println("linkType:" + linkType);

			// LinkageName
			byte[] linkageNamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				linkageNamebyte[j] = buf.readByte();
			}
			String linkageName = StringNamesUtils.byteToString(linkageNamebyte);

			// linkageID
			byte linkageID = buf.readByte();

			// uidSource
			byte[] udiSource = new byte[3];
			for (int j = 0; j < 3; j++) {
				udiSource[j] = buf.readByte();
			}

			// devType
			byte devType = buf.readByte();

			// uidLinkage
			byte[] uidLinkage = new byte[3];
			for (int j = 0; j < 3; j++) {
				uidLinkage[j] = buf.readByte();
			}

			// ruleMin
			byte ruleMin = buf.readByte();

			// ruleMax
			byte ruleMax = buf.readByte();

			// ruleVal
			byte ruleVal = buf.readByte();

			// cmd
			byte[] tbd = new byte[8];
			for (int j = 0; j < 8; j++) {
				tbd[j] = buf.readByte();
			}

			TaskDeviceAction taskDeviceAction = new TaskDeviceAction(udiSource, devType, ruleMin, ruleMax, ruleVal);

			DeviceTaskInfo deviceTaskInfo = new DeviceTaskInfo(uidLinkage, tbd);

			if (linkType == 0x01) {
				TaskInfo taskinfo = new TaskInfo(linkageID, linkageName, taskDeviceAction, deviceTaskInfo, 1);

				taskDeviceInfos.add(taskinfo);
			} else if (linkType == 0x02) {
				TaskInfo taskinfo = new TaskInfo(linkageID, linkageName, taskDeviceAction, uidLinkage[0], 2);

				// taskSceneInfos.add(taskinfo);
				taskDeviceInfos.add(taskinfo);
			}

		}

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().getDeviceLinkageTasks_callBack(taskDeviceInfos);

		// BaseApplication.getInstance().getSceneLinkageTasks_callBack(taskSceneInfos);

	}

	public static void getAreaDetails(ByteBuf buf) {

		AreaInfo areaInfo = new AreaInfo();
		// state
		buf.readByte();

		// areaName
		byte[] areaNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			areaNamebyte[j] = buf.readByte();
		}
		String areaName = StringNamesUtils.byteToString(areaNamebyte);

		byte areaId = buf.readByte();

		// totals
		byte totals = buf.readByte();

		List<DeviceInfo> infos = new ArrayList<DeviceInfo>();

		// judgement
		for (int i = 0; i < totals; i++) {

			DeviceInfo info = new DeviceInfo();
			byte memberType = buf.readByte();

			byte[] uid = new byte[3];
			for (int j = 0; j < uid.length; j++) {
				uid[j] = buf.readByte();
			}

			for (int j = 0; j < 8; j++) {
				buf.readByte();
			}
			info.setuId(uid);
			infos.add(info);
		}

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		areaInfo.setAreaId(areaId);
		areaInfo.setAreaName(areaName);
		areaInfo.setInfos(infos);
		BaseApplication.getInstance().getAreaDetails_callBack(areaInfo);

	}

	public static void getAllArea(ByteBuf buf) {

		List<AreaInfo> areaInfos = new ArrayList<AreaInfo>();

		// state
		buf.readByte();

		// totals
		int totals = buf.readByte();

		for (int i = 0; i < totals; i++) {
			// judgement
			byte[] areaNamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				areaNamebyte[j] = buf.readByte();
			}
			String areaName = StringNamesUtils.byteToString(areaNamebyte);

			// areaID
			byte areaId = buf.readByte();

			// TBD
			for (int j = 0; j < 8; j++) {
				buf.readByte();
			}

			AreaInfo areaInfo = new AreaInfo(areaId, areaName);
			areaInfos.add(areaInfo);

		}
		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		Collections.reverse(areaInfos);
		BaseApplication.getInstance().getAllArea_callBack(areaInfos);

	}

	public static void addArea(ByteBuf buf) {
		// TODO Auto-generated method stub
		// state
		byte state = buf.readByte();

		// areaID
		byte areaId = buf.readByte();

		byte[] areaNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			areaNamebyte[j] = buf.readByte();
		}
		String areaName = StringNamesUtils.byteToString(areaNamebyte);

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().addArea_callBack(state);

	}

	public static void queryMotorStatus(ByteBuf buf) {
		// state
		byte state = buf.readByte();

		byte[] uid = new byte[3];
		for (int j = 0; j < uid.length; j++) {
			uid[j] = buf.readByte();
		}

		// value
		byte value = buf.readByte();

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		byte[] b = Test16Binary.getBooleanArray(value);
		BaseApplication.getInstance().queryElectricMotorStatus_CallBack(b[7], b[6], b[4]);
	}

	public static void queryElectricInfo(ByteBuf buf) {
		// TODO Auto-generated method stub
		// state
		byte state = buf.readByte();

		byte[] uid = new byte[3];
		for (int j = 0; j < uid.length; j++) {
			uid[j] = buf.readByte();
		}

		// value
		byte value = buf.readByte();

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryElectricInfo_CallBack((value & 0xf0) >> 4, value & 0x0f);
	}

	public static void queryCurtainPosition(ByteBuf buf) {
		// TODO Auto-generated method stub
		byte state = buf.readByte();

		byte[] uid = new byte[3];
		for (int j = 0; j < uid.length; j++) {
			uid[j] = buf.readByte();
		}

		// value
		byte value = buf.readByte();

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryCurtainPosition_CallBack(value);
	}

	public static void queryDoorlockSwitchState(ByteBuf buf) {

		byte state = buf.readByte();

		byte[] uid = new byte[3];
		for (int j = 0; j < uid.length; j++) {
			uid[j] = buf.readByte();
		}

		// value
		byte value = buf.readByte();

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryDoorlockSwitchState_CallBack(uid, value);
	}

	public static void operationEventNotification(ByteBuf buf) {

		byte state = buf.readByte();

		byte[] uid = new byte[3];
		for (int j = 0; j < uid.length; j++) {
			uid[j] = buf.readByte();
		}

		int userid = buf.readShort();

		int eventSource = buf.readByte();

		int event = buf.readByte();

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance()
				.operationEventNotification(new DoorlockNotification(uid, userid, eventSource, event), state);
	}

	public static void queryPermissionDoorlock(ByteBuf buf) {

		byte state = buf.readByte();

		byte[] uid = new byte[3];
		for (int j = 0; j < uid.length; j++) {
			uid[j] = buf.readByte();
		}

		byte permission = buf.readByte();
		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryPermissionDoorlock_CallBack(uid, permission);
	}

	public static void requestGaOrZigbeeVersion(ByteBuf buf) {

		byte state = buf.readByte();

		byte command = buf.readByte();

		int version = buf.readShort();

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().requestGaOrZigbeeVersion_callBack(command, version);
	}

	public static void report_upgrade_status(ByteBuf buf) {

		byte state = buf.readByte();

		byte command = buf.readByte();

		int version = buf.readShort();

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().reportUpgradeStatus_callBack(command, version);
	}

	public static void requestTemperatureAndHumidity(ByteBuf buf) {

		byte state = buf.readByte();

		int tem = buf.readShort();

		int hum = buf.readShort();

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().requestTemperatureAndHumidity_callBack(tem, hum);
	}

	public static void getTheOnlineStatusOfThClient(ByteBuf buf) {

		byte state = buf.readByte();

		int status = buf.readByte();

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().getTheOnlineStatusOfThClient_callback(status);

	}

	public static void queryDoorlockElectricity(ByteBuf buf) {

		byte state = buf.readByte();

		byte[] uid = new byte[3];
		for (int j = 0; j < uid.length; j++) {
			uid[j] = buf.readByte();
		}

		// byte eb1 = buf.readByte();
		// byte eb2 = buf.readByte();

		short e = buf.readShort();

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		/*
		 * BaseApplication.getInstance().queryDoorlockElectricity_callback(uid,
		 * Integer.toHexString(eb1) + "." + Integer.toHexString(eb2));
		 */
		BaseApplication.getInstance().queryDoorlockElectricity_callback(uid, e + "", state);
	}

	public static void queryDoorUserInfos(ByteBuf buf) {

		List<DoorlockUser> list = new ArrayList<DoorlockUser>();

		byte state = buf.readByte();

		byte[] uid = new byte[3];
		for (int j = 0; j < uid.length; j++) {
			uid[j] = buf.readByte();
		}

		int totalUsers = buf.readByte();

		for (int i = 0; i < totalUsers; i++) {

			DoorlockUser doorlockUser = new DoorlockUser();

			byte userType = buf.readByte();
			doorlockUser.setUserType(userType);

			int userid = buf.readShort();
			doorlockUser.setUserid(userid);

			byte[] userNamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				userNamebyte[j] = buf.readByte();
			}
			String userName = StringNamesUtils.byteToString(userNamebyte);
			doorlockUser.setUsername(userName);

			byte[] createTime = new byte[6];
			for (int j = 0; j < createTime.length; j++) {
				createTime[j] = buf.readByte();
			}
			doorlockUser.setCreateTime(StringNamesUtils.byteToCreateTime(createTime));

			byte src = buf.readByte();
			doorlockUser.setSrc(src);

			list.add(doorlockUser);
		}

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryDoorUserInfos_callBack(uid, list);
	}

	public static void queryUnlockRecord(ByteBuf buf) {

		List<UnlockRecordInfo> list = new ArrayList<UnlockRecordInfo>();
		byte state = buf.readByte();

		byte[] uid = new byte[3];
		for (int j = 0; j < uid.length; j++) {
			uid[j] = buf.readByte();
		}

		int totalRecords = buf.readByte();

		for (int i = 0; i < totalRecords; i++) {
			int recordId = buf.readShort();
			int userid = buf.readShort();
			byte userType = buf.readByte();
			byte[] userNamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				userNamebyte[j] = buf.readByte();
			}
			String userName = StringNamesUtils.byteToString(userNamebyte);

			byte[] unlockTimebyte = new byte[6];
			for (int j = 0; j < unlockTimebyte.length; j++) {
				unlockTimebyte[j] = buf.readByte();
			}
			String unlockTime = StringNamesUtils.byteToCreateTime(unlockTimebyte);

			UnlockRecordInfo unlockRecordInfo = new UnlockRecordInfo(recordId, userid, userType, userName, unlockTime);
			list.add(unlockRecordInfo);
		}
		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryUnlockRecord_callBack(list);

	}

	public static void queryAbnormalRecord(ByteBuf buf) {

		List<AbnormalRecordInfo> list = new ArrayList<AbnormalRecordInfo>();
		byte state = buf.readByte();

		byte[] uid = new byte[3];
		for (int j = 0; j < uid.length; j++) {
			uid[j] = buf.readByte();
		}

		int totalRecords = buf.readByte();

		for (int i = 0; i < totalRecords; i++) {
			int recordId = buf.readShort();
			int event = buf.readByte();
			byte[] unlockTimebyte = new byte[6];
			for (int j = 0; j < unlockTimebyte.length; j++) {
				unlockTimebyte[j] = buf.readByte();
			}
			String unlockTime = StringNamesUtils.byteToCreateTime(unlockTimebyte);

			AbnormalRecordInfo abnormalRecordInfo = new AbnormalRecordInfo(recordId, event, unlockTime);
			list.add(abnormalRecordInfo);
		}
		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryAbnormalRecord_callBack(list);

	}

	public static void abnormalEventNotification(ByteBuf buf) {

		byte state = buf.readByte();

		byte[] uid = new byte[3];
		for (int j = 0; j < uid.length; j++) {
			uid[j] = buf.readByte();
		}

		byte event = buf.readByte();

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().abnormalEventNotification_callBack(uid, event);
	}

	public static void addUserToDoorlock(ByteBuf buf) {

		byte state = buf.readByte();

		byte[] uid = new byte[3];
		for (int j = 0; j < uid.length; j++) {
			uid[j] = buf.readByte();
		}

		buf.readBytes(new byte[32]);

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().addUserToDoorlock_callBack(state);
	}

	public static void curtainStrokeControl(ByteBuf buf) {

		byte state = buf.readByte();

		byte[] uid = new byte[3];
		for (int j = 0; j < uid.length; j++) {
			uid[j] = buf.readByte();
		}

		byte value = buf.readByte();

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().curtainStrokeControl_callBack(uid, state);
	}

	public static void deleteUserToDoorlock(ByteBuf buf) {

		byte state = buf.readByte();

		byte[] uid = new byte[3];
		for (int j = 0; j < uid.length; j++) {
			uid[j] = buf.readByte();
		}

		int userid = buf.readShort();

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().deleteUserToDoorlock_callBack(uid, userid);
	}

	public static void deleteUnlockRecord(ByteBuf buf) {
		// TODO Auto-generated method stub
		byte state = buf.readByte();

		byte[] uid = new byte[3];
		for (int j = 0; j < uid.length; j++) {
			uid[j] = buf.readByte();
		}

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().deleteUnlockRecord_callBack(uid);
	}

	public static void deleteSence(ByteBuf buf) {
		byte state = buf.readByte();

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().deleteSence_callBack(state);
	}

	public static void ChangeSceneName(ByteBuf buf) {
		byte state = buf.readByte();

		buf.readByte();
		buf.readBytes(new byte[32]);

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().ChangeSceneName_callBack(state);
	}

	public static void modifyScene(ByteBuf buf) {

		byte state = buf.readByte();

		int senceId = buf.readByte();
		byte[] senceNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			senceNamebyte[j] = buf.readByte();
		}
		String senceName = StringNamesUtils.byteToString(senceNamebyte);
		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().modifyScene_callBack(senceId, senceName);
	}

	public static void deleteTask(ByteBuf buf) {
		byte state = buf.readByte();

		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().deleteTask_callBack(state);
	}

	public static void updateTimerTask(ByteBuf buf) {

		// state
		buf.readByte();

		// taskID
		int taskId = buf.readShort();

		// taskType
		byte taskType = buf.readByte();

		// taskName
		byte[] taskNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			taskNamebyte[j] = buf.readByte();
		}
		String taskName = StringNamesUtils.byteToString(taskNamebyte);

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		if (taskType == 0x01) {
			BaseApplication.getInstance().updateDeviceTimerTask_callBack(taskId, taskName);
		} else if (taskType == 0x02) {
			BaseApplication.getInstance().updateSceneTimerTask_callBack(taskId, taskName);
		}
	}

	public static void updateTaskName(ByteBuf buf) {
		// state
		buf.readByte();

		// taskID
		int taskId = buf.readShort();

		// taskType
		byte taskType = buf.readByte();

		// taskName
		byte[] taskNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			taskNamebyte[j] = buf.readByte();
		}
		String taskName = StringNamesUtils.byteToString(taskNamebyte);

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().updateTaskName_callBack(taskId, taskType, taskName);
	}

	public static void getTimerTask(ByteBuf buf) {
		// state
		buf.readByte();

		// taskType
		byte taskType = buf.readByte();

		int totalTasks = buf.readByte();

		List<TaskInfo> taskInfos = new ArrayList<TaskInfo>();
		for (int i = 0; i < totalTasks; i++) {

			short taskId = buf.readShort();

			// taskName
			byte[] taskNamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				taskNamebyte[j] = buf.readByte();
			}
			String taskName = StringNamesUtils.byteToString(taskNamebyte);

			if (taskType == 1) {

				byte[] uid = new byte[3];
				for (int j = 0; j < 3; j++) {
					uid[j] = buf.readByte();
				}
				byte minute = buf.readByte();
				byte hour = buf.readByte();
				byte day = buf.readByte();
				byte month = buf.readByte();
				byte week = buf.readByte();
				byte cmd = buf.readByte();
				byte data[] = new byte[9];
				for (int j = 0; j < 9; j++) {
					data[j] = buf.readByte();
				}

				byte taskStatus = buf.readByte();

				TaskTimerAction taskTimerAction = new TaskTimerAction(week, hour, minute, month, day);
				DeviceTaskInfo deviceTaskInfo = new DeviceTaskInfo(uid, cmd, data);
				TaskInfo info = new TaskInfo(taskId, taskName, taskType, taskTimerAction, deviceTaskInfo);
				info.setTaskState(taskStatus);
				taskInfos.add(info);

			} else {
				int sceneid = buf.readShort();
				buf.readByte();

				byte minute = buf.readByte();
				byte hour = buf.readByte();
				byte day = buf.readByte();
				byte month = buf.readByte();
				byte week = buf.readByte();
				for (int j = 0; j < 10; j++) {
					buf.readByte();
				}
				byte taskStatus = buf.readByte();
				TaskTimerAction taskTimerAction = new TaskTimerAction(week, hour, minute, month, day);
				TaskInfo info = new TaskInfo(taskId, taskName, taskType, taskTimerAction, (byte) sceneid, taskStatus);
				taskInfos.add(info);
			}

		}
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		if (taskType == 1) {
			BaseApplication.getInstance().getDeviceTimerTask_CallBack(taskInfos);
		} else {
			BaseApplication.getInstance().getTimerTaskBySceneId_CallBack(taskInfos);
		}
	}

	public static void addLinkageTask(ByteBuf buf) {
		// state
		int state = buf.readByte();

		// taskType
		byte linkageType = buf.readByte();

		// linkageName
		byte[] linkageNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			linkageNamebyte[j] = buf.readByte();
		}
		String linkageName = StringNamesUtils.byteToString(linkageNamebyte);
		int linkageId = buf.readShort();

		int linkageStatus = buf.readByte();
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		if (linkageType == 1) {
			BaseApplication.getInstance().addDeviceLinkageTask_callBack(state, linkageId, linkageName);
		} else {
			BaseApplication.getInstance().addSceneLinkageTask_callBack(state, linkageId, linkageName);
		}

	}

	public static void deleteLinkageTask(ByteBuf buf) {
		// state
		int state = buf.readByte();
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().deleteLinkageTask_callBack(state);
	}

	public static void modityLinkageTask(ByteBuf buf) {
		// state
		int state = buf.readByte();
		int linkageId = buf.readShort();
		// taskType
		byte linkageType = buf.readByte();

		// linkageName
		byte[] linkageNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			linkageNamebyte[j] = buf.readByte();
		}
		String linkageName = StringNamesUtils.byteToString(linkageNamebyte);

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		if (linkageType == 1) {
			BaseApplication.getInstance().updateDeviceLinkageTask_callBack(state, linkageId, linkageName);
		} else {
			BaseApplication.getInstance().updateSceneLinkageTask_callBack(state, linkageId, linkageName);
		}
	}

	public static void updateLinkageName(ByteBuf buf) {
		// state
		int state = buf.readByte();
		int linkageId = buf.readShort();
		// taskType
		byte linkageType = buf.readByte();

		// linkageName
		byte[] linkageNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			linkageNamebyte[j] = buf.readByte();
		}
		String linkageName = StringNamesUtils.byteToString(linkageNamebyte);

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().updateLinkageName_callBack(state, linkageId, linkageType, linkageName);
	}

	public static void updateLinkageStutus(ByteBuf buf) {
		// TODO Auto-generated method stub
		// state
		int state = buf.readByte();
		int linkageId = buf.readShort();
		// taskType
		byte linkageType = buf.readByte();

		byte status = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().updateLinkageStutus_callBack(state);
	}

	public static void queryAllGaLinkage(ByteBuf buf) {

		List<LinkageInfo> linkageInfoList = new ArrayList<LinkageInfo>();

		buf.readByte();

		int TotalLinkages = buf.readByte();

		for (int i = 0; i < TotalLinkages; i++) {
			List<LinkageCondition> conditionList = new ArrayList<LinkageCondition>();

			List<LinkageTask> taskList = new ArrayList<LinkageTask>();

			int linkageId = buf.readShort();

			// LinkageType
			byte linkageType = buf.readByte();

			// LinkageName
			byte[] linkageNamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				linkageNamebyte[j] = buf.readByte();
			}
			String linkageName = StringNamesUtils.byteToString(linkageNamebyte);

			int totalCondition = buf.readByte();
			for (int j = 0; j < totalCondition; j++) {

				byte conditionType = buf.readByte();
				if (conditionType == 1) {
					byte[] uid = new byte[3];
					for (int z = 0; z < uid.length; z++) {
						uid[z] = buf.readByte();
					}
					byte symbol = buf.readByte();
					byte value = buf.readByte();

					buf.readByte();
					buf.readByte();
					buf.readByte();

					LinkageCondition condition = new LinkageCondition(uid, symbol, value, conditionType);
					conditionList.add(condition);
				}
				if (conditionType == 2) {
					byte month = buf.readByte();
					byte day = buf.readByte();
					byte weekdays = buf.readByte();
					byte symbol = buf.readByte();
					byte hour = buf.readByte();
					byte minute = buf.readByte();

					buf.readByte();
					buf.readByte();

					LinkageCondition condition = new LinkageCondition(symbol, conditionType, month, day, weekdays, hour,
							minute);
					conditionList.add(condition);
				}
			}

			int totalTask = buf.readByte();
			for (int j = 0; j < totalTask; j++) {
				if (linkageType == 1) {
					byte[] uid = new byte[3];
					for (int z = 0; z < uid.length; z++) {
						uid[z] = buf.readByte();
					}
					byte cmd = buf.readByte();
					byte value = buf.readByte();
					byte delay = buf.readByte();

					buf.readByte();
					buf.readByte();
					LinkageTask task = new LinkageTask(uid, cmd, value, delay);

					taskList.add(task);
				} else {
					int sceneid = buf.readShort();

					buf.readByte();
					buf.readByte();
					buf.readByte();

					byte delay = buf.readByte();

					buf.readByte();
					buf.readByte();

					LinkageTask task = new LinkageTask(delay, (byte) sceneid);
					taskList.add(task);
				}
			}

			int linkageStatus = buf.readByte();

			LinkageInfo linageInfo = new LinkageInfo(linkageType, linkageId, linkageName, conditionList, taskList,
					linkageStatus);
			linkageInfoList.add(linageInfo);
		}
		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryAllGaLinkage_callBack(linkageInfoList);
	}

	public static void queryGaLinkageByUid(ByteBuf buf) {
		List<LinkageInfo> linkageInfoList = new ArrayList<LinkageInfo>();

		buf.readByte();

		byte[] suid = new byte[3];
		for (int z = 0; z < suid.length; z++) {
			suid[z] = buf.readByte();
		}

		int TotalLinkages = buf.readByte();

		for (int i = 0; i < TotalLinkages; i++) {
			List<LinkageCondition> conditionList = new ArrayList<LinkageCondition>();

			List<LinkageTask> taskList = new ArrayList<LinkageTask>();

			int linkageId = buf.readShort();

			// LinkageType
			byte linkageType = buf.readByte();

			// LinkageName
			byte[] linkageNamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				linkageNamebyte[j] = buf.readByte();
			}
			String linkageName = StringNamesUtils.byteToString(linkageNamebyte);

			int totalCondition = buf.readByte();
			for (int j = 0; j < totalCondition; j++) {

				byte conditionType = buf.readByte();
				if (conditionType == 1) {
					byte[] uid = new byte[3];
					for (int z = 0; z < uid.length; z++) {
						uid[z] = buf.readByte();
					}
					byte symbol = buf.readByte();
					byte value = buf.readByte();

					buf.readByte();
					buf.readByte();
					buf.readByte();

					LinkageCondition condition = new LinkageCondition(uid, symbol, value, conditionType);
					conditionList.add(condition);
				}
				if (conditionType == 2) {
					byte month = buf.readByte();
					byte day = buf.readByte();
					byte weekdays = buf.readByte();
					byte symbol = buf.readByte();
					byte hour = buf.readByte();
					byte minute = buf.readByte();

					buf.readByte();
					buf.readByte();

					LinkageCondition condition = new LinkageCondition(symbol, conditionType, month, day, weekdays, hour,
							minute);
					conditionList.add(condition);
				}
			}

			int totalTask = buf.readByte();
			for (int j = 0; j < totalTask; j++) {
				if (linkageType == 1) {
					byte[] uid = new byte[3];
					for (int z = 0; z < uid.length; z++) {
						uid[z] = buf.readByte();
					}
					byte cmd = buf.readByte();
					byte value = buf.readByte();
					byte delay = buf.readByte();

					buf.readByte();
					buf.readByte();
					LinkageTask task = new LinkageTask(uid, cmd, value, delay);

					taskList.add(task);
				} else {
					int sceneid = buf.readShort();

					buf.readByte();
					buf.readByte();
					buf.readByte();

					byte delay = buf.readByte();

					buf.readByte();
					buf.readByte();

					LinkageTask task = new LinkageTask(delay, (byte) sceneid);
					taskList.add(task);
				}
			}

			int linkageStatus = buf.readByte();

			LinkageInfo linageInfo = new LinkageInfo(linkageType, linkageId, linkageName, conditionList, taskList,
					linkageStatus);
			linkageInfoList.add(linageInfo);
		}
		// TBD
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryGaLinkageByUid_callBack(linkageInfoList);
	}

	public static void deleteDevice(ByteBuf buf) {
		int state = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().deleteDevice_callBack(state);
	}

	public static void deviceKeyConfigure(ByteBuf buf) {

		int state = buf.readByte();

		byte[] keyUid = new byte[3];
		for (int z = 0; z < keyUid.length; z++) {
			keyUid[z] = buf.readByte();
		}

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().deviceKeyConfigure_callBack(keyUid, state);
	}

	public static void deleteConfigureOfDeviceKey(ByteBuf buf) {

		int state = buf.readByte();

		byte[] keyUid = new byte[3];
		for (int z = 0; z < keyUid.length; z++) {
			keyUid[z] = buf.readByte();
		}

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().deleteConfigureOfDeviceKey_callBack(keyUid, state);
	}

	public static void queryAllConfigureOfTheDevice(ByteBuf buf) {

		List<ScenePanelInfo> list = new ArrayList<ScenePanelInfo>();

		int state = buf.readByte();

		byte[] ieeeAddr = new byte[8];
		for (int i = 0; i < ieeeAddr.length; i++) {
			ieeeAddr[i] = buf.readByte();
		}

		int totalConfigures = buf.readByte();

		for (int i = 0; i < totalConfigures; i++) {

			byte[] keyUid = new byte[3];
			for (int y = 0; y < keyUid.length; y++) {
				keyUid[y] = buf.readByte();
			}

			byte taskType = buf.readByte();

			int totalTasks = buf.readByte();

			List<ScenePanelTask> taskList = new ArrayList<ScenePanelTask>();

			for (int j = 0; j < totalTasks; j++) {

				if (taskType == 1) {
					byte[] uid = new byte[3];
					for (int y = 0; y < uid.length; y++) {
						uid[y] = buf.readByte();
					}

					byte cmd = buf.readByte();
					byte value = buf.readByte();
					byte delay = buf.readByte();
					buf.readByte();
					buf.readByte();
					ScenePanelTask task = new ScenePanelTask(uid, cmd, value, delay);
					taskList.add(task);
				} else {
					int sceneId = buf.readShort();
					buf.readByte();
					buf.readByte();
					buf.readByte();
					byte delay = buf.readByte();
					buf.readByte();
					buf.readByte();
					ScenePanelTask task = new ScenePanelTask(delay, sceneId);
					taskList.add(task);
				}
			}

			ScenePanelInfo scenePanelInfo = new ScenePanelInfo(keyUid, taskType, taskList);
			list.add(scenePanelInfo);
		}
		BaseApplication.getInstance().queryAllConfigureOfTheDevice_callBack(list);
	}

	public static void setTheThermostatMode(ByteBuf buf) {

		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		int modelValue = buf.readByte();
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().setTheThermostatMode_callBack(uid, modelValue);
	}

	public static void setTheWindSpeed(ByteBuf buf) {

		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		int speed = buf.readByte();
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().setTheWindSpeed_callBack(uid, speed);
	}

	public static void adjusttTheTemperature(ByteBuf buf) {

		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		int value = buf.readByte();
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().adjusttTheTemperature_callBack(uid, value);

	}

	public static void setTheRunModeThatPowerResume(ByteBuf buf) {

		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		int value = buf.readByte();
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().setTheRunModeThatPowerResume_callBack(uid, value);
	}

	public static void queryTheThermostatConfigureInfo(ByteBuf buf) {

		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		int switchState = buf.readByte();
		int mode = buf.readByte();
		int speed = buf.readByte();
		int temperature = buf.readShort();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		ThermostatConfigureInfo thermostatConfigureInfo = new ThermostatConfigureInfo(uid, switchState, mode, speed,
				temperature);
		BaseApplication.getInstance().queryTheThermostatConfigureInfo_callBack(thermostatConfigureInfo);
	}

	public static void queryTheThermostatRunStatus(ByteBuf buf) {

		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		int fault = buf.readByte();
		int switchState = buf.readByte();
		int mode = buf.readByte();
		int speed = buf.readByte();
		int temperature = buf.readShort();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		ThermostatRunStatusInfo thermostatRunStatusInfo = new ThermostatRunStatusInfo(uid, fault, switchState, mode,
				speed, temperature);
		BaseApplication.getInstance().queryTheThermostatRunStatus_callBack(thermostatRunStatusInfo);
	}

	public static void setThermostatState(ByteBuf buf) {
		// TODO Auto-generated method stub
		buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		int state = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().setThermostatState_callBack(uid, state);
	}

	public static void setDoorlockSwitchState(ByteBuf buf) {

		int state = buf.readByte();

		for (int i = 0; i < 14; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().setDoorlockSwitchState_callBack(state);

	}

	public static void queryGyDoorlockSwitchState(ByteBuf buf) {

		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		int switchState = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryGyDoorlockSwitchState_callBack(uid, switchState);
	}

	public static void queryDoorlockRecentStatus(ByteBuf buf) {

		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		int normalOpen = buf.readByte();

		int electric = buf.readByte();

		int totaluser = buf.readByte();

		int houseKeeper = buf.readByte();

		int renter = buf.readByte();

		int casual = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		DoorlockRecentStatusInfo info = new DoorlockRecentStatusInfo(uid, normalOpen, electric, totaluser, houseKeeper,
				renter, casual);

		BaseApplication.getInstance().queryDoorlockRecentStatus_callBack(info);

	}

	public static void queryAllLockUserInfo(ByteBuf buf) {

		List<LockUserInfo> infos = new ArrayList<LockUserInfo>();

		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		int totalUsers = buf.readByte();

		for (int i = 0; i < totalUsers; i++) {
			// username
			byte[] namebyte = new byte[8];
			for (int j = 0; j < 8; j++) {
				namebyte[j] = buf.readByte();
			}
			String name = StringNamesUtils.byteToString(namebyte);

			int permission = buf.readByte();
			int userType = buf.readByte();
			int userState = buf.readByte();
			int addType = buf.readByte();

			byte[] createTimebyte = new byte[6];
			for (int j = 0; j < 6; j++) {
				createTimebyte[j] = buf.readByte();
			}
			String createTime = StringNamesUtils.byteToString(createTimebyte);

			LockUserInfo info = new LockUserInfo(permission, name, userType, userState, addType, createTime);
			infos.add(info);
		}

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryAllLockUserInfo_callBack(infos);
	}

	public static void doorlockEventPush(ByteBuf buf) {

		int state = buf.readByte();

		byte[] ieee = new byte[8];
		for (int z = 0; z < ieee.length; z++) {
			ieee[z] = buf.readByte();
		}

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		int eventType = buf.readByte();

		int event = buf.readByte();

		byte[] time = new byte[6];
		for (int z = 0; z < time.length; z++) {
			time[z] = buf.readByte();
		}

		int permission = buf.readByte();

		byte[] namebyte = new byte[8];
		for (int j = 0; j < 8; j++) {
			namebyte[j] = buf.readByte();
		}
		String name = StringNamesUtils.byteToString(namebyte);

		BaseApplication.getInstance().doorlockEventPush(ieee, uid, eventType, event, time, permission, name);
	}

	public static void queryLockMachineCode(ByteBuf buf) {
		// TODO Auto-generated method stub
		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		byte[] machineCodebyte = new byte[10];
		for (int j = 0; j < 10; j++) {
			machineCodebyte[j] = buf.readByte();
		}
		System.out.println("machineCodebyte:" + Test16Binary.bytes2hex03(machineCodebyte));

		String machineCode = StringNamesUtils.byteToString(machineCodebyte);

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryLockMachineCode_callBack(uid, machineCode);
	}

	public static void bindDevice(ByteBuf buf) {

		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().bindDevice_callBack(state);
	}

	public static void cancelBind(ByteBuf buf) {

		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().cancelBind_callBack(state);
	}

	public static void queryAllBind(ByteBuf buf) {

		List<BindDeviceInfo> list = new ArrayList<BindDeviceInfo>();

		int state = buf.readByte();

		byte[] ieeeAddr = new byte[8];
		for (int z = 0; z < ieeeAddr.length; z++) {
			ieeeAddr[z] = buf.readByte();
		}

		int TotalBinds = buf.readByte();

		for (int i = 0; i < TotalBinds; i++) {
			byte[] srcuid = new byte[3];
			for (int z = 0; z < srcuid.length; z++) {
				srcuid[z] = buf.readByte();
			}

			byte[] destuid = new byte[3];
			for (int z = 0; z < destuid.length; z++) {
				destuid[z] = buf.readByte();
			}

			BindDeviceInfo info = new BindDeviceInfo(srcuid, destuid);
			list.add(info);
		}

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryAllBind_callBack(list);
	}

	public static void queryAlarmRecords(ByteBuf buf) {

		List<AlarmRecordsInfo> list = new ArrayList<AlarmRecordsInfo>();

		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		int totalRecords = buf.readByte();
		for (int i = 0; i < totalRecords; i++) {

			int recordId = buf.readShort();
			byte[] srcuid = new byte[3];
			for (int z = 0; z < srcuid.length; z++) {
				srcuid[z] = buf.readByte();
			}

			// srcDevName
			byte[] srcDevNamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				srcDevNamebyte[j] = buf.readByte();
			}
			String srcDevName = StringNamesUtils.byteToString(srcDevNamebyte);

			int ruleSymbol = buf.readByte();

			int ruleValue = buf.readByte();

			byte[] createTime = new byte[6];
			buf.readBytes(createTime);

			String ct = "20" + createTime[0] + "-" + createTime[1] + "-" + createTime[2] + " " + createTime[3] + ":"
					+ createTime[4] + ":" + createTime[5];

			AlarmRecordsInfo info = new AlarmRecordsInfo(recordId, srcuid, srcDevName, ruleSymbol, ruleValue, ct);
			list.add(info);
		}

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryAlarmRecords_callBack(list);
	}

	public static void deviceEmergencyAlarmPush(ByteBuf buf) {
		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		byte[] profileId = new byte[2];
		buf.readBytes(profileId);

		byte[] deviceID = new byte[2];
		buf.readBytes(deviceID);

		byte[] attrID = new byte[2];
		buf.readBytes(attrID);

		int alarmType = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().deviceEmergencyAlarmPush(uid, alarmType);
	}

	public static void getK1DeviceStates(ByteBuf buf) {

		Map<Integer, String> stateMap = new HashMap<Integer, String>();

		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		int count = buf.readByte();

		for (int i = 0; i < count; i++) {
			int type = buf.readByte();
			int length = buf.readByte();
			String value = "";
			if (length == 1) {
				value = buf.readByte() + "";
			}
			if (length == 2) {
				value = buf.readShort() + "";
			}
			if (length == 4) {
				value = buf.readInt() + "";
			}
			stateMap.put(type, value);
		}

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().getK1DeviceStates_callBack(uid, stateMap);
	}

	public static void reportk1State(ByteBuf buf) {

		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		int type = buf.readByte();
		int length = buf.readByte();
		String value = "";
		if (length == 1) {
			value = buf.readByte() + "";
		}
		if (length == 2) {
			value = buf.readShort() + "";
		}
		if (length == 4) {
			value = buf.readInt() + "";
		}

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().reportk1State(uid, type, value);
	}

	public static void reportK1Abnormal(ByteBuf buf) {

		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		int code = buf.readByte();

		// memberName
		byte[] memberNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			memberNamebyte[j] = buf.readByte();
		}
		String memberName = StringNamesUtils.byteToString(memberNamebyte);

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().reportK1Abnormal(uid, code, memberName);
	}

	public static void getK1KeysId(ByteBuf buf) {
		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		// userName
		byte[] uesrNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			uesrNamebyte[j] = buf.readByte();
		}
		String userName = StringNamesUtils.byteToString(uesrNamebyte);

		int id = buf.readShort();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().getK1KeysId_callBack(uid, userName, id);
	}

	public static void getK1Member(ByteBuf buf) {

		List<K1MemberInfo> infos = new ArrayList<K1MemberInfo>();

		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		int count = buf.readByte();

		for (int i = 0; i < count; i++) {
			int memberId = buf.readShort();
			// memberName
			byte[] memberNamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				memberNamebyte[j] = buf.readByte();
			}
			String memberName = StringNamesUtils.byteToString(memberNamebyte);

			// username
			byte[] usernamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				usernamebyte[j] = buf.readByte();
			}
			String username = StringNamesUtils.byteToString(usernamebyte);

			int access = buf.readByte();

			K1MemberInfo info = new K1MemberInfo();
			info.setAccess(access);
			info.setId(memberId);
			info.setUsername(username);
			info.setName(memberName);

			infos.add(info);
		}

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().getK1Member_callBack(infos);
	}

	public static void addK1Member(ByteBuf buf) {

		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}

		int id = buf.readShort();

		// username
		byte[] memberNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			memberNamebyte[j] = buf.readByte();
		}
		String memberName = StringNamesUtils.byteToString(memberNamebyte);

		int access = buf.readByte();
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().addK1Member_callBack(state,id,memberName);
	}

	public static void deleteK1Member(ByteBuf buf) {
		
		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		int id = buf.readShort();
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().deleteK1Member_callBack(state);

	}

	public static void updateK1MemberName(ByteBuf buf) {
		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		int id = buf.readShort();
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().updateK1MemberName_callBack(state);
	}

	public static void getK1MemberInfo(ByteBuf buf) {
		
		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		int id = buf.readShort();
		
		int networkKeyId = buf.readShort();
		
		int passwordKeyId = buf.readShort();
		
		int antiHijackPasswordKeyId = buf.readShort();
		
		int antiHijackFingerprintKeyId = buf.readShort();
		
		int count = buf.readByte();
		Map<Integer, String> fingerprints = new HashMap<Integer, String>();
		
		for (int i = 0; i < count; i++) {
			int fingerprintId = buf.readShort();
			// fingerprint
			byte[] fingerprintNamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				fingerprintNamebyte[j] = buf.readByte();
			}
			String fingerprintName = StringNamesUtils.byteToString(fingerprintNamebyte);
			
			fingerprints.put(fingerprintId, fingerprintName);
		}
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		K1MemberDetailsInfo info = new K1MemberDetailsInfo();
		info.setAntiHijackFingerprintKeyId(antiHijackFingerprintKeyId);
		info.setAntiHijackPasswordKeyId(antiHijackPasswordKeyId);
		info.setMembeId(id);
		info.setNetworkKeyId(networkKeyId);
		info.setPasswordKeyId(passwordKeyId);
		info.setUid(uid);
		info.setFingerprints(fingerprints);
		
		BaseApplication.getInstance().getK1MemberInfo_callBack(info);
		
	}

	public static void addK1Key(ByteBuf buf) {
		
		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		buf.readShort();
		
		int type = buf.readByte();
		
		buf.readShort();
		
		/*if (type ==2) {
			byte[] keyNamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				keyNamebyte[j] = buf.readByte();
			}
			String keyName = StringNamesUtils.byteToString(keyNamebyte);
		}*/
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().addK1Key_callBack(state);
	}

	public static void reportFingerprintState(ByteBuf buf) {
		
		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		int memberId = buf.readShort();
		
		int keyType = buf.readByte();
		
		int keyId = buf.readShort();
		
		int fstate = buf.readByte();
		
		int number = buf.readByte();
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().reportFingerprintState(uid, memberId, keyType, keyId, fstate, number);
		
	}

	public static void deteteK1Key(ByteBuf buf) {
		
		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		int memberId = buf.readShort();
		
		int keyType = buf.readByte();
		
		int keyId = buf.readShort();
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().deteteK1Key_callBack(state);
	}

	public static void updateK1Password(ByteBuf buf) {
		
		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		int memberId = buf.readShort();
		
		int keyType = buf.readByte();
		
		int keyId = buf.readShort();
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().updateK1Password_callBack(state);
	}

	public static void updateK1FingerprintName(ByteBuf buf) {
		
		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		int memberId = buf.readShort();
		
		int keyType = buf.readByte();
		
		int keyId = buf.readShort();
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().updateK1FingerprintName_callBack(state);
	}

	public static void getK1RecordList(ByteBuf buf) {
		
		List<K1RecordInfo> infos = new ArrayList<K1RecordInfo>();
		
		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		int page = buf.readByte();
		
		int count = buf.readByte();
		
		for (int i = 0; i < count; i++) {
			int id = buf.readShort();
			
			int type = buf.readByte();
			
			int code = buf.readByte();
			
			int sstate = buf.readByte();
			
			byte[] memberNamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				memberNamebyte[j] = buf.readByte();
			}
			String memberName = StringNamesUtils.byteToString(memberNamebyte);
			
			byte[] timebyte = new byte[6];
			for (int j = 0; j < 6; j++) {
				timebyte[j] = buf.readByte();
			}
			
			
			K1RecordInfo info = new K1RecordInfo();
			info.setCode(code);
			info.setId(id);
			info.setMemberName(memberName);
			info.setState(sstate);
			info.setType(type);
			info.setDateTime(EffectiveTimeUtils.byteToTime(timebyte));
			
			infos.add(info);
		}
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().getK1RecordList_callBack(uid, page, infos);
		
	}

	public static void deleteK1Record(ByteBuf buf) {
		

		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		buf.readByte();
		buf.readByte();
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().deleteK1Record_callBack(state);
	}

	public static void relieveAlarm(ByteBuf buf) {
		
		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		buf.readByte();
		buf.readShort();
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().relieveAlarm_callBack(state);
	}

	public static void addK1TemPassword(ByteBuf buf) {
		
		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		byte[] namebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			namebyte[j] = buf.readByte();
		}
		String name = StringNamesUtils.byteToString(namebyte);
		
		byte[] numberbyte = new byte[16];
		for (int j = 0; j < 16; j++) {
			numberbyte[j] = buf.readByte();
		}
		String number = StringNamesUtils.byteToString(numberbyte);
		
		int id = buf.readShort();
		
		int passwordId = buf.readShort();
		
		int pstate = buf.readByte();
		
		String addTime = "";	
		
		byte[] timebyte = new byte[6];
		for (int j = 0; j < 6; j++) {
			timebyte[j] = buf.readByte();
		}
		
		addTime = EffectiveTimeUtils.byteToTime(timebyte);
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().addK1TemPassword_callBack(state,uid, name, number, id, passwordId, pstate, addTime);
	}

	public static void deleteK1TemPassword(ByteBuf buf) {
		
		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		buf.readShort();
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().deleteK1TemPassword_callBack(state);
		
	}

	public static void getK1TemPassworkList(ByteBuf buf) {
		
		List<K1TemPassworkInfo> infos = new ArrayList<K1TemPassworkInfo>();
		
		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		int page = buf.readByte();
		
		int count = buf.readByte();
		
		for (int i = 0; i < count; i++) {
			int rid = buf.readShort();
			
			byte[] namebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				namebyte[j] = buf.readByte();
			}
			String name = StringNamesUtils.byteToString(namebyte);
			
			byte[] numberbyte = new byte[16];
			for (int j = 0; j < 16; j++) {
				numberbyte[j] = buf.readByte();
			}
			String number = StringNamesUtils.byteToString(numberbyte);
			
			int pwdId = buf.readShort();
			
			int pwdState = buf.readByte();
			
			byte[] createTimebyte = new byte[6];
			for (int j = 0; j < 6; j++) {
				createTimebyte[j] = buf.readByte();
			}
			
			byte[] operTimebyte = new byte[6];
			for (int j = 0; j < 6; j++) {
				operTimebyte[j] = buf.readByte();
			}
			
			K1TemPassworkInfo info = new K1TemPassworkInfo();
			info.setId(rid);
			info.setName(name);
			info.setNumber(number);
			info.setPwdId(pwdId);
			info.setState(pwdState);
			info.setAddTime(EffectiveTimeUtils.byteToTime(createTimebyte));
			info.setOperTime(EffectiveTimeUtils.byteToTime(operTimebyte));
			infos.add(info);
		}
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().getK1TemPassworkList_callBack(uid, page, infos);
	}

	public static void deleteTemPasswordRecords(ByteBuf buf) {
		
		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		 buf.readByte();
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().deleteTemPasswordRecords_callBack(state);
	}

	public static void reportHijack(ByteBuf buf) {
		
		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		int code = buf.readByte();
		
		byte[] namebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			namebyte[j] = buf.readByte();
		}
		String name = StringNamesUtils.byteToString(namebyte);
		
		int count = buf.readByte();
		
		List<String> phones = new ArrayList<String>();
		
		for (int i = 0; i < count; i++) {
			byte[] phonebyte = new byte[16];
			for (int j = 0; j < 16; j++) {
				phonebyte[j] = buf.readByte();
			}
			String phone = StringNamesUtils.byteToString(phonebyte);
			phones.add(phone);
		}
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().reportHijack(uid, code, name, phones);
	}

	public static void getK1Infos(ByteBuf buf) {
		
		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		int type = buf.readByte();
		
		int length = buf.readByte();
		System.out.println("length"+length);
		String value = "";
		if (length !=0) {
			if (type ==1 || type == 2 ) {
				byte[] vbyte = new byte[length];
				for (int j = 0; j < length; j++) {
					vbyte[j] = buf.readByte();
				}
				value = Test16Binary.bytes2hex04(vbyte);
			}else if(type ==3 ){
				byte[] vbyte = new byte[length];
				for (int j = 0; j < length; j++) {
					vbyte[j] = buf.readByte();
				}
				value = new String(vbyte);
			}else if(type==5){
				byte[] vbyte = new byte[length];
				for (int j = 0; j < length; j++) {
					vbyte[j] = buf.readByte();
				}
				value = vbyte[0]+"."+vbyte[1]+vbyte[2];
			}else if(type==4){
				byte[] vbyte = new byte[length];
				for (int j = 0; j < length; j++) {
					vbyte[j] = buf.readByte();
				}
				value = Test16Binary.bytes2hex05(vbyte);
			}else{
				value = buf.readInt()+"";
			}
		}
		
		 
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().getK1Infos_callBack(uid, value);
		
	}

	public static void upgradeK1Request(ByteBuf buf) {
		// TODO Auto-generated method stub
		int state = buf.readByte();
		
		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		int version = buf.readInt();
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().upgradeK1Request_callBack(state);
	}

	public static void reportUpgradeK1(ByteBuf buf) {
		
		int state = buf.readByte();
		
		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		int version = buf.readInt();
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().reportUpgradeK1(version);
		
	}

	public static void vilidateK1Pwd(ByteBuf buf) {
		// TODO Auto-generated method stub
		int state = buf.readByte();
		
		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		buf.readShort();
		buf.readByte();
		buf.readShort();
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().vilidateK1Pwd_callBack(state);
	}

	public static void configurWIFIInfo(ByteBuf buf) {
		// TODO Auto-generated method stub
		int state = buf.readByte();
		
		int cmd = buf.readByte();
		
		byte[] ssidbyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			ssidbyte[j] = buf.readByte();
		}
		String ssid = StringNamesUtils.byteToString(ssidbyte);
		byte[] pwdbyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			pwdbyte[j] = buf.readByte();
		}
		String pwd = StringNamesUtils.byteToString(pwdbyte);
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().configurWIFIInfo_callBack(state,cmd,ssid,pwd);
	}

	public static void searchWifi(ByteBuf buf) {
		// TODO Auto-generated method stub
		int state = buf.readByte();
		
		int total = buf.readByte();
		List<String> list = new ArrayList<String>();
		for (int i = 0; i < total; i++) {
			byte[] ssidbyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				ssidbyte[j] = buf.readByte();
			}
			String ssid = StringNamesUtils.byteToString(ssidbyte);
			list.add(ssid);
		}
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().searchWifi_callBack(list);
	}

	public static void reportUpgradeSpeed(ByteBuf buf) {
		
		int state = buf.readByte();
		
		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		int speed = buf.readByte();
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().reportUpgradeSpeed(uid, speed);
	}

	public static void m1notic(ByteBuf buf) {
		
		int state = buf.readByte();
		
		int ntype = buf.readByte();
		
		byte[] pwdbyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			pwdbyte[j] = buf.readByte();
		}
		String pwd = StringNamesUtils.byteToString(pwdbyte);
		
		byte[] snByte = new byte[8];
		for (int j = 0; j < 8; j++) {
			snByte[j] = buf.readByte();
		}
		String sn = StringNamesUtils.byteToString(snByte);
		
		for (int i = 0; i < 2; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().reportM1Notice(ntype, sn);
		
	}

	public static void set3DModule(ByteBuf buf) {
		
		int state = buf.readByte();
		
		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		int type = buf.readByte();
		
		byte length = buf.readByte();
		
		int value = buf.readUnsignedByte();
		
		for (int i = 0; i < 2; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().set3DModule_callback(state,type,value);
		
	}

	public static void getK1RecordListAnd3d(ByteBuf buf) {

		List<K1RecordInfo> infos = new ArrayList<K1RecordInfo>();
		
		int state = buf.readByte();

		byte[] uid = new byte[3];
		for (int z = 0; z < uid.length; z++) {
			uid[z] = buf.readByte();
		}
		
		int page = buf.readByte();
		
		int count = buf.readByte();
		
		for (int i = 0; i < count; i++) {
			int id = buf.readShort();
			
			int type = buf.readByte();
			
			int code = buf.readByte();
			
			int sstate = buf.readByte();
			
			byte[] memberNamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				memberNamebyte[j] = buf.readByte();
			}
			String memberName = StringNamesUtils.byteToString(memberNamebyte);
			
			byte[] timebyte = new byte[6];
			for (int j = 0; j < 6; j++) {
				timebyte[j] = buf.readByte();
			}
			
			int angle = buf.readUnsignedByte();
			
			int knocking = buf.readByte();
			
			K1RecordInfo info = new K1RecordInfo();
			info.setCode(code);
			info.setId(id);
			info.setMemberName(memberName);
			info.setState(sstate);
			info.setType(type);
			info.setDateTime(EffectiveTimeUtils.byteToTime(timebyte));
			info.setAngle(angle);
			info.setKnocking(knocking);
			infos.add(info);
		}
		
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		
		BaseApplication.getInstance().getK1RecordList_callBack(uid, page, infos);
		
	}

}
