package com.b_noble.n_life.handler.processing;

import java.io.UnsupportedEncodingException;

import com.b_noble.n_life.info.IrLinkageInfo;
import com.b_noble.n_life.info.IrTaskCmdInfo;
import com.b_noble.n_life.model.RequestCustomRemoteControlData;
import com.b_noble.n_life.model.RequestGetIrDeviceInfoData;
import com.b_noble.n_life.model.RequestIrColorTemperatureData;
import com.b_noble.n_life.model.RequestIrDeviceSwitchStateData;
import com.b_noble.n_life.model.RequestIrLigthBrightnessData;
import com.b_noble.n_life.model.RequestIrLigthHueAndSatData;
import com.b_noble.n_life.model.RequestIrModeData;
import com.b_noble.n_life.model.RequestIrTaskData;
import com.b_noble.n_life.model.RequestLinkageDetailsData;
import com.b_noble.n_life.model.RequestRemoveIrDeviceData;
import com.b_noble.n_life.model.RequestReportNewDeviceData;
import com.b_noble.n_life.model.RequestRequireRICodeData;
import com.b_noble.n_life.model.RequestResetRemoteControlData;
import com.b_noble.n_life.model.RequestSmartModeData;
import com.b_noble.n_life.model.RequestTHInformationData;
import com.b_noble.n_life.model.RequestToUpgradeData;
import com.b_noble.n_life.model.RequestUpdateIrDeviceNameData;
import com.b_noble.n_life.model.RequestWifiNetworkInformationData;

import io.netty.buffer.ByteBuf;

/**
 * 公司：深圳市中泰智丰物联网科技有限公司 项目：智能家居 简述：编码处理实现类 作者：zhangfan 时间：2017-03-18 版本：V0.0.1
 */
public class IrEncoderProcessingRealization {

	public static void quiryIrAllDevice(ByteBuf buf) {

		// state
		buf.writeByte(0xFF);

		// total packets
		buf.writeByte(0x01);

		// Current packet
		buf.writeByte(0x01);

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void getIrDeviceInfo(RequestGetIrDeviceInfoData data, ByteBuf buf) {

		// state
		buf.writeByte(0xFF);

		// total packets
		buf.writeByte(0x01);

		// Current packet
		buf.writeByte(0x01);

		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getIrid());

		buf.writeByte(data.getRequestCode());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void setIrDeviceSwitchState(RequestIrDeviceSwitchStateData data, ByteBuf buf) {

		// state
		buf.writeByte(0xFF);

		// total packets
		buf.writeByte(0x01);

		// Current packet
		buf.writeByte(0x01);

		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getIrid());
		
		buf.writeByte(data.getEffective());

		buf.writeByte(data.getSwitchState());
		
		buf.writeByte(data.getBrigth());
		
		buf.writeByte(data.getSaturation());
		
		buf.writeByte(data.getR());
		buf.writeByte(data.getG());
		buf.writeByte(data.getB());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void getIrDeviceSwitchState(RequestIrDeviceSwitchStateData data, ByteBuf buf) {

		// state
		buf.writeByte(0xFF);

		// total packets
		buf.writeByte(0x01);

		// Current packet
		buf.writeByte(0x01);

		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getIrid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void setIrLigthBrightness(RequestIrLigthBrightnessData data, ByteBuf buf) {

		// state
		buf.writeByte(0xFF);

		// total packets
		buf.writeByte(0x01);

		// Current packet
		buf.writeByte(0x01);

		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getIrid());

		buf.writeByte(data.getBrightCommand());

		buf.writeShort(data.getCutTime());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void getIrLigthBrightness(RequestIrLigthBrightnessData data, ByteBuf buf) {

		// state
		buf.writeByte(0xFF);

		// total packets
		buf.writeByte(0x01);

		// Current packet
		buf.writeByte(0x01);

		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getIrid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}

	}

	public static void setIrLigthHueAndSat(RequestIrLigthHueAndSatData data, ByteBuf buf) {

		// state
		buf.writeByte(0xFF);

		// total packets
		buf.writeByte(0x01);

		// Current packet
		buf.writeByte(0x01);

		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getIrid());

		buf.writeByte(data.getR());

		buf.writeByte(data.getG());

		buf.writeByte(data.getB());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void getIrLigthHueAndSat(RequestIrLigthHueAndSatData data, ByteBuf buf) {

		// state
		buf.writeByte(0xFF);

		// total packets
		buf.writeByte(0x01);

		// Current packet
		buf.writeByte(0x01);

		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getIrid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void setColorTemperature(RequestIrColorTemperatureData data, ByteBuf buf) {

		// state
		buf.writeByte(0xFF);

		// total packets
		buf.writeByte(0x01);

		// Current packet
		buf.writeByte(0x01);

		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getIrid());

		buf.writeShort(data.getColorTemperature());

		buf.writeShort(data.getSwitchTime());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void getColorTemperature(RequestIrColorTemperatureData data, ByteBuf buf) {

		// state
		buf.writeByte(0xFF);

		// total packets
		buf.writeByte(0x01);

		// Current packet
		buf.writeByte(0x01);

		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getIrid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void setLampSensingMode(RequestIrModeData data, ByteBuf buf) {

		// state
		buf.writeByte(0xFF);

		// total packets
		buf.writeByte(0x01);

		// Current packet
		buf.writeByte(0x01);

		buf.writeByte(data.getSwitchState());

		buf.writeShort(data.getKeepTime());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void setLightAmbilightMode(RequestIrModeData data, ByteBuf buf) {

		// state
		buf.writeByte(0xFF);

		// total packets
		buf.writeByte(0x01);

		// Current packet
		buf.writeByte(0x01);

		buf.writeByte(data.getSwitchState());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void requireRemoteControlInfraredCode(RequestRequireRICodeData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		// total packets
		buf.writeByte(0x01);

		// Current packet
		buf.writeByte(0x01);

		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getIrid());

		buf.writeBytes(data.getIrCode().getBytes());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryAllIrTask(ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void addIrTask(RequestIrTaskData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeByte(data.getTasktype());

		try {
			buf.writeBytes(data.getIrTaskInfo().getTaskName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getIrTaskInfo().getTaskName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		buf.writeBytes(data.getIrTaskInfo().getIrid());

		buf.writeByte(data.getIrTaskInfo().getTaskTimerAction().getM());
		buf.writeByte(data.getIrTaskInfo().getTaskTimerAction().getH());
		buf.writeByte(data.getIrTaskInfo().getTaskTimerAction().getS());
		buf.writeByte(data.getIrTaskInfo().getTaskTimerAction().getWorkMode());

		buf.writeByte(data.getIrTaskInfo().getKey());

		// buf.writeBytes(IrTaskCmdInfo.tobytes(data.getIrTaskInfo().getIrtaskCmdInfo()));
		if (data.getIrTaskInfo().getTaskflag() == 0) {
			buf.writeByte(data.getIrTaskInfo().getIrtaskCmdInfo().getLigthSwitch());
			buf.writeByte(data.getIrTaskInfo().getIrtaskCmdInfo().getLigthMode());
		} else {
			buf.writeBytes(data.getIrTaskInfo().getInfraredcode().getBytes());
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void deleteIrTask(RequestIrTaskData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeByte(data.getTaskid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void updateIrTask(RequestIrTaskData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeByte(data.getTasktype());

		try {
			buf.writeBytes(data.getIrTaskInfo().getTaskName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getIrTaskInfo().getTaskName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		buf.writeByte(data.getTaskid());

		buf.writeBytes(data.getIrTaskInfo().getIrid());

		buf.writeByte(data.getIrTaskInfo().getTaskTimerAction().getM());
		buf.writeByte(data.getIrTaskInfo().getTaskTimerAction().getH());
		buf.writeByte(data.getIrTaskInfo().getTaskTimerAction().getS());
		buf.writeByte(data.getIrTaskInfo().getTaskTimerAction().getWorkMode());

		buf.writeByte(data.getIrTaskInfo().getKey());

		if (data.getIrTaskInfo().getTaskflag() != 1) {
			buf.writeByte(data.getIrTaskInfo().getIrtaskCmdInfo().getLigthSwitch());
			buf.writeByte(data.getIrTaskInfo().getIrtaskCmdInfo().getLigthMode());
		} else {
			buf.writeBytes(data.getIrTaskInfo().getInfraredcode().getBytes());
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryIrTaskInfo(RequestIrTaskData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeByte(data.getTasktype());

		buf.writeByte(data.getTaskid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryAllIrtaskInfo(ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryIrTaskInfoByDevice(ByteBuf buf) {
		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void updateIrTaskState(RequestIrTaskData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeByte(data.getTaskid());
		buf.writeByte(data.getState());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void getRemoteControlInformation(ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void setWifiNetworkInformation(RequestWifiNetworkInformationData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		try {
			buf.writeBytes(data.getSsid().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getSsid().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		try {
			buf.writeBytes(data.getPwd().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getPwd().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void requestWifiNetworkInformation(ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void resetRemoteControl(RequestResetRemoteControlData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeByte(data.getResetCommand());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void requestTemperatureInformation(RequestTHInformationData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getIrid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void requestHumidityInformation(RequestTHInformationData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getIrid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void reportNewDevice(RequestReportNewDeviceData data, ByteBuf buf) {
		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeByte(data.getDevType());

		buf.writeShort(data.getDevkindsid());

		try {
			buf.writeBytes(data.getDevName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getDevName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void removeIrDevice(RequestRemoveIrDeviceData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getIrid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void updateIrDeviceName(RequestUpdateIrDeviceNameData data, ByteBuf buf) {
		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeByte(data.getAddressMode());

		buf.writeBytes(data.getIrid());

		try {
			buf.writeBytes(data.getDeviceName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getDeviceName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void addIrLinkage(IrLinkageInfo data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		// linkageType
		buf.writeByte(data.getLinkageType());

		// linkageName
		try {
			buf.writeBytes(data.getTaskName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getTaskName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		buf.writeBytes(data.getSourceIrid());

		buf.writeBytes(data.getLinkageIrid());

		buf.writeByte(data.getRuleMin());

		buf.writeByte(data.getRuleMax());

		buf.writeByte(data.getRuleVal());

		buf.writeByte(0x00);

		if (data.getLinkageType() == 1) {
			// cmd
			buf.writeByte(data.getIrTaskCmdInfo().getLigthSwitch());

			buf.writeByte(data.getIrTaskCmdInfo().getLigthMode());
		} else {

			try {
				buf.writeBytes(data.getInfraredcode().getBytes());
			} catch (Exception e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryAllLinkage(ByteBuf buf) {
		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void queryLinkageDetails(RequestLinkageDetailsData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeByte(data.getLinkageid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void deleteLinkage(RequestLinkageDetailsData data, ByteBuf buf) {
		// TODO Auto-generated method stub
		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeByte(data.getLinkageid());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void setSmartMode(RequestSmartModeData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		try {
			buf.writeBytes(data.getSmartName().getBytes("gbk"));
			for (int i = 0; i < 32 - data.getSmartName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		buf.writeBytes(data.getIrid());

		buf.writeByte(data.getAmbientTemperature());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void setSmartModeLowTemperatureCmd(RequestSmartModeData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeByte(data.getTemperature());

		buf.writeBytes(data.getIrcode().getBytes());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void setSmartModeHighTemperatureCmd(RequestSmartModeData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeByte(data.getTemperature());

		buf.writeBytes(data.getIrcode().getBytes());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void querySmartMode(ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void updateSmartState(RequestSmartModeData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeByte(data.getState());
		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void requestRemoteControlVersion(ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void requestToUpgrade(RequestToUpgradeData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeByte(data.getTotalPackets());

		buf.writeBytes(data.getNewVersion());

		buf.writeByte(data.getFileTotalCs8());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void customRemoteControlKeys(RequestCustomRemoteControlData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeByte(0x02);

		buf.writeBytes(data.getIrid());

		try {
			buf.writeBytes(data.getKeyName().getBytes("gbk"));
			for (int i = 0; i < 8 - data.getKeyName().getBytes("gbk").length; i++) {
				buf.writeByte(0x00);
			}
		} catch (UnsupportedEncodingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void requestCustomRemoteControlByDevice(RequestCustomRemoteControlData data, ByteBuf buf) {
		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeByte(0x02);

		buf.writeBytes(data.getIrid());
		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void sendCustomRemoteControlKey(RequestCustomRemoteControlData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeByte(0x02);

		buf.writeBytes(data.getIrid());

		buf.writeShort(data.getKey());

		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

	public static void requestRemoteControlFirmwareLength(RequestToUpgradeData data, ByteBuf buf) {

		// state
		buf.writeByte(0xff);

		buf.writeByte(0x01);
		buf.writeByte(0x01);

		buf.writeBytes(data.getNewVersion());
		
		// tbd 8 bytes
		for (int i = 0; i < 10; i++) {
			buf.writeByte(0x00);
		}
	}

}
