package com.b_noble.n_life.handler.processing;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.b_noble.n_life.BaseApplication;
import com.b_noble.n_life.info.IrDeviceInfo;
import com.b_noble.n_life.info.IrLinkageInfo;
import com.b_noble.n_life.info.IrTaskCmdInfo;
import com.b_noble.n_life.info.IrTaskInfo;
import com.b_noble.n_life.info.RemoteControlInfo;
import com.b_noble.n_life.info.TaskTimerAction;
import com.b_noble.n_life.utils.StringNamesUtils;

import io.netty.buffer.ByteBuf;

/**
 * @公司：深圳市中泰智丰物联网科技有限公司
 * @项目：智能家居 @简述： handler处理实现类
 * @作者：zhangfan @date：2016-08-04 @版本：V0.0.1
 */
public class IrHandlerProcessingRealization {

	public static void quiryIrAllDevice(ByteBuf buf, byte[] sn) {
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		List<IrDeviceInfo> deviceInfos = new ArrayList<IrDeviceInfo>();

		byte totalOnlines = buf.readByte();

		// 循环获取Device
		for (int i = 0; i < totalOnlines; i++) {
			IrDeviceInfo irdeviceInfo = new IrDeviceInfo();

			byte devtype = buf.readByte();

			byte[] irid = new byte[3];
			// shortAddress endPoint
			irid[0] = buf.readByte();
			irid[1] = buf.readByte();
			irid[2] = buf.readByte();

			int devkindsid = buf.readShort();

			// deviceName
			byte[] dnamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				dnamebyte[j] = buf.readByte();
			}
			String deviceName = StringNamesUtils.byteToString(dnamebyte);

			// recentValue
			byte[] recentValue = new byte[7];
			for (int j = 0; j < 7; j++) {
				recentValue[j] = buf.readByte();
			}

			short timeout = buf.readShort();

			irdeviceInfo.setDeviceName(deviceName);
			irdeviceInfo.setRecentValue(recentValue);
			irdeviceInfo.setDevtype(devtype);
			irdeviceInfo.setIrid(irid);
			irdeviceInfo.setDevkindsid(devkindsid);
			irdeviceInfo.setTimeout(timeout);
			irdeviceInfo.setSn(new String(sn));
			deviceInfos.add(irdeviceInfo);

			// System.out.println("Timeout:"+Timeout);
		}

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		// 为回调函数赋值
		BaseApplication.getInstance().quiryIrAllDevice_Callback(deviceInfos);
	}

	public static void getIrDeviceInfo(ByteBuf buf,byte[] sn) {

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		byte devtype = buf.readByte();

		byte[] irid = new byte[3];
		// shortAddress endPoint
		irid[0] = buf.readByte();
		irid[1] = buf.readByte();
		irid[2] = buf.readByte();

		// recentValue
		byte[] recentValue = new byte[7];
		for (int j = 0; j < 7; j++) {
			recentValue[j] = buf.readByte();
		}

		short timeout = buf.readShort();

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		IrDeviceInfo irdeviceInfo = new IrDeviceInfo();
		irdeviceInfo.setDevtype(devtype);
		irdeviceInfo.setRecentValue(recentValue);
		irdeviceInfo.setIrid(irid);
		irdeviceInfo.setTimeout(timeout);

		BaseApplication.getInstance().getIrDeviceInfo_Callback(irdeviceInfo);

	}

	public static void getIrDeviceSwitchState(ByteBuf buf,byte[] sn) {

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		byte[] irid = new byte[3];
		// shortAddress endPoint
		irid[0] = buf.readByte();
		irid[1] = buf.readByte();
		irid[2] = buf.readByte();

		byte state = buf.readByte();
		byte brigth = buf.readByte();
		byte sat = buf.readByte();
		byte r = buf.readByte();
		byte g = buf.readByte();
		byte b = buf.readByte();
		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().getLampState_callBack(irid, state, brigth, sat, r, g, b);
	}

	public static void getIrLigthBrightness(ByteBuf buf,byte[] sn) {

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		byte[] irid = new byte[3];
		// shortAddress endPoint
		irid[0] = buf.readByte();
		irid[1] = buf.readByte();
		irid[2] = buf.readByte();

		short brightness = buf.readUnsignedByte();

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().getIrLigthBrightness_Callback(irid, brightness);
	}

	public static void getIrLigthHueAndSat(ByteBuf buf) {

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		byte[] irid = new byte[3];
		// shortAddress endPoint
		irid[0] = buf.readByte();
		irid[1] = buf.readByte();
		irid[2] = buf.readByte();

		byte r = buf.readByte();
		byte g = buf.readByte();
		byte b = buf.readByte();
		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().getIrLigthHueAndSat_Callback(irid, r, g, b);
	}

	public static void getColorTemperature(ByteBuf buf) {

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		byte[] irid = new byte[3];
		// shortAddress endPoint
		irid[0] = buf.readByte();
		irid[1] = buf.readByte();
		irid[2] = buf.readByte();

		short colorTemperature = buf.readShort();

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().getColorTemperature_Callback(irid, colorTemperature);
	}

	public static void queryAllIrTask(ByteBuf buf,byte[] sn) {

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		// totalTasks
		int totalTasks = buf.readByte();
		List<IrTaskInfo> list = new ArrayList<IrTaskInfo>();

		for (int i = 0; i < totalTasks; i++) {
			byte taskType = buf.readByte();
			byte taskid = buf.readByte();
			byte state = buf.readByte();

			// taskname
			byte[] tasknamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				tasknamebyte[j] = buf.readByte();
			}
			String taskName = StringNamesUtils.byteToString(tasknamebyte);

			IrTaskInfo irTaskInfo = new IrTaskInfo(taskid, taskName, taskType, state);
			list.add(irTaskInfo);
		}

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryAllIrTask_callBack(list);
	}

	public static void queryIrTaskInfo(ByteBuf buf,byte[] sn) {

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		// taskType
		byte taskType = buf.readByte();

		// taskname
		byte[] tasknamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			tasknamebyte[j] = buf.readByte();
		}
		String taskName = StringNamesUtils.byteToString(tasknamebyte);

		// taskid
		byte taskid = buf.readByte();

		byte[] irid = new byte[3];
		// shortAddress endPoint
		irid[0] = buf.readByte();
		irid[1] = buf.readByte();
		irid[2] = buf.readByte();

		// m
		byte m = buf.readByte();
		byte h = buf.readByte();
		byte s = buf.readByte();
		byte w = buf.readByte();

		byte state = buf.readByte();

		byte key = buf.readByte();

		byte switchState = buf.readByte();
		byte modelState = buf.readByte();

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		TaskTimerAction taskTimerAction = new TaskTimerAction(w, h, m, s);

		IrTaskCmdInfo irtaskCmdInfo = new IrTaskCmdInfo();
		irtaskCmdInfo.setLigthSwitch(switchState);
		irtaskCmdInfo.setLigthMode(modelState);

		IrTaskInfo irTaskInfo = new IrTaskInfo(taskName, taskType, irid, taskTimerAction);
		irTaskInfo.setState(state);
		irTaskInfo.setKey(key);
		irTaskInfo.setIrtaskCmdInfo(irtaskCmdInfo);
		BaseApplication.getInstance().queryIrTaskInfo_callBack(irTaskInfo);
	}

	public static void queryAllIrtaskInfo(ByteBuf buf) {

		List<IrTaskInfo> list = new ArrayList<IrTaskInfo>();

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		// totalTasks
		byte totalTasks = buf.readByte();

		for (int i = 0; i < totalTasks; i++) {
			// taskType
			byte taskType = buf.readByte();

			// taskname
			byte[] tasknamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				tasknamebyte[j] = buf.readByte();
			}
			String taskName = StringNamesUtils.byteToString(tasknamebyte);

			// taskid
			byte taskid = buf.readByte();

			byte[] irid = new byte[3];
			// shortAddress endPoint
			irid[0] = buf.readByte();
			irid[1] = buf.readByte();
			irid[2] = buf.readByte();

			// m
			byte m = buf.readByte();
			byte h = buf.readByte();
			byte s = buf.readByte();
			byte w = buf.readByte();

			byte state = buf.readByte();

			byte key = buf.readByte();

			byte switchState = buf.readByte();
			byte modelState = buf.readByte();

			TaskTimerAction taskTimerAction = new TaskTimerAction(w, h, m, s);
			IrTaskCmdInfo irtaskCmdInfo = new IrTaskCmdInfo();
			irtaskCmdInfo.setLigthSwitch(switchState);
			irtaskCmdInfo.setLigthMode(modelState);

			IrTaskInfo irTaskInfo = new IrTaskInfo(taskName, taskType, irid, taskTimerAction);
			irTaskInfo.setState(state);
			irTaskInfo.setKey(key);
			irTaskInfo.setTaskId(taskid);
			irTaskInfo.setIrtaskCmdInfo(irtaskCmdInfo);

			list.add(irTaskInfo);
		}
		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryAllIrtaskInfo_callBack(list);

	}

	public static void getRemoteControlInformation(ByteBuf buf) {

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		// version
		byte[] versionbyte = new byte[8];
		for (int j = 0; j < 8; j++) {
			versionbyte[j] = buf.readByte();
		}
		String version = StringNamesUtils.byteToString(versionbyte);

		byte totalUsers = buf.readByte();

		byte totalDevices = buf.readByte();

		byte totalGroups = buf.readByte();

		byte totalTimers = buf.readByte();

		byte totalScenes = buf.readByte();

		byte totalTasks = buf.readByte();

		byte totallinkages = buf.readByte();

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		RemoteControlInfo rcinfo = new RemoteControlInfo(version, totalUsers, totalDevices, totalGroups, totalTimers,
				totalScenes, totalTasks, totallinkages);

		BaseApplication.getInstance().getRemoteControlInformation_callBack(rcinfo);
	}

	public static void requestWifiNetworkInformation(ByteBuf buf) {

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		// ssid
		byte[] ssidbyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			ssidbyte[j] = buf.readByte();
		}
		String ssid = StringNamesUtils.byteToString(ssidbyte);

		// pwd
		byte[] pwdbyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			pwdbyte[j] = buf.readByte();
		}
		String pwd = StringNamesUtils.byteToString(pwdbyte);

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().requestWifiNetworkInformation_callBack(ssid, pwd);
	}

	public static void requestTemperatureInformation(ByteBuf buf) {

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		byte[] irid = new byte[3];
		// shortAddress endPoint
		irid[0] = buf.readByte();
		irid[1] = buf.readByte();
		irid[2] = buf.readByte();

		byte t1 = buf.readByte();
		byte t2 = buf.readByte();

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		/*String st1 = Integer.toHexString(t1);
		String st2 = Integer.toHexString(t2);
		if (st1.getBytes().length > 2) {
			st1 = st1.substring(st1.getBytes().length - 2, st1.getBytes().length);
		}
		if (st2.getBytes().length > 2) {
			st2 = st2.substring(st2.getBytes().length - 2, st2.getBytes().length);
		}
		if (st2.getBytes().length == 1) {
			st2 = "0" + st2;
		}*/

		BaseApplication.getInstance().requestTemperatureInformation_callBack(new byte[]{t1,t2});

	}

	public static void requestHumidityInformation(ByteBuf buf) {

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		byte[] irid = new byte[3];
		// shortAddress endPoint
		irid[0] = buf.readByte();
		irid[1] = buf.readByte();
		irid[2] = buf.readByte();

		byte h1 = buf.readByte();
		byte h2 = buf.readByte();

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		/*String sh1 = Integer.toHexString(h1);
		String sh2 = Integer.toHexString(h2);

		if (sh1.getBytes().length > 2) {
			sh1 = sh1.substring(sh1.getBytes().length - 2, sh1.getBytes().length);
		}
		if (sh2.getBytes().length > 2) {
			sh2 = sh2.substring(sh2.getBytes().length - 2, sh2.getBytes().length);
		}
		if (sh2.getBytes().length == 1) {
			sh2 = "0" + sh2;
		}*/

		BaseApplication.getInstance().requestHumidityInformation_callBack(new byte[]{h1,h2});
	}

	public static void queryAllLinkage(ByteBuf buf) {

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		List<IrLinkageInfo> list = new ArrayList<IrLinkageInfo>();

		// totallinkage
		int totallinkage = buf.readByte();

		for (int i = 0; i < totallinkage; i++) {

			byte linkageid = buf.readByte();

			// linkageType
			byte linkageType = buf.readByte();

			byte[] sourceirid = new byte[3];
			// shortAddress endPoint
			sourceirid[0] = buf.readByte();
			sourceirid[1] = buf.readByte();
			sourceirid[2] = buf.readByte();

			byte[] linkageirid = new byte[3];
			// shortAddress endPoint
			linkageirid[0] = buf.readByte();
			linkageirid[1] = buf.readByte();
			linkageirid[2] = buf.readByte();

			// ruleMin
			byte ruleMin = buf.readByte();
			byte ruleMax = buf.readByte();
			byte ruleVal = buf.readByte();

			byte key = buf.readByte();

			byte switchState = buf.readByte();
			byte modelState = buf.readByte();

			IrTaskCmdInfo irtaskCmdInfo = new IrTaskCmdInfo();
			irtaskCmdInfo.setLigthSwitch(switchState);
			irtaskCmdInfo.setLigthMode(modelState);

			IrLinkageInfo info = new IrLinkageInfo();
			info.setLinkageType(linkageType);
			info.setRuleMax(ruleMax);
			info.setRuleMin(ruleMin);
			info.setRuleVal(ruleVal);
			info.setTaskId(linkageid);
			info.setLinkageIrid(linkageirid);
			info.setSourceIrid(sourceirid);
			info.setIrTaskCmdInfo(irtaskCmdInfo);
			list.add(info);
		}

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryAllLinkage_callBack(list);
	}

	public static void queryLinkageDetails(ByteBuf buf) {

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		// linkageType
		byte linkageType = buf.readByte();

		byte[] sourceirid = new byte[3];
		// shortAddress endPoint
		sourceirid[0] = buf.readByte();
		sourceirid[1] = buf.readByte();
		sourceirid[2] = buf.readByte();

		byte[] linkageirid = new byte[3];
		// shortAddress endPoint
		linkageirid[0] = buf.readByte();
		linkageirid[1] = buf.readByte();
		linkageirid[2] = buf.readByte();

		// ruleMin
		byte ruleMin = buf.readByte();
		byte ruleMax = buf.readByte();
		byte ruleVal = buf.readByte();

		byte key = buf.readByte();

		byte switchState = buf.readByte();
		byte modelState = buf.readByte();

		IrTaskCmdInfo irtaskCmdInfo = new IrTaskCmdInfo();
		irtaskCmdInfo.setLigthSwitch(switchState);
		irtaskCmdInfo.setLigthMode(modelState);

		IrLinkageInfo info = new IrLinkageInfo();
		info.setLinkageType(linkageType);
		info.setRuleMax(ruleMax);
		info.setRuleMin(ruleMin);
		info.setRuleVal(ruleVal);
		info.setLinkageIrid(linkageirid);
		info.setSourceIrid(sourceirid);
		info.setIrTaskCmdInfo(irtaskCmdInfo);

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryLinkageDetails_callBack(info);
	}

	public static void querySmartMode(ByteBuf buf) {

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		int state = buf.readByte();

		// smartName
		byte[] smartNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			smartNamebyte[j] = buf.readByte();
		}
		String smartName = StringNamesUtils.byteToString(smartNamebyte);

		byte[] irid = new byte[3];
		// shortAddress endPoint
		irid[0] = buf.readByte();
		irid[1] = buf.readByte();
		irid[2] = buf.readByte();

		int ambientTemperature = buf.readByte();
		int lowTemperature = buf.readByte();
		int higthTemperature = buf.readByte();

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().querySmartMode_callBack(irid, ambientTemperature, lowTemperature,
				higthTemperature, state);
	}

	public static void requestRemoteControlVersion(ByteBuf buf) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		byte[] versionbyte = new byte[4];
		// shortAddress endPoint
		versionbyte[0] = buf.readByte();
		versionbyte[1] = buf.readByte();
		versionbyte[2] = buf.readByte();
		versionbyte[3] = buf.readByte();

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance()
				.requestRemoteControlVersion_callBack(StringNamesUtils.versionByteToString(versionbyte));
	}

	public static void requestCustomRemoteControlByDevice(ByteBuf buf) {

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		byte[] irid = new byte[3];
		// shortAddress endPoint
		irid[0] = buf.readByte();
		irid[1] = buf.readByte();
		irid[2] = buf.readByte();

		int totalKeys = buf.readByte();

		Map<Integer, String> map = new HashMap<Integer, String>();

		for (int i = 0; i < totalKeys; i++) {
			// smartName
			byte[] keyNamebyte = new byte[8];
			for (int j = 0; j < 8; j++) {
				keyNamebyte[j] = buf.readByte();
			}
			String keyName = StringNamesUtils.byteToString(keyNamebyte);

			int key = buf.readShort();

			map.put(key, keyName);
		}

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().requestCustomRemoteControlByDevice_callBack(irid, map);
	}

	public static void customRemoteControlKeys(ByteBuf buf) {

		// state
		int state = buf.readByte();

		buf.readByte();
		buf.readByte();

		byte[] irid = new byte[3];
		// shortAddress endPoint
		irid[0] = buf.readByte();
		irid[1] = buf.readByte();
		irid[2] = buf.readByte();

		// smartName
		byte[] keyNamebyte = new byte[8];
		for (int j = 0; j < 8; j++) {
			keyNamebyte[j] = buf.readByte();
		}
		String keyName = StringNamesUtils.byteToString(keyNamebyte);

		int key = buf.readShort();

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().customRemoteControlKeys_callBack(irid, state, keyName, key);
	}

	public static void requestRemoteControlFirmwareLength(ByteBuf buf) {

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		byte[] versionbyte = new byte[4];
		// shortAddress endPoint
		versionbyte[0] = buf.readByte();
		versionbyte[1] = buf.readByte();
		versionbyte[2] = buf.readByte();
		versionbyte[3] = buf.readByte();

		int length = buf.readShort();

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().requestRemoteControlFirmwareLength_callBack(new String(versionbyte), length);
	}

	public static void reportNewDevice(ByteBuf buf) {

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		byte devtype = buf.readByte();

		byte[] irid = new byte[3];
		// shortAddress endPoint
		irid[0] = buf.readByte();
		irid[1] = buf.readByte();
		irid[2] = buf.readByte();

		int devkinds = buf.readShort();

		// smartName
		byte[] deviceNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			deviceNamebyte[j] = buf.readByte();
		}
		String deviceName = StringNamesUtils.byteToString(deviceNamebyte);

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().reportNewDevice_callBack(irid, devkinds, deviceName);
	}

	public static void upgradeOk(ByteBuf buf) {
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();
		int totalPacket = buf.readByte();
		int currentPacket = buf.readByte();
		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		if (totalPacket == currentPacket) {
			BaseApplication.getInstance().upgradeOk_callBack(totalPacket, currentPacket);
		}

	}

	public static void removeIrDevice(ByteBuf buf) {

		// state
		int state = buf.readByte();

		buf.readByte();
		buf.readByte();

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().removeIrDevice_callBack(state);
	}

	public static void updateIrDeviceName(ByteBuf buf) {

		// state
		int state = buf.readByte();

		buf.readByte();
		buf.readByte();

		byte[] irid = new byte[3];
		// shortAddress endPoint
		irid[0] = buf.readByte();
		irid[1] = buf.readByte();
		irid[2] = buf.readByte();

		// smartName
		byte[] deviceNamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			deviceNamebyte[j] = buf.readByte();
		}
		String deviceName = StringNamesUtils.byteToString(deviceNamebyte);

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().updateIrDeviceName_callBack(state);
	}

	public static void addIrTask(ByteBuf buf) {

		// state
		int state = buf.readByte();

		buf.readByte();
		buf.readByte();

		buf.readByte();
		// smartName
		byte[] taskbyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			taskbyte[j] = buf.readByte();
		}
		String taskName = StringNamesUtils.byteToString(taskbyte);

		buf.readByte();

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().addIrTask_callBack(state);
	}

}
