package com.b_noble.n_life.handler.processing;

import com.b_noble.n_life.event.WifiControlTypeEnum;
import com.b_noble.n_life.model.RequestAddWifiTaskData;
import com.b_noble.n_life.model.RequestConfigurationElectricMotorData;
import com.b_noble.n_life.model.RequestHead;
import com.b_noble.n_life.model.RequestMessage;
import com.b_noble.n_life.model.RequestOpenOrCloseCurtainData;
import com.b_noble.n_life.model.RequestRollingBlindData;
import com.b_noble.n_life.model.RequestSetColorTemperatureData;
import com.b_noble.n_life.model.RequestSetDeviceColorData;
import com.b_noble.n_life.model.RequestSetDeviceLevelData;
import com.b_noble.n_life.model.RequestSetDeviceStateData;
import com.b_noble.n_life.model.RequestSetDlectricMotorDirectionData;
import com.b_noble.n_life.model.RequestUpgradeDate;
import com.b_noble.n_life.model.RequestWifiNetworkInformationData;

import io.netty.buffer.ByteBuf;

public class WifiEncoderProcessing {

	/**
	 * @param requestMessage
	 * @param buf
	 */
	public static void processing(RequestMessage requestMessage, ByteBuf buf) {
		
		RequestHead head = requestMessage.getHeader();

		/**
		 * 查询模块信息
		 */
		if (head.getControlType() == WifiControlTypeEnum.GET_MODEL_INFORMATION.getVal()) {
			
			WifiEncoderProcessingRealization.getWifiModuleInformation(buf);
		}
		/**
		 * 设置wifi信息
		 */
		if (head.getControlType() == WifiControlTypeEnum.SET_WIFIMODULE_WIFINETWORK_INFORMATION.getVal()) {
			RequestWifiNetworkInformationData data = (RequestWifiNetworkInformationData) requestMessage.getData();
			WifiEncoderProcessingRealization.setWifiModuleWifiNetworkInformation(buf,data);
		}
		
		/**
		 * 查询wifi信息
		 */
		if (head.getControlType() == WifiControlTypeEnum.REQUEST_WIFIMODULE_WIFINETWORK_INFORMATION.getVal()) {
			
			WifiEncoderProcessingRealization.requestWifiModuleWifiNetworkInformation(buf);
		}
		
		/**
		 * 升级或重置模块
		 */
		if (head.getControlType() == WifiControlTypeEnum.UPGRADE_OR_RESET_WIFIMODULE.getVal()) {
			RequestUpgradeDate data = (RequestUpgradeDate) requestMessage.getData();
			WifiEncoderProcessingRealization.upgradeOrResetWifiModule(buf,data);
		}
		
		/**
		 * 切换在线状态
		 */
		if (head.getControlType() == WifiControlTypeEnum.SWITCH_ONLINESTATE_OF_WIFIMODULE.getVal()) {
			RequestSetDeviceStateData data = (RequestSetDeviceStateData) requestMessage.getData();
			WifiEncoderProcessingRealization.switchOnlineStateOfWifiModule(buf,data);
		}
		
		/**
		 * 获取所有设备
		 */
		if (head.getControlType() == WifiControlTypeEnum.GET_MODULE_ALL_DEVICE.getVal()) {
			
			WifiEncoderProcessingRealization.getModuleAllDevice(buf);
		}
		
		/**
		 * 获取模块的版本
		 */
		if (head.getControlType() == WifiControlTypeEnum.REQUEST_WIFIMODULE_VERSION.getVal()) {
			
			RequestUpgradeDate data = (RequestUpgradeDate) requestMessage.getData();
			WifiEncoderProcessingRealization.requestWifiModuleVersion(buf,data);
		}
		
		/**
		 * 将模块设置成网络模式
		 */
		if (head.getControlType() == WifiControlTypeEnum.SET_WIFIMODULE_INTOTHE_NETWORKMODE.getVal()) {
			
			WifiEncoderProcessingRealization.setWifiModuleIntoTheNetworkMode(buf);
		}
		
		/**
		 * 设置设备的开关状态
		 */
		if (head.getControlType() == WifiControlTypeEnum.SET_WIFI_DEVICE_SWITCHSTATE.getVal()) {
			
			RequestSetDeviceStateData data = (RequestSetDeviceStateData) requestMessage.getData();
			WifiEncoderProcessingRealization.setWifiDeviceSwitchState(buf,data);
		}
		
		/**
		 *获取设备的开关状态
		 */
		if (head.getControlType() == WifiControlTypeEnum.REQUIRE_WIFIDEVICE_SWITCHSTATE.getVal()) {
			
			RequestSetDeviceStateData data = (RequestSetDeviceStateData) requestMessage.getData();
			WifiEncoderProcessingRealization.requireWifiDeviceSwitchState(buf,data);
		}
		
		/**
		 *设置灯的亮度
		 */
		if (head.getControlType() == WifiControlTypeEnum.SET_WIFILIGHT_BRIGHTNESS.getVal()) {
			
			RequestSetDeviceLevelData data = (RequestSetDeviceLevelData) requestMessage.getData();
			WifiEncoderProcessingRealization.setWifiLightBrightness(buf,data);
		}
		
		/**
		 *获取灯的亮度
		 */
		if (head.getControlType() == WifiControlTypeEnum.REQUIRE_WIFILIGHT_BRIGHTNESS.getVal()) {
			
			RequestSetDeviceLevelData data = (RequestSetDeviceLevelData) requestMessage.getData();
			WifiEncoderProcessingRealization.requireWifiLightBrightness(buf,data);
		}
		
		/**
		 *设置灯的色调饱和度
		 */
		if (head.getControlType() == WifiControlTypeEnum.SET_WIFILIGHTHUE_OR_SATURATION.getVal()) {
			
			RequestSetDeviceColorData data = (RequestSetDeviceColorData) requestMessage.getData();
			WifiEncoderProcessingRealization.setWifiLighthueOrSaturation(buf,data);
		}
		
		/**
		 *获取灯的色调饱和度
		 */
		if (head.getControlType() == WifiControlTypeEnum.REQUIRE_WIFILIGHTHUE_OR_SATURATION.getVal()) {
			
			RequestSetDeviceColorData data = (RequestSetDeviceColorData) requestMessage.getData();
			WifiEncoderProcessingRealization.requireWifiLighthueOrSaturation(buf,data);
		}
		
		/**
		 *设置灯的色温
		 */
		if (head.getControlType() == WifiControlTypeEnum.SET_WIFILIGHT_COLORTEMPERATURE.getVal()) {
			
			RequestSetColorTemperatureData data = (RequestSetColorTemperatureData) requestMessage.getData();
			WifiEncoderProcessingRealization.setWifiLightColorTemperature(buf,data);
		}
		
		/**
		 *设置灯的色温
		 */
		if (head.getControlType() == WifiControlTypeEnum.REQUIRE_WIFILIGHT_COLORTEMPERATURE.getVal()) {
			
			RequestSetColorTemperatureData data = (RequestSetColorTemperatureData) requestMessage.getData();
			WifiEncoderProcessingRealization.requireWifiLightColorTemperature(buf,data);
		}
		
		/**
		 *设置电机方向
		 */
		if (head.getControlType() == WifiControlTypeEnum.SET_WIFIELECTRICMOTOR_DIRECTION.getVal()) {
			
			RequestSetDlectricMotorDirectionData data = (RequestSetDlectricMotorDirectionData) requestMessage.getData();
			WifiEncoderProcessingRealization.setWifiElectricMotorDirection(buf,data);
		}
		
		/**
		 *配置电动马达
		 */
		if (head.getControlType() == WifiControlTypeEnum.CONFIGURATION_WIFIELECTRIC_MOTOR.getVal()) {
			
			RequestConfigurationElectricMotorData data = (RequestConfigurationElectricMotorData) requestMessage.getData();
			WifiEncoderProcessingRealization.configurationWifiElectricMotor(buf,data);
		}
		
		/**
		 *查询电机配置信息
		 */
		if (head.getControlType() == WifiControlTypeEnum.QUERY_WIFIELECTRIC_MOTOR_CONFIGURATIONINFO.getVal()) {
			
			RequestConfigurationElectricMotorData data = (RequestConfigurationElectricMotorData) requestMessage.getData();
			WifiEncoderProcessingRealization.queryWifiElectricMotorConfigurationInfo(buf,data);
		}
		
		/**
		 *查询电机状态
		 */
		if (head.getControlType() == WifiControlTypeEnum.QUERY_WIFIELECTRIC_MOTOR_STATUS.getVal()) {
			
			RequestConfigurationElectricMotorData data = (RequestConfigurationElectricMotorData) requestMessage.getData();
			WifiEncoderProcessingRealization.queryWifiElectricMotorStatus(buf,data);
		}
		
		/**
		 *打开或关闭窗帘
		 */
		if (head.getControlType() == WifiControlTypeEnum.OPEN_OR_CLOSE_WIFICURTAIN.getVal()) {
			
			RequestOpenOrCloseCurtainData data = (RequestOpenOrCloseCurtainData) requestMessage.getData();
			WifiEncoderProcessingRealization.openOrCloseWifiCurtain(buf,data);
		}
		
		/**
		 *停止窗帘操作
		 */
		if (head.getControlType() == WifiControlTypeEnum.STOP_OPERATING_WIFICURTAIN.getVal()) {
			
			RequestOpenOrCloseCurtainData data = (RequestOpenOrCloseCurtainData) requestMessage.getData();
			WifiEncoderProcessingRealization.stopOperatingWifiCurtain(buf,data);
		}
		
		/**
		 *查询窗帘位置
		 */
		if (head.getControlType() == WifiControlTypeEnum.QUERY_WIFICURTAIN_POSITION.getVal()) {
			
			RequestOpenOrCloseCurtainData data = (RequestOpenOrCloseCurtainData) requestMessage.getData();
			WifiEncoderProcessingRealization.queryWifiCurtainPosition(buf,data);
		}
		
		/**
		 *窗帘行程控制（卷帘）
		 */
		if (head.getControlType() == WifiControlTypeEnum.CURTAIN_STROKE_CONTROL.getVal()) {
			
			RequestRollingBlindData data = (RequestRollingBlindData) requestMessage.getData();
			WifiEncoderProcessingRealization.wifiCurtainStrokeControl(buf,data);
		}
		
		/**
		 *删除行程
		 */
		if (head.getControlType() == WifiControlTypeEnum.DELETE_WIFI_STROKE.getVal()) {
			
			RequestRollingBlindData data = (RequestRollingBlindData) requestMessage.getData();
			WifiEncoderProcessingRealization.deleteWifiStroke(buf,data);
		}
		
		/**
		 *添加定时任务
		 */
		if (head.getControlType() == WifiControlTypeEnum.ADD_TASK.getVal()) {
			
			RequestAddWifiTaskData data = (RequestAddWifiTaskData) requestMessage.getData();
			WifiEncoderProcessingRealization.addWifiTask(buf,data);
		}
		/**
		 *删除定时任务
		 */
		if (head.getControlType() == WifiControlTypeEnum.DELETE_TASK.getVal()) {
			
			RequestAddWifiTaskData data = (RequestAddWifiTaskData) requestMessage.getData();
			WifiEncoderProcessingRealization.deleteWifiTask(buf,data);
		}
		/**
		 *修改定时任务
		 */
		if (head.getControlType() == WifiControlTypeEnum.UPDATE_TASK.getVal()) {
			
			RequestAddWifiTaskData data = (RequestAddWifiTaskData) requestMessage.getData();
			WifiEncoderProcessingRealization.updateWifiTask(buf,data);
		}
		/**
		 *查询定时任务详细
		 */
		if (head.getControlType() == WifiControlTypeEnum.QUERY_DETAILS_TASKS.getVal()) {
			
			RequestAddWifiTaskData data = (RequestAddWifiTaskData) requestMessage.getData();
			WifiEncoderProcessingRealization.queryTheWifiTaskDetails(buf,data);
		}
		
		/**
		 *查询所有任务详细
		 */
		if (head.getControlType() == WifiControlTypeEnum.QUERY_ALL_TASKS.getVal()) {
			
			RequestAddWifiTaskData data = (RequestAddWifiTaskData) requestMessage.getData();
			WifiEncoderProcessingRealization.queryAllWifiTask(buf,data);
		}
		
	}
}
