package com.b_noble.n_life.handler.processing;

import java.util.ArrayList;
import java.util.List;

import com.b_noble.n_life.BaseApplication;
import com.b_noble.n_life.info.TaskInfo;
import com.b_noble.n_life.info.TaskTimerAction;
import com.b_noble.n_life.info.WifiModelDeviceInfo;
import com.b_noble.n_life.info.WifiModuleInformation;
import com.b_noble.n_life.model.DeviceTaskInfo;
import com.b_noble.n_life.utils.StringNamesUtils;

import io.netty.buffer.ByteBuf;

public class WifiHandlerProcessingRealization {

	public static void getWifiModuleInformation(ByteBuf buf, byte[] snb) {
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		byte[] snbyte = new byte[8];
		for (int j = 0; j < 8; j++) {
			snbyte[j] = buf.readByte();
		}
		String sn = StringNamesUtils.byteToString(snbyte);

		// user
		byte[] userbyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			userbyte[j] = buf.readByte();
		}
		String user = StringNamesUtils.byteToString(userbyte);

		// taskname
		byte[] passwordbyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			passwordbyte[j] = buf.readByte();
		}
		String password = StringNamesUtils.byteToString(passwordbyte);

		int totalDevices = buf.readByte();
		int totalGroups = buf.readByte();
		int totalTimers = buf.readByte();
		int totalScenes = buf.readByte();
		int totalTasks = buf.readByte();

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		WifiModuleInformation wifiModuleInformation = new WifiModuleInformation(sn, user, password, totalDevices,
				totalGroups, totalTimers, totalScenes, totalTasks);

		BaseApplication.getInstance().getWifiModuleInformation_callBack(wifiModuleInformation);
	}

	public static void setWifiModuleWifiNetworkInformation(ByteBuf buf, byte[] snb) {

		// state
		int state = buf.readByte();

		buf.readByte();
		buf.readByte();
		byte[] snbyte = new byte[8];
		for (int j = 0; j < 8; j++) {
			snbyte[j] = buf.readByte();
		}
		String sn = StringNamesUtils.byteToString(snbyte);

		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().setWifiModuleWifiNetworkInformation_callBack(sn, state);
	}

	public static void requestWifiModuleWifiNetworkInformation(ByteBuf buf, byte[] sn) {

		// state
		int state = buf.readByte();

		buf.readByte();
		buf.readByte();

		// user
		byte[] ssidbyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			ssidbyte[j] = buf.readByte();
		}
		String ssid = StringNamesUtils.byteToString(ssidbyte);

		// taskname
		byte[] passwordbyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			passwordbyte[j] = buf.readByte();
		}
		String password = StringNamesUtils.byteToString(passwordbyte);
		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().requestWifiModuleWifiNetworkInformation_callBack(ssid, password);
	}

	public static void switchOnlineStateOfWifiModule(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();
		int state = buf.readByte();
		// TBD +crc16
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().switchOnlineStateOfWifiModule_callBack(state);
	}

	public static void getModuleAllDevice(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();
		int total = buf.readByte();

		List<WifiModelDeviceInfo> devices = new ArrayList<WifiModelDeviceInfo>();
		for (int i = 0; i < total; i++) {

			// devicename
			byte[] devicenamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				devicenamebyte[j] = buf.readByte();
			}
			String devicename = StringNamesUtils.byteToString(devicenamebyte);

			byte[] uid = new byte[3];
			// shortAddress endPoint
			uid[0] = buf.readByte();
			uid[1] = buf.readByte();
			uid[2] = buf.readByte();
			WifiModelDeviceInfo deviceInfo = new WifiModelDeviceInfo(devicename, uid);

			devices.add(deviceInfo);
		}

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().getModuleAllDevice_callBack(devices);
	}

	public static void requestWifiModuleVersion(ByteBuf buf, byte[] sn) {

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		buf.readByte();

		int version = buf.readShort();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().requestWifiModuleVersion_callBack(version + "");
	}

	public static void reportUpgradeStatus(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		int responseCode = buf.readByte();

		int version = buf.readShort();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().reportUpgradeStatus(responseCode, version + "");
	}

	public static void setWifiModuleIntoTheNetworkMode(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		int panID = buf.readShort();

		byte[] expan = new byte[8];
		for (int j = 0; j < 8; j++) {
			expan[j] = buf.readByte();
		}

		int channel = buf.readByte();

		int version = buf.readInt();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().setWifiModuleIntoTheNetworkMode_callBack(panID, expan, channel, version);
	}

	public static void setWifiDeviceSwitchState(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		byte[] uid = new byte[3];
		// shortAddress endPoint
		uid[0] = buf.readByte();
		uid[1] = buf.readByte();
		uid[2] = buf.readByte();

		int switchState = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}
		BaseApplication.getInstance().setWifiDeviceSwitchState_callBack(uid, switchState);
	}

	public static void requireWifiDeviceSwitchState(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();
		byte[] uid = new byte[3];
		// shortAddress endPoint
		uid[0] = buf.readByte();
		uid[1] = buf.readByte();
		uid[2] = buf.readByte();

		int switchState = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().requireWifiDeviceSwitchState_callBack(uid, switchState);
	}

	public static void setWifiLightBrightness(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();
		byte[] uid = new byte[3];
		// shortAddress endPoint
		uid[0] = buf.readByte();
		uid[1] = buf.readByte();
		uid[2] = buf.readByte();

		int brightValue = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().setWifiLightBrightness_callBack(uid, brightValue);
	}

	public static void requireWifiLightBrightness(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();
		byte[] uid = new byte[3];
		// shortAddress endPoint
		uid[0] = buf.readByte();
		uid[1] = buf.readByte();
		uid[2] = buf.readByte();

		int brightValue = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().requireWifiLightBrightness_callBack(uid, brightValue);
	}

	public static void setWifiLighthueOrSaturation(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();
		byte[] uid = new byte[3];
		// shortAddress endPoint
		uid[0] = buf.readByte();
		uid[1] = buf.readByte();
		uid[2] = buf.readByte();

		int hue = buf.readByte();

		int sat = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().setWifiLighthueOrSaturation_callBack(uid, hue, sat);
	}

	public static void requireWifiLighthueOrSaturation(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();
		byte[] uid = new byte[3];
		// shortAddress endPoint
		uid[0] = buf.readByte();
		uid[1] = buf.readByte();
		uid[2] = buf.readByte();

		int hue = buf.readByte();

		int sat = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().requireWifiLighthueOrSaturation_callBack(uid, hue, sat);
	}

	public static void setWifiLightColorTemperature(ByteBuf buf, byte[] sn) {

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();
		byte[] uid = new byte[3];
		// shortAddress endPoint
		uid[0] = buf.readByte();
		uid[1] = buf.readByte();
		uid[2] = buf.readByte();

		int colorTemperature = buf.readShort();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().setWifiLightColorTemperature_callBack(uid, colorTemperature);
	}

	public static void requireWifiLightColorTemperature(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();
		byte[] uid = new byte[3];

		// shortAddress endPoint
		uid[0] = buf.readByte();
		uid[1] = buf.readByte();
		uid[2] = buf.readByte();

		int colorTemperature = buf.readShort();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().requireWifiLightColorTemperature_callBack(uid, colorTemperature);
	}

	public static void setWifiElectricMotorDirection(ByteBuf buf, byte[] sn) {
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();
		byte[] uid = new byte[3];

		// shortAddress endPoint
		uid[0] = buf.readByte();
		uid[1] = buf.readByte();
		uid[2] = buf.readByte();

		int direction = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().setWifiElectricMotorDirection_callBack(uid, direction);
	}

	public static void configurationWifiElectricMotor(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();
		byte[] uid = new byte[3];

		// shortAddress endPoint
		uid[0] = buf.readByte();
		uid[1] = buf.readByte();
		uid[2] = buf.readByte();

		byte value = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().configurationWifiElectricMotor_callBack(uid, value);
	}

	public static void queryWifiElectricMotorConfigurationInfo(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();
		byte[] uid = new byte[3];

		// shortAddress endPoint
		uid[0] = buf.readByte();
		uid[1] = buf.readByte();
		uid[2] = buf.readByte();

		byte value = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryWifiElectricMotorConfigurationInfo_callBack(uid, value);
	}

	public static void queryWifiElectricMotorStatus(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();
		byte[] uid = new byte[3];

		// shortAddress endPoint
		uid[0] = buf.readByte();
		uid[1] = buf.readByte();
		uid[2] = buf.readByte();

		byte value = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryWifiElectricMotorStatus_callBack(uid, value);
	}

	public static void openOrCloseWifiCurtain(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();
		byte[] uid = new byte[3];

		// shortAddress endPoint
		uid[0] = buf.readByte();
		uid[1] = buf.readByte();
		uid[2] = buf.readByte();

		byte value = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().openOrCloseWifiCurtain_callBack(uid, value);
	}

	public static void stopOperatingWifiCurtain(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();
		byte[] uid = new byte[3];

		// shortAddress endPoint
		uid[0] = buf.readByte();
		uid[1] = buf.readByte();
		uid[2] = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().stopOperatingWifiCurtain_callBack(uid);
	}

	public static void queryWifiCurtainPosition(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();
		byte[] uid = new byte[3];

		// shortAddress endPoint
		uid[0] = buf.readByte();
		uid[1] = buf.readByte();
		uid[2] = buf.readByte();

		int value = buf.readByte();
		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryWifiCurtainPosition_callBack(uid, value);
	}

	public static void wifiCurtainStrokeControl(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();
		byte[] uid = new byte[3];

		// shortAddress endPoint
		uid[0] = buf.readByte();
		uid[1] = buf.readByte();
		uid[2] = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().wifiCurtainStrokeControl_callBack(uid);
	}

	public static void deleteWifiStroke(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();
		byte[] uid = new byte[3];

		// shortAddress endPoint
		uid[0] = buf.readByte();
		uid[1] = buf.readByte();
		uid[2] = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().deleteWifiStroke_callBack(uid);
	}

	public static void queryAllWifiTask(ByteBuf buf, byte[] sn) {

		List<TaskInfo> list = new ArrayList<TaskInfo>();

		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		int totalTasks = buf.readByte();

		for (int i = 0; i < totalTasks; i++) {
			byte taskType = buf.readByte();

			// taskname
			byte[] tasknamebyte = new byte[32];
			for (int j = 0; j < 32; j++) {
				tasknamebyte[j] = buf.readByte();
			}
			String taskname = StringNamesUtils.byteToString(tasknamebyte);

			byte taskid = buf.readByte();

			byte[] uid = new byte[3];

			// shortAddress endPoint
			uid[0] = buf.readByte();
			uid[1] = buf.readByte();
			uid[2] = buf.readByte();

			byte m = buf.readByte();

			byte h = buf.readByte();

			byte s = buf.readByte();

			byte weeek = buf.readByte();

			byte tstate = buf.readByte();

			byte cmd = buf.readByte();

			byte data[] = new byte[] { buf.readByte() };

			TaskTimerAction taskTimerAction = new TaskTimerAction(weeek, h, m, s);
			DeviceTaskInfo deviceTaskInfo = new DeviceTaskInfo(uid, cmd, data);
			TaskInfo taskinfo = new TaskInfo(taskid, taskname, taskType, taskTimerAction, deviceTaskInfo);

			list.add(taskinfo);
		}

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().queryAllWifiTask_callBack(list);

	}

	public static void queryTheWifiTaskDetails(ByteBuf buf, byte[] sn) {
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		byte taskType = buf.readByte();

		// taskname
		byte[] tasknamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			tasknamebyte[j] = buf.readByte();
		}
		String taskname = StringNamesUtils.byteToString(tasknamebyte);

		byte taskid = buf.readByte();

		byte[] uid = new byte[3];

		// shortAddress endPoint
		uid[0] = buf.readByte();
		uid[1] = buf.readByte();
		uid[2] = buf.readByte();

		byte m = buf.readByte();

		byte h = buf.readByte();

		byte s = buf.readByte();

		byte weeek = buf.readByte();

		byte tstate = buf.readByte();

		byte cmd = buf.readByte();

		byte data[] = new byte[] { buf.readByte() };

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		TaskTimerAction taskTimerAction = new TaskTimerAction(weeek, h, m, s);
		DeviceTaskInfo deviceTaskInfo = new DeviceTaskInfo(uid, cmd, data);
		TaskInfo taskinfo = new TaskInfo(taskid, taskname, taskType, taskTimerAction, deviceTaskInfo);

		BaseApplication.getInstance().queryTheWifiTaskDetails_callBack(taskinfo);
	}

	public static void addWifiTask(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		byte taskType = buf.readByte();

		// taskname
		byte[] tasknamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			tasknamebyte[j] = buf.readByte();
		}
		String taskname = StringNamesUtils.byteToString(tasknamebyte);

		byte taskid = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().addWifiTask_callBack(taskid);
	}

	public static void deleteWifiTask(ByteBuf buf, byte[] sn) {
		// TODO Auto-generated method stub
		// state
		int state = buf.readByte();

		buf.readByte();
		buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().deleteWifiTask_callBack(state);
	}

	public static void updateWifiTask(ByteBuf buf, byte[] sn) {
		// state
		buf.readByte();

		buf.readByte();
		buf.readByte();

		byte taskType = buf.readByte();

		// taskname
		byte[] tasknamebyte = new byte[32];
		for (int j = 0; j < 32; j++) {
			tasknamebyte[j] = buf.readByte();
		}
		String taskname = StringNamesUtils.byteToString(tasknamebyte);

		byte taskid = buf.readByte();

		for (int i = 0; i < 10; i++) {
			buf.readByte();
		}

		BaseApplication.getInstance().updateWifiTask_callBack(taskid);
	}

}
