 package com.b_noble.n_life.impl;

import java.io.IOException;
import java.net.ConnectException;
import java.net.SocketTimeoutException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.CountDownLatch;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;
import org.json.JSONTokener;

import com.b_noble.n_life.BaseApplication;
import com.b_noble.n_life.Serial;
import com.b_noble.n_life.event.CmdTypeEnum;
import com.b_noble.n_life.event.ControlTypeEnum;
import com.b_noble.n_life.event.IrControlTypeEnum;
import com.b_noble.n_life.event.WifiControlTypeEnum;
import com.b_noble.n_life.info.AbnormalRecordInfo;
import com.b_noble.n_life.info.AlarmRecordsInfo;
import com.b_noble.n_life.info.AreaInfo;
import com.b_noble.n_life.info.BindDeviceInfo;
import com.b_noble.n_life.info.DeviceInfo;
import com.b_noble.n_life.info.DoorlockNotification;
import com.b_noble.n_life.info.DoorlockRecentStatusInfo;
import com.b_noble.n_life.info.DoorlockUser;
import com.b_noble.n_life.info.GateWayInfo;
import com.b_noble.n_life.info.IrDeviceInfo;
import com.b_noble.n_life.info.IrLinkageInfo;
import com.b_noble.n_life.info.IrTaskInfo;
import com.b_noble.n_life.info.K1MemberDetailsInfo;
import com.b_noble.n_life.info.K1MemberInfo;
import com.b_noble.n_life.info.K1RecordInfo;
import com.b_noble.n_life.info.K1TemPassworkInfo;
import com.b_noble.n_life.info.LinkageCondition;
import com.b_noble.n_life.info.LinkageInfo;
import com.b_noble.n_life.info.LinkageTask;
import com.b_noble.n_life.info.LockAbnormalRecordInfo;
import com.b_noble.n_life.info.LockUnlockRecordInfo;
import com.b_noble.n_life.info.LockUserInfo;
import com.b_noble.n_life.info.RemoteControlInfo;
import com.b_noble.n_life.info.ScenePanelInfo;
import com.b_noble.n_life.info.ScenePanelTask;
import com.b_noble.n_life.info.SenceInfo;
import com.b_noble.n_life.info.TaskDeviceAction;
import com.b_noble.n_life.info.TaskInfo;
import com.b_noble.n_life.info.TaskTimerAction;
import com.b_noble.n_life.info.ThermostatConfigureInfo;
import com.b_noble.n_life.info.ThermostatRunStatusInfo;
import com.b_noble.n_life.info.UnlockRecordInfo;
import com.b_noble.n_life.info.WifiModelDeviceInfo;
import com.b_noble.n_life.info.WifiModuleInformation;
import com.b_noble.n_life.model.DeviceTaskInfo;
import com.b_noble.n_life.model.RequesUpdateTaskStateData;
import com.b_noble.n_life.model.Request3DModuleData;
import com.b_noble.n_life.model.RequestAddSenceData;
import com.b_noble.n_life.model.RequestAddUserToGaDate;
import com.b_noble.n_life.model.RequestAddWifiTaskData;
import com.b_noble.n_life.model.RequestAlarmRecordsData;
import com.b_noble.n_life.model.RequestAreaData;
import com.b_noble.n_life.model.RequestBindDeviceData;
import com.b_noble.n_life.model.RequestConfigurWIFIInfoData;
import com.b_noble.n_life.model.RequestConfigurationElectricMotorData;
import com.b_noble.n_life.model.RequestCustomRemoteControlData;
import com.b_noble.n_life.model.RequestDeleteDeviceData;
import com.b_noble.n_life.model.RequestDeleteSceneData;
import com.b_noble.n_life.model.RequestDeleteTaskData;
import com.b_noble.n_life.model.RequestDeleteUserFromGatewayData;
import com.b_noble.n_life.model.RequestDoorlockData;
import com.b_noble.n_life.model.RequestDoorlockUserData;
import com.b_noble.n_life.model.RequestGetColorTemperatureData;
import com.b_noble.n_life.model.RequestGetDeviceHueAndSatData;
import com.b_noble.n_life.model.RequestGetDeviceLevelData;
import com.b_noble.n_life.model.RequestGetDeviceStateData;
import com.b_noble.n_life.model.RequestGetIrDeviceInfoData;
import com.b_noble.n_life.model.RequestGetSceneMemberData;
import com.b_noble.n_life.model.RequestGetSensorTaskByUidData;
import com.b_noble.n_life.model.RequestGetTaskBySceneIdData;
import com.b_noble.n_life.model.RequestGetTaskByUidData;
import com.b_noble.n_life.model.RequestGetTaskInfoData;
import com.b_noble.n_life.model.RequestGetTheOnlineStatusOfThClientData;
import com.b_noble.n_life.model.RequestGyDoorlockData;
import com.b_noble.n_life.model.RequestHead;
import com.b_noble.n_life.model.RequestIrDeviceSwitchStateData;
import com.b_noble.n_life.model.RequestIrLigthBrightnessData;
import com.b_noble.n_life.model.RequestIrLigthHueAndSatData;
import com.b_noble.n_life.model.RequestIrModeData;
import com.b_noble.n_life.model.RequestIrTaskData;
import com.b_noble.n_life.model.RequestK1DeviceData;
import com.b_noble.n_life.model.RequestLinkageData;
import com.b_noble.n_life.model.RequestLinkageDetailsData;
import com.b_noble.n_life.model.RequestLoginGaByLanData;
import com.b_noble.n_life.model.RequestLoginValidateData;
import com.b_noble.n_life.model.RequestMessage;
import com.b_noble.n_life.model.RequestModifyPwdData;
import com.b_noble.n_life.model.RequestOpenOrCloseCurtainData;
import com.b_noble.n_life.model.RequestQueryCurtainPositionData;
import com.b_noble.n_life.model.RequestQueryElectricInfoData;
import com.b_noble.n_life.model.RequestQueryElectricMotorStatusData;
import com.b_noble.n_life.model.RequestQueryPwdData;
import com.b_noble.n_life.model.RequestRecallSceneData;
import com.b_noble.n_life.model.RequestRemoveIrDeviceData;
import com.b_noble.n_life.model.RequestReportNewDeviceData;
import com.b_noble.n_life.model.RequestRequireRICodeData;
import com.b_noble.n_life.model.RequestResetRemoteControlData;
import com.b_noble.n_life.model.RequestRollingBlindData;
import com.b_noble.n_life.model.RequestSetColorTemperatureData;
import com.b_noble.n_life.model.RequestSetDeviceColorData;
import com.b_noble.n_life.model.RequestSetDeviceLevelData;
import com.b_noble.n_life.model.RequestSetDeviceStateData;
import com.b_noble.n_life.model.RequestSetDlectricMotorDirectionData;
import com.b_noble.n_life.model.RequestSetDoorlockSwitchStateData;
import com.b_noble.n_life.model.RequestSmartModeData;
import com.b_noble.n_life.model.RequestStopOperatingCurtainData;
import com.b_noble.n_life.model.RequestTHInformationData;
import com.b_noble.n_life.model.RequestThermostatData;
import com.b_noble.n_life.model.RequestTimerTaskData;
import com.b_noble.n_life.model.RequestToUpgradeData;
import com.b_noble.n_life.model.RequestUpdateDeviceData;
import com.b_noble.n_life.model.RequestUpdateIrDeviceNameData;
import com.b_noble.n_life.model.RequestUpdateSceneNameData;
import com.b_noble.n_life.model.RequestUpdateTimerTaskData;
import com.b_noble.n_life.model.RequestUpgradeDate;
import com.b_noble.n_life.model.RequestUserToGaDate;
import com.b_noble.n_life.model.RequestVerificationManagerPwdData;
import com.b_noble.n_life.model.RequestWifiNetworkInformationData;
import com.b_noble.n_life.model.SceneMemberInfo;
import com.b_noble.n_life.model.ScenePanelData;
import com.b_noble.n_life.utils.BandingUdpUtils;
import com.b_noble.n_life.utils.BroadcastUdpUtils;
import com.b_noble.n_life.utils.Global;
import com.b_noble.n_life.utils.HttpRequest;
import com.b_noble.n_life.utils.MD5;
import com.b_noble.n_life.utils.MyProperUtil;
import com.b_noble.n_life.utils.NettySendMessageUtil;
import com.b_noble.n_life.utils.SocketUtil;
import com.b_noble.n_life.utils.StringNamesUtils;

import android.content.Context;

/**
 * @公司：深圳市中泰智丰物联网科技有限公司
 * @项目：智能家居
 * @简述：app接口实现类
 * @作者：zhangfan @date：2016-08-04 @版本：V0.0.1
 */
public class SerialImpl implements Serial {

	
	//private static String Httpip = LoadPropertiesUtil.load("config/config.properties").getProperty("auth.http.url");
	
	//private static String Httpip = ConfigFactory.load().getString("auth.http.url");
	
	public static Context mContext;

	public void setmContext(Context mContext) {
		this.mContext = mContext;
	}
	
	private static String Httpip = MyProperUtil.getHttpurl();

	/**
	 * 连接到远程的网关
	 * 
	 * @param userName
	 *            用户名
	 * @param passWd
	 *            密码
	 * @return 1，连接成功且已绑定网关,-1为账号或密码错误,0为未绑定网关,-2与服务端或网关建立链接失败，-3鉴权系统链接超时，-4mac错误
	 * 
	 */
	public int connectRemoteZll(String userName, String passWd) {
		// TODO Auto-generated method stub
		return connectRemoteZll(userName, passWd, null,null,null,null,null,null);

	}
	
	/**
	 * 连接到远程的网关
	 * 
	 * @param userName
	 *            用户名
	 * @param passWd
	 *            密码
	 * @param mac 手机mac地址
	 * @return 1，连接成功且已绑定网关,-1为账号或密码错误,0为未绑定网关,-2与服务端或网关建立链接失败，-3鉴权系统链接超时，-4mac错误
	 * 
	 */
	public int connectRemoteZll(String userName, String passWd,String mac,String appToken,String ostype,String appLang) {
		
		return connectRemoteZll(userName, passWd, null,null,mac,appToken,ostype,appLang);
	}

	/**
	 * 连接到远程的网关
	 * 
	 * @param userName
	 *            用户名
	 * @param passWd
	 *            密码
	 * @param sn
	 * 
	 * @return 1，连接成功且已绑定网关,-1为账号或密码错误,0为未绑定网关,-2与服务端或网关建立链接失败，-3鉴权系统链接超时，-4mac错误
	 */
	public int connectRemoteZll(String userName, String passWd, String sncode,String tokencode,String mac,String appToken,String ostype,String appLang) {
		// 创建链接前先关闭原有链接
		closeAllSocket();

		int perstate = 0 ; 
		
		try {
			String result = HttpRequest.sendPost(
					"http://"+Httpip+"/validateLoginNamePwd",
					"loginName=" + userName + "&loginPwd=" + passWd+"&mac="+mac+"&appToken="+appToken+"&osType="+ostype+"&appLang="+appLang);

			JSONTokener jt = new JSONTokener(result);

			System.out.println(result);
			
			JSONObject jo = (JSONObject)jt.nextValue();
			String state = jo.getString("flag");
			
			
			// 用户名或密码错误
			if ("-2".equals(state)) {
				return -1;
			}
			if("-3".equals(state)){
				return -4;
			}
			// 登录成功但网关未绑定
			else if ("0".equals(state)) {
				JSONArray jsono =jo.getJSONArray("data");

				JSONObject datajson = (JSONObject) jsono.get(0);
				
				int userid = jo.getInt("userid");
				String token = "249E03DBE54344471CAA45764DF02D53";
				String sn = "ZTCT1000";
				//String ip = "127.0.0.1";
				String ip = jo.getString("ip");
				String port = jo.getString("port");
				perstate = 0;

				if (sncode !=null) {
					sn = sncode;
					token = tokencode;
				}
				
				Global.sncode = sn;
				Global.token = token;
				Global.userid = userid;
				Global.loginName = userName;
				Global.perstate = perstate;
				Global.utoken = jo.getString("token");
				
				
				CountDownLatch threadSignal = new CountDownLatch(1);// 初始化countDown
				SocketUtil su = new SocketUtil(ip, Integer.parseInt(port), threadSignal);

				su.start();

				try {
					threadSignal.await();// 等待所有子线程执行完
				} catch (InterruptedException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
				if (Global.group.size() == 0) {
					return -2;
				} else {
					// 向服务端发送登录验证指令
					BaseApplication.getInstance().sendLoginCmd();
					
					//linkSuccess();
				}	
				return 0;
				
			}
			// 登录成功且有绑定网关
			else if ("1".equals(state)) {

				JSONArray jsono =jo.getJSONArray("data");

				JSONObject datajson = (JSONObject) jsono.get(0);
				
				int userid = jo.getInt("userid");
				String token = datajson.getString("token");
				String sn = datajson.getString("sn");
				//String token = "646F29C86894ED12D3C877C4BB953A9D";
				//String sn = "ZTN88P27";
				//String ip = "192.168.0.146";
				//String ip = "52.66.25.143";
				String ip = jo.getString("ip");
				String port = jo.getString("port");
				//String port = "8888";
				perstate = datajson.getInt("state");

				if (sncode !=null) {
					sn = sncode;
					token = tokencode;
				}
				
				Global.sncode = sn;
				Global.token = token;
				Global.userid = userid;
				Global.loginName = userName;
				Global.perstate = perstate;
				Global.utoken = jo.getString("token");
				
				CountDownLatch threadSignal = new CountDownLatch(1);// 初始化countDown
				SocketUtil su = new SocketUtil(ip, Integer.parseInt(port), threadSignal);

				su.start();

				try {
					threadSignal.await();// 等待所有子线程执行完
				} catch (InterruptedException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}

				if (Global.group.size() == 0) {
					return -2;
				} else {
					// 向服务端发送登录验证指令
					BaseApplication.getInstance().sendLoginCmd();
					
					if (perstate == 0) {
						BaseApplication.getInstance().addUserToGa(userName, passWd);
					}
					
					//linkSuccess();
					
 					return 1;
				}

			}
		} catch (Exception e) {
		e.printStackTrace();
			
			if (e instanceof SocketTimeoutException) {
				return -3;
			}
			else if (e instanceof JSONException) {
				return 0;
			}
			else if (e instanceof ConnectException) {
				return -3;
			}
			else if (e instanceof 	IOException) {
				return -3;
			}else{
				return -3;
			}
		}
		return 0;

	}
	
	public static void linkSuccess(){
		
		/************************此处可放测试方法，例：获取或有网关设备列表接口如下********************************/
		//BaseApplication.getInstance().getK1Infos(uid, type);
		
		//BaseApplication.getInstance().requestGaOrZigbeeVersion(2);
		
		//BaseApplication.getInstance().getDevices();
		
		//BaseApplication.getInstance().getTheOnlineStatusOfThClient("ZT040160");
		
		//BaseApplication.getInstance().quiryIrAllDevice();
		
		//BaseApplication.getInstance().permitJoin();
		
		//k1   e2 9a 08
		byte[] uid = new byte[]{(byte) 0x97, (byte) 0x06, 0x08};
		
		//BaseApplication.getInstance().getK1RecordListAnd3D(uid, 0, 1, 16, "2018-10-01 10:10:10", "2018-10-11 10:10:10");
		
		List<Integer> stypes = new ArrayList<Integer>();
		stypes.add(9);
		
		//BaseApplication.getInstance().getK1DeviceStates(uid, stypes);
	    //BaseApplication.getInstance().set3DModule(uid, 2, 1);
		
		
		//BaseApplication.getInstance().getK1Infos(uid, 4);
		
		//BaseApplication.getInstance().getK1Infos(uid, 2);
		
		//BaseApplication.getInstance().getDevices();
		
		//BaseApplication.getInstance().vilidateK1Pwd(uid,5,0,2,"6661666");
		
		//BaseApplication.getInstance().searchWifi();
		
		//BaseApplication.getInstance().configurWIFIInfo(1,"ztzf-0331","13662684551");
		
		
		// k1查看设备状态
		/*List<Integer> stypes = new ArrayList<Integer>();
		stypes.add(3);
		stypes.add(1);
		stypes.add(2);
		stypes.add(4);
		stypes.add(5);
		stypes.add(6);*/
		//BaseApplication.getInstance().getK1DeviceStates(uid, stypes);
		
		//BaseApplication.getInstance().getK1KeysId(uid, "15991615037");
		
		//sBaseApplication.getInstance().getK1Member(uid);
		
		K1MemberInfo member = new K1MemberInfo();
		member.setName("梅超风");
		member.setUsername("15991615037");
		//BaseApplication.getInstance().addK1Member(uid, member);
		
		//BaseApplication.getInstance().deleteK1Member(uid, 12);
		
		//BaseApplication.getInstance().updateK1MemberName(uid, 3, "张三丰");
		
		//BaseApplication.getInstance().getK1MemberInfo(uid, 5);
		
		//BaseApplication.getInstance().addK1Key(uid, 11, 0, "123456");
		
		//BaseApplication.getInstance().addK1Key(uid, 4, 5, "123654");
		
		//BaseApplication.getInstance().deteteK1Key(uid, 4, 0, 1);
		
		//BaseApplication.getInstance().updateK1Password(uid, 4, 0, 1, "888888");
		//
		
		List<Integer> ids = new ArrayList<Integer>();
		ids.add(2);
		//ids.add(4);
		
		//BaseApplication.getInstance().deleteK1Record(uid, 2, ids);
		
		//BaseApplication.getInstance().relieveAlarm(uid, 2, 2);
		
		//BaseApplication.getInstance().addK1TemPassword(uid, "王麻子1", "15991615039", "123321");
		
		//BaseApplication.getInstance().getK1TemPassworkList(uid, 1, 16);
		
	//	BaseApplication.getInstance().deleteK1TemPassword(uid, 2);
		
		
		//BaseApplication.getInstance().deleteTemPasswordRecords(uid, bids);
		
		//BaseApplication.getInstance().updateK1FingerprintName(uid, 1, 2, 1, "谁的指纹");
		
		
		
		//BaseApplication.getInstance().upgradeK1Request(uid, 2);
		
		
		//BaseApplication.getInstance().sendHeartbeat();
		//BaseApplication.getInstance().setTheThermostatMode(uid, modelValue);
		//BaseApplication.getInstance().UserBindToGa("ZTB2R412", "15991615037", "123456");
		//BaseApplication.getInstance().getSences();
		
		//BaseApplication.getInstance().quiryIrAllDevice();
		//ce 8c 08
		
		
		
		
		//BaseApplication.getInstance().quiryIrAllDevice();
		
		//BaseApplication.getInstance().getTheOnlineStatusOfThClient("ZT7UQ91W");
		
		//ea bb 01
	
		//BaseApplication.getInstance().queryCurtainPosition(uid);
		//BaseApplication.getInstance().stopOperatingCurtain(uid);
		
		//BaseApplication.getInstance().queryAlarmRecords(uid, "2016-10-10 10:0:0", "2017-12-20 10:0:0");
		
		List<Integer> recordIds = new ArrayList<Integer>();
		recordIds.add(2);
		//BaseApplication.getInstance().deleteAlarmRecords(uid, recordIds);
		//BaseApplication.getInstance().setGwDoorlockSwitchState(uid, 1);
		
		
		
		//BaseApplication.getInstance().queryDoorlockElectricity(uid);
	//	BaseApplication.getInstance().queryDoorUserInfos(uid);
		//BaseApplication.getInstance().freezeLockUserPassword(uid, 0xff, 1, 1);
		
		//BaseApplication.getInstance().queryLockMachineCode(uid);
		//BaseApplication.getInstance().quiryIrAllDevice(); 
		
		DeviceInfo dInfo = new DeviceInfo(uid);
		//BaseApplication.getInstance().ChangeDeviceName(dInfo, "新灯");
		
		//BaseApplication.getInstance().setTheThermostatMode(uid, 1);
		
		//BaseApplication.getInstance().setTheWindSpeed(uid, 1);
		
		//BaseApplication.getInstance().deleteUserFromGateway("159155454", "123", 1);
		
		//BaseApplication.getInstance().adjusttTheTemperature(uid, 1);
		
		//BaseApplication.getInstance().setTheRunModeThatPowerResume(uid, 1);
		
		//BaseApplication.getInstance().queryTheThermostatConfigureInfo(uid);
		
		//BaseApplication.getInstance().queryTheThermostatRunStatus(uid);
		
		//BaseApplication.getInstance().setThermostatState(uid, 0);
		
		//BaseApplication.getInstance().getTheOnlineStatusOfThClient("ZR88E01C");
		
		
		//门锁 cb bf 40 
		//byte[] uid = new byte[]{(byte) 0xcb, (byte) 0xbf, 0x40};
		
		//BaseApplication.getInstance().queryAllLockUserInfo(uid);
		
		LockUserInfo lockUserInfo = new LockUserInfo(3, "房客1", "128741", new byte[]{17,12,2,15,20,0,17,12,9,12,0,0}, 1);
		//BaseApplication.getInstance().addGyDoorlockUser(uid, lockUserInfo);
		
		List<byte[]> uids = new ArrayList<byte[]>();
		//uids.add(uid);
		 
		//BaseApplication.getInstance().setGwDoorlockSwitchState(uid, 1);
		
		//BaseApplication.getInstance().queryGyDoorlockSwitchState(uid);
		
		//BaseApplication.getInstance().configureDoorlockNormalOpen(uid, 1);
		
		//BaseApplication.getInstance().queryDoorlockRecentStatus(uid);
		
		//BaseApplication.getInstance().modifyDoorlockUserPasswd(uid, lockUserInfo);
	
		//BaseApplication.getInstance().freezeDoorlockUser(uid, lockUserInfo, 0);
		
		//BaseApplication.getInstance().deleteGyDoorlockUser(uid, lockUserInfo);
		
		//BaseApplication.getInstance().modifyDoorlockUserAlias(uid, lockUserInfo, "管家1");
		
		//0b 20 08
		//byte[] uid = new byte[]{(byte) 0x0b, (byte) 0x20, 0x08};
		
		//BaseApplication.getInstance().setDoorlockSwitchState(uid, 1);
		
		byte[] srcUid = new byte[]{(byte) 0xe2, (byte) 0x7a, 0x0f};
		byte[] destUid = new byte[]{(byte) 0xb6, (byte) 0xeb, 0x08};
		
		byte[] ieeeAddr = new byte[]{(byte) 0x00 , (byte) 0x12 , (byte) 0x4b , (byte) 0x00 , (byte) 0x0c , (byte) 0xb8 , (byte) 0x9f , (byte) 0xf0 };
		//BaseApplication.getInstance().bindDevice(srcUid, destUid);
		
		
		//BaseApplication.getInstance().cancelBind(srcUid);
		//BaseApplication.getInstance().queryAllBind(srcUid, ieeeAddr);
	}
	

	/**
	 * 局域网登录网关，执行改方法前需要先执行connectLANZllByIp方法
	 * 
	 * @param userName
	 *            用户名
	 * @param passWd
	 *            密码 登录结果在回调loginGaByLan_Callback()中返回
	 */
	public int loginGaByLan(String userName, String passWd) {

		RequestLoginGaByLanData data = new RequestLoginGaByLanData((byte) 0xFF, userName, MD5.Encode(passWd));
		RequestHead header = new RequestHead(90, Global.sncode, ControlTypeEnum.LOGIN_GA_LAN.getVal());
		RequestMessage requestMessage = new RequestMessage(header, data);

		if (Global.group.size() > 0) {
			NettySendMessageUtil.send(requestMessage);
		}

		return 1;

	}

	/**
	 * 向服务端发送登录验证指令
	 */
	public void sendLoginCmd() {

		RequestLoginValidateData data = new RequestLoginValidateData((byte) 0x00, Global.sncode, Global.token,
				Global.loginName);
		RequestHead header = new RequestHead(66 + 32, Global.sncode, ControlTypeEnum.LOGIN_VALODATE.getVal());
		RequestMessage requestMessage = new RequestMessage(header, data);

		if (Global.group.size() > 0) {
			NettySendMessageUtil.send(requestMessage);
		}
	}
	
	/**
	 * 获取网关或zigbee版本
	 * @param 0x01：request gateway version 0x02：request zigbee version
	 */
	public void requestGaOrZigbeeVersion(int command){
		
		RequestHead header = new RequestHead(27, Global.sncode, ControlTypeEnum.REQUEST_GATE_ZIGBEE_VERSION.getVal());

		RequestUpgradeDate data = new RequestUpgradeDate((byte)command);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 获取网关或zigbee版本回调
	 */
	public void requestGaOrZigbeeVersion_callBack(int command,int version){}
	
	public void reportUpgradeStatus_callBack(int command,int version ){}
	
	/**
	 * 升级网关或zigbee固件
	 * @param command
	 * @param majorVersion
	 * @param minorVersion
	 */
	public void upgradeGaOrZigbee(int command,int version){
		
		RequestHead header = new RequestHead(29, Global.sncode, ControlTypeEnum.RESET_GATE.getVal());

		RequestUpgradeDate data = new RequestUpgradeDate((byte)command, version);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}

	/**
	 * 通过输入ip的方式来连接到本地的网关
	 * 
	 * @param ip
	 * @param snid
	 * @return -1 连接失败，-3连接超时，>0连接成功
	 */
	public int connectLANZllByIp(String ip, String snid, int port) {
		// TODO Auto-generated method stub

		
		// 创建链接前先关闭原有链接
		//closeAllSocket();

		Global.sncode = snid;
		
		CountDownLatch threadSignal = new CountDownLatch(1);// 初始化countDown
		SocketUtil su = new SocketUtil(ip, port, threadSignal);
		su.start();

		try {
			threadSignal.await();// 等待所有子线程执行完
		} catch (InterruptedException e) {
			e.printStackTrace();
		}

		if (Global.group.size() == 0) {
			return -3;
		} else {
			return 1;
		}

	}

	/**
	 * 获取当前找到所有的网关ip
	 * 
	 * @return
	 */
	public Map<String, String> getGatewayIps() {
		// TODO Auto-generated method stub

		CountDownLatch threadSignal = new CountDownLatch(1);// 初始化countDown

		BroadcastUdpUtils bu = new BroadcastUdpUtils(threadSignal);
		bu.start();

		try {
			Thread.sleep(3000);
		} catch (InterruptedException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		
		return Global.ips;

	}

	/**
	 * 向网关发送绑定网关指令
	 * 
	 * @param sn
	 *            网关sn码
	 * @return 若返回ip:可以绑定 ，返回0则表示该网关不能绑定
	 */
	public String bangdingGa(String sn) {

		CountDownLatch threadSignal = new CountDownLatch(1);// 初始化countDown

		BandingUdpUtils bu = new BandingUdpUtils(threadSignal, sn);
		bu.start();

		try {
			Thread.sleep(5000);
		} catch (InterruptedException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return Global.bingState;

	}

	/**
	 * 向网关发送网关绑定信息 绑定结果在UserBindToGa_callBack()中返回
	 */
	public void UserBindToGa(String sn, String username, String password) {

		RequestHead header = new RequestHead(98, Global.sncode, ControlTypeEnum.BING_GA.getVal());

		RequestUserToGaDate data = new RequestUserToGaDate(sn, username, password);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

	}

	/**
	 * 向网关发送新增用户指令 结果在addUserToGa_callBack()回调中返回
	 */
	public void addUserToGa(String username, String password) {

		RequestHead header = new RequestHead(90, Global.sncode, ControlTypeEnum.ADD_USER_GA.getVal());

		RequestAddUserToGaDate data = new RequestAddUserToGaDate(username, password);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}

	/**
	 * 查看网关信息
	 */
	public void getGateWayInfo() {

		byte[] data = new byte[0];
		RequestHead header = new RequestHead(21, Global.sncode, ControlTypeEnum.GET_GATEWAY_INFO.getVal());
		RequestMessage requestMessage = new RequestMessage(header, data);

		if (Global.group.size() > 0) {
			NettySendMessageUtil.send(requestMessage);
		}

	}

	/**
	 * 复位网关
	 * 
	 * @return
	 */
	public int resetGateway() {
		return 0;
		// TODO Auto-generated method stub

		/*
		 * if (Global.group.size()>0) { String result = (String)
		 * NettySendMessageUtil.send("{v:resetGateway,t:2}");
		 * System.out.println(result+"-----------------------------------");
		 * return 1; }else{ return 0; }
		 */

	}
	
	/**
	 * 查询该用户所有网关
	 */
	public List<GateWayInfo> getGateWays(String username){
		
		
		 List<GateWayInfo> lst = new ArrayList<GateWayInfo>();
		
		try {
			String result = HttpRequest.sendPost("http://"+Httpip+"/searchAllGateWay", "loginName="+username);
		
			System.out.println(result);
			
			JSONTokener json = new JSONTokener(result);
			
			JSONArray jsono =((JSONObject)json.nextValue()).getJSONArray("data");
			
			for (int i = 0; i < jsono.length(); i++) {
				JSONObject jsonstr = (JSONObject) jsono.get(i);
				String sn = jsonstr.get("sn").toString();
				String token = jsonstr.get("token").toString();
				String state = jsonstr.get("state").toString();
				String flag = jsonstr.get("flag").toString();
				
				GateWayInfo ga = new GateWayInfo(sn, token, Integer.parseInt(state), Integer.parseInt(flag));
				lst.add(ga);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		
		
		return lst;
		
	}
	

	/**
	 * 获取当前连接的所有设备 可以在newDevice_CallBack（）这个回调中，来获得所有设备
	 */
	public DeviceInfo[] getDevices() {
		// TODO Auto-generated method stub

		byte[] data = new byte[0];
		RequestHead header = new RequestHead(26, Global.sncode, ControlTypeEnum.GET_DEVICE.getVal());
		RequestMessage requestMessage = new RequestMessage(header, data);

		if (Global.group.size() > 0) {
			NettySendMessageUtil.send(requestMessage);
		}
		return null;
	}

	/**
	 * 更改设备或组名称,传入字符数组
	 * 
	 * @param dInfo
	 *            要更改的设备（必须有device UId 和deviceName）
	 * @param dName
	 *            新的设备名
	 */
	public int ChangeDeviceName(DeviceInfo dInfo, String dName) {

		RequestHead header = new RequestHead(62, Global.sncode, ControlTypeEnum.UPDATE_DEVICE_NAME.getVal());

		RequestUpdateDeviceData data = new RequestUpdateDeviceData(dInfo.getuId(), dName);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;

	}

	/**
	 * 删除当前设备
	 * 
	 * @param info
	 *            要删除的设备（必须有device Uid）
	 */
	public int deleteDevice(DeviceInfo info) {
		RequestHead header = new RequestHead(38, Global.sncode, ControlTypeEnum.DELETE_DEVICE.getVal());

		RequestDeleteDeviceData data = new RequestDeleteDeviceData(info.getuId(), info.getIEEE(), (byte) 0x00);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}
	/**
	 * 删除当前设备回调
	 * 
	 */
	public void deleteDevice_callBack(int state){}

	/**
	 * 改变设备状态：1 开/ 0 关
	 * 
	 * @param info
	 *            要改变状态的设备（必须要有Uid）
	 * @param state
	 *            要改变的状态
	 */
	public int setDeviceState(DeviceInfo info, int state) {
		// TODO Auto-generated method stub

		return setDeviceState(info, state, 0);
	}
	
	/**
	 * 改变设备状态：1 开/ 0 关
	 * 
	 * @param info
	 *            要改变状态的设备（必须要有Uid）
	 * @param state
	 *            要改变的状态 
	 * @param transitionTime 延迟时间
	 *      执行此方法后在setDeviceState_CallBack() 中返回状态
	 *            
	 */
	public int setDeviceState(DeviceInfo info, int state,int transitionTime){
		
		RequestHead header = new RequestHead(31, Global.sncode, ControlTypeEnum.SET_DEVICE_STATE.getVal());

		RequestSetDeviceStateData data = new RequestSetDeviceStateData(info.getuId(), state,transitionTime);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}


	/**
	 * 获得设备状态，结果在getDeviceState_CallBack这个回调中会有返回
	 * 
	 * @param info
	 *            要获取的设备（必须要有Uid）
	 */
	public int getDeviceState(DeviceInfo info) {
		// TODO Auto-generated method stub
		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.GET_DEVICE_STATE.getVal());

		RequestGetDeviceStateData data = new RequestGetDeviceStateData(info.getuId());

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}

	/**
	 * 改变设备值，（亮度）
	 * 
	 * @param info
	 *            要改变设备值的设备（必须要有Uid）
	 * @param value
	 *            要改变的值
	 */
	public int setDeviceLevel(DeviceInfo info, byte value) {

		return setDeviceLevel(info, value, (short) 0);
	}

	/**
	 * 改变设备值，（亮度）
	 * 
	 * @param info
	 *            要改变设备值的设备（必须要有Uid）
	 * @param value
	 *            要改变的值
	 * @param transitionTime
	 *            延时时间
	 * @return
	 */
	public int setDeviceLevel(DeviceInfo info, byte value, short transitionTime) {
		RequestHead header = new RequestHead(33, Global.sncode, ControlTypeEnum.SET_DEVICE_LEVEL.getVal());

		RequestSetDeviceLevelData data = new RequestSetDeviceLevelData(info.getuId(), value, transitionTime);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}

	/**
	 * 获得设备值（输出级别， 如亮度） ， 结果在getDeviceLevel_CallBack这个回调中有返回
	 * 
	 * @param info
	 *            要获取设备值的设备（必须要有Uid）
	 */
	public int getDeviceLevel(DeviceInfo info) {
		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.GET_DEVICE_LEVEL.getVal());

		RequestGetDeviceLevelData data = new RequestGetDeviceLevelData(info.getuId());

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}

	/**
	 * 改变设备色调、饱和度
	 * 
	 * @param info
	 *            要改变色调、饱和度的设备
	 * @param hue
	 *            色调
	 * @param sat
	 *            饱和度
	 */
	public int setDeviceHueSat(DeviceInfo info, byte hue, byte sat) {
		return setDeviceHueSat(info, hue, sat, (short) 0);
	}

	/**
	 * 改变设备色调、饱和度
	 * 
	 * @param info
	 *            要改变色调、饱和度的设备
	 * @param hue
	 *            色调
	 * @param sat
	 *            饱和度
	 * @param transitionTime
	 *            延时时间（单位100ms）
	 * 
	 * @return
	 */
	public int setDeviceHueSat(DeviceInfo info, byte hue, byte sat, short transitionTime) {
		RequestHead header = new RequestHead(34, Global.sncode, ControlTypeEnum.SET_DEVICE_COLOR.getVal());

		RequestSetDeviceColorData data = new RequestSetDeviceColorData(info.getuId(), hue, sat, transitionTime);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}

	/**
	 * 改变设备色温
	 * 
	 * @param info
	 *            要改变设备的色温
	 * @param value
	 *            色温值
	 */
	public int SetColorTemperature(DeviceInfo info, int value) {
		// TODO Auto-generated method stub
		return SetColorTemperature(info, value, (short) 0);
	}

	/**
	 * 
	 * 改变设备色温
	 * 
	 * @param info
	 *            要改变设备的色温
	 * @param value
	 *            色温值
	 * @param transitionTime
	 *            延时时间（单位100ms）
	 * @return
	 */
	public int SetColorTemperature(DeviceInfo info, int value, short transitionTime) {
		// TODO Auto-generated method stub
		RequestHead header = new RequestHead(34, Global.sncode, ControlTypeEnum.SET_COLOR_TEMPERATURE.getVal());

		RequestSetColorTemperatureData data = new RequestSetColorTemperatureData(info.getuId(), value, transitionTime);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;

	}

	/**
	 * 获取设备色调与饱和度，结果在 getDeviceHueAndSat_CallBack这个回调中
	 * 
	 * @param info
	 *            要获取设备色调的设备 （必须要有Uid）
	 */
	public int getDeviceHueAndSat(DeviceInfo info) {
		// TODO Auto-generated method stub
		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.GET_DEVICE_HUE.getVal());

		RequestGetDeviceHueAndSatData data = new RequestGetDeviceHueAndSatData(info.getuId());

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}

	/**
	 * 获取设备色温值，结果在 getColorTemperature_CallBack这个回调中
	 * 
	 * @param info
	 *            要获取设备色温的设备（必须要有Uid）
	 */
	public int getColorTemperature(DeviceInfo info) {

		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.GET_DEVICE_COLORTEMPERATURE.getVal());

		RequestGetColorTemperatureData data = new RequestGetColorTemperatureData(info.getuId());

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}

	/**
	 * 获取当前所有场景
	 * 
	 * @return 当是串口连接时，会立即返回当前所有场景；当是lan、net连接时，返回NULL，其结果在newSence_CallBack（）
	 *         中返回
	 */
	public SenceInfo[] getSences() {
		// TODO Auto-generated method stub

		byte[] data = new byte[0];
		RequestHead header = new RequestHead(26, Global.sncode, ControlTypeEnum.GET_SENCE.getVal());
		RequestMessage requestMessage = new RequestMessage(header, data);

		if (Global.group.size() > 0) {
			NettySendMessageUtil.send(requestMessage);
		}
		return null;
	}

	/**
	 * 创建新场景
	 * 
	 * @param senceName
	 *            场景名
	 * @param smInfos
	 *            场景成员信息，包括操作设备uid，操作类型：如开关、灯颜色等，设备值以及延迟时间
	 * 
	 *            添加完成后新场景在addSence_callBack(byte sceneId,String senceName)中返回
	 */
	public int addSence(String senceName, List<SceneMemberInfo> smInfos) {

		int length = 59 + smInfos.size() * 13;
		RequestHead header = new RequestHead(length, Global.sncode, ControlTypeEnum.ADD_SENCE.getVal());

		RequestAddSenceData data = new RequestAddSenceData(senceName, smInfos.size(), smInfos);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;

	}

	/**
	 * 将指定的设备动作添加到指定的场景中
	 * 
	 * @param senceId
	 *            场景id
	 * @param uids
	 *            要添加的设备列表
	 *            
	 *            升级后去除掉
	 */
	/*public int addDeviceToSence(int senceId, List<byte[]> uids, int delaytime) {

		int length = 16 + uids.size() * 3;
		RequestHead header = new RequestHead(length, Global.sncode, ControlTypeEnum.ADD_DEVICE_SENCE.getVal());

		RequestAddDeviceToSenceData data = new RequestAddDeviceToSenceData(senceId, uids.size(), uids, delaytime);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}*/
	
	/**
	 * 修改场景
	 * @param senceId
	 * @param senceName
	 * @param smInfos
	 */
	public void modifyScene(int senceId,String senceName, List<SceneMemberInfo> smInfos){
		
		int length = 60 + smInfos.size() * 13;
		RequestHead header = new RequestHead(length, Global.sncode, ControlTypeEnum.MODITY_SCENE.getVal());

		RequestAddSenceData data = new RequestAddSenceData(senceName, smInfos.size(), smInfos);
		data.setSceneId(senceId);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

	}
	
	/**
	 * 修改场景回调
	 */
	public void modifyScene_callBack(int senceId,String senceName){}

	/**
	 * 打开指定的场景
	 * 
	 * @param senceId
	 *            要打开的场景的ID
	 */
	public int recallScene(int sceneId) {
		RequestHead header = new RequestHead(27, Global.sncode, ControlTypeEnum.RECALL_SENCE.getVal());

		RequestRecallSceneData data = new RequestRecallSceneData(sceneId,0);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
		
	
	}
	
	/**
	 * 打开指定的场景
	 * 
	 * @param senceId
	 *            要打开的场景的ID
	 *        delaytime 延迟时间
	 *        升级去掉接口
	 */
	/*public int recallScene(int sceneId,int delaytime){
		
		RequestHead header = new RequestHead(27, Global.sncode, ControlTypeEnum.RECALL_SENCE.getVal());

		RequestRecallSceneData data = new RequestRecallSceneData(sceneId,delaytime);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}*/

	/**
	 * 获取指定场景的详细信息， 结果在getSenceMember_CallBack()这个回调中返回
	 * 
	 * @param senceId
	 *            场景Id
	 */
	public int getSenceMember(int sceneId) {

		RequestHead header = new RequestHead(27, Global.sncode, ControlTypeEnum.GET_SENCE_MEMBER.getVal());

		RequestGetSceneMemberData data = new RequestGetSceneMemberData(sceneId);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}

	/**
	 * 删除场景中指定设备成员
	 * 
	 * @param senceName
	 *            场景名
	 * @param uIds
	 *            设备uId列表
	 *      升级去掉接口
	 */
	/*public int deleteSenceMember(int sceneId, String sceneName, List<byte[]> uId) {
		// TODO Auto-generated method stub
		RequestHead header = new RequestHead(47, Global.sncode, ControlTypeEnum.DELETE_SENCE_MEMBER.getVal());

		RequestDeleteSceneMemberData data = new RequestDeleteSceneMemberData(sceneId, sceneName, uId);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}*/

	/**
	 * 删除指定场景
	 * 
	 * @param senceId
	 * @param senceName
	 */
	public int deleteSence(int senceId, String sceneName) {

		RequestHead header = new RequestHead(59, Global.sncode, ControlTypeEnum.DELETE_SENCE.getVal());

		RequestDeleteSceneData data = new RequestDeleteSceneData(senceId, sceneName);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}
	
	/**
	 * 删除指定场景回调
	 */
	public void deleteSence_callBack(int state){}

	/**
	 * 修改场景名称
	 * 
	 * @param senceId
	 *            场景Id
	 * @param sName
	 *            新的场景名
	 */
	public int ChangeSceneName(short sceneId, String newSceneName) {

		RequestHead header = new RequestHead(59, Global.sncode, ControlTypeEnum.UPDATE_SENCE_NAME.getVal());

		RequestUpdateSceneNameData data = new RequestUpdateSceneNameData(sceneId, newSceneName);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}
	
	/**
	 * 修改场景名称回调
	 * 
	 */
	public void ChangeSceneName_callBack(int state){}

	/**
	 * 获取当前所有任务
	 * 
	 * @return 获取的任务在newTask_CallBack这个回调函数中
	 */
	/*public void getTasks() {

		RequestHead header = new RequestHead(26, Global.sncode, ControlTypeEnum.GET_ALL_TASK.getVal());

		RequestMessage message = new RequestMessage(header, null);

		NettySendMessageUtil.send(message);

	}*/
	
	/**
	 * 更改任务状态
	 * @param taskId 任务id
	 * @param state 任务状态 1开 0关
	 */
	public void updateTaskState(byte taskId,byte taskType,byte state){
		
		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.UPDATE_TASK_STATE.getVal());

		RequesUpdateTaskStateData data = new RequesUpdateTaskStateData(taskId,taskType, state);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}


	/**
	 * 根据场景id与任务类型查询该场景的任务
	 * 
	 * @param sceneid
	 *            场景id
	 * @param taskType
	 *            任务类型
	 */
	public void getTasksBySceneId(int sceneid, byte taskType) {

		RequestHead header = new RequestHead(28, Global.sncode, ControlTypeEnum.GET_TASK_SCENE.getVal());

		RequestGetTaskBySceneIdData data = new RequestGetTaskBySceneIdData(sceneid, taskType);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}

	/**
	 * 简述 根据场景id查询该场景的所有定时任务
	 * 
	 * @param sceneId
	 *            场景id
	 * @author zhangfan
	 * @date 2016-07-26
	 * @return 此方法在getTimerTaskBySceneId_CallBack这个回调方法中返回
	 */
	public void getTimerTaskBySceneId(int sceneId) {

		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.GET_TIMER_TASK.getVal());

		RequestTimerTaskData data = new RequestTimerTaskData();
		data.setTaskType(0x02);
		data.setSceneId(sceneId);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

	}

	/**
	 * 根据设备uid与任务类型查询该设备的任务
	 * 
	 * @param uid
	 *            设备id
	 * @param taskType
	 *            任务类型
	 */
	public void getTasksByUid(byte[] uid, byte taskType) {

		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.GET_TASK_DEVICE.getVal());

		RequestGetTaskByUidData data = new RequestGetTaskByUidData(uid, taskType);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

	}

	/**
	 * 简述 根据设备uid查询该设备的所有联动任务
	 * 
	 * @param uid
	 *            设备uid shortAddress+endPoint
	 * @author zhangfan
	 * @date 2016-07-27
	 * @return 此方法在getSensorTaskByUid_CallBack这个回调方法中返回
	 */
	public void getSensorTaskByUid(byte[] uid) {

		RequestHead header = new RequestHead(16, Global.sncode, ControlTypeEnum.GET_TASK_UID.getVal());

		RequestGetSensorTaskByUidData data = new RequestGetSensorTaskByUidData(uid);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}

	/**
	 * 添加场景定时任务
	 * 
	 * @param taskInfo
	 * @return 此方法在addSceneTimerTask_callBack这个回调中返回
	 */
	public int addSceneTimerTask(String taskName, TaskTimerAction timerAction, int sceneId) {
		RequestHead header = new RequestHead(78, Global.sncode, ControlTypeEnum.ADD_TASK.getVal());

		RequestTimerTaskData data = new RequestTimerTaskData();

		data.setTaskType(0x02);
		data.setTaskName(taskName);
		data.setSceneId(sceneId);
		data.setWeek(timerAction.getWorkMode());
		data.setHour(timerAction.getH());
		data.setMinute(timerAction.getM());
		data.setSecond(timerAction.getS());
		data.setDay(timerAction.getDay());
		data.setMonth(timerAction.getMonth());

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}

	/**
	 * 添加设备定时任务
	 * 
	 * @param taskInfo
	 * @return 此方法在addDeviceTimerTask_callBack这个回调中返回
	 */
	public int addDeviceTimerTask(String taskName, TaskTimerAction timerAction, DeviceTaskInfo deviceTaskInfo) {

		// TODO Auto-generated method stub
		RequestHead header = new RequestHead(78, Global.sncode, ControlTypeEnum.ADD_TASK.getVal());

		RequestTimerTaskData data = new RequestTimerTaskData();

		data.setTaskType(0x01);
		data.setTaskName(taskName);
		data.setUid(deviceTaskInfo.getUid());
		data.setWeek(timerAction.getWorkMode());
		data.setHour(timerAction.getH());
		data.setMinute(timerAction.getM());
		data.setSecond(timerAction.getS());
		data.setDay(timerAction.getDay());
		data.setMonth(timerAction.getMonth());
		data.setCmd(deviceTaskInfo.getCommand());
		data.setTbd(deviceTaskInfo.getData());

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}
	
	/**
	 * 修改场景定时任务
	 * 
	 * @return 此方法在updateSceneTimerTask_callBack这个回调中返回
	 * @return
	 */
	public int updateSceneTimerTask(int taksId, String taskName, TaskTimerAction timerAction, short sceneId){
		
		RequestHead header = new RequestHead(80, Global.sncode, ControlTypeEnum.MODITY_TASK.getVal());

		RequestTimerTaskData data = new RequestTimerTaskData();

		data.setTaskType(0x02);
		data.setTaskid(taksId);
		data.setTaskName(taskName);
		data.setSceneId(sceneId);
		data.setWeek(timerAction.getWorkMode());
		data.setHour(timerAction.getH());
		data.setMinute(timerAction.getM());
		data.setSecond(timerAction.getS());
		data.setDay(timerAction.getDay());
		data.setMonth(timerAction.getMonth());

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}
	/**
	 * 修改场景定时任务回调
	 * @param taksId
	 * @param taskName
	 */
	public void updateSceneTimerTask_callBack(int taksId, String taskName){}
	/**
	 * 修改设备定时任务
	 * 
	 * @return 此方法在updateDeviceTimerTask_callBack这个回调中返回
	 */
	public int updateDeviceTimerTask(int taksId, String taskName, TaskTimerAction timerAction, DeviceTaskInfo deviceTaskInfo){
		
		RequestHead header = new RequestHead(80, Global.sncode, ControlTypeEnum.MODITY_TASK.getVal());

		RequestTimerTaskData data = new RequestTimerTaskData();

		data.setTaskType(0x01);
		data.setTaskid(taksId);
		data.setTaskName(taskName);
		data.setUid(deviceTaskInfo.getUid());
		data.setWeek(timerAction.getWorkMode());
		data.setHour(timerAction.getH());
		data.setMinute(timerAction.getM());
		data.setSecond(timerAction.getS());
		data.setDay(timerAction.getDay());
		data.setMonth(timerAction.getMonth());
		data.setCmd(deviceTaskInfo.getCommand());
		data.setTbd(deviceTaskInfo.getData());

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}
	
	/**
	 * 修改设备定时任务回调
	 */
	public void updateDeviceTimerTask_callBack(int taksId, String taskName){}
	
	/**	
	 * 修改任务名称
	 * @param taskId
	 * @param taskType
	 * @param taskName
	 */
	public void updateTaskName(int taskId,int taskType, String taskName){
		
		RequestHead header = new RequestHead(61, Global.sncode, ControlTypeEnum.UPDATE_TASK_NAME.getVal());

		RequestTimerTaskData data = new RequestTimerTaskData();

		data.setTaskType(taskType);
		data.setTaskid(taskId);
		data.setTaskName(taskName);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**	
	 * 修改任务名称回调
	 * @param taskId
	 * @param taskType
	 * @param taskName
	 */
	public void updateTaskName_callBack(int taskId,int taskType, String taskName){}
	
	
	
	

	/**
	 * 添加设备触发任务
	 * @return
	 */
	public int addSceneLinkageTask(String taskName, List<LinkageCondition> conditionList,List<LinkageTask> taskList) {
		// TODO Auto-generated method stub
		RequestHead header = new RequestHead(62+conditionList.size()*9+taskList.size()*8, Global.sncode, ControlTypeEnum.ADD_LINKAGE_TASK.getVal());

		RequestLinkageData data = new RequestLinkageData();
		data.setConditionList(conditionList);
		data.setLinkageName(taskName);
		data.setLinkageStatus((byte)1);
		data.setLinkageType((byte)2);
		data.setTaskList(taskList);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}
	
	/**
	 * 添加场景联动任务回调
	 * @param linkageid
	 * @param linkageName
	 */
	public void addSceneLinkageTask_callBack(int state,int linkageid,String linkageName){}
	
	/**
	 * 添加设备联动任务
	 */
	public int addDeviceLinkageTask(String taskName, List<LinkageCondition> conditionList,List<LinkageTask> taskList){
		
		RequestHead header = new RequestHead(62+conditionList.size()*9+taskList.size()*8, Global.sncode, ControlTypeEnum.ADD_LINKAGE_TASK.getVal());

		RequestLinkageData data = new RequestLinkageData();
		data.setConditionList(conditionList);
		data.setLinkageName(taskName);
		data.setLinkageStatus((byte)1);
		data.setLinkageType((byte)1);
		data.setTaskList(taskList);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}
	
	/**
	 * 添加设备联动任务回调
	 * @param linkageid
	 * @param linkageName
	 */
	public void addDeviceLinkageTask_callBack(int state,int linkageid,String linkageName){}
	
	
	
	
	/**
	 * 查询联动任务详细
	 */
	public void getLinkageTaskDetails(int linkageId){
		
		RequestHead header = new RequestHead(28, Global.sncode, ControlTypeEnum.GET_LINKAGE_TASK_DETAILS.getVal());

		RequestLinkageData data = new RequestLinkageData();
		data.setLinkageId(linkageId);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

	}
	/**
	 * 查询联动任务详细回调
	 */
	public void getLinkageTaskDetails_callBack(LinkageInfo linkageInfo){}
	
	
	/**
	 * 查询所有联动任务
	 */
	public void queryAllGaLinkage(){
		
		RequestHead header = new RequestHead(26, Global.sncode, ControlTypeEnum.QUERY_ALL_LINKAGE.getVal());

		RequestMessage message = new RequestMessage(header, null);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 查询所有联动任务
	 */
	public void queryAllGaLinkage_callBack(List<LinkageInfo> linkageInfoList){
	}
	
	/**
	 * 根据设备查询联动任务
	 */
	public void queryGaLinkageByUid(byte[] uid){
		RequestHead header = new RequestHead(29, Global.sncode, ControlTypeEnum.QUERY_LINKAGE_UID.getVal());

		RequestGetTaskByUidData data = new RequestGetTaskByUidData();
		data.setUid(uid);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 根据设备查询联动任务
	 */
	public void queryGaLinkageByUid_callBack(List<LinkageInfo> linkageInfoList){}
	
	
	
	
	/**
	 * 查询设备联动任务详细
	 * 结果在getDeviceLinkageTaskDetails_callBack()中返回
	 */
	public void getDeviceLinkageTaskDetails(byte linkageId){
		
		//getLinkageTaskDetails((byte)0x01, linkageId);
	}
	
	/**
	 * 查询场景联动任务详细
	 * 结果在getSceneLinkageTaskDetails_callBack()中返回
	 */
	public void getSceneLinkageTaskDetails(byte linkageId){
		//getLinkageTaskDetails((byte)0x02, linkageId);
	}
	
	/**
	 * 根据场景id查询该场景的联动任务
	 * 结果在getSceneLinkageTasks_callBack()中返回
	 */
	public void getSceneLinkageTasks(int sceneId){
		
		RequestHead header = new RequestHead(27, Global.sncode, ControlTypeEnum.GET_LINKAGE_SCENE.getVal());

		RequestGetTaskBySceneIdData data = new RequestGetTaskBySceneIdData(sceneId);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 根据设备短地址+endpoint查询该设备的联动任务
	 * 	结果在getDeviceLinkageTasks_callBack()中返回
	 */
	public void getDeviceLinkageTasks(byte[] uid){
		
		RequestHead header = new RequestHead(29, Global.sncode, ControlTypeEnum.GET_LINKAGE_DEVICE.getVal());

		RequestGetTaskByUidData data = new RequestGetTaskByUidData(uid);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}


	/**
	 * 修改定时任务
	 * 
	 * @param taskInfo
	 * @return
	 */
	public int updateTimerTask(int taskId, String taskName, TaskTimerAction timerAction, short sceneId) {
		RequestHead header = new RequestHead(74, Global.sncode, ControlTypeEnum.UPDATE_TASK.getVal());

		RequestUpdateTimerTaskData data = new RequestUpdateTimerTaskData();

		data.setTaskName(taskName);
		data.setSceneId(sceneId);
		data.setEnable(0x01);
		data.setAlarm(0x00);
		data.setWeek(timerAction.getWorkMode());
		data.setHour(timerAction.getH());
		data.setMinute(timerAction.getM());
		data.setSecond(timerAction.getS());
		data.setTaskId(taskId);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;

	}

	

	/**
	 * 删除指定任务
	 * 
	 * @param taskID
	 *            指定的任务id
	 * @return
	 */
	public int deleteTask(List<Integer> taskIds) {

		RequestHead header = new RequestHead(27+taskIds.size()*2, Global.sncode, ControlTypeEnum.DELETE_TASK.getVal());

		RequestDeleteTaskData data = new RequestDeleteTaskData(taskIds);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}
	/**
	 * 删除指定定时任务回调
	 * 
	 */
	public void deleteTask_callBack(int state){}

	/**
	 * 查看指定定时任务的详细信息,结果在getSceneTimerTaskDetails_CallBack/getDeviceTimerTaskDetails_CallBack
	 * 
	 * @param taskId
	 *            指定的任务id
	 * @return
	 */
	public int getTaskInfo(int taskId, byte taskType) {
		// TODO Auto-generated method stub
		RequestHead header = new RequestHead(28, Global.sncode, ControlTypeEnum.GET_TASK_INFO.getVal());

		RequestGetTaskInfoData data = new RequestGetTaskInfoData(taskId, taskType);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}

	/**
	 * 查询设备定时任务详细 查询结果在getDeviceTimerTaskDetails_CallBack中返回
	 */
	public void getDeviceTimerTaskInfo(int taskId) {

		getTaskInfo(taskId, (byte) 0x01);
	}

	/**
	 * 查询场景定时任务详细 查询结果在getSceneTimerTaskDetails_CallBack中返回
	 */
	public void getSceneTimerTaskInfo(int taskId) {
		getTaskInfo(taskId, (byte) 0x02);
	}

	

	/**
	 * 获取指定设备的所有定时任务，结果在getDeviceTimerTask_CallBack中返回
	 * 
	 * @param uid
	 *            设备唯一标示
	 */
	public void getDeviceTimerTask(byte[] uid) {

		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.GET_TIMER_TASK.getVal());

		RequestTimerTaskData data = new RequestTimerTaskData();
		data.setTaskType(0x01);
		data.setUid(uid);;

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 删除指定的联动任务
	 */
	public void deleteLinkageTask(List<Integer> linkageIds){
		
		RequestHead header = new RequestHead(27+linkageIds.size()*2, Global.sncode, ControlTypeEnum.DELETE_LINKAGE_TASK.getVal());

		RequestDeleteTaskData data = new RequestDeleteTaskData();
		data.setTaskids(linkageIds);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

	}
	/**
	 * 删除指定的联动任务
	 */
	public void deleteLinkageTask_callBack(int state){}
	
	/**
	 * 修改联动场景任务
	 * 
	 * @return
	 */
	public int updateSceneLinkageTask(int linkageId,String taskName, List<LinkageCondition> conditionList,List<LinkageTask> taskList){
		
		RequestHead header = new RequestHead(64+conditionList.size()*9+taskList.size()*8, Global.sncode, ControlTypeEnum.MODITY_LINKAGE_TASK.getVal());

		RequestLinkageData data = new RequestLinkageData();
		data.setConditionList(conditionList);
		data.setLinkageName(taskName);
		data.setLinkageStatus((byte)1);
		data.setLinkageType((byte)2);
		data.setTaskList(taskList);
		data.setLinkageId(linkageId);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}
	
	/**
	 * 修改场景联动任务回调
	 */
	public void updateSceneLinkageTask_callBack(int state,int linkageid,String linkageName){}

	/**
	 * 修改联动设备任务
	 * 
	 */
	public int updateDeviceLinkageTask(int linkageId,String taskName, List<LinkageCondition> conditionList,List<LinkageTask> taskList){
		
		RequestHead header = new RequestHead(64+conditionList.size()*9+taskList.size()*8, Global.sncode, ControlTypeEnum.MODITY_LINKAGE_TASK.getVal());

		RequestLinkageData data = new RequestLinkageData();
		data.setConditionList(conditionList);
		data.setLinkageName(taskName);
		data.setLinkageStatus((byte)1);
		data.setLinkageType((byte)1);
		data.setTaskList(taskList);
		data.setLinkageId(linkageId);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;
	}
	
	/**
	 * 修改设备联动任务回调
	 */
	public void updateDeviceLinkageTask_callBack(int state,int linkageid,String linkageName){}
	
	/**
	 * 修改联动任务名称
	 */
	public void updateLinkageName(int linkageId,int linkageType,String linkageName){
		

		RequestHead header = new RequestHead(61, Global.sncode, ControlTypeEnum.UPDATE_LINKAGE_NAME.getVal());

		RequestLinkageData data = new RequestLinkageData();
		data.setLinkageName(linkageName);
		data.setLinkageType((byte)1);
		data.setLinkageId(linkageId);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 修改联动任务名称回调
	 */
	public void updateLinkageName_callBack(int state,int linkageId,int linkageType,String linkageName){}
	
	/**
	 * 修改联动任务状态
	 */
	public void updateLinkageStutus(int linkageId,int linkageType,int status){
		
		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.UPDATE_LINKAGE_STATUS.getVal());

		RequestLinkageData data = new RequestLinkageData();
		data.setLinkageType((byte)linkageType);
		data.setLinkageId(linkageId);
		data.setLinkageStatus((byte)status);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 修改联动任务状态回调
	 */
	public void updateLinkageStutus_callBack(int state){}
	
	/*******************************************区域*****************************************/
	/**
	 * 添加区域
	 */
	public void addArea(AreaInfo areaInfo){
		
		RequestHead header = new RequestHead(71+(areaInfo.getInfos().size()-1)*12, Global.sncode, ControlTypeEnum.ADD_AREA.getVal());

		List<byte[]> uids = new ArrayList<byte[]>();
		for (DeviceInfo dinfo : areaInfo.getInfos()) {
			uids.add(dinfo.getuId());
		}
		
		RequestAreaData data = new RequestAreaData(areaInfo.getAreaName(),areaInfo.getInfos().size(),(byte)0x01,uids);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 根据查询区域详细
	 * 结果在getAreaDetails_callBack()中返回
	 */
	public void getAreaDetails(int areaId){
		
		RequestHead header = new RequestHead(27, Global.sncode, ControlTypeEnum.GET_AREA_DETAILS.getVal());
		
		RequestAreaData data = new RequestAreaData(areaId);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 删除区域
	 */
	public void deleteArea(int areaId){
		
		RequestHead header = new RequestHead(27, Global.sncode, ControlTypeEnum.DELETE_AREA.getVal());
		
		RequestAreaData data = new RequestAreaData(areaId);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 查询所有区域
	 * 结果在getAllArea_callBack()中返回
	 */
	public void getAllArea(){
		
		RequestHead header = new RequestHead(27, Global.sncode, ControlTypeEnum.GET_ALL_AREA.getVal());
		
		RequestAreaData data = new RequestAreaData();

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	

	/**
	 * 向网关发送心跳信息
	 */
	public void sendHeartbeat() {
		RequestHead header = new RequestHead(26, Global.sncode, ControlTypeEnum.SEND_HEARTBEAT.getVal());

		RequestMessage message = new RequestMessage(header, null);

		NettySendMessageUtil.send(message);

	}

	/**
	 * 允许入网指令，设备入网成功后结果在回调newDevice_Callback()中返回
	 */
	public int permitJoin() {

		byte[] data = new byte[0];
		RequestHead header = new RequestHead(26, Global.sncode, ControlTypeEnum.ALLOW_NET.getVal());
		RequestMessage requestMessage = new RequestMessage(header, data);

		if (Global.group.size() > 0) {
			NettySendMessageUtil.send(requestMessage);
		}

		return 1;
	}

	/**
	 * 收到设备入网指令返回给网关
	 */
	public void responseReportNewDevice() {

		byte[] data = new byte[0];
		RequestHead header = new RequestHead(26, Global.sncode, ControlTypeEnum.REPORT_NEW_DEVICE.getVal());
		RequestMessage requestMessage = new RequestMessage(header, data);

		if (Global.group.size() > 0) {
			NettySendMessageUtil.send(requestMessage);
		}
	}
	
	
	

	/**
	 * 验证网关管理密码,结果在verificationManagerPwd_Callback()中返回
	 */
	public int verificationManagerPwd(String username, String managerPwd) {
		RequestHead header = new RequestHead(90, Global.sncode, ControlTypeEnum.VERIFICATION_MANAGERPWD.getVal());

		RequestVerificationManagerPwdData data = new RequestVerificationManagerPwdData((byte) 0xff, username,
				managerPwd);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;

	}

	/**
	 * 修改管理密码
	 */
	public int modifyManagerPwd(String username, String oldManagerPwd, String newManagerPwd) {

		RequestHead header = new RequestHead(122, Global.sncode, ControlTypeEnum.MODIFY_MANAGE_PASSWORD.getVal());

		RequestModifyPwdData data = new RequestModifyPwdData((byte) 0xFF, username, oldManagerPwd, newManagerPwd);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);

		return 1;

	}

	/**
	 * 修改登录密码,修改结果状态在回调方法modifyLoginPwd_Callback()中返回
	 * @param isNotBindGa  ：是否有绑定网关 1有，0没有
	 */
	public int modifyLoginPwd(String username, String oldLoginPwd, String newLoginPwd,int isNotBindGa) {

		if (isNotBindGa == 1) {
			RequestHead header = new RequestHead(122, Global.sncode, ControlTypeEnum.MODIFY_LOGIN_PASSWORD.getVal());

			RequestModifyPwdData data = new RequestModifyPwdData((byte) 0xFF, username, oldLoginPwd, newLoginPwd);

			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}else if(isNotBindGa == 0){
			try {
				String result = HttpRequest.sendPost(
						"http://"+Httpip+"/updateLoginPwd",
						"loginName=" + username + "&loginPwd=" + newLoginPwd);
				if (result.equals("1")) {
					result = "0";
				}
				BaseApplication.getInstance().modifyLoginPwd_Callback(Integer.parseInt(result));
				
			} catch (Exception e) {
				e.printStackTrace();
			}
		}

		return 1;

	}

	/**
	 * 查询管理密码 结果在queryManagerPwd_callBack()回调中返回
	 */
	public void queryManagerPwd(String username) {

		RequestHead header = new RequestHead(59, Global.sncode, ControlTypeEnum.QUERY_PASSWORD.getVal());

		RequestQueryPwdData data = new RequestQueryPwdData((byte) 0x01, username);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}

	/**
	 * 关闭所有现有socket链接
	 */
	public void closeAllSocket() {

		Global.sncode="";
		Global.group.close();
	}
	
	/**
	 * 发送清除网关用户指令
	 */
	public void deleteUserFromGateway(String username,String pwd,int userLevel){
		
		RequestHead header = new RequestHead(91, Global.sncode, ControlTypeEnum.DELETE_USER_FROM_GATEWAY.getVal());

		RequestDeleteUserFromGatewayData data = new RequestDeleteUserFromGatewayData(userLevel, username,pwd);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 发送清除网关用户指令
	 */
	public void deleteUserFromGateway(String username, String pwd, int userLevel,String sn){
		
		RequestHead header = new RequestHead(91, sn, ControlTypeEnum.DELETE_USER_FROM_GATEWAY.getVal());

		RequestDeleteUserFromGatewayData data = new RequestDeleteUserFromGatewayData(userLevel, username,pwd);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	
	/* about electric  */
	/***********************************************/
	/**
	 * 设置窗帘电机方向
	 * @param uid
	 * @param direction 0默认方向，1相反方向
	 */
	public void setDlectricMotorDirection(byte[] uid,int direction){
		
		RequestHead header = new RequestHead(31, Global.sncode, ControlTypeEnum.SET_ELECTRIC_MOTOR_DIRECTION.getVal());

		RequestSetDlectricMotorDirectionData data = new RequestSetDlectricMotorDirectionData((byte) 0x02, uid,(byte)direction);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
		
	}
	/**
	 * 配置窗帘电机
	 * @param handPull 是否启动手拉  0关闭，1启动
	 * @param linkage 是否启动联动    0关闭，1启动
	 */
	public void configurationElectricMotor(byte[] uid,int handPull,int linkage){
		
		RequestHead header = new RequestHead(31, Global.sncode, ControlTypeEnum.CONFIGURATION_ELECTRIC_MOTOR.getVal());

		RequestConfigurationElectricMotorData data = new RequestConfigurationElectricMotorData((byte) 0x02, uid,handPull,linkage);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 查询窗帘电机配置信息
	 * @param uid
	 * 返回：查询结果在queryElectricInfo_CallBack()回调中返回
	 */
	public void queryElectricInfo(byte[] uid){
		
		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.QUERY_ELECTRIC_INFO.getVal());

		RequestQueryElectricInfoData data = new RequestQueryElectricInfoData((byte) 0x02, uid);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 查询窗帘电机状态
	 * @param uid
	 * 返回:查询结果在queryElectricMotorStatus_CallBack()回调中返回
	 */
	public void queryElectricMotorStatus(byte[] uid){
		
		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.QUERY_MOTOR_STATUS.getVal());

		RequestQueryElectricMotorStatusData data = new RequestQueryElectricMotorStatusData((byte) 0x02, uid);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 打开或关闭窗帘
	 * @param uid
	 * @param state 0表示全关  100表示全开  0~100表示打开到指定位置
	 */
	public void openOrCloseCurtain(byte[] uid ,int state){
		
		RequestHead header = new RequestHead(31, Global.sncode, ControlTypeEnum.OPEN_OR_CLOSE_CURTAIN.getVal());

		RequestOpenOrCloseCurtainData data = new RequestOpenOrCloseCurtainData((byte) 0x02, uid,(byte)state);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 停止操作窗帘
	 * @param uid
	 */
	public void stopOperatingCurtain(byte[] uid){
		
		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.STOP_OPERATING_CURTAIN.getVal());

		RequestStopOperatingCurtainData data = new RequestStopOperatingCurtainData((byte) 0x02, uid);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 查询窗帘位置
	 * 返回:查询结果在queryCurtainPosition_CallBack()回调中返回
	 */
	public void queryCurtainPosition(byte[] uid){
		
		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.QUERY_CURTAIN_POSITION.getVal());

		RequestQueryCurtainPositionData data = new RequestQueryCurtainPositionData((byte) 0x02, uid);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 卷帘行程控制 0x00-set the upper limit position 0x01-set the lower limit
	 * position 0x02-upward 0x03-downward
	 */
	public void curtainStrokeControl(byte[] uid,int value){
		
		RequestHead header = new RequestHead(31, Global.sncode, ControlTypeEnum.CURTAIN_STROKE_CONTROL.getVal());

		RequestRollingBlindData data = new RequestRollingBlindData(uid,0x02, value);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 卷帘行程控制回调
	 */
	public void curtainStrokeControl_callBack(byte[] uid,int state){}


	/**
	 * 删除行程
	 */
	public void deleteStroke(byte[] uid){
		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.DELETE_STROKE.getVal());

		RequestRollingBlindData data = new RequestRollingBlindData(uid,0x02);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
		
	}
	
	
	/* about doorlock  */
	/**
	 * 设置门锁开关状态
	 * @param uid
	 * @param state: 1-open 0-close
	 */
	public void setDoorlockSwitchState(byte[] uid ,int state){
		
		RequestHead header = new RequestHead(31, Global.sncode, ControlTypeEnum.SET_DOORLOCK_SWITCH_STATE.getVal());

		RequestSetDoorlockSwitchStateData data = new RequestSetDoorlockSwitchStateData(uid ,state);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}	
	
	/**
	 * 查询门锁开关状态
	 * @param uid
	 * 返回：查询结果在queryDoorlockSwitchState_CallBack()回调中返回
	 */
	public void queryDoorlockSwitchState(byte[] uid){
		
		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.QUERY_DOORLOCK_SWITCH_STATE.getVal());

		RequestSetDoorlockSwitchStateData data = new RequestSetDoorlockSwitchStateData(uid ,0);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 查询门锁电量
	 */
	public void queryDoorlockElectricity(byte[] uid){
		
		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.QUERY_DOORLOCK_ELECTRICITY.getVal());

		RequestSetDoorlockSwitchStateData data = new RequestSetDoorlockSwitchStateData(uid ,0);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 查询门锁电量
	 */
	public void queryDoorlockElectricity_callback(byte[] uid,String electricity,int state){}
	
	/**
	 * 设置门锁权限
	 * @param uid
	 * @param permission 0- ordinary users，	1-only manage
	 *//*
	public void setPermissionDoorlock(byte[] uid,int permission){
		
		RequestHead header = new RequestHead(31, Global.sncode, ControlTypeEnum.SET_PERMISSION_DOORLOCK.getVal());

		RequestPermissionDoorlockData data = new RequestPermissionDoorlockData(uid ,permission);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	*//**
	 * 查询门锁权限
	 * @param uid
	 * 返回：查询结果在queryPermissionDoorlock_CallBack()回调中返回
	 *//*
	public void queryPermissionDoorlock(byte[] uid){
		
		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.QUERY_PERMISSION_DOORLOCK.getVal());

		RequestPermissionDoorlockData data = new RequestPermissionDoorlockData(uid);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}*/
	
	/**
	 * 设置门锁用户名称
	 */
	public void setUserName(byte[] uid,int uerid,String uname){
		RequestHead header = new RequestHead(64, Global.sncode, ControlTypeEnum.SET_USER_NAME.getVal());

		RequestDoorlockData data = new RequestDoorlockData(uid,uname,uerid);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 获取门锁用户列表
	 */
	public void queryDoorUserInfos(byte[] uid){
		
		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.QUERY_USER_INFO.getVal());

		RequestDoorlockData data = new RequestDoorlockData();
		data.setUid(uid);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 获取门锁用户列表回调
	 */
	public void queryDoorUserInfos_callBack(byte[] uid,List<DoorlockUser> list){}
	
	

	/**
	 * 添加用户到门锁
	 * @param doorlockUser
	 */
	public void addUserToDoorlock(DoorlockUser doorlockUser){
		
		RequestHead header = new RequestHead(48+32, Global.sncode, ControlTypeEnum.ADD_USER_TO_DOORLOCK.getVal());

		RequestDoorlockUserData data = new RequestDoorlockUserData();
		data.setUid(doorlockUser.getUid());
		data.setEffectiveTime(doorlockUser.getEffectiveTime());
		data.setValue(doorlockUser.getValue());
		data.setUsername(doorlockUser.getUsername());
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 添加用户返回
	 */
	public void addUserToDoorlock_callBack(int state){}
	
	/**
	 * 删除用户从门锁
	 * @param doorlockUser
	 */
	public void deleteUserToDoorlock(byte[] uid,int  userid){
		
		RequestHead header = new RequestHead(32, Global.sncode, ControlTypeEnum.DELETE_USER_TO_DOORLOCK.getVal());

		RequestDoorlockUserData data = new RequestDoorlockUserData();
		data.setUid(uid);
		data.setUserid(userid);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 删除用户从门锁回调
	 * 
	 * @param doorlockUser
	 */
	public void deleteUserToDoorlock_callBack(byte[] uid, int userid){}
	
	/**
	 * 查询开锁记录
	 */
	public void  queryUnlockRecord(byte[] uid){
		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.QUERY_UNLOCK_RECORD.getVal());

		RequestDoorlockData data = new RequestDoorlockData();
		data.setUid(uid);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 查询开锁记录
	 */
	public void  queryUnlockRecord_callBack(List<UnlockRecordInfo> list){}
	
	/**
	 * 删除开锁记录
	 */
	public void deleteUnlockRecord(byte[] uid,List<Integer> listrecordId){
		
		RequestHead header = new RequestHead(31+listrecordId.size()*2, Global.sncode, ControlTypeEnum.DELETE_UNLOCK_RECORD.getVal());

		RequestDoorlockData data = new RequestDoorlockData();
		data.setUid(uid);
		data.setRecordIdList(listrecordId);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 删除开锁记录回调
	 */
	public void deleteUnlockRecord_callBack(byte[] uid){}
	
	/**
	 * 设置门锁时间
	 */
	public void SetTheLocktime(byte[] uid,byte[] lockTime){
		
		RequestHead header = new RequestHead(36, Global.sncode, ControlTypeEnum.SET_THE_LOCK_TIME.getVal());

		RequestDoorlockData data = new RequestDoorlockData();
		data.setUid(uid);
		data.setStarttime(lockTime);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 异常事件通知
	 * event: 0x01- password error
	   0x02-fingerprint error
	   0x03-violent destruction

	 */
	public void abnormalEventNotification_callBack(byte[] uid ,byte event){}
	
	
	/**
	 * 根据时间查询开锁记录
	 */
	public void  queryUnlockRecordByTime(byte[] uid,byte[] starttime,byte[] endTime){
		
		RequestHead header = new RequestHead(42, Global.sncode, ControlTypeEnum.QUERY_UNLOCK_RECORD_BY_TIME.getVal());

		RequestDoorlockData data = new RequestDoorlockData();
		data.setUid(uid);
		data.setStarttime(starttime);
		data.setEndtime(endTime);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
		
	}	
	
	
	/**
	 * 查询异常记录
	 */
	public void queryAbnormalRecord(byte[] uid){
		
		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.QUERY_ABNORMAL_RECORD.getVal());

		RequestDoorlockData data = new RequestDoorlockData();
		data.setUid(uid);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 根据时间查询异常记录
	 */
	public void queryAbnormalRecordByTime(byte[] uid,byte[] starttime,byte[] endTime){
		
		RequestHead header = new RequestHead(42, Global.sncode, ControlTypeEnum.QUERY_ABNORMAL_RECORD_BY_TIME.getVal());

		RequestDoorlockData data = new RequestDoorlockData();
		data.setUid(uid);
		data.setStarttime(starttime);
		data.setEndtime(endTime);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 查询异常记录回调
	 */
	public void queryAbnormalRecord_callBack(List<AbnormalRecordInfo> list){}
	
	/**
	 * 删除异常记录
	 */
	public void deleteAbnormalRecord(byte[] uid,List<Integer> listrecordId){
		
		RequestHead header = new RequestHead(31+listrecordId.size()*2, Global.sncode, ControlTypeEnum.DELETE_ABNORMAL_RECORD.getVal());

		RequestDoorlockData data = new RequestDoorlockData();
		data.setUid(uid);
		data.setRecordIdList(listrecordId);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 冻结门锁用户（爱尔福德锁）
	 * @param uid
	 * @param type   0x00-Keypad，0x01-R，0x02-Manual，0x03-RFID，0xFF-all user
	 * @param userId
	 * @param freeze 1 冻结 0 解除冻结
	 */
	public void freezeLockUserPassword(byte[] uid,int type,int userId,int freeze){
		
		RequestHead header = new RequestHead(34, Global.sncode, ControlTypeEnum.FREEZE_LOCK_USER_PASSWORD.getVal());

		RequestDoorlockData data = new RequestDoorlockData(uid,userId,type,freeze);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 查询机器码
	 * @param uid
	 */
	public void queryLockMachineCode(byte[] uid){
		
		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.QUERY_LOCK_MACHINE_CODE.getVal());

		RequestDoorlockData data = new RequestDoorlockData();
		data.setUid(uid);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 查询机器码回调
	 * @param uid
	 */
	public void queryLockMachineCode_callBack(byte[] uid,String machineCode){}
	
	
	
	/**
	 * 获取网关温湿度
	 */
	public void requestTemperatureAndHumidity(){
		
		RequestHead header = new RequestHead(26, Global.sncode, ControlTypeEnum.BIND_DEVICE.getVal());

		RequestMessage message = new RequestMessage(header, null);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 获取网关温湿度
	 */
	public void requestTemperatureAndHumidity_callBack(int tem,int hum){}
	
	
	/**************************红外遥控器相关方法*******************************/
	/**
	 * 获取红外遥控器所有设备
	 */
	public void quiryIrAllDevice(){
		
		RequestHead header = new RequestHead(28, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.QUIRYIR_ALL_DEVICE.getVal());

		RequestMessage message = new RequestMessage(header, null);

		NettySendMessageUtil.send(message);
		
	}
	
	
	
	
	/**
	 * 获取指定设备的信息
	 */
	public void getIrDeviceInfo(byte[] irid){
		
		RequestHead header = new RequestHead(33, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.REQUEST_DEVICE_INFORMATION.getVal());

		RequestGetIrDeviceInfoData data = new RequestGetIrDeviceInfoData((byte)0x02, irid, (byte)0x00);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 设置灯的状态
	 */
	public void setLampState(byte[] irid,byte effective,byte switchState,byte brigth,byte saturation,byte r,byte g, byte b){
		RequestHead header = new RequestHead(39, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.SET_DEVICE_SWITCH_STATE.getVal());

		RequestIrDeviceSwitchStateData data = new RequestIrDeviceSwitchStateData((byte)0x02, irid, effective, switchState, brigth, saturation, r, g,  b);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
		
	}
	
	/**
	 * 获取灯的状态
	 */
	public void getLampState(byte[] irid){
		RequestHead header = new RequestHead(32, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.GET_DEVICE_SWITCH_STATE.getVal());

		RequestIrDeviceSwitchStateData data = new RequestIrDeviceSwitchStateData((byte)0x02, irid);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
		
	}
	
	/**
	 * 获取灯的状态回调
	 */
	public void getLampState_callBack(byte[] irid,byte switchState,byte brigth,byte saturation,byte r,byte g, byte b){}
	
	
	
	
	
	/**
	 * 设置指定设备开关状态
	 */
	public void setIrDeviceSwitchState(byte[] irid,byte state){
		
		/*RequestHead header = new RequestHead(33, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.SET_DEVICE_SWITCH_STATE.getVal());

		RequestIrDeviceSwitchStateData data = new RequestIrDeviceSwitchStateData((byte)0x02, irid, state);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);*/
		
		setLampState(irid, (byte)0x01, state, (byte)0, (byte)0, (byte)0, (byte)0, (byte)0);
	}
	
	/**
	 * 设置指定设备饱和度
	 */
	public void setIrDeviceSaturation(byte[] irid,byte saturation){
		
		setLampState(irid, (byte)0x04, (byte)0, (byte)0, saturation, (byte)0, (byte)0, (byte)0);
	}
	
	/**
	 * 获取指定设备开关状态
	 */
	public void getIrDeviceSwitchState(byte[] irid){
		
		RequestHead header = new RequestHead(32, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.GET_DEVICE_SWITCH_STATE.getVal());

		RequestIrDeviceSwitchStateData data = new RequestIrDeviceSwitchStateData((byte)0x02, irid, (byte)0X00);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 设置红外灯的亮度
	 */
	public void setIrLigthBrightness(byte[] irid ,byte brightness,int curtime){
		
		/*RequestHead header = new RequestHead(35, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.SET_LIGHT_BRIGHTNESS.getVal());

		RequestIrLigthBrightnessData data = new RequestIrLigthBrightnessData((byte)0x02, irid, brightness,curtime);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);*/
		
		setLampState(irid, (byte)0x02, (byte)0, brightness, (byte)0, (byte)0, (byte)0, (byte)0);
	}
	
	/**
	 * 获取红外灯的亮度
	 */
	public void getIrLigthBrightness(byte[] irid){
		
		RequestHead header = new RequestHead(32, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.GET_LIGHT_BRIGHTNESS.getVal());

		RequestIrLigthBrightnessData data = new RequestIrLigthBrightnessData((byte)0x02, irid);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 设置灯的色调饱和度
	 */
	public void setIrLigthRgb(byte[] irid,byte r,byte g,byte b,int curtime){
		
		/*RequestHead header = new RequestHead(35, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.SET_LIGHTHUE_OR_SATURATION.getVal());

		RequestIrLigthHueAndSatData data = new RequestIrLigthHueAndSatData((byte)0x02, irid,r,g,b,curtime);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);*/
		
		setLampState(irid, (byte)0x08, (byte)0, (byte)0, (byte)0, r, g, b);
	}
	
	/**
	 * 获取红外灯的色调饱和度
	 */
	public void getIrLigthRgb(byte[] irid){
		
		RequestHead header = new RequestHead(32, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.GET_LIGHTHUE_OR_SATURATION.getVal());

		RequestIrLigthHueAndSatData data = new RequestIrLigthHueAndSatData((byte)0x02, irid);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	
	/**
	 * 设置灯的感应模式
	 */
	public void setLampSensingMode(byte switchState,int keeyTime){
		RequestHead header = new RequestHead(31, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.SET_LAMP_SENSING_MODE.getVal());

		RequestIrModeData data = new RequestIrModeData(switchState, keeyTime);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 设置灯光流光溢彩的模式
	 */
	public void setLightAmbilightMode(byte switchState){
		
		RequestHead header = new RequestHead(29, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.SET_LIGHT_AMBILIGHT_MODE.getVal());

		RequestIrModeData data = new RequestIrModeData(switchState);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 发送红外码
	 */
	public void requireRemoteControlInfraredCode(byte[] irid,String ircode){
		
		RequestHead header = new RequestHead(32+ircode.getBytes().length, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.REQUIRE_REMOTE_CONTROL_INFRARED_CODE.getVal());

		RequestRequireRICodeData data = new RequestRequireRICodeData((byte)0x02,irid,ircode);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 获取温度
	 */
	public void requestTemperatureInformation(byte[] irid){
		
		RequestHead header = new RequestHead(32, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.REQUEST_TEMPERATURE_INFORMATION.getVal());

		RequestTHInformationData data = new RequestTHInformationData((byte)0x02,irid);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 获取温度回调
	 */
	public void requestTemperatureInformation_callBack(byte[] Temperature){}
	
	/**
	 * 获取湿度
	 */
	public void requestHumidityInformation(byte[] irid){
		RequestHead header = new RequestHead(32, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.REQUEST_HUMIDITY_INFORMATION.getVal());

		RequestTHInformationData data = new RequestTHInformationData((byte)0x02,irid);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
		
	}
	/**
	 * 获取湿度
	 */
	public void requestHumidityInformation_callBack(byte[] Humidity){}
	
	
	/**
	 * 查询所有红外遥控器定时任务
	 */
	public void queryAllIrTask(){
		
		RequestHead header = new RequestHead(28, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.QUERY_ALL_IRTASK.getVal());

		RequestMessage message = new RequestMessage(header, null);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 查询所有红外遥控器定时任务回调
	 */
	public void queryAllIrTask_callBack(List<IrTaskInfo> list){}
	
	/**
	 * 添加任务
	 */
	public void addIrTask(IrTaskInfo irtaskInfo){
		
		int cmdtable = 2;
		if (irtaskInfo.getTaskflag() ==1) {
			cmdtable = irtaskInfo.getInfraredcode().getBytes().length;
		}
		
		RequestHead header = new RequestHead(69+cmdtable, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.ADD_IRTASK.getVal());

		RequestIrTaskData data = new RequestIrTaskData((byte)0x01,irtaskInfo);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 添加任务回调
	 */
	public void addIrTask_callBack(int state){}
	
	/**
	 * 删除任务
	 */
	public void deleteIrTask(int taskid){
		
		RequestHead header = new RequestHead(29, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.DELETE_IRTASK.getVal());

		RequestIrTaskData data = new RequestIrTaskData();
		data.setTaskid((byte)taskid);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 修改任务
	 */
	public void updateIrTask(IrTaskInfo irtaskInfo){
		
		int cmdtable = 2;
		if (irtaskInfo.getTaskflag() ==1) {
			cmdtable = irtaskInfo.getInfraredcode().getBytes().length;
		}
		
		RequestHead header = new RequestHead(70+cmdtable, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.UPDATE_IRTASK.getVal());

		RequestIrTaskData data = new RequestIrTaskData((byte)0x01,irtaskInfo);
		data.setTaskid((byte)irtaskInfo.getTaskId());
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 查询指定任务详细
	 */
	public void queryIrTaskInfo(int taskid){
		
		RequestHead header = new RequestHead(30, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.QUERY_TASKINFO_TASKID.getVal());

		RequestIrTaskData data = new RequestIrTaskData((byte)taskid,(byte)0x01);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 查询指定任务详细回调
	 */
	public void queryIrTaskInfo_callBack(IrTaskInfo irTaskInfo){}
	
	/**
	 * 查询所有任务详细
	 */
	public void queryAllIrtaskInfo(){
		RequestHead header = new RequestHead(28, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.QUERY_ALL_TASKINFO.getVal());

		RequestMessage message = new RequestMessage(header, null);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 查询所有任务详细回调
	 */
	public void queryAllIrtaskInfo_callBack(List<IrTaskInfo> list){}
	
	
	/**
	 * 更新任务状态
	 */
	public void updateIrTaskState(int taskid,int state){
		RequestHead header = new RequestHead(30, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.UPDATE_IRTASK_STATE.getVal());

		RequestIrTaskData data = new RequestIrTaskData();
		data.setTaskid((byte)taskid);
		data.setState((byte)state);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 获取遥控器信息
	 */
	public void getRemoteControlInformation(){
		
		RequestHead header = new RequestHead(28, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.GET_REMOTECONTROL_INFORMATION.getVal());

		RequestMessage message = new RequestMessage(header, null);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 获取遥控器信息回调
	 */
	public void getRemoteControlInformation_callBack(RemoteControlInfo rcinfo){}
	/**
	 * 设置wifi信息
	 */
	public void setWifiNetworkInformation(String ssid,String pwd){
		
		RequestHead header = new RequestHead(92, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.SET_WIFI_NETWORK_INFORMATION.getVal());

		RequestWifiNetworkInformationData data = new RequestWifiNetworkInformationData(ssid,pwd);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 获取wifi信息
	 */
	public void requestWifiNetworkInformation(){
		
		RequestHead header = new RequestHead(28, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.REQUEST_WIFI_NETWORK_INFORMATION.getVal());

		RequestMessage message = new RequestMessage(header, null);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 获取wifi信息回调
	 */
	public void requestWifiNetworkInformation_callBack(String ssid,String pwd){}
	/**
	 * 重置遥控器
	 * 0x0A：only reset user flash of gateway
		0x50：delete the wifi netwok information ,Restore the factory value
		0x06：upgrade
	 */
	public void resetRemoteControl(byte resetCommand){
		RequestHead header = new RequestHead(29, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.RESET_REMOTE_CONTROL.getVal());

		RequestResetRemoteControlData data = new RequestResetRemoteControlData(resetCommand);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 上报新红外设备
	 */
	public void  reportNewDevice(int devType,String devName,int devkindsid){
		
		RequestHead header = new RequestHead(63, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.REPORT_NEW_DEVICE.getVal());

		RequestReportNewDeviceData data = new RequestReportNewDeviceData((byte)devType,devName,devkindsid);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
		
	}
	/**
	 * 上报新红外设备回调
	 */
	public void  reportNewDevice_callBack(byte[] irid,int devkinds,String deviceName){}
	
	/**
	 * 移除红外设备
	 */
	public void removeIrDevice(byte[] irid){
		
		RequestHead header = new RequestHead(32, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.REMOVE_IR_DEVICE.getVal());

		RequestRemoveIrDeviceData data = new RequestRemoveIrDeviceData((byte)0x02,irid);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 移除红外设备回调
	 */
	public void removeIrDevice_callBack(int state){}
	
	/**
	 * 更新遥控器名称
	 */
	public void updateIrDeviceName(byte[] irid,String deviceName){
		
		RequestHead header = new RequestHead(64, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.UPDATE_DEVICE_NAME.getVal());

		RequestUpdateIrDeviceNameData data = new RequestUpdateIrDeviceNameData((byte)0x02,irid,deviceName);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 更新遥控器名称回调
	 */
	public void updateIrDeviceName_callBack(int state){}
	
	/**
	 * 添加红外联动任务
	 */
	public void addIrLinkage(IrLinkageInfo irLinkageInfo){
		
		int length = 0;
		
		if (irLinkageInfo.getLinkageType()==1) {
			length = 73;
		}else{
			length = 71+irLinkageInfo.getInfraredcode().getBytes().length;
		}
		
		RequestHead header = new RequestHead(length, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.ADD_LINKAGE.getVal());

		RequestMessage message = new RequestMessage(header, irLinkageInfo);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 查询红外联动任务详细
	 */
	public void  queryLinkageDetails(int linkageid){
		RequestHead header = new RequestHead(29, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.QUERY_LINKAGE_DETAILS.getVal());

		RequestLinkageDetailsData data = new RequestLinkageDetailsData(linkageid);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 查询红外联动任务详细回调
	 */
	public void  queryLinkageDetails_callBack(IrLinkageInfo irLinkageInfo){}
	
	/**
	 * 查询所有联动任务
	 */
	public void queryAllLinkage(){
		
		RequestHead header = new RequestHead(28, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.QUERY_ALL_LINKAGE.getVal());

		RequestMessage message = new RequestMessage(header, null);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 查询所有联动任务回调
	 */
	public void queryAllLinkage_callBack(List<IrLinkageInfo> list){}
	
	/**
	 * 删除联动任务
	 */
	public void deleteLinkage(int linkageid){
		
		RequestHead header = new RequestHead(29, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.DELETE_LINKAGE.getVal());

		RequestLinkageDetailsData data = new RequestLinkageDetailsData(linkageid);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 设置智能模式
	 * @param smartName
	 * @param irid
	 * @param ambientTemperature
	 */
	public void  setSmartMode(String smartName,byte[] irid,int ambientTemperature){
		
		RequestHead header = new RequestHead(64, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.SET_SMART_MODE.getVal());

		RequestSmartModeData data = new RequestSmartModeData(smartName,irid,ambientTemperature);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 设置低温智能模式
	 * @param lowTemperature
	 * @param ircode
	 */
	public void setSmartModeLowTemperatureCmd(int lowTemperature,String ircode){
		RequestHead header = new RequestHead(29+ircode.getBytes().length, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.SET_SMART_MODE_LOW_TEMPERATURE_CMD.getVal());

		RequestSmartModeData data = new RequestSmartModeData(lowTemperature,ircode);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 设置高温智能模式
	 * @param lowTemperature
	 * @param ircode
	 */
	public void setSmartModeHigthTemperatureCmd(int higthTemperature,String ircode){
		
		RequestHead header = new RequestHead(29+ircode.getBytes().length, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.SET_SMART_MODE_HIGH_TEMPERATURE_CMD.getVal());

		RequestSmartModeData data = new RequestSmartModeData(higthTemperature,ircode);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 查询智能模式
	 */
	public void querySmartMode(){
		
		RequestHead header = new RequestHead(28, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.QUERY_THE_SMART_MODE.getVal());

		RequestMessage message = new RequestMessage(header, null);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 查询智能模式
	 */
	public void querySmartMode_callBack(byte[] irid,int ambientTemperature,int lowTemperature,int higthTemperature,int state){}
	
	/**
	 * 设置智能模式状态
	 * @param state
	 */
	public void updateSmartState(int state){
		
		RequestHead header = new RequestHead(29, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.UPDATE_SMART_STATE.getVal());

		RequestSmartModeData data = new RequestSmartModeData();
		data.setState(state);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 获取遥控器固件版本
	 */
	public void requestRemoteControlVersion(){
		
		RequestHead header = new RequestHead(28, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.REQUEST_REMOTECONTROL_VERSION.getVal());

		RequestMessage message = new RequestMessage(header, null);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 获取遥控器固件版本回调
	 */
	public void requestRemoteControlVersion_callBack(String version){}
	
	/**
	 * 获取遥控器固件长度
	 */
	public void requestRemoteControlFirmwareLength(String version){
		
		RequestHead header = new RequestHead(32, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.REQUEST_REMOTE_CONTROL_FIRMWARE_LENGTH.getVal());

		RequestToUpgradeData data = new RequestToUpgradeData();
		data.setNewVersion(StringNamesUtils.versionStringToByte(version));
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 获取遥控器固件长度回调
	 */
	public void requestRemoteControlFirmwareLength_callBack(String version,int totalPackets){}
	
	/**
	 * 要求遥控器升级固件
	 */
	public void requestToUpgrade(int totalPackets,String newVersion,int cs8){
		
		RequestHead header = new RequestHead(34, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.REQUEST_TO_UPGRADE.getVal());

		RequestToUpgradeData data = new RequestToUpgradeData();
		data.setNewVersion(StringNamesUtils.versionStringToByte(newVersion));
		data.setTotalPackets(totalPackets);
		data.setFileTotalCs8(cs8);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 升级成功
	 */
	public void upgradeOk_callBack(int totalPacket,int currentPacket){}
	
	/**
	 * 自定义遥控器按键
	 */
	public void customRemoteControlKeys(byte[] irid ,String keyName){
		
		RequestHead header = new RequestHead(40, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.CUSTOM_REMOTE_CONTROL_KEYS.getVal());

		RequestCustomRemoteControlData data = new RequestCustomRemoteControlData(irid,keyName);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 自定义遥控器按键回调
	 */
	public void customRemoteControlKeys_callBack(byte[] irid ,int state,String keyName,int key){}
	/**
	 * 根据设备查询自定义遥控器按键
	 */
	public void requestCustomRemoteControlByDevice(byte[] irid){
		
		RequestHead header = new RequestHead(32, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.REQUEST_CUSTOM_REMOTE_CONTROL_BY_DEVICEADDR_AND_PROFILEID.getVal());

		RequestCustomRemoteControlData data = new RequestCustomRemoteControlData(irid);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 根据设备查询自定义遥控器按键回调
	 */
	public void requestCustomRemoteControlByDevice_callBack(byte[] irid,Map<Integer,String> keys){}
	/**
	 * 执行自定义遥控器按键操作
	 */
	public void  sendCustomRemoteControlKey(byte[] irid,int key){
		RequestHead header = new RequestHead(34, Global.irsn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.SEND_CUSTOM_REMOTE_CONTROL_KEY.getVal());

		RequestCustomRemoteControlData data = new RequestCustomRemoteControlData(irid,key);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
		
	}
	
	/**
	 * 获取客户端是否在线状态
	 */
	public void  getTheOnlineStatusOfThClient(String sn){
		
		RequestHead header = new RequestHead(34, sn,CmdTypeEnum.IR.getVal(), IrControlTypeEnum.GET_ONLINESTATUS_OF_CLIENT.getVal());

		RequestGetTheOnlineStatusOfThClientData data = new RequestGetTheOnlineStatusOfThClientData(sn);
		
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 获取客户端是否在线状态回调
	 * @param status: 0离线  1在线
	 */
	public void  getTheOnlineStatusOfThClient_callback(int status){}

	/************************* 以下是回调方法实现 ************************************/

	/**
	 * 回调方法测试
	 */
	public void callback(String result) {
		System.out.println("result:" + result);

	}

	/**
	 * 获取所有设备回调
	 */
	public void newDevice_CallBack(List<DeviceInfo> dinfos) {

	}

	/**
	 * 本地查找网关返回
	 * 
	 * @param ip
	 */
	public void newGate_CallBack(String ip, String sn) {
		
	}

	/**
	 * 获取设备的值回调方法
	 */
	public void getDeviceLevel_CallBack(int level, byte[] uId) {
	}

	/**
	 * 获取所有场景回调
	 * 
	 * @param dinfo
	 */
	public void newSence_CallBack(List<SenceInfo> sinfos) {

	}

	/**
	 * 获取网关信息返回
	 */
	public void getGateWayInfo_CallBack(GateWayInfo gainfo) {

	}

	public void getDeviceState_CallBack(int state, byte[] uId) {
		// TODO Auto-generated method stub

	}

	/**
	 * 获取设备色调与饱和度回调
	 * 
	 * @param hue
	 *            色调
	 * @param sat
	 *            饱和度
	 * @param uId
	 */
	public void getDeviceHueAndSat_CallBack(int hue, int sat, byte[] uId) {

	}

	/**
	 * 获取设备色温值回调
	 * 
	 * @param colorTemperature
	 * @param uId
	 */
	public void getColorTemperature_CallBack(int colorTemperature, byte[] uId) {

	}

	/**
	 * 获取场景成员回调
	 */
	public void getSenceMember_CallBack(int sceneId, String sceneName, List<DeviceTaskInfo> dts) {

	}

	/**
	 * 允许入网回调
	 */
	public void newDevice_Callback(DeviceInfo info) {

	}

	/**
	 * 获取所有任务回调
	 */
	public void newTask_CallBack(List<TaskInfo> tasks) {

	}

	/**
	 * 当调用getTaskInfo()时返回
	 * 
	 * @param taskInfo
	 * 
	 * @param action1
	 *            first task's action
	 * @param action2
	 *            second task's action
	 */
	public void getSceneTimerTaskDetails_CallBack(TaskInfo taskInfo, TaskTimerAction timerAction, short sceneId) {
	}

	/**
	 * 当调用getTaskInfo()时返回
	 * 
	 * @param taskId
	 *            task's id
	 * @param taskName
	 *            task's name
	 * @param action1
	 *            first task's action
	 * @param action2
	 *            second task's action
	 */
	public void getDeviceTimerTaskDetails_CallBack(TaskInfo taskInfo, TaskTimerAction timerAction,
			DeviceTaskInfo DeviceTaskInfo) {
	}

	/**
	 * 当调用getTaskInfo()时返回，返回获取设备联动任务
	 * 
	 * @param TaskInfo
	 *            taskInfo
	 * @param deviceAction
	 *            设备联动时，设备动作信息
	 * @param senceName
	 *            联动执行场景
	 * @param isAlarm
	 *            是否报警标志
	 */
	public void getDeviceTaskDetails_CallBack(TaskInfo taskInfo, TaskDeviceAction deviceAction, short sceneId,
			byte isAlarm) {
	}

	/**
	 * 当调用addSence后返回
	 * 
	 * @param sceneId
	 *            场景id
	 * 
	 * @param senceName
	 *            场景名称
	 */
	public void addSence_callBack(byte sceneId, String senceName) {

	}

	/**
	 * 当调用ChangeDeviceName后返回
	 * 
	 * @param uid
	 *            uid
	 * 
	 * @param deviceName
	 *            设备名称
	 */
	public void ChangeDeviceName_callBack(byte[] uid, String deviceName) {
	}

	/**
	 * 传感器推送数据回调
	 * 
	 * @param uid
	 *            设备uid
	 * @param 参数
	 *            请参考recentValue对照表
	 */
	public void sensorReport_callBack(byte[] uid, byte[] recentValue, byte[] deviceId, short attrId) {

	}

	/**
	 * 温湿度传感器推送回调方法
	 * 
	 * @param temperature
	 *            温度
	 * @param humidity
	 *            湿度
	 * @param battery
	 *            电量 0正常，1低电量
	 */
	public void TemperatureAndHumidityReport_callBack(Double temperature, Double humidity, Integer battery, byte[] uid) {

	}

	/**
	 * 紧急按钮推送回调方法
	 * 
	 * @param state
	 *            状态
	 */
	public void EmergencyButtonReprot_callBack(byte state, byte[] uid) {
	}

	/**
	 * 燃气传感器推送回调方法
	 * 
	 * @param state
	 *            状态
	 */
	public void GasSensorReprot_callBack(byte state, byte[] uid) {
	}

	/**
	 * 烟雾传感器推送回调方法
	 * 
	 * @param state
	 *            状态
	 */
	public void FireSensorReprot_callBack(byte state, byte[] uid) {
	}

	/**
	 * 一氧化碳传感器推送回调方法
	 * 
	 * @param state
	 *            状态
	 */
	public void CoSensorReprot_callBack(byte state, byte[] uid) {
	}

	/**
	 * 多功能遥控器推送回调方法
	 * 
	 * @param state
	 *            状态
	 */
	public void KeyFobReprot_callBack(byte state, byte[] uid) {
	}

	/**
	 * 客户端离线后回调方法
	 */
	public void clientClose() {
	}

	/**
	 * 客户端建立链接回调方法
	 */
	public void clientActive() {
	}

	/**
	 * 获取指定场景定时任务 当调用getTimerTaskBySceneId方法后回调
	 */
	public void getTimerTaskBySceneId_CallBack(List<TaskInfo> tasks) {
	}

	/**
	 * 获取指定设备联动任务 当条用getSensorTaskByUid方法后回调
	 */
	public void getSensorTaskByUid_CallBack(List<TaskInfo> tasks) {
	}

	/**
	 * 获取设备定时任务回调方法
	 */
	public void getDeviceTimerTask_CallBack(List<TaskInfo> taskInfos) {

	}

	/**
	 * 心跳响应回调方法
	 */
	public void sendHeartbeat_CallBack() {
	}

	/**
	 * 验证管理面回调方法
	 */
	public void verificationManagerPwd_Callback(int state) {
	}

	/**
	 * 修改登录密码回调方法
	 * 
	 * @param state
	 *            : 0成功，1网关为链接云，2 用户名无效，3 原始密码错误，4新密码无效
	 */
	public void modifyLoginPwd_Callback(int state) {
	}

	/**
	 * 修改管理密码密码回调方法
	 * 
	 * @param state
	 *            : 0成功，1 用户名无效，2 原始密码错误，3新密码无效
	 */
	public void modifyManagerPwd_Callback(int state) {
	}

	/**
	 * 网关局域网登录验证回调方法
	 * 
	 * @param state
	 *            ：0成功，1用户名无效，2密码错误
	 */
	public void loginGaByLan_Callback(int state) {
	}

	/**
	 * 绑定网关结果回调方法
	 * 
	 * @param state：
	 *            0成功，1网关为链接云，2sn无效，3用户名无效，4密码无效
	 */
	public void UserBindToGa_callBack(int state) {
	}

	/**
	 * 添加用户到网关回调方法
	 * 
	 * @param state：
	 *            0成功,1 用户名无效，2密码无效
	 */
	public void addUserToGa_callBack(int state) {
	}

	/**
	 * 查询管理密码返回
	 * 
	 * @param username
	 * @param password
	 */
	public void queryManagerPwd_callBack(String username, String password) {
	}

	/**
	 * 添加场景定时任务回调
	 */
	public void addSceneTimerTask_callBack(String taskName, int taskId) {
	}

	/**
	 * 添加场景定时任务回调
	 */
	public void addDeviceTimerTask_callBack(String taskName, int taskId) {
	}
	
	/**
	 * 查询设备联动任务回调
	 */
	public void getDeviceLinkageTaskDetails_callBack(TaskInfo taskInfo){}
	
	/**
	 * 查询场景联动任务回调
	 */
	public void getSceneLinkageTaskDetails_callBack(TaskInfo taskInfo){}
	
	/**
	 * 获取指定场景联动任务列表回调
	 */
	public void getSceneLinkageTasks_callBack(List<TaskInfo> taskInfos){}
	/**
	 * 获取指定设备联动任务列表回调
	 */
	public void getDeviceLinkageTasks_callBack(List<TaskInfo> taskInfos){}
	
	/**
	 * 获取区域详细回调
	 */
	public void getAreaDetails_callBack(AreaInfo areaInfo){}
	
	/**
	 * 获取所有区域
	 */
	public void getAllArea_callBack(List<AreaInfo> areaInfos){}
	
	/**
	 * 添加区域回调
	 * @param state 0、响应成功 1、一般错误 2、区域名称冲突 3、区域数量达到上限
	 */
	public void addArea_callBack(int state)
	{}
	
	/**
	 * 强制退出登录回调
	 */
	public void signOut_callBack(){}
	
	/**
	 * 未找到网关
	 */
	public void  notFindGa_callback(){}
	
	/**
	 * 未找到遥控器
	 */
	public void notFindIr_callback(){}
	
	/** 
	 * 查询窗帘电机状态回调
	 * @param operable 是否可操作  0可以，1不行
	 * @param ismobile 是否可动    0不可移动，1可移动
	 */
	public void queryElectricMotorStatus_CallBack(int operable ,int ismobile,int direction){}
	
	/** 
	 * 查询窗帘电机配置信息回调
	 * @param handPull 是否启动手拉  0关闭，1启动
	 * @param linkage 是否启动联动    0关闭，1启动
	 */
	public void  queryElectricInfo_CallBack(int handpull,int linkage){}
	
	/**
	 * 查询窗帘位置回调
	 * @param value : 0全关  100全开 0-100当前位置
	 */
	public void queryCurtainPosition_CallBack(int value){}
	
	/**
	 * 查询门锁状态
	 * @param uid
	 * @param state: 1-open 0-close
	 */
	public void queryDoorlockSwitchState_CallBack(byte[] uid,int state){}
	
	
	/**
	 * 门锁操作状态推送
	 */
	public void operationEventNotification(DoorlockNotification doorlockNotification,int state){}
	
	/**
	 * 查询门锁权限回调
	 * @param uid
	 * @param permission 0x00- ordinary users，0x01-only manage
	 */
	public void queryPermissionDoorlock_CallBack(byte[] uid,int permission){}

	/**
	 * 获取红外遥控器所有设备回调
	 */
	public void quiryIrAllDevice_Callback(List<IrDeviceInfo> list){}
	/**
	 * 获取指定设备的信息回调
	 */
	public void getIrDeviceInfo_Callback(IrDeviceInfo irdeviceInfo){}
	
	/**
	 * 获取指定设备开关状态回调
	 */
	public void getIrDeviceSwitchState_Callback(byte[] irid,int state){}
	
	/**
	 * 获取红外灯的亮度回调
	 */
	public void getIrLigthBrightness_Callback(byte[] irid,short brightness){}
	
	/**
	 * 获取红外灯的色调饱和度回调
	 */
	public void getIrLigthHueAndSat_Callback(byte[] irid,byte r,byte g,byte b){}
	
	/**
	 * 获取红外灯的色温回调
	 */
	public void getColorTemperature_Callback(byte[] irid,short colorTemperature){}
	
	/************************************************ wifi模块接口 *****************************************/

	/**
	 * 获取wifi模块信息
	 */
	public void getWifiModuleInformation(String sn){
		
		RequestHead header = new RequestHead(28, sn, WifiControlTypeEnum.GET_MODEL_INFORMATION.getVal());

		RequestMessage message = new RequestMessage(header, null);

		NettySendMessageUtil.send(message);
	}

	/**
	 * 获取wifi模块信息回调
	 */
	public void getWifiModuleInformation_callBack(WifiModuleInformation wifiModuleInformation){}

	/**
	 * 设置wifi信息
	 */
	public void setWifiModuleWifiNetworkInformation(String sn,String ssid, String password){
		
		RequestHead header = new RequestHead(92, sn, WifiControlTypeEnum.SET_WIFIMODULE_WIFINETWORK_INFORMATION.getVal());

		RequestWifiNetworkInformationData data = new RequestWifiNetworkInformationData(ssid,password);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}

	/**
	 * 设置wifi信息回调
	 */
	public void setWifiModuleWifiNetworkInformation_callBack(String sn, int state){}

	/**
	 * 获取wifi信息
	 */
	public void requestWifiModuleWifiNetworkInformation(String sn){
		
		RequestHead header = new RequestHead(28, sn, WifiControlTypeEnum.REQUEST_WIFIMODULE_WIFINETWORK_INFORMATION.getVal());

		RequestMessage message = new RequestMessage(header, null);

		NettySendMessageUtil.send(message);
	}

	/**
	 * 获取wifi信息回调
	 */
	public void requestWifiModuleWifiNetworkInformation_callBack(String ssid, String password){}

	/**
	 * 升级或重置wifi模块 resetCommand: 0x01： upgrade wifi module 0x02： Reset wifi
	 * module
	 */
	public void upgradeOrResetWifiModule(String sn,int resetCommand, int newVersion){
		
		RequestHead header = new RequestHead(31, sn, WifiControlTypeEnum.UPGRADE_OR_RESET_WIFIMODULE.getVal());

		RequestUpgradeDate data = new RequestUpgradeDate((byte)resetCommand,newVersion);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}

	/**
	 * 切换模块的在线状态
	 */
	public void switchOnlineStateOfWifiModule(String sn,int state){
		
		RequestHead header = new RequestHead(29, sn, WifiControlTypeEnum.SWITCH_ONLINESTATE_OF_WIFIMODULE.getVal());

		RequestSetDeviceStateData data = new RequestSetDeviceStateData();
		data.setState(state);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}

	/**
	 * 切换模块的在线状态回调
	 */
	public void switchOnlineStateOfWifiModule_callBack(int state){}

	/**
	 * 获取模块上的所有设备
	 */
	public void getModuleAllDevice(String sn){
		
		RequestHead header = new RequestHead(28, sn, WifiControlTypeEnum.GET_MODULE_ALL_DEVICE.getVal());

		RequestMessage message = new RequestMessage(header, null);

		NettySendMessageUtil.send(message);
	}

	/**
	 * 获取模块上的所有设备回调
	 */
	public void getModuleAllDevice_callBack(List<WifiModelDeviceInfo> devices){}

	/**
	 * 获取模块的版本
	 */
	public void requestWifiModuleVersion(String sn,int command){
		
		RequestHead header = new RequestHead(29, sn,4, WifiControlTypeEnum.REQUEST_WIFIMODULE_VERSION.getVal());

		RequestUpgradeDate data = new RequestUpgradeDate((byte)command);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}

	/**
	 * 获取模块的版本回调
	 */
	public void requestWifiModuleVersion_callBack(String version){}

	/**
	 * 报告升级状态
	 */
	public void reportUpgradeStatus(int responseCode, String version){}

	/**
	 * 将模块设置成网络模式
	 */
	public void setWifiModuleIntoTheNetworkMode(String sn){
		
		RequestHead header = new RequestHead(28, sn, WifiControlTypeEnum.SET_WIFIMODULE_INTOTHE_NETWORKMODE.getVal());

		RequestMessage message = new RequestMessage(header, null);

		NettySendMessageUtil.send(message);
	}

	/**
	 * 将模块设置成网络模式
	 */
	public void setWifiModuleIntoTheNetworkMode_callBack(int panID, byte[] expan, int channel, int version){}

	/**
	 * 设置wifi设备开关状态
	 */
	public void setWifiDeviceSwitchState(String sn,byte[] uid, int switchState){
		
		RequestHead header = new RequestHead(33, sn, WifiControlTypeEnum.SET_WIFI_DEVICE_SWITCHSTATE.getVal());

		RequestSetDeviceStateData data = new RequestSetDeviceStateData(uid,switchState);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 设置wifi设备开关状态回调
	 */
	public void setWifiDeviceSwitchState_callBack(byte[] uid, int switchState){}
	
	/**
	 * 获取设备开关状态
	 */
	public void requireWifiDeviceSwitchState(String sn,byte[] uid){
		
		RequestHead header = new RequestHead(32, sn, WifiControlTypeEnum.REQUIRE_WIFIDEVICE_SWITCHSTATE.getVal());

		RequestSetDeviceStateData data = new RequestSetDeviceStateData(uid,0);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 获取设备开关状态回调
	 */
	public void requireWifiDeviceSwitchState_callBack(byte[] uid, int switchState){}
	
	/**
	 * 设置灯的亮度
	 */
	public void setWifiLightBrightness(String sn,byte[] uid,int brightCommand,int cutTime){
		
		RequestHead header = new RequestHead(35, sn, WifiControlTypeEnum.SET_WIFILIGHT_BRIGHTNESS.getVal());

		RequestSetDeviceLevelData data = new RequestSetDeviceLevelData(uid,brightCommand,cutTime);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
		
	}
	/**
	 * 设置灯的亮度
	 */
	public void setWifiLightBrightness_callBack(byte[] uid,int brightValue){}
	
	/**
	 * 获取灯的亮度
	 */
	public void requireWifiLightBrightness(String sn,byte[] uid){
		
		RequestHead header = new RequestHead(32, sn, WifiControlTypeEnum.REQUIRE_WIFILIGHT_BRIGHTNESS.getVal());

		RequestSetDeviceLevelData data = new RequestSetDeviceLevelData(uid,0,0);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
		
	}
	/**
	 * 获取灯的亮度回调
	 */
	public void requireWifiLightBrightness_callBack(byte[] uid,int brightValue){}
	
	/**
	 * 设置灯的色调与饱和度
	 */
	public void setWifiLighthueOrSaturation(String sn,byte[] uid,int hue,int sat,int cutTime){
		
		RequestHead header = new RequestHead(36, sn, WifiControlTypeEnum.SET_WIFILIGHTHUE_OR_SATURATION.getVal());

		RequestSetDeviceColorData data = new RequestSetDeviceColorData(uid,hue,sat,cutTime);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 设置灯的色调与饱和度回调
	 */
	public void setWifiLighthueOrSaturation_callBack(byte[] uid,int hue,int sat){}
	
	/**
	 * 查询灯的色调饱和度
	 */
	public void requireWifiLighthueOrSaturation(String sn,byte[] uid){
		
		RequestHead header = new RequestHead(32, sn, WifiControlTypeEnum.REQUIRE_WIFILIGHTHUE_OR_SATURATION.getVal());

		RequestSetDeviceColorData data = new RequestSetDeviceColorData(uid,0,0,0);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 查询灯的色调饱和度回调
	 */
	public void requireWifiLighthueOrSaturation_callBack(byte[] uid,int hue,int sat){}
	
	/**
	 * 设置灯的色温
	 */
	public void setWifiLightColorTemperature(String sn,byte[] uid,int colorTemperature,int cutTime){
		
		RequestHead header = new RequestHead(36, sn, WifiControlTypeEnum.SET_WIFILIGHT_COLORTEMPERATURE.getVal());

		RequestSetColorTemperatureData data = new RequestSetColorTemperatureData(uid,colorTemperature,cutTime);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 设置灯的色温回调
	 */
	public void setWifiLightColorTemperature_callBack(byte[] uid,int colorTemperature){}
	
	/**
	 * 获取灯的色温
	 */
	public void requireWifiLightColorTemperature(String sn,byte[] uid){
		
		RequestHead header = new RequestHead(32, sn, WifiControlTypeEnum.REQUIRE_WIFILIGHT_COLORTEMPERATURE.getVal());

		RequestSetColorTemperatureData data = new RequestSetColorTemperatureData(uid,0,0);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 获取灯的色温回调
	 */
	public void requireWifiLightColorTemperature_callBack(byte[] uid,int colorTemperature){}
	
	/**
	 * 设置电机方向
	 */
	public void  setWifiElectricMotorDirection(String sn,byte[] uid ,int direction){
		
		RequestHead header = new RequestHead(33, sn,4, WifiControlTypeEnum.SET_WIFIELECTRICMOTOR_DIRECTION.getVal());

		RequestSetDlectricMotorDirectionData data = new RequestSetDlectricMotorDirectionData((byte)0x02,uid,(byte)direction);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 设置电机方向回调
	 */
	public void  setWifiElectricMotorDirection_callBack(byte[] uid ,int direction){}
	
	/**
	 * 配置电动马达
	 */
	public void configurationWifiElectricMotor(String sn,byte[] uid,int handPull,int linkage){
		
		RequestHead header = new RequestHead(33, sn,4, WifiControlTypeEnum.CONFIGURATION_WIFIELECTRIC_MOTOR.getVal());

		RequestConfigurationElectricMotorData data = new RequestConfigurationElectricMotorData((byte)0x02,uid,handPull,linkage);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
		
	}
	/**
	 * 配置电动马达回调
	 */
	public void configurationWifiElectricMotor_callBack(byte[] uid,byte value){}
	
	/**
	 * 查询电机配置信息
	 */
	public void queryWifiElectricMotorConfigurationInfo(String sn,byte[] uid){
		
		RequestHead header = new RequestHead(32, sn, WifiControlTypeEnum.QUERY_WIFIELECTRIC_MOTOR_CONFIGURATIONINFO.getVal());

		RequestConfigurationElectricMotorData data = new RequestConfigurationElectricMotorData((byte)0x02,uid,0,0);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 查询电机配置信息回调
	 */
	public void queryWifiElectricMotorConfigurationInfo_callBack(byte[] uid,byte value){}
	
	/**
	 * 查询电机状态
	 */
	public void queryWifiElectricMotorStatus(String sn,byte[] uid){
		
		RequestHead header = new RequestHead(32, sn, WifiControlTypeEnum.QUERY_WIFIELECTRIC_MOTOR_STATUS.getVal());

		RequestConfigurationElectricMotorData data = new RequestConfigurationElectricMotorData((byte)0x02,uid,0,0);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 查询电机状态回调
	 */
	public void queryWifiElectricMotorStatus_callBack(byte[] uid,byte value){}
	
	/**
	 *开启或关闭窗帘 
	 */
	public void openOrCloseWifiCurtain(String sn,byte[] uid,int value){
		
		RequestHead header = new RequestHead(33, sn, 4,WifiControlTypeEnum.OPEN_OR_CLOSE_WIFICURTAIN.getVal());

		RequestOpenOrCloseCurtainData data = new RequestOpenOrCloseCurtainData((byte)0x02,uid,(byte)value);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 *开启或关闭窗帘 回调
	 */
	public void openOrCloseWifiCurtain_callBack(byte[] uid,int value){}
	
	/**
	 * 停止操作窗帘
	 */
	public void stopOperatingWifiCurtain(String sn,byte[] uid){
		
		RequestHead header = new RequestHead(32, sn, 4,WifiControlTypeEnum.STOP_OPERATING_WIFICURTAIN.getVal());

		RequestOpenOrCloseCurtainData data = new RequestOpenOrCloseCurtainData((byte)0x02,uid,(byte)0);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 停止操作窗帘回调
	 */
	public void stopOperatingWifiCurtain_callBack(byte[] uid){}
	
	/**
	 * 查询窗帘位置
	 */
	public void queryWifiCurtainPosition(String sn,byte[] uid){
		
		RequestHead header = new RequestHead(32, sn, 4,WifiControlTypeEnum.QUERY_WIFICURTAIN_POSITION.getVal());

		RequestOpenOrCloseCurtainData data = new RequestOpenOrCloseCurtainData((byte)0x02,uid,(byte)0);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
		
	}
	/**
	 * 查询窗帘位置回调
	 */
	public void queryWifiCurtainPosition_callBack(byte[] uid,int value){}
	
	/**
	 * 窗帘行程控制（卷帘）
	 */
	public void wifiCurtainStrokeControl(String sn,byte[] uid,int value){
		
		RequestHead header = new RequestHead(33, sn, WifiControlTypeEnum.CURTAIN_STROKE_CONTROL.getVal());

		RequestRollingBlindData data = new RequestRollingBlindData(uid,0x02, value);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 窗帘行程控制回调
	 */
	public void wifiCurtainStrokeControl_callBack(byte[] uid){}
	
	/**
	 * 删除行程
	 */
	public void  deleteWifiStroke(String sn,byte[] uid){
		
		RequestHead header = new RequestHead(32, sn, WifiControlTypeEnum.DELETE_WIFI_STROKE.getVal());

		RequestRollingBlindData data = new RequestRollingBlindData(uid,0x02, 0);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 删除行程回调
	 */
	public void  deleteWifiStroke_callBack(byte[] uid){}
	
	/**
	 * 添加定时任务
	 */
	public void addWifiTask(String sn,TaskInfo taskInfo){
		
		RequestHead header = new RequestHead(71, sn, 4, WifiControlTypeEnum.ADD_TASK.getVal());

		RequestAddWifiTaskData data = new RequestAddWifiTaskData();
		data.setTaskType(0);
		data.setTaskName(taskInfo.getTaskName());
		data.setUid(taskInfo.getDeviceTaskInfo().getUid());
		data.setMinute(taskInfo.getTaskTimerAction().getM());
		data.setHour(taskInfo.getTaskTimerAction().getH());
		data.setSecond(taskInfo.getTaskTimerAction().getS());
		data.setWeek(taskInfo.getTaskTimerAction().getWorkMode());
		data.setCmd(taskInfo.getDeviceTaskInfo().getCommand());
		data.setData(taskInfo.getDeviceTaskInfo().getData());
		data.setTstate(taskInfo.getTaskState());
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
		
	}
	/**
	 * 添加wifi定时任务回调
	 * @param taskId
	 */
	public void addWifiTask_callBack(int taskId){}
	
	/**
	 * 删除任务
	 */
	public void deleteWifiTask(String sn,int taskId){
		
		RequestHead header = new RequestHead(29, sn, 4, WifiControlTypeEnum.DELETE_TASK.getVal());

		RequestAddWifiTaskData data = new RequestAddWifiTaskData((byte)taskId);
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 删除任务回调
	 */
	public void deleteWifiTask_callBack(int state){}
	
	/**
	 * 修改定时任务
	 */
	public void updateWifiTask(String sn,TaskInfo taskInfo){
		RequestHead header = new RequestHead(72, sn, 4, WifiControlTypeEnum.UPDATE_TASK.getVal());

		RequestAddWifiTaskData data = new RequestAddWifiTaskData();
		data.setTaskType(0);
		data.setTaskName(taskInfo.getTaskName());
		data.setUid(taskInfo.getDeviceTaskInfo().getUid());
		data.setMinute(taskInfo.getTaskTimerAction().getM());
		data.setHour(taskInfo.getTaskTimerAction().getH());
		data.setSecond(taskInfo.getTaskTimerAction().getS());
		data.setWeek(taskInfo.getTaskTimerAction().getWorkMode());
		data.setCmd(taskInfo.getDeviceTaskInfo().getCommand());
		data.setData(taskInfo.getDeviceTaskInfo().getData());
		data.setTstate(taskInfo.getTaskState());
		data.setTaskId((byte)taskInfo.getTaskId());
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 修改定时任务回调
	 */
	public void updateWifiTask_callBack(int taskId){}
	
	/**
	 * 查询定时任务详细
	 */
	public void queryTheWifiTaskDetails(String sn,int taskId){
		
		RequestHead header = new RequestHead(30, sn, 4, WifiControlTypeEnum.QUERY_DETAILS_TASKS.getVal());

		RequestAddWifiTaskData data = new RequestAddWifiTaskData((byte)taskId);
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 查询定时任务详细回调
	 */
	public void queryTheWifiTaskDetails_callBack(TaskInfo taskInfo){}
	
	/**
	 * 查询定时任务详细
	 */
	public void queryAllWifiTask(String sn){
		
		RequestHead header = new RequestHead(28, sn, 4, WifiControlTypeEnum.QUERY_ALL_TASKS.getVal());

		RequestAddWifiTaskData data = new RequestAddWifiTaskData();
		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 查询定时任务详细回调
	 */
	public void queryAllWifiTask_callBack(List<TaskInfo> list){}
	
	/**************************情景面板*****************************************/
	/**
	 * 设备按键配置
	 */
	public void deviceKeyConfigureForDevice(byte[] keyUid,List<ScenePanelTask> listTask){
		
		RequestHead header = new RequestHead(32+listTask.size()*8, Global.sncode, ControlTypeEnum.DEVICE_KEY_CONFIGURE.getVal());

		ScenePanelData data = new ScenePanelData(keyUid,(byte)0x01,listTask);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 场景按键配置
	 */
	public void deviceKeyConfigureForScene(byte[] keyUid,List<ScenePanelTask> listTask){
		
		RequestHead header = new RequestHead(32+listTask.size()*8, Global.sncode, ControlTypeEnum.DEVICE_KEY_CONFIGURE.getVal());

		ScenePanelData data = new ScenePanelData(keyUid,(byte)0x02,listTask);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 按键配置回调
	 * @param keyUid
	 * @param state
	 */
	public void deviceKeyConfigure_callBack(byte[] keyUid,int state){}
	
	/**
	 * 删除按键配置
	 * @param keyUid
	 */
	public void deleteConfigureOfDeviceKey(byte[] keyUid){
		
		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.DELETE_CONFIGURE_OF_DEVICEKEY.getVal());

		ScenePanelData data = new ScenePanelData(keyUid);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 删除按键配置回调
	 */
	public void deleteConfigureOfDeviceKey_callBack(byte[] keyUid,int state){}
	
	/**
	 * 查询所有按键配置
	 */
	public void queryAllConfigureOfTheDevice(byte[] uid,byte[] ieeeAddr){
		
		RequestHead header = new RequestHead(37, Global.sncode, ControlTypeEnum.QUERY_ALL_CONFIGURE_OF_THE_DEVICE.getVal());

		ScenePanelData data = new ScenePanelData(uid,ieeeAddr);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}

	/**
	 * 查询所有按键配置回调
	 */
	public void queryAllConfigureOfTheDevice_callBack(List<ScenePanelInfo> list){}
	
	
	/**************************************温控器*****************************************/
	/**
	 * 设置温控器模式
	 * @param uid 
	 * @param modelValue 制冷：0x01 ,风扇：0x02,制热：0x03,自动：0x04
	 */
	public void  setTheThermostatMode(byte[] uid,int modelValue){
		
		RequestHead header = new RequestHead(31, Global.sncode, ControlTypeEnum.SET_THE_THERMOSTAT_MODE.getVal());

		RequestThermostatData data = new RequestThermostatData(uid,modelValue);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	
	/**
	 * 设置温控器模式回调
	 * @param uid 
	 * @param modelValue 制冷：0x01 ,风扇：0x02,制热：0x03,自动：0x04
	 */
	public void  setTheThermostatMode_callBack(byte[] uid,int modelValue){}
	
	/**
	 *  设置风速
	 * @param uid
	 * @param speed 低速：0x01,中速：0x02,高速：0x03,自动：0x04
	 */
	public void  setTheWindSpeed(byte[] uid,int speed){
		
		RequestHead header = new RequestHead(31, Global.sncode, ControlTypeEnum.SET_THE_WIND_SPEED.getVal());

		RequestThermostatData data = new RequestThermostatData();
		data.setUid(uid);
		data.setSpeed(speed);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 *  设置风速回调
	 * @param uid
	 * @param speed 低速：0x01,中速：0x02,高速：0x03,自动：0x04
	 */
	public void  setTheWindSpeed_callBack(byte[] uid,int speed){}
	
	/**
	 * 调节温度
	 * @param uid
	 * @param value 上调 1℃： 0x01,下调 1℃： 0x00
	 */
	public void adjusttTheTemperature(byte[] uid,int value){
		
		RequestHead header = new RequestHead(31, Global.sncode, ControlTypeEnum.ADJUSTT_THE_TEMPERATURE.getVal());

		RequestThermostatData data = new RequestThermostatData();
		data.setUid(uid);
		data.setTemperature(value);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 调节温度回调
	 * @param uid
	 * @param value 上调 1℃： 0x01,下调 1℃： 0x00
	 */
	public void adjusttTheTemperature_callBack(byte[] uid,int value){}
	
	/**
	 * 配置来电运行方式
	 * @param uid
	 * @param value 来电保持关机 0x00,来电恢复断电前的状态 0x01,来电强制开机 0x02
	 */
	public void setTheRunModeThatPowerResume(byte[] uid,int value){
		
		RequestHead header = new RequestHead(31, Global.sncode, ControlTypeEnum.SET_THE_RUN_MODE_THAT_POWERRESUME.getVal());

		RequestThermostatData data = new RequestThermostatData();
		data.setUid(uid);
		data.setSwitchState(value);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 配置来电运行方式回调
	 * @param uid
	 * @param value 来电保持关机 0x00,来电恢复断电前的状态 0x01,来电强制开机 0x02
	 */
	public void setTheRunModeThatPowerResume_callBack(byte[] uid,int value){}
	
	/**
	 * 查询温控器配置信息
	 */
	public void queryTheThermostatConfigureInfo(byte[] uid){
		
		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.QUERY_THE_THERMOSTAT_CONFIGUREINFO.getVal());

		RequestThermostatData data = new RequestThermostatData();
		data.setUid(uid);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 查询温控器配置信息回调
	 */
	public void queryTheThermostatConfigureInfo_callBack(ThermostatConfigureInfo thermostatConfigureInfo){}
	
	/**
	 * 查询温控器当前运行状态
	 * @param uid
	 */
	public void queryTheThermostatRunStatus(byte[] uid){
		
		RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.QUERY_THE_THERMOSTAT_RUN_STATUS.getVal());

		RequestThermostatData data = new RequestThermostatData();
		data.setUid(uid);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 查询温控器当前运行状态回调
	 * @param uid
	 */
	public void queryTheThermostatRunStatus_callBack(ThermostatRunStatusInfo thermostatRunStatusInfo){}
	
	/**
	 * 设置温控器开关状态
	 */
	public void setThermostatState(byte[] uid,int state){
		
		RequestHead header = new RequestHead(31, Global.sncode, ControlTypeEnum.SET_THE_THERMOSTAT_STATE.getVal());

		RequestThermostatData data = new RequestThermostatData();
		data.setUid(uid);
		data.setState(state);

		RequestMessage message = new RequestMessage(header, data);

		NettySendMessageUtil.send(message);
	}
	/**
	 * 设置温控器开关状态回调
	 */
	public void setThermostatState_callBack(byte[] uid,int state){}
	
	
	
	//*****************************杨格公寓锁相关************************************/
		/**
		 * 根据用户名查询设备的操作权限
		 */
		/*public void queryOperationPermissionByusername(String username,List<byte[]> uids){
			RequestHead header = new RequestHead(59+uids.size()*3, Global.sncode, ControlTypeEnum.QUERY_OPERATION_PERMISSION_BY_USERNAME.getVal());

			RequestGyDoorlockData data = new RequestGyDoorlockData();
			data.setUids(uids);
			data.setUsername(username);

			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		*//**
		 * 根据用户名查询设备的操作权限回调
		 *//*
		public void queryOperationPermissionByusername_callBack(String username,List<LockOperationPermissionInfo> infos){}*/
		
		/**
		 * 设置锁的开关状态
		 */
		public void setGwDoorlockSwitchState(byte[] uid,int switchState){
			
			RequestHead header = new RequestHead(31, Global.sncode, ControlTypeEnum.SET_DOORLOCK_SWITCHSTATE.getVal());

			RequestGyDoorlockData data = new RequestGyDoorlockData();
			data.setUid(uid);
			data.setSwitchState(switchState);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}	
		/**
		 * 设置锁的开关状态回调
		 */
		public void setDoorlockSwitchState_callBack(int state){}	
		
		/**
		 * 查询锁的开关状态
		 */
		public void queryGyDoorlockSwitchState(byte[] uid){
			
			RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.QUERY_GYDOORLOCK_SWITCHSTATE.getVal());

			RequestGyDoorlockData data = new RequestGyDoorlockData();
			data.setUid(uid);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 查询锁的开关状态回调
		 */
		public void queryGyDoorlockSwitchState_callBack(byte[] uid,int switchState){}
		
		/**
		 * 配置门锁是否长开
		 */
		public void configureDoorlockNormalOpen(byte[] uid,int state){
			RequestHead header = new RequestHead(31, Global.sncode, ControlTypeEnum.CONFIGURE_DOORLOCK_NORMALOPEN.getVal());

			RequestGyDoorlockData data = new RequestGyDoorlockData();
			data.setUid(uid);
			data.setSwitchState(state);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		} 
		/**
		 * 配置门锁是否长开回调(未实现)
		 */
		public void configureDoorlockNormalOpen_callBack(int state){}
		
		/**
		 * 查询门锁最近状态
		 */
		public void queryDoorlockRecentStatus(byte[] uid){
			RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.QUERY_DOORLOCK_RECENT_STATUS.getVal());

			RequestGyDoorlockData data = new RequestGyDoorlockData();
			data.setUid(uid);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 查询门锁最近状态回调
		 */
		public void queryDoorlockRecentStatus_callBack(DoorlockRecentStatusInfo info){}
		
		/**
		 * 添加门锁用户
		 */
		public void addGyDoorlockUser(byte[] uid,LockUserInfo lockUserInfo){
			
			RequestHead header = new RequestHead(64, Global.sncode, ControlTypeEnum.ADD_GYDOORLOCK_USER.getVal());

			RequestGyDoorlockData data = new RequestGyDoorlockData();
			data.setUid(uid);
			data.setLockUserInfo(lockUserInfo);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 添加门锁用户回调( 未实现)
		 */
		public void addGyDoorlockUser_callBack(int state){}
		
		/**
		 * 删除门锁用户
		 */
		public void deleteGyDoorlockUser(byte[] uid,LockUserInfo lockUserInfo){
			
			RequestHead header = new RequestHead(39, Global.sncode, ControlTypeEnum.DELETE_GYDOORLOCK_USER.getVal());

			RequestGyDoorlockData data = new RequestGyDoorlockData();
			data.setUid(uid);
			data.setLockUserInfo(lockUserInfo);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 删除门锁用户回调( 未实现)
		 */
		public void deleteGyDoorlockUser_callBack(int state){}
		
		/**
		 * 冻结门锁用户
		 */
		public void freezeDoorlockUser(byte[] uid,LockUserInfo lockUserInfo,int freeze){
			RequestHead header = new RequestHead(40, Global.sncode, ControlTypeEnum.FREEZE_DOORLOCK_USER.getVal());

			RequestGyDoorlockData data = new RequestGyDoorlockData();
			data.setUid(uid);
			data.setLockUserInfo(lockUserInfo);
			data.setFreeze(freeze);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 冻结门锁用户回调(未实现)
		 */
		public void freezeDoorlockUser_callBack(int state){}
		
		/**
		 * 更改门锁用户密码
		 */
		public void modifyDoorlockUserPasswd(byte[] uid,LockUserInfo lockUserInfo){
			
			RequestHead header = new RequestHead(63, Global.sncode, ControlTypeEnum.MODIFY_DOORLOCK_USER_PASSWD.getVal());

			RequestGyDoorlockData data = new RequestGyDoorlockData();
			data.setUid(uid);
			data.setLockUserInfo(lockUserInfo);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}	
		/**
		 * 更改门锁用户密码回调(未实现)
		 */
		public void modifyDoorlockUserPasswd_callBack(int state){}
		
		/**
		 * 查询所有用户信息
		 */
		public void queryAllLockUserInfo(byte[] uid){
			
			RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.QUERY_ALL_LOCKUSER_INFO.getVal());

			RequestGyDoorlockData data = new RequestGyDoorlockData();
			data.setUid(uid);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 查询所有用户信息回调
		 */
		public void queryAllLockUserInfo_callBack(List<LockUserInfo> infos){}
		
		/**
		 * 更改用户别名
		 */
		public void modifyDoorlockUserAlias(byte[] uid,LockUserInfo info,String newAlias){
			RequestHead header = new RequestHead(47, Global.sncode, ControlTypeEnum.MODIFY_DOORLOCK_USER_ALIAS.getVal());

			RequestGyDoorlockData data = new RequestGyDoorlockData();
			data.setUid(uid);
			data.setLockUserInfo(info);
			data.setUsername(newAlias);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 更改用户别名
		 */
		public void modifyDoorlockUserAlias_callBack(int state){}
		
		/**
		 * 查询开锁记录(未实现)
		 */
		public void queryUnlockRecord(byte[] uid,String username,String startTime,String endTime){}	
		/**
		 * 查询开锁记录回调(未实现)
		 */
		public void queryUnlockRecord_callBack(byte[] uid,String username,List<LockUnlockRecordInfo> infos){}	
		
		/**
		 * 删除开锁记录(未实现)
		 */
		public void deleteUnlockRecord(byte[] uid,String username,List<Integer> idList){}
		/**
		 * 删除开锁记录回调(未实现)
		 */
		public void deleteUnlockRecord_callBack(int state){}
		
		/**
		 * 查询异常记录(未实现)
		 */
		public void queryAbnormalRecord(byte[] uid,String username,String startTime,String endTime){}
		/**
		 * 查询异常记录回调(未实现)
		 */
		public void queryAbnormalRecord_callBack(byte[] uid,String username,List<LockAbnormalRecordInfo> infos){}
		
		/**
		 * 删除异常记录(未实现)
		 */
		public void deleteAbnormalRecord(byte[] uid,String username,List<Integer> idList){}
		/**
		 * 删除异常记录回调(未实现)
		 */
		public void deleteAbnormalRecord_callBack(int state){}
	
		/**
		 * 门锁操作通知
		 */
		public void doorlockEventPush(byte[] ieee,byte[] uid,int eventType,int event,byte[] time,int permission,String name){}
		
		
		/***********************************窗帘面板相关***************************************************/
		/**
		 * 窗帘面板绑定
		 * 
		 */
		public void bindDevice(byte[] uid,byte[] destUid){
			
			RequestHead header = new RequestHead(33, Global.sncode, ControlTypeEnum.BIND_DDEVICE.getVal());

			RequestBindDeviceData data = new RequestBindDeviceData();
			data.setSrcUid(uid);
			data.setDestUid(destUid);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 窗帘面板绑定回调
		 * 
		 */
		public void bindDevice_callBack(int state){}
		
		/**
		 * 删除窗帘面板绑定
		 */
		public void cancelBind(byte[] uid){
			
			RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.CANCEL_BIND.getVal());

			RequestBindDeviceData data = new RequestBindDeviceData();
			data.setSrcUid(uid);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 删除窗帘面板绑定回调
		 */
		public void cancelBind_callBack(int state){}
		
		/**
		 * 查询面板绑定信息
		 */
		public void queryAllBind(byte[] uid,byte[] ieeeAddr){
			
			RequestHead header = new RequestHead(37, Global.sncode, ControlTypeEnum.QUERY_ALL_BIND.getVal());

			RequestBindDeviceData data = new RequestBindDeviceData();
			data.setSrcUid(uid);
			data.setIeeeAddr(ieeeAddr);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 查询面板绑定信息回调
		 */
		public void queryAllBind_callBack(List<BindDeviceInfo> list){}
		
		/***********************报警器相关*****************************/
		/**
		 * 查询报警器记录
		 * @param uid
		 * @param startTime
		 * @param endTime
		 */
		public void queryAlarmRecords(byte[] uid,String startTime,String endTime){
			
			RequestHead header = new RequestHead(42, Global.sncode, ControlTypeEnum.QUERY_ALARM_RECORDS.getVal());

			RequestAlarmRecordsData data = new RequestAlarmRecordsData();
			data.setUid(uid);
			data.setStartTime(startTime);
			data.setEndTime(endTime);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 查询报警器记录
		 * @param uid
		 * @param startTime
		 * @param endTime
		 */
		public void queryAlarmRecords_callBack(List<AlarmRecordsInfo> list){}
		
		/**
		 * 删除记录
		 */
		public void deleteAlarmRecords(byte[] uid,List<Integer> recordIds){
			RequestHead header = new RequestHead(31+recordIds.size()*2, Global.sncode, ControlTypeEnum.DELETE_ALARM_RECORDS.getVal());

			RequestAlarmRecordsData data = new RequestAlarmRecordsData();
			data.setUid(uid);
			data.setRecordIds(recordIds);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		
		/**
		 *设备紧急报警推送
		 *alarmType: 0x01 异常报警, 0x02 低电报警,0x03 钥匙非法开锁报警
		 */
		public void deviceEmergencyAlarmPush(byte[] uid,int alarmType){}
		
		
		
		
		
		/******************************k1锁相关接口********************************/
		/**
		 * k1查看设备状态
		 * stypes:状态类型数组，状态类型如下
		 * 状态类型： 1-在线状态	2-开关状态  3-电量状态  4-室内反锁状态  5-上提反锁状态  6-网关互动开关状态
		 * */
		public void getK1DeviceStates(byte[] uid,List<Integer> stypes){
			RequestHead header = new RequestHead(31+stypes.size(), Global.sncode, ControlTypeEnum.GET_K1_DEVICE_STATES.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid,stypes);
			
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
			
		}
		
		/**
		 * k1查看设备状态回调
		 * @param uid
		 */
		public void getK1DeviceStates_callBack(byte[] uid,Map<Integer, String> stateMap){}
		
		/**
		 * k1锁上报设备状态
		 * stype 状态类型： 1-在线状态	2-开关状态  3-电量状态  4-室内反锁状态  5-上提反锁状态  6-网关互动开关状态 7-锁按键1开关状态  8-锁按键2开关状态
		 */
		public void reportk1State(byte[] uid,Integer stype,String stateValue){}
		
		/**
		 * k1异常报警信息推送
		 * code:报警码 1-密码错误 2-指纹错误 3-暴力破坏 4-常开报警 5-钥匙非法开锁报警 6-低电报警
		 */
		public void reportK1Abnormal(byte[] uid,Integer code,String memberName){}
		
		/**
		 * 查看当前 APP  开锁钥匙 ID
		 */
		public void getK1KeysId(byte[] uid,String username){
			
			RequestHead header = new RequestHead(62, Global.sncode, ControlTypeEnum.GET_K1_KEYS_ID.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid,username);
			
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		
		/**
		 * 查看当前 APP  开锁钥匙 ID回调
		 */
		public void getK1KeysId_callBack(byte[] uid,String username,Integer keysId){}
		
		/**
		 * 查询成员列表
		 */
		public void getK1Member(byte[] uid){
			
			RequestHead header = new RequestHead(30, Global.sncode, ControlTypeEnum.GET_K1_MEMBER.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid);
			
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 查询成员列表回调
		 */
		public void getK1Member_callBack(List<K1MemberInfo> members){}
		
		/**
		 * 添加成员
		 */
		public void addK1Member(byte[] uid,K1MemberInfo member){
			
			RequestHead header = new RequestHead(94, Global.sncode, ControlTypeEnum.ADD_K1_MEMBER.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid);
			data.setMemberInfo(member);
			
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 添加成员回调
		 */
		public void addK1Member_callBack(Integer state,Integer memberId,String memberName){}
		
		/**
		 * 删除成员
		 */
		public void deleteK1Member(byte[] uid,Integer memberId){
			
			RequestHead header = new RequestHead(32, Global.sncode, ControlTypeEnum.DELETE_K1_MEMBER.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid);
			data.setMemberId(memberId);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		} 
		/**
		 * 删除成员回调
		 */
		public void deleteK1Member_callBack(Integer state){} 
		
		/**
		 * 修成成员名称
		 */
		public void updateK1MemberName(byte[] uid,Integer memberId,String memberName){
			
			RequestHead header = new RequestHead(64, Global.sncode, ControlTypeEnum.UPDATE_K1_MEMBER_NAME.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid);
			data.setMemberId(memberId);
			data.setMemberName(memberName);
			
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 修成成员名称回调
		 */
		public void updateK1MemberName_callBack(Integer state){}
		
		/**
		 * 查询成员详细信息
		 */
		public void getK1MemberInfo(byte[] uid,Integer memberId){
			
			RequestHead header = new RequestHead(32, Global.sncode, ControlTypeEnum.GET_K1_MEMBER_INFO.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid);
			data.setMemberId(memberId);
			
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 查询成员详细信息
		 */
		public void getK1MemberInfo_callBack(K1MemberDetailsInfo info){}
		
		/**
		 * 添加钥匙
		 * 注：本接口仅适用于添加指纹、密码、防挟持密码
				keyType钥匙类型： 0-密码 1-网络 2-指纹 3-卡 4-防挟持密码 5-防挟持指纹
				keyName钥匙名称：仅用于指纹类型
				password密码：仅用于密码类型和防挟持密码类型
		 */
		public void addK1Key(byte[] uid,Integer memberId,Integer keyType,String password){
			
			int length = 77-32;
			
			RequestHead header = new RequestHead(length, Global.sncode, ControlTypeEnum.ADD_K1_KEY.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid);
			data.setMemberId(memberId);
			data.setKeyType(keyType);
			data.setPassword(password);
			
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
			
		}
		/**
		 * 添加钥匙回调
		 */
		public void addK1Key_callBack(Integer state){}
		
		/**
		 * 指纹钥匙录入上报
		 * state状态： 0-成功 1-失败
		   number录入次数：1-第一次 2-第二次 ... 0xFF-录入完成
		 */
		public void reportFingerprintState(byte[] uid,Integer memberId,Integer keyType,Integer keyId,Integer state,Integer number){}
		
		/**
		 * 删除钥匙
		 * 本接口仅适用于删除指纹、密码、防挟持密码、防挟持指纹
			keyType钥匙类型： 0-密码 1-网络 2-指纹 3-卡 4-防挟持密码 5-防挟持指纹
		 */
		public void deteteK1Key(byte[] uid,Integer memberId,Integer keyType,Integer keyId){
			
			RequestHead header = new RequestHead(35, Global.sncode, ControlTypeEnum.DETETE_K1_KEY.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid);
			data.setMemberId(memberId);
			data.setKeyType(keyType);
			data.setKeyId(keyId);
			
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
			
		}
		/**
		 * 删除钥匙回调
		 */
		public void deteteK1Key_callBack(Integer state){}
		
		/**
		 * 修改密码
		 * 本接口仅适用于修改密码和防挟持密码
			keyType钥匙类型： 0-密码 1-网络 2-指纹 3-卡 4-防挟持密码 5-防挟持指纹
		 */
		public void updateK1Password(byte[] uid,Integer memberId,Integer keyType,Integer keyId,String password){
			
			RequestHead header = new RequestHead(47, Global.sncode, ControlTypeEnum.UPDATE_K1_PASSWORD.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid);
			data.setMemberId(memberId);
			data.setKeyType(keyType);
			data.setKeyId(keyId);
			data.setPassword(password);
			
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 修改密码回调
		 */
		public void updateK1Password_callBack(Integer state){}
		
		/**
		 * 修改指纹名称
		 */
		public void updateK1FingerprintName(byte[] uid,Integer memberId,Integer keyType,Integer keyId,String kname){
			RequestHead header = new RequestHead(67, Global.sncode, ControlTypeEnum.UPDATE_K1_FINGERPRINT_NAME.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid);
			data.setMemberId(memberId);
			data.setKeyType(keyType);
			data.setKeyId(keyId);
			data.setKeyName(kname);
			
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 修改指纹名称
		 * 本接口仅适用于修改指纹名称
		 */
		public void updateK1FingerprintName_callBack(Integer state){}
		
		/**
		 * 查询记录列表
		 * type事件类型： 0-所有记录 1-开锁记录 2-异常记录
			page页码：表示开始查询的页数，默认从 1 开始。
			pageSize最大数量：每一页记录的最大条数，默认为 16 条，最大不超过 32 条
			startTime起始时间：按时间查询的起始值
			endTime终止时间：按时间查询的终止值
		 */
		public void getK1RecordList(byte[] uid,Integer type,Integer page,Integer pageSize,String startTime,String endTime){
			
			RequestHead header = new RequestHead(45, Global.sncode, ControlTypeEnum.GET_K1_RECORD_LIST.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid);
			data.setEndTime(endTime);
			data.setStartTime(startTime);
			data.setType(type);
			data.setPage(page);
			data.setPageSize(pageSize);
			
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 查询记录列表回调
		 */
		public void getK1RecordList_callBack(byte[] uid,Integer page,List<K1RecordInfo> infos){}
		
		/**
		 * 删除记录
		 */
		public void deleteK1Record(byte[] uid,int type,List<Integer> ids){
			RequestHead header = new RequestHead(32+ids.size()*2, Global.sncode, ControlTypeEnum.DELETE_K1_RECORD.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid);
			data.setStypes(ids);
			data.setKeyType(type);
			
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 删除记录回调
		 */
		public void deleteK1Record_callBack(Integer state){}
		
		/**
		 * 解除当前警报
		 */
		public void relieveAlarm(byte[] uid,Integer type,Integer recordId){
			
			RequestHead header = new RequestHead(33, Global.sncode, ControlTypeEnum.RELIEVE_ALARM.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid);
			data.setKeyType(type);
			data.setRecordId(recordId);
			
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 解除当前警报回调
		 */
		public void relieveAlarm_callBack(Integer state){}
		
		/**
		 * 添加临时密码
		 */
		public void addK1TemPassword(byte[] uid,String name,String number,String password){
			
			RequestHead header = new RequestHead(90, Global.sncode, ControlTypeEnum.ADD_K1_TEM_PASSWORD.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid);
			data.setMemberName(name);
			data.setNumber(number);
			data.setPassword(password);
			
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 添加临时密码回调
		 * id 记录 ID：每添加一个临时密码，新增一条记录
			pwdId密码 ID：对应锁端 ID
			state密码状态 0-正常 1-已使用 2-已取消 3-已过期
		 */
		public void addK1TemPassword_callBack(Integer states,byte[] uid,String name,String number,Integer id,Integer pwdId,Integer state,String addTime){}
		
		/**
		 * 删除临时密码
		 */
		public void deleteK1TemPassword(byte[] uid,Integer pwdId){
			
			RequestHead header = new RequestHead(32, Global.sncode, ControlTypeEnum.DELETE_K1_TEM_PASSWORD.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid);
			data.setKeyId(pwdId);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 删除临时密码回调
		 */
		public void deleteK1TemPassword_callBack(Integer state){}
		
		/**
		 * 查看临时密码列表
		 */
		public void getK1TemPassworkList(byte[] uid,Integer page,Integer pageSize){
			
			RequestHead header = new RequestHead(32, Global.sncode, ControlTypeEnum.GET_K1_TEM_PASSWORK_LIST.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid);
			data.setPage(page);
			data.setPageSize(pageSize);
			
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		
		/**
		 * 查看临时密码列表回调
		 */
		public void getK1TemPassworkList_callBack(byte[] uid,Integer page,List<K1TemPassworkInfo> infos){}
		
		/**
		 * 删除临时密码记录
		 */
		public void deleteTemPasswordRecords(byte[] uid,List<Integer> ids){
			RequestHead header = new RequestHead(31+ids.size()*2, Global.sncode, ControlTypeEnum.DELETE_TEM_PASSWORD_RECORDS.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid);
			data.setStypes(ids);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 删除临时密码记录回调
		 */
		public void deleteTemPasswordRecords_callBack(Integer state){}
		
		/**
		 * 防劫持上报
		 * 注：code报警码 	1-防挟持开锁报警 
			uname成员名称：被挟持成员名称
			phones 电话1~n：待接收短信通知的手机号码

		 */
		public void reportHijack(byte[] uid,Integer code,String uname,List<String> phones){}
		
		/**
		 * 读取门锁信息
		 * type类型  1-ZigBee Mac地址
			2-BLE Mac地址
			3-机芯码
			4-Zigbee 软件版本号 

		 */
		public void getK1Infos(byte[] uid,Integer type){
			RequestHead header = new RequestHead(31, Global.sncode, ControlTypeEnum.GET_K1_INFOS.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid);
			data.setType(type);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 读取门锁信息回调
		 */
		public void getK1Infos_callBack(byte[] uid,String value){}
		
		/**
		 * 门锁升级请求
		 */
		public void upgradeK1Request(byte[] uid,int version){
			
			RequestHead header = new RequestHead(34, Global.sncode, ControlTypeEnum.UPGRADE_K1_REQUEST.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid);
			data.setVersion(version);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 门锁升级请求回调
		 */
		public void upgradeK1Request_callBack(Integer state){}
		
		/**
		 * 门锁升级上报
		 */
		public void reportUpgradeK1(int version){}
		
		/**
		 * 验证原始密码
		 */
		public void vilidateK1Pwd(byte[] uid,int memberId,int keyType,int keyId,String pwd){
			
			RequestHead header = new RequestHead(47, Global.sncode, ControlTypeEnum.VILIDATE_K1_PWD.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid);
			data.setMemberId(memberId);
			data.setKeyId(keyId);
			data.setKeyType(keyType);
			data.setPassword(pwd);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 验证原始密码回调
		 */
		public void vilidateK1Pwd_callBack(int state){}
		
		/**
		 * 配置wifi信息
		 * subCmd：0x01-query wifi info
			0x02-set wifi info
		 */
		public void configurWIFIInfo(int subCmd,String ssid,String pwd){
			
			RequestHead header = new RequestHead(91, Global.sncode, ControlTypeEnum.CONFIGUR_WIFI_INFO.getVal());

			RequestConfigurWIFIInfoData data = new RequestConfigurWIFIInfoData(subCmd,ssid,pwd);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 配置wifi信息回调
		 */
		public void configurWIFIInfo_callBack(int state,int subCmd,String ssid,String pwd){}
		
		/**
		 * 搜索wifi
		 */
		public void searchWifi(){
			RequestHead header = new RequestHead(26, Global.sncode, ControlTypeEnum.SEARCH_WIFI.getVal());

			RequestMessage message = new RequestMessage(header, null);

			NettySendMessageUtil.send(message);
		}
		/**
		 * 搜索wifi回调
		 */
		public void searchWifi_callBack(List<String> list){}

		@Override
		public void reportUpgradeSpeed(byte[] uid, int Speed) {
			// TODO Auto-generated method stub
			
		}
		
		/**
		 * M1通知
		 */
		public void reportM1Notice(int ntype,String sn){}

		@Override
		public void set3DModule(byte[] uid, Integer type,Integer value) {
			
			RequestHead header = new RequestHead(33, Global.sncode, ControlTypeEnum.SET_3D_MODULE.getVal());

			Request3DModuleData data = new Request3DModuleData();
			data.setType(type);
			data.setUid(uid);
			data.setValue(value);
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}

		@Override
		public void set3DModule_callback(Integer state,Integer type,Integer value) {
			// TODO Auto-generated method stub
			
		}
		
		/**
		 * 带3D角度的记录查询
		 * type事件类型： 0-所有记录 1-开锁记录 2-异常记录
			page页码：表示开始查询的页数，默认从 1 开始。
			pageSize最大数量：每一页记录的最大条数，默认为 16 条，最大不超过 32 条
			startTime起始时间：按时间查询的起始值
			endTime终止时间：按时间查询的终止值
		 */
		public void getK1RecordListAnd3D(byte[] uid,Integer type,Integer page,Integer pageSize,String startTime,String endTime){
			
			RequestHead header = new RequestHead(45, Global.sncode, ControlTypeEnum.GET_K1_RECORD_LIST_3D.getVal());

			RequestK1DeviceData data = new RequestK1DeviceData(uid);
			data.setEndTime(endTime);
			data.setStartTime(startTime);
			data.setType(type);
			data.setPage(page);
			data.setPageSize(pageSize);
			
			RequestMessage message = new RequestMessage(header, data);

			NettySendMessageUtil.send(message);
		}

}
