
package com.b_noble.n_life.utils;

import java.io.UnsupportedEncodingException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;
import java.util.Arrays;

import javax.crypto.BadPaddingException;
import javax.crypto.Cipher;
import javax.crypto.IllegalBlockSizeException;
import javax.crypto.KeyGenerator;
import javax.crypto.NoSuchPaddingException;
import javax.crypto.SecretKey;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.push.tools.common.Profiler;
import com.push.tools.crypto.CryptoException;

/**
 * Created by ohun on 2015/12/25.
 *
 * @author ohun@live.cn
 */
public final class AESUtils {
	private static final Logger LOGGER = LoggerFactory.getLogger(AESUtils.class);
	public static final String KEY_ALGORITHM = "AES";
	public static final String KEY_ALGORITHM_PADDING = "AES/CBC/PKCS5Padding";

	public static SecretKey getSecretKey(byte[] seed) throws Exception {
		SecureRandom secureRandom = new SecureRandom(seed);
		KeyGenerator keyGenerator = KeyGenerator.getInstance(KEY_ALGORITHM);
		keyGenerator.init(secureRandom);
		return keyGenerator.generateKey();
	}

	public static byte[] encrypt(byte[] data, byte[] encryptKey, byte[] iv) {
		IvParameterSpec zeroIv = new IvParameterSpec(iv);
		SecretKeySpec key = new SecretKeySpec(encryptKey, KEY_ALGORITHM);
		return encrypt(data, zeroIv, key);
	}

	public static byte[] decrypt(byte[] data, byte[] decryptKey, byte[] iv) {
		IvParameterSpec zeroIv = new IvParameterSpec(iv);
		SecretKeySpec key = new SecretKeySpec(decryptKey, KEY_ALGORITHM);
		return decrypt(data, zeroIv, key);
	}

	public static byte[] encrypt(byte[] data, IvParameterSpec zeroIv, SecretKeySpec keySpec) {
		try {
			Profiler.enter("time cost on [aes encrypt]: data length=" + data.length);
			Cipher cipher = Cipher.getInstance(KEY_ALGORITHM_PADDING);
			cipher.init(Cipher.ENCRYPT_MODE, keySpec, zeroIv);
			return cipher.doFinal(data);
		} catch (Exception e) {
			LOGGER.error("AES encrypt ex, iv={}, key={}", Arrays.toString(zeroIv.getIV()),
					Arrays.toString(keySpec.getEncoded()), e);
			throw new CryptoException("AES encrypt ex", e);
		} finally {
			Profiler.release();
		}
	}

	public static byte[] decrypt(byte[] data, IvParameterSpec zeroIv, SecretKeySpec keySpec) {
		try {
			Profiler.enter("time cost on [aes decrypt]: data length=" + data.length);
			Cipher cipher = Cipher.getInstance(KEY_ALGORITHM_PADDING);
			cipher.init(Cipher.DECRYPT_MODE, keySpec, zeroIv);
			return cipher.doFinal(data);
		} catch (Exception e) {
			LOGGER.error("AES decrypt ex, iv={}, key={}", Arrays.toString(zeroIv.getIV()),
					Arrays.toString(keySpec.getEncoded()), e);
			throw new CryptoException("AES decrypt ex", e);
		} finally {
			Profiler.release();
		}
	}

	public static void main(String[] args) {

		String password = "1234567890123456";
		String content = "123456";
		
		try {             
            KeyGenerator kgen = KeyGenerator.getInstance("AES");  
            kgen.init(128, new SecureRandom(password.getBytes()));  
            SecretKey secretKey = kgen.generateKey();  
            byte[] enCodeFormat = secretKey.getEncoded();  
            SecretKeySpec key = new SecretKeySpec(enCodeFormat, "AES");  
            Cipher cipher = Cipher.getInstance("AES");// 创建密码器  
            byte[] byteContent = content.getBytes("utf-8");  
            cipher.init(Cipher.ENCRYPT_MODE, key);// 初始化  
            byte[] result = cipher.doFinal(byteContent);  
            
            System.out.println(new String(result,"utf-8"));
    } catch (NoSuchAlgorithmException e) {  
            e.printStackTrace();  
    } catch (NoSuchPaddingException e) {  
            e.printStackTrace();  
    } catch (InvalidKeyException e) {  
            e.printStackTrace();  
    } catch (UnsupportedEncodingException e) {  
            e.printStackTrace();  
    } catch (IllegalBlockSizeException e) {  
            e.printStackTrace();  
    } catch (BadPaddingException e) {  
            e.printStackTrace();  
    }  
	}
}
